# ContextExtract

A Python package for extracting contextual key-value pairs from URLs, PDFs, or text inputs using the Groq API.

## Example Output

When you run the package on a URL like https://en.wikipedia.org/wiki/Artificial_intelligence (Wikipedia's Artificial Intelligence page), you'll get structured JSON output similar to:

```json

{
  "content": {
    "title": "Artificial intelligence - Wikipedia",
    "canonical_url": "https://en.wikipedia.org/wiki/Artificial_intelligence",
    "links": [
      {
        "text": "Jump to content",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#bodyContent"
      },
      {
        "text": "Main page",
        "url": "https://en.wikipedia.org/wiki/Main_Page",
        "title": "Visit the main page [z]"
      },
      {
        "text": "Contents",
        "url": "https://en.wikipedia.org/wiki/Wikipedia:Contents",
        "title": "Guides to browsing Wikipedia"
      },
      {
        "text": "Current events",
        "url": "https://en.wikipedia.org/wiki/Portal:Current_events",
        "title": "Articles related to current events"
      },
      {
        "text": "Random article",
        "url": "https://en.wikipedia.org/wiki/Special:Random",
        "title": "Visit a randomly selected article [x]"
      },
      {
        "text": "About Wikipedia",
        "url": "https://en.wikipedia.org/wiki/Wikipedia:About",
        "title": "Learn about Wikipedia and how it works"
      },
      {
        "text": "Contact us",
        "url": "https://en.wikipedia.org/wiki/Wikipedia:Contact_us",
        "title": "How to contact Wikipedia"
      },
      {
        "text": "Help",
        "url": "https://en.wikipedia.org/wiki/Help:Contents",
        "title": "Guidance on how to use and edit Wikipedia"
      },
      {
        "text": "Learn to edit",
        "url": "https://en.wikipedia.org/wiki/Help:Introduction",
        "title": "Learn how to edit Wikipedia"
      },
      {
        "text": "Community portal",
        "url": "https://en.wikipedia.org/wiki/Wikipedia:Community_portal",
        "title": "The hub for editors"
      },
      {
        "text": "Recent changes",
        "url": "https://en.wikipedia.org/wiki/Special:RecentChanges",
        "title": "A list of recent changes to Wikipedia [r]"
      },
      {
        "text": "Upload file",
        "url": "https://en.wikipedia.org/wiki/Wikipedia:File_upload_wizard",
        "title": "Add images or other media for use on Wikipedia"
      },
      {
        "text": "Special pages",
        "url": "https://en.wikipedia.org/wiki/Special:SpecialPages"
      },
      {
        "text": "Search",
        "url": "https://en.wikipedia.org/wiki/Special:Search",
        "title": "Search Wikipedia [f]"
      },
      {
        "text": "Donate",
        "url": "https://donate.wikimedia.org/?wmf_source=donate&wmf_medium=sidebar&wmf_campaign=en.wikipedia.org&uselang=en"
      },
      {
        "text": "Create account",
        "url": "https://en.wikipedia.org/w/index.php?title=Special:CreateAccount&returnto=Artificial+intelligence",
        "title": "You are encouraged to create an account and log in; however, it is not mandatory"
      },
      {
        "text": "Log in",
        "url": "https://en.wikipedia.org/w/index.php?title=Special:UserLogin&returnto=Artificial+intelligence",
        "title": "You're encouraged to log in; however, it's not mandatory. [o]"
      },
      {
        "text": "Donate",
        "url": "https://donate.wikimedia.org/?wmf_source=donate&wmf_medium=sidebar&wmf_campaign=en.wikipedia.org&uselang=en"
      },
      {
        "text": "Create account",
        "url": "https://en.wikipedia.org/w/index.php?title=Special:CreateAccount&returnto=Artificial+intelligence",
        "title": "You are encouraged to create an account and log in; however, it is not mandatory"
      },
      {
        "text": "Log in",
        "url": "https://en.wikipedia.org/w/index.php?title=Special:UserLogin&returnto=Artificial+intelligence",
        "title": "You're encouraged to log in; however, it's not mandatory. [o]"
      },
      {
        "text": "learn more",
        "url": "https://en.wikipedia.org/wiki/Help:Introduction"
      },
      {
        "text": "Contributions",
        "url": "https://en.wikipedia.org/wiki/Special:MyContributions",
        "title": "A list of edits made from this IP address [y]"
      },
      {
        "text": "Talk",
        "url": "https://en.wikipedia.org/wiki/Special:MyTalk",
        "title": "Discussion about edits from this IP address [n]"
      },
      {
        "text": "(Top)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence"
      },
      {
        "text": "1\nGoals",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Goals"
      },
      {
        "text": "1.1\nReasoning and problem-solving",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Reasoning_and_problem-solving"
      },
      {
        "text": "1.2\nKnowledge representation",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Knowledge_representation"
      },
      {
        "text": "1.3\nPlanning and decision-making",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Planning_and_decision-making"
      },
      {
        "text": "1.4\nLearning",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Learning"
      },
      {
        "text": "1.5\nNatural language processing",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Natural_language_processing"
      },
      {
        "text": "1.6\nPerception",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Perception"
      },
      {
        "text": "1.7\nSocial intelligence",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Social_intelligence"
      },
      {
        "text": "1.8\nGeneral intelligence",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#General_intelligence"
      },
      {
        "text": "2\nTechniques",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Techniques"
      },
      {
        "text": "2.1\nSearch and optimization",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Search_and_optimization"
      },
      {
        "text": "2.1.1\nState space search",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#State_space_search"
      },
      {
        "text": "2.1.2\nLocal search",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Local_search"
      },
      {
        "text": "2.2\nLogic",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Logic"
      },
      {
        "text": "2.3\nProbabilistic methods for uncertain reasoning",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Probabilistic_methods_for_uncertain_reasoning"
      },
      {
        "text": "2.4\nClassifiers and statistical learning methods",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Classifiers_and_statistical_learning_methods"
      },
      {
        "text": "2.5\nArtificial neural networks",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Artificial_neural_networks"
      },
      {
        "text": "2.6\nDeep learning",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Deep_learning"
      },
      {
        "text": "2.7\nGPT",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#GPT"
      },
      {
        "text": "2.8\nHardware and software",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Hardware_and_software"
      },
      {
        "text": "3\nApplications",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Applications"
      },
      {
        "text": "3.1\nHealth and medicine",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Health_and_medicine"
      },
      {
        "text": "3.2\nGames",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Games"
      },
      {
        "text": "3.3\nMathematics",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Mathematics"
      },
      {
        "text": "3.4\nFinance",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Finance"
      },
      {
        "text": "3.5\nMilitary",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Military"
      },
      {
        "text": "3.6\nGenerative AI",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Generative_AI"
      },
      {
        "text": "3.7\nAgents",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Agents"
      },
      {
        "text": "3.8\nSexuality",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Sexuality"
      },
      {
        "text": "3.9\nOther industry-specific tasks",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Other_industry-specific_tasks"
      },
      {
        "text": "4\nEthics",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Ethics"
      },
      {
        "text": "4.1\nRisks and harm",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Risks_and_harm"
      },
      {
        "text": "4.1.1\nPrivacy and copyright",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Privacy_and_copyright"
      },
      {
        "text": "4.1.2\nDominance by tech giants",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Dominance_by_tech_giants"
      },
      {
        "text": "4.1.3\nPower needs and environmental impacts",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Power_needs_and_environmental_impacts"
      },
      {
        "text": "4.1.4\nMisinformation",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Misinformation"
      },
      {
        "text": "4.1.5\nAlgorithmic bias and fairness",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Algorithmic_bias_and_fairness"
      },
      {
        "text": "4.1.6\nLack of transparency",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Lack_of_transparency"
      },
      {
        "text": "4.1.7\nBad actors and weaponized AI",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Bad_actors_and_weaponized_AI"
      },
      {
        "text": "4.1.8\nTechnological unemployment",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Technological_unemployment"
      },
      {
        "text": "4.1.9\nExistential risk",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Existential_risk"
      },
      {
        "text": "4.2\nEthical machines and alignment",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Ethical_machines_and_alignment"
      },
      {
        "text": "4.3\nOpen source",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Open_source"
      },
      {
        "text": "4.4\nFrameworks",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Frameworks"
      },
      {
        "text": "4.5\nRegulation",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Regulation"
      },
      {
        "text": "5\nHistory",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#History"
      },
      {
        "text": "6\nPhilosophy",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Philosophy"
      },
      {
        "text": "6.1\nDefining artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Defining_artificial_intelligence"
      },
      {
        "text": "6.2\nEvaluating approaches to AI",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Evaluating_approaches_to_AI"
      },
      {
        "text": "6.2.1\nSymbolic AI and its limits",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Symbolic_AI_and_its_limits"
      },
      {
        "text": "6.2.2\nNeat vs. scruffy",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Neat_vs._scruffy"
      },
      {
        "text": "6.2.3\nSoft vs. hard computing",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Soft_vs._hard_computing"
      },
      {
        "text": "6.2.4\nNarrow vs. general AI",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Narrow_vs._general_AI"
      },
      {
        "text": "6.3\nMachine consciousness, sentience, and mind",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Machine_consciousness,_sentience,_and_mind"
      },
      {
        "text": "6.3.1\nConsciousness",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Consciousness"
      },
      {
        "text": "6.3.2\nComputationalism and functionalism",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Computationalism_and_functionalism"
      },
      {
        "text": "6.3.3\nAI welfare and rights",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#AI_welfare_and_rights"
      },
      {
        "text": "7\nFuture",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Future"
      },
      {
        "text": "7.1\nSuperintelligence and the singularity",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Superintelligence_and_the_singularity"
      },
      {
        "text": "7.2\nTranshumanism",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Transhumanism"
      },
      {
        "text": "7.3\nDecomputing",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Decomputing"
      },
      {
        "text": "8\nIn fiction",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#In_fiction"
      },
      {
        "text": "9\nSee also",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#See_also"
      },
      {
        "text": "10\nExplanatory notes",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Explanatory_notes"
      },
      {
        "text": "11\nReferences",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#References"
      },
      {
        "text": "11.1\nAI textbooks",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#AI_textbooks"
      },
      {
        "text": "11.2\nHistory of AI",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#History_of_AI"
      },
      {
        "text": "11.3\nOther sources",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Other_sources"
      },
      {
        "text": "12\nFurther reading",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Further_reading"
      },
      {
        "text": "13\nExternal links",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#External_links"
      },
      {
        "text": "Afrikaans",
        "url": "https://af.wikipedia.org/wiki/Kunsmatige_intelligensie",
        "title": "Kunsmatige intelligensie – Afrikaans"
      },
      {
        "text": "Alemannisch",
        "url": "https://als.wikipedia.org/wiki/K%C3%BCnstliche_Intelligenz",
        "title": "Künstliche Intelligenz – Alemannic"
      },
      {
        "text": "አማርኛ",
        "url": "https://am.wikipedia.org/wiki/%E1%88%B0%E1%8B%8D_%E1%88%A0%E1%88%AB%E1%88%BD_%E1%8B%A8%E1%88%9B%E1%88%B0%E1%89%A5_%E1%89%BD%E1%88%8E%E1%89%B3",
        "title": "ሰው ሠራሽ የማሰብ ችሎታ – Amharic"
      },
      {
        "text": "العربية",
        "url": "https://ar.wikipedia.org/wiki/%D8%B0%D9%83%D8%A7%D8%A1_%D8%A7%D8%B5%D8%B7%D9%86%D8%A7%D8%B9%D9%8A",
        "title": "ذكاء اصطناعي – Arabic"
      },
      {
        "text": "Aragonés",
        "url": "https://an.wikipedia.org/wiki/Intelichencia_artificial",
        "title": "Intelichencia artificial – Aragonese"
      },
      {
        "text": "Արեւմտահայերէն",
        "url": "https://hyw.wikipedia.org/wiki/%D4%B1%D6%80%D5%B0%D5%A5%D5%BD%D5%BF%D5%A1%D5%AF%D5%A1%D5%B6_%D4%B2%D5%A1%D5%B6%D5%A1%D5%AF%D5%A1%D5%B6%D5%B8%D6%82%D5%A9%D5%AB%D6%82%D5%B6",
        "title": "Արհեստական Բանականութիւն – Western Armenian"
      },
      {
        "text": "অসমীয়া",
        "url": "https://as.wikipedia.org/wiki/%E0%A6%95%E0%A7%83%E0%A6%A4%E0%A7%8D%E0%A7%B0%E0%A6%BF%E0%A6%AE_%E0%A6%AC%E0%A7%81%E0%A6%A6%E0%A7%8D%E0%A6%A7%E0%A6%BF%E0%A6%AE%E0%A6%A4%E0%A7%8D%E0%A6%A4%E0%A6%BE",
        "title": "কৃত্ৰিম বুদ্ধিমত্তা – Assamese"
      },
      {
        "text": "Asturianu",
        "url": "https://ast.wikipedia.org/wiki/Intelixencia_artificial",
        "title": "Intelixencia artificial – Asturian"
      },
      {
        "text": "Avañe'ẽ",
        "url": "https://gn.wikipedia.org/wiki/Ava_japopyre_arandu",
        "title": "Ava japopyre arandu – Guarani"
      },
      {
        "text": "Azərbaycanca",
        "url": "https://az.wikipedia.org/wiki/S%C3%BCni_intellekt",
        "title": "Süni intellekt – Azerbaijani"
      },
      {
        "text": "تۆرکجه",
        "url": "https://azb.wikipedia.org/wiki/%D9%85%D8%B5%D9%86%D9%88%D8%B9%DB%8C_%D8%B0%DA%A9%D8%A7",
        "title": "مصنوعی ذکا – South Azerbaijani"
      },
      {
        "text": "বাংলা",
        "url": "https://bn.wikipedia.org/wiki/%E0%A6%95%E0%A7%83%E0%A6%A4%E0%A7%8D%E0%A6%B0%E0%A6%BF%E0%A6%AE_%E0%A6%AC%E0%A7%81%E0%A6%A6%E0%A7%8D%E0%A6%A7%E0%A6%BF%E0%A6%AE%E0%A6%A4%E0%A7%8D%E0%A6%A4%E0%A6%BE",
        "title": "কৃত্রিম বুদ্ধিমত্তা – Bangla"
      },
      {
        "text": "閩南語 / Bân-lâm-gú",
        "url": "https://zh-min-nan.wikipedia.org/wiki/J%C3%AEn-kang_t%C3%AC-l%C3%AAng",
        "title": "Jîn-kang tì-lêng – Minnan"
      },
      {
        "text": "Башҡортса",
        "url": "https://ba.wikipedia.org/wiki/%D0%AF%D2%BB%D0%B0%D0%BB%D0%BC%D0%B0_%D0%B8%D0%BD%D1%82%D0%B5%D0%BB%D0%BB%D0%B5%D0%BA%D1%82",
        "title": "Яһалма интеллект – Bashkir"
      },
      {
        "text": "Беларуская",
        "url": "https://be.wikipedia.org/wiki/%D0%A8%D1%82%D1%83%D1%87%D0%BD%D1%8B_%D1%96%D0%BD%D1%82%D1%8D%D0%BB%D0%B5%D0%BA%D1%82",
        "title": "Штучны інтэлект – Belarusian"
      },
      {
        "text": "Беларуская (тарашкевіца)",
        "url": "https://be-tarask.wikipedia.org/wiki/%D0%A8%D1%82%D1%83%D1%87%D0%BD%D1%8B_%D1%96%D0%BD%D1%82%D1%8D%D0%BB%D0%B5%D0%BA%D1%82",
        "title": "Штучны інтэлект – Belarusian (Taraškievica orthography)"
      },
      {
        "text": "भोजपुरी",
        "url": "https://bh.wikipedia.org/wiki/%E0%A4%86%E0%A4%B0%E0%A5%8D%E0%A4%9F%E0%A4%BF%E0%A4%AB%E0%A4%BF%E0%A4%B6%E0%A4%BF%E0%A4%AF%E0%A4%B2_%E0%A4%87%E0%A4%82%E0%A4%9F%E0%A5%87%E0%A4%B2%E0%A4%BF%E0%A4%9C%E0%A5%87%E0%A4%82%E0%A4%B8",
        "title": "आर्टिफिशियल इंटेलिजेंस – Bhojpuri"
      },
      {
        "text": "Bikol Central",
        "url": "https://bcl.wikipedia.org/wiki/Artipisyal_na_intelihensya",
        "title": "Artipisyal na intelihensya – Central Bikol"
      },
      {
        "text": "Български",
        "url": "https://bg.wikipedia.org/wiki/%D0%98%D0%B7%D0%BA%D1%83%D1%81%D1%82%D0%B2%D0%B5%D0%BD_%D0%B8%D0%BD%D1%82%D0%B5%D0%BB%D0%B5%D0%BA%D1%82",
        "title": "Изкуствен интелект – Bulgarian"
      },
      {
        "text": "Boarisch",
        "url": "https://bar.wikipedia.org/wiki/Kinschtlicha_Intelligenz",
        "title": "Kinschtlicha Intelligenz – Bavarian"
      },
      {
        "text": "བོད་ཡིག",
        "url": "https://bo.wikipedia.org/wiki/%E0%BD%98%E0%BD%B2%E0%BC%8B%E0%BD%96%E0%BD%9F%E0%BD%BC%E0%BD%A6%E0%BC%8B%E0%BD%A2%E0%BD%B2%E0%BD%82%E0%BC%8B%E0%BD%93%E0%BD%B4%E0%BD%A6%E0%BC%8D",
        "title": "མི་བཟོས་རིག་ནུས། – Tibetan"
      },
      {
        "text": "Bosanski",
        "url": "https://bs.wikipedia.org/wiki/Umjetna_inteligencija",
        "title": "Umjetna inteligencija – Bosnian"
      },
      {
        "text": "Brezhoneg",
        "url": "https://br.wikipedia.org/wiki/Naouegezh_artifisiel",
        "title": "Naouegezh artifisiel – Breton"
      },
      {
        "text": "Буряад",
        "url": "https://bxr.wikipedia.org/wiki/%D0%A5%D1%8D%D0%BC%D1%8D%D0%BB_%D0%BE%D1%8E%D1%83%D0%BD",
        "title": "Хэмэл оюун – Russia Buriat"
      },
      {
        "text": "Català",
        "url": "https://ca.wikipedia.org/wiki/Intel%C2%B7lig%C3%A8ncia_artificial",
        "title": "Intel·ligència artificial – Catalan"
      },
      {
        "text": "Чӑвашла",
        "url": "https://cv.wikipedia.org/wiki/%C4%82%D1%81%D0%BB%D0%B0%D0%B9%D0%BB%D0%B0%D0%BD%C4%83_%C4%83%D1%81%D1%82%C4%83%D0%BD",
        "title": "Ăслайланă ăстăн – Chuvash"
      },
      {
        "text": "Cebuano",
        "url": "https://ceb.wikipedia.org/wiki/Intelihensiya_artipisyal",
        "title": "Intelihensiya artipisyal – Cebuano"
      },
      {
        "text": "Čeština",
        "url": "https://cs.wikipedia.org/wiki/Um%C4%9Bl%C3%A1_inteligence",
        "title": "Umělá inteligence – Czech"
      },
      {
        "text": "Cymraeg",
        "url": "https://cy.wikipedia.org/wiki/Deallusrwydd_artiffisial",
        "title": "Deallusrwydd artiffisial – Welsh"
      },
      {
        "text": "Dansk",
        "url": "https://da.wikipedia.org/wiki/Kunstig_intelligens",
        "title": "Kunstig intelligens – Danish"
      },
      {
        "text": "الدارجة",
        "url": "https://ary.wikipedia.org/wiki/%D8%AF%D9%83%D8%A7_%D8%B5%D8%B7%D9%8A%D9%86%D8%A7%D8%B9%D9%8A",
        "title": "دكا صطيناعي – Moroccan Arabic"
      },
      {
        "text": "Deutsch",
        "url": "https://de.wikipedia.org/wiki/K%C3%BCnstliche_Intelligenz",
        "title": "Künstliche Intelligenz – German"
      },
      {
        "text": "Eesti",
        "url": "https://et.wikipedia.org/wiki/Tehisintellekt",
        "title": "Tehisintellekt – Estonian"
      },
      {
        "text": "Ελληνικά",
        "url": "https://el.wikipedia.org/wiki/%CE%A4%CE%B5%CF%87%CE%BD%CE%B7%CF%84%CE%AE_%CE%BD%CE%BF%CE%B7%CE%BC%CE%BF%CF%83%CF%8D%CE%BD%CE%B7",
        "title": "Τεχνητή νοημοσύνη – Greek"
      },
      {
        "text": "Español",
        "url": "https://es.wikipedia.org/wiki/Inteligencia_artificial",
        "title": "Inteligencia artificial – Spanish"
      },
      {
        "text": "Esperanto",
        "url": "https://eo.wikipedia.org/wiki/Artefarita_intelekto",
        "title": "Artefarita intelekto – Esperanto"
      },
      {
        "text": "Estremeñu",
        "url": "https://ext.wikipedia.org/wiki/Enteligencia_artificial",
        "title": "Enteligencia artificial – Extremaduran"
      },
      {
        "text": "Euskara",
        "url": "https://eu.wikipedia.org/wiki/Adimen_artifizial",
        "title": "Adimen artifizial – Basque"
      },
      {
        "text": "فارسی",
        "url": "https://fa.wikipedia.org/wiki/%D9%87%D9%88%D8%B4_%D9%85%D8%B5%D9%86%D9%88%D8%B9%DB%8C",
        "title": "هوش مصنوعی – Persian"
      },
      {
        "text": "Fiji Hindi",
        "url": "https://hif.wikipedia.org/wiki/Artificial_intelligence",
        "title": "Artificial intelligence – Fiji Hindi"
      },
      {
        "text": "Français",
        "url": "https://fr.wikipedia.org/wiki/Intelligence_artificielle",
        "title": "Intelligence artificielle – French"
      },
      {
        "text": "Furlan",
        "url": "https://fur.wikipedia.org/wiki/Inteligjence_artifici%C3%A2l",
        "title": "Inteligjence artificiâl – Friulian"
      },
      {
        "text": "Gaeilge",
        "url": "https://ga.wikipedia.org/wiki/Intleacht_shaorga",
        "title": "Intleacht shaorga – Irish"
      },
      {
        "text": "Gaelg",
        "url": "https://gv.wikipedia.org/wiki/Far-in%C3%A7hynaght",
        "title": "Far-inçhynaght – Manx"
      },
      {
        "text": "Gàidhlig",
        "url": "https://gd.wikipedia.org/wiki/Tuigse_inntealta",
        "title": "Tuigse inntealta – Scottish Gaelic"
      },
      {
        "text": "Galego",
        "url": "https://gl.wikipedia.org/wiki/Intelixencia_artificial",
        "title": "Intelixencia artificial – Galician"
      },
      {
        "text": "贛語",
        "url": "https://gan.wikipedia.org/wiki/%E4%BA%BA%E5%B7%A5%E6%99%BA%E8%83%BD",
        "title": "人工智能 – Gan"
      },
      {
        "text": "Gĩkũyũ",
        "url": "https://ki.wikipedia.org/wiki/%C5%A8%C5%A9g%C4%A9_wa_Kanyonde",
        "title": "Ũũgĩ wa Kanyonde – Kikuyu"
      },
      {
        "text": "गोंयची कोंकणी / Gõychi Konknni",
        "url": "https://gom.wikipedia.org/wiki/%E0%A4%95%E0%A5%83%E0%A4%A4%E0%A5%8D%E0%A4%B0%E0%A4%BF%E0%A4%AE_%E0%A4%AC%E0%A5%81%E0%A4%A7%E0%A5%8D%E0%A4%A6%E0%A5%80",
        "title": "कृत्रिम बुध्दी – Goan Konkani"
      },
      {
        "text": "한국어",
        "url": "https://ko.wikipedia.org/wiki/%EC%9D%B8%EA%B3%B5%EC%A7%80%EB%8A%A5",
        "title": "인공지능 – Korean"
      },
      {
        "text": "Hausa",
        "url": "https://ha.wikipedia.org/wiki/Kirkirar_Basira",
        "title": "Kirkirar Basira – Hausa"
      },
      {
        "text": "Հայերեն",
        "url": "https://hy.wikipedia.org/wiki/%D4%B1%D6%80%D5%B0%D5%A5%D5%BD%D5%BF%D5%A1%D5%AF%D5%A1%D5%B6_%D5%A2%D5%A1%D5%B6%D5%A1%D5%AF%D5%A1%D5%B6%D5%B8%D6%82%D5%A9%D5%B5%D5%B8%D6%82%D5%B6",
        "title": "Արհեստական բանականություն – Armenian"
      },
      {
        "text": "हिन्दी",
        "url": "https://hi.wikipedia.org/wiki/%E0%A4%95%E0%A5%83%E0%A4%A4%E0%A5%8D%E0%A4%B0%E0%A4%BF%E0%A4%AE_%E0%A4%AC%E0%A5%81%E0%A4%A6%E0%A5%8D%E0%A4%A7%E0%A4%BF",
        "title": "कृत्रिम बुद्धि – Hindi"
      },
      {
        "text": "Hrvatski",
        "url": "https://hr.wikipedia.org/wiki/Umjetna_inteligencija",
        "title": "Umjetna inteligencija – Croatian"
      },
      {
        "text": "Ido",
        "url": "https://io.wikipedia.org/wiki/Artifical_inteligenteso",
        "title": "Artifical inteligenteso – Ido"
      },
      {
        "text": "Igbo",
        "url": "https://ig.wikipedia.org/wiki/%E1%BB%8Cg%E1%BB%A5g%E1%BB%A5_isi",
        "title": "Ọgụgụ isi – Igbo"
      },
      {
        "text": "Ilokano",
        "url": "https://ilo.wikipedia.org/wiki/Parbo_a_saririt",
        "title": "Parbo a saririt – Iloko"
      },
      {
        "text": "Bahasa Indonesia",
        "url": "https://id.wikipedia.org/wiki/Kecerdasan_buatan",
        "title": "Kecerdasan buatan – Indonesian"
      },
      {
        "text": "Interlingua",
        "url": "https://ia.wikipedia.org/wiki/Intelligentia_artificial",
        "title": "Intelligentia artificial – Interlingua"
      },
      {
        "text": "Interlingue",
        "url": "https://ie.wikipedia.org/wiki/Inteligentie_artificial",
        "title": "Inteligentie artificial – Interlingue"
      },
      {
        "text": "IsiZulu",
        "url": "https://zu.wikipedia.org/wiki/UHlakahlisombulu",
        "title": "UHlakahlisombulu – Zulu"
      },
      {
        "text": "Íslenska",
        "url": "https://is.wikipedia.org/wiki/Gervigreind",
        "title": "Gervigreind – Icelandic"
      },
      {
        "text": "Italiano",
        "url": "https://it.wikipedia.org/wiki/Intelligenza_artificiale",
        "title": "Intelligenza artificiale – Italian"
      },
      {
        "text": "עברית",
        "url": "https://he.wikipedia.org/wiki/%D7%91%D7%99%D7%A0%D7%94_%D7%9E%D7%9C%D7%90%D7%9B%D7%95%D7%AA%D7%99%D7%AA",
        "title": "בינה מלאכותית – Hebrew"
      },
      {
        "text": "Jawa",
        "url": "https://jv.wikipedia.org/wiki/Kacerdhasan_gaw%C3%A9yan",
        "title": "Kacerdhasan gawéyan – Javanese"
      },
      {
        "text": "ಕನ್ನಡ",
        "url": "https://kn.wikipedia.org/wiki/%E0%B2%95%E0%B3%83%E0%B2%A4%E0%B2%95_%E0%B2%AC%E0%B3%81%E0%B2%A6%E0%B3%8D%E0%B2%A7%E0%B2%BF%E0%B2%AE%E0%B2%A4%E0%B3%8D%E0%B2%A4%E0%B3%86",
        "title": "ಕೃತಕ ಬುದ್ಧಿಮತ್ತೆ – Kannada"
      },
      {
        "text": "ქართული",
        "url": "https://ka.wikipedia.org/wiki/%E1%83%AE%E1%83%94%E1%83%9A%E1%83%9D%E1%83%95%E1%83%9C%E1%83%A3%E1%83%A0%E1%83%98_%E1%83%98%E1%83%9C%E1%83%A2%E1%83%94%E1%83%9A%E1%83%94%E1%83%A5%E1%83%A2%E1%83%98",
        "title": "ხელოვნური ინტელექტი – Georgian"
      },
      {
        "text": "कॉशुर / کٲشُر",
        "url": "https://ks.wikipedia.org/wiki/%D9%85%D9%8E%D8%B5%D9%86%D9%88%D8%B9%DB%8C_%D8%B0%D9%8E%DB%81%D9%B2%D9%86%D9%90%DB%8C%D9%8E%D8%AA%DA%BE",
        "title": "مَصنوعی ذَہٲنِیَتھ – Kashmiri"
      },
      {
        "text": "Қазақша",
        "url": "https://kk.wikipedia.org/wiki/%D0%96%D0%B0%D1%81%D0%B0%D0%BD%D0%B4%D1%8B_%D0%B8%D0%BD%D1%82%D0%B5%D0%BB%D0%BB%D0%B5%D0%BA%D1%82",
        "title": "Жасанды интеллект – Kazakh"
      },
      {
        "text": "Kiswahili",
        "url": "https://sw.wikipedia.org/wiki/Akili_mnemba",
        "title": "Akili mnemba – Swahili"
      },
      {
        "text": "Kreyòl ayisyen",
        "url": "https://ht.wikipedia.org/wiki/Ent%C3%A8lijans_atifisy%C3%A8l",
        "title": "Entèlijans atifisyèl – Haitian Creole"
      },
      {
        "text": "Kriyòl gwiyannen",
        "url": "https://gcr.wikipedia.org/wiki/Ent%C3%A9lijans_artifisy%C3%A8l",
        "title": "Entélijans artifisyèl – Guianan Creole"
      },
      {
        "text": "Kurdî",
        "url": "https://ku.wikipedia.org/wiki/Zekaya_s%C3%BBn%C3%AE",
        "title": "Zekaya sûnî – Kurdish"
      },
      {
        "text": "Кыргызча",
        "url": "https://ky.wikipedia.org/wiki/%D0%96%D0%B0%D1%81%D0%B0%D0%BB%D0%BC%D0%B0_%D0%B8%D0%BD%D1%82%D0%B5%D0%BB%D0%BB%D0%B5%D0%BA%D1%82",
        "title": "Жасалма интеллект – Kyrgyz"
      },
      {
        "text": "ລາວ",
        "url": "https://lo.wikipedia.org/wiki/%E0%BA%9B%E0%BA%B1%E0%BA%99%E0%BA%8D%E0%BA%B2%E0%BA%9B%E0%BA%B0%E0%BA%94%E0%BA%B4%E0%BA%94",
        "title": "ປັນຍາປະດິດ – Lao"
      },
      {
        "text": "Latina",
        "url": "https://la.wikipedia.org/wiki/Intellegentia_artificialis",
        "title": "Intellegentia artificialis – Latin"
      },
      {
        "text": "Latviešu",
        "url": "https://lv.wikipedia.org/wiki/M%C4%81ksl%C4%ABgais_intelekts",
        "title": "Mākslīgais intelekts – Latvian"
      },
      {
        "text": "Lëtzebuergesch",
        "url": "https://lb.wikipedia.org/wiki/K%C3%ABnschtlech_Intelligenz",
        "title": "Kënschtlech Intelligenz – Luxembourgish"
      },
      {
        "text": "Lietuvių",
        "url": "https://lt.wikipedia.org/wiki/Dirbtinis_intelektas",
        "title": "Dirbtinis intelektas – Lithuanian"
      },
      {
        "text": "Ligure",
        "url": "https://lij.wikipedia.org/wiki/Intelligensa_artifi%C3%A7iale",
        "title": "Intelligensa artifiçiale – Ligurian"
      },
      {
        "text": "Limburgs",
        "url": "https://li.wikipedia.org/wiki/K%C3%B3nsmaesige_intelligentie",
        "title": "Kónsmaesige intelligentie – Limburgish"
      },
      {
        "text": "La .lojban.",
        "url": "https://jbo.wikipedia.org/wiki/rutni_menli",
        "title": "rutni menli – Lojban"
      },
      {
        "text": "Lombard",
        "url": "https://lmo.wikipedia.org/wiki/Intelligenza_artificiala",
        "title": "Intelligenza artificiala – Lombard"
      },
      {
        "text": "Magyar",
        "url": "https://hu.wikipedia.org/wiki/Mesters%C3%A9ges_intelligencia",
        "title": "Mesterséges intelligencia – Hungarian"
      },
      {
        "text": "Madhurâ",
        "url": "https://mad.wikipedia.org/wiki/Kecerdasan_buatan",
        "title": "Kecerdasan buatan – Madurese"
      },
      {
        "text": "Македонски",
        "url": "https://mk.wikipedia.org/wiki/%D0%92%D0%B5%D1%88%D1%82%D0%B0%D1%87%D0%BA%D0%B0_%D0%B8%D0%BD%D1%82%D0%B5%D0%BB%D0%B8%D0%B3%D0%B5%D0%BD%D1%86%D0%B8%D1%98%D0%B0",
        "title": "Вештачка интелигенција – Macedonian"
      },
      {
        "text": "Malagasy",
        "url": "https://mg.wikipedia.org/wiki/Haranitan-tsaina_voatr%27_olombelona",
        "title": "Haranitan-tsaina voatr' olombelona – Malagasy"
      },
      {
        "text": "മലയാളം",
        "url": "https://ml.wikipedia.org/wiki/%E0%B4%A8%E0%B4%BF%E2%80%8D%E0%B5%BC%E0%B4%AE%E0%B5%8D%E0%B4%AE%E0%B4%BF%E0%B4%A4_%E0%B4%AC%E0%B5%81%E0%B4%A6%E0%B5%8D%E0%B4%A7%E0%B4%BF",
        "title": "നി‍ർമ്മിത ബുദ്ധി – Malayalam"
      },
      {
        "text": "Malti",
        "url": "https://mt.wikipedia.org/wiki/Intelli%C4%A1enza_artifi%C4%8Bjali",
        "title": "Intelliġenza artifiċjali – Maltese"
      },
      {
        "text": "मराठी",
        "url": "https://mr.wikipedia.org/wiki/%E0%A4%95%E0%A5%83%E0%A4%A4%E0%A5%8D%E0%A4%B0%E0%A4%BF%E0%A4%AE_%E0%A4%AC%E0%A5%81%E0%A4%A6%E0%A5%8D%E0%A4%A7%E0%A4%BF%E0%A4%AE%E0%A4%A4%E0%A5%8D%E0%A4%A4%E0%A4%BE",
        "title": "कृत्रिम बुद्धिमत्ता – Marathi"
      },
      {
        "text": "მარგალური",
        "url": "https://xmf.wikipedia.org/wiki/%E1%83%AE%E1%83%94%E1%83%9A%E1%83%A3%E1%83%90%E1%83%9C%E1%83%A3%E1%83%A0%E1%83%98_%E1%83%98%E1%83%9C%E1%83%A2%E1%83%94%E1%83%9A%E1%83%94%E1%83%A5%E1%83%A2%E1%83%98",
        "title": "ხელუანური ინტელექტი – Mingrelian"
      },
      {
        "text": "مصرى",
        "url": "https://arz.wikipedia.org/wiki/%D8%B0%D9%83%D8%A7%D8%A1_%D8%B5%D9%86%D8%A7%D8%B9%D9%89",
        "title": "ذكاء صناعى – Egyptian Arabic"
      },
      {
        "text": "Bahasa Melayu",
        "url": "https://ms.wikipedia.org/wiki/Kecerdasan_buatan",
        "title": "Kecerdasan buatan – Malay"
      },
      {
        "text": "Minangkabau",
        "url": "https://min.wikipedia.org/wiki/Kacerdasan_buatan",
        "title": "Kacerdasan buatan – Minangkabau"
      },
      {
        "text": "Монгол",
        "url": "https://mn.wikipedia.org/wiki/%D0%A5%D0%B8%D0%B9%D0%BC%D1%8D%D0%BB_%D0%BE%D1%8E%D1%83%D0%BD",
        "title": "Хиймэл оюун – Mongolian"
      },
      {
        "text": "မြန်မာဘာသာ",
        "url": "https://my.wikipedia.org/wiki/%E1%80%89%E1%80%AC%E1%80%8F%E1%80%BA%E1%80%9B%E1%80%8A%E1%80%BA%E1%80%90%E1%80%AF",
        "title": "ဉာဏ်ရည်တု – Burmese"
      },
      {
        "text": "Nederlands",
        "url": "https://nl.wikipedia.org/wiki/Kunstmatige_intelligentie",
        "title": "Kunstmatige intelligentie – Dutch"
      },
      {
        "text": "Nedersaksies",
        "url": "https://nds-nl.wikipedia.org/wiki/Keunstklookte",
        "title": "Keunstklookte – Low Saxon"
      },
      {
        "text": "नेपाली",
        "url": "https://ne.wikipedia.org/wiki/%E0%A4%95%E0%A5%83%E0%A4%A4%E0%A5%8D%E0%A4%B0%E0%A4%BF%E0%A4%AE_%E0%A4%AC%E0%A5%8C%E0%A4%A6%E0%A5%8D%E0%A4%A7%E0%A4%BF%E0%A4%95%E0%A4%A4%E0%A4%BE",
        "title": "कृत्रिम बौद्धिकता – Nepali"
      },
      {
        "text": "नेपाल भाषा",
        "url": "https://new.wikipedia.org/wiki/%E0%A4%86%E0%A4%B0%E0%A5%8D%E0%A4%9F%E0%A4%BF%E0%A4%AB%E0%A4%BF%E0%A4%B8%E0%A4%BF%E0%A4%AF%E0%A4%B2_%E0%A4%87%E0%A4%A8%E0%A5%8D%E0%A4%9F%E0%A5%87%E0%A4%B2%E0%A4%BF%E0%A4%9C%E0%A5%87%E0%A4%A8%E0%A5%8D%E0%A4%B8",
        "title": "आर्टिफिसियल इन्टेलिजेन्स – Newari"
      },
      {
        "text": "日本語",
        "url": "https://ja.wikipedia.org/wiki/%E4%BA%BA%E5%B7%A5%E7%9F%A5%E8%83%BD",
        "title": "人工知能 – Japanese"
      },
      {
        "text": "Nordfriisk",
        "url": "https://frr.wikipedia.org/wiki/Konstelk_Inteligens",
        "title": "Konstelk Inteligens – Northern Frisian"
      },
      {
        "text": "Norsk bokmål",
        "url": "https://no.wikipedia.org/wiki/Kunstig_intelligens",
        "title": "Kunstig intelligens – Norwegian Bokmål"
      },
      {
        "text": "Norsk nynorsk",
        "url": "https://nn.wikipedia.org/wiki/Kunstig_intelligens",
        "title": "Kunstig intelligens – Norwegian Nynorsk"
      },
      {
        "text": "Occitan",
        "url": "https://oc.wikipedia.org/wiki/Intellig%C3%A9ncia_artificiala",
        "title": "Intelligéncia artificiala – Occitan"
      },
      {
        "text": "ଓଡ଼ିଆ",
        "url": "https://or.wikipedia.org/wiki/%E0%AC%86%E0%AC%B0%E0%AD%8D%E0%AC%9F%E0%AC%BF%E0%AC%AB%E0%AC%BF%E0%AC%B8%E0%AC%BF%E0%AC%86%E0%AC%B2_%E0%AC%87%E0%AC%A3%E0%AD%8D%E0%AC%9F%E0%AD%87%E0%AC%B2%E0%AC%BF%E0%AC%9C%E0%AD%87%E0%AC%A8%E0%AD%8D%E0%AC%B8",
        "title": "ଆର୍ଟିଫିସିଆଲ ଇଣ୍ଟେଲିଜେନ୍ସ – Odia"
      },
      {
        "text": "Oʻzbekcha / ўзбекча",
        "url": "https://uz.wikipedia.org/wiki/Sun%CA%BCiy_intellekt",
        "title": "Sunʼiy intellekt – Uzbek"
      },
      {
        "text": "ਪੰਜਾਬੀ",
        "url": "https://pa.wikipedia.org/wiki/%E0%A8%AC%E0%A8%A3%E0%A8%BE%E0%A8%B5%E0%A8%9F%E0%A9%80_%E0%A8%AC%E0%A9%81%E0%A9%B1%E0%A8%A7%E0%A9%80_(_AI)",
        "title": "ਬਣਾਵਟੀ ਬੁੱਧੀ ( AI) – Punjabi"
      },
      {
        "text": "پنجابی",
        "url": "https://pnb.wikipedia.org/wiki/%D8%A8%D9%86%D8%A7%D8%A6%DB%8C_%DA%AF%D8%A6%DB%8C_%D8%B0%DB%81%D8%A7%D9%86%D8%AA",
        "title": "بنائی گئی ذہانت – Western Punjabi"
      },
      {
        "text": "پښتو",
        "url": "https://ps.wikipedia.org/wiki/%D9%85%D8%B5%D9%86%D9%88%D8%B9%D9%8A_%DA%81%D9%8A%D8%B1%DA%A9%D8%AA%DB%8C%D8%A7",
        "title": "مصنوعي ځيرکتیا – Pashto"
      },
      {
        "text": "Patois",
        "url": "https://jam.wikipedia.org/wiki/Aatifishal_intelijens",
        "title": "Aatifishal intelijens – Jamaican Creole English"
      },
      {
        "text": "ភាសាខ្មែរ",
        "url": "https://km.wikipedia.org/wiki/%E1%9E%94%E1%9E%89%E1%9F%92%E1%9E%89%E1%9E%B6%E1%9E%9F%E1%9E%B7%E1%9E%94%E1%9F%92%E1%9E%94%E1%9E%93%E1%9E%B7%E1%9E%98%E1%9F%92%E1%9E%98%E1%9E%B7%E1%9E%8F",
        "title": "បញ្ញាសិប្បនិម្មិត – Khmer"
      },
      {
        "text": "Picard",
        "url": "https://pcd.wikipedia.org/wiki/Int%C3%A9rligince_artificielle",
        "title": "Intérligince artificielle – Picard"
      },
      {
        "text": "Piemontèis",
        "url": "https://pms.wikipedia.org/wiki/Inteligensa_Artifissial",
        "title": "Inteligensa Artifissial – Piedmontese"
      },
      {
        "text": "Plattdüütsch",
        "url": "https://nds.wikipedia.org/wiki/K%C3%BCnstlike_Intelligenz",
        "title": "Künstlike Intelligenz – Low German"
      },
      {
        "text": "Polski",
        "url": "https://pl.wikipedia.org/wiki/Sztuczna_inteligencja",
        "title": "Sztuczna inteligencja – Polish"
      },
      {
        "text": "Português",
        "url": "https://pt.wikipedia.org/wiki/Intelig%C3%AAncia_artificial",
        "title": "Inteligência artificial – Portuguese"
      },
      {
        "text": "Qaraqalpaqsha",
        "url": "https://kaa.wikipedia.org/wiki/Jasalma_intellekt",
        "title": "Jasalma intellekt – Kara-Kalpak"
      },
      {
        "text": "Qırımtatarca",
        "url": "https://crh.wikipedia.org/wiki/Suniy_zek%C3%A2",
        "title": "Suniy zekâ – Crimean Tatar"
      },
      {
        "text": "Reo tahiti",
        "url": "https://ty.wikipedia.org/wiki/Intelligence_artificiel",
        "title": "Intelligence artificiel – Tahitian"
      },
      {
        "text": "Ripoarisch",
        "url": "https://ksh.wikipedia.org/wiki/Artificial_Intelligence",
        "title": "Artificial Intelligence – Colognian"
      },
      {
        "text": "Română",
        "url": "https://ro.wikipedia.org/wiki/Inteligen%C8%9B%C4%83_artificial%C4%83",
        "title": "Inteligență artificială – Romanian"
      },
      {
        "text": "Runa Simi",
        "url": "https://qu.wikipedia.org/wiki/Wallpasqa_yuyay",
        "title": "Wallpasqa yuyay – Quechua"
      },
      {
        "text": "Русиньскый",
        "url": "https://rue.wikipedia.org/wiki/%D0%A3%D0%BC%D0%B5%D0%BB%D0%B0_%D1%96%D0%BD%D1%82%D0%B5%D0%BB%D1%96%D2%91%D0%B5%D0%BD%D1%86%D1%96%D1%8F",
        "title": "Умела інтеліґенція – Rusyn"
      },
      {
        "text": "Русский",
        "url": "https://ru.wikipedia.org/wiki/%D0%98%D1%81%D0%BA%D1%83%D1%81%D1%81%D1%82%D0%B2%D0%B5%D0%BD%D0%BD%D1%8B%D0%B9_%D0%B8%D0%BD%D1%82%D0%B5%D0%BB%D0%BB%D0%B5%D0%BA%D1%82",
        "title": "Искусственный интеллект – Russian"
      },
      {
        "text": "Саха тыла",
        "url": "https://sah.wikipedia.org/wiki/%D0%9E%D2%A5%D0%BE%D2%BB%D1%83%D1%83_%D0%B8%D0%BD%D1%82%D0%B5%D0%BB%D0%BB%D0%B5%D0%BA%D1%82",
        "title": "Оҥоһуу интеллект – Yakut"
      },
      {
        "text": "Scots",
        "url": "https://sco.wikipedia.org/wiki/Artifeecial_intelligence",
        "title": "Artifeecial intelligence – Scots"
      },
      {
        "text": "Shqip",
        "url": "https://sq.wikipedia.org/wiki/Inteligjenca_artificiale",
        "title": "Inteligjenca artificiale – Albanian"
      },
      {
        "text": "සිංහල",
        "url": "https://si.wikipedia.org/wiki/%E0%B6%9A%E0%B7%98%E0%B6%AD%E0%B7%8A%E2%80%8D%E0%B6%BB%E0%B7%93%E0%B6%B8_%E0%B6%B6%E0%B7%94%E0%B6%AF%E0%B7%8A%E0%B6%B0%E0%B7%92%E0%B6%BA",
        "title": "කෘත්‍රීම බුද්ධිය – Sinhala"
      },
      {
        "text": "Simple English",
        "url": "https://simple.wikipedia.org/wiki/Artificial_intelligence",
        "title": "Artificial intelligence – Simple English"
      },
      {
        "text": "سنڌي",
        "url": "https://sd.wikipedia.org/wiki/%DA%BE%D9%BF%D8%B1%D8%A7%DA%8C%D9%88_%D8%B0%DA%BE%D8%A7%D9%86%D8%AA",
        "title": "ھٿراڌو ذھانت – Sindhi"
      },
      {
        "text": "Slovenčina",
        "url": "https://sk.wikipedia.org/wiki/Umel%C3%A1_inteligencia",
        "title": "Umelá inteligencia – Slovak"
      },
      {
        "text": "Slovenščina",
        "url": "https://sl.wikipedia.org/wiki/Umetna_inteligenca",
        "title": "Umetna inteligenca – Slovenian"
      },
      {
        "text": "Ślůnski",
        "url": "https://szl.wikipedia.org/wiki/Kategoryjo:Sztuczno_inteligencyjo",
        "title": "Kategoryjo:Sztuczno inteligencyjo – Silesian"
      },
      {
        "text": "کوردی",
        "url": "https://ckb.wikipedia.org/wiki/%DA%98%DB%8C%D8%B1%DB%8C%DB%8C_%D8%AF%DB%95%D8%B3%D8%AA%DA%A9%D8%B1%D8%AF",
        "title": "ژیریی دەستکرد – Central Kurdish"
      },
      {
        "text": "Српски / srpski",
        "url": "https://sr.wikipedia.org/wiki/%D0%92%D0%B5%D1%88%D1%82%D0%B0%D1%87%D0%BA%D0%B0_%D0%B8%D0%BD%D1%82%D0%B5%D0%BB%D0%B8%D0%B3%D0%B5%D0%BD%D1%86%D0%B8%D1%98%D0%B0",
        "title": "Вештачка интелигенција – Serbian"
      },
      {
        "text": "Srpskohrvatski / српскохрватски",
        "url": "https://sh.wikipedia.org/wiki/Vje%C5%A1ta%C4%8Dka_inteligencija",
        "title": "Vještačka inteligencija – Serbo-Croatian"
      },
      {
        "text": "Suomi",
        "url": "https://fi.wikipedia.org/wiki/Teko%C3%A4ly",
        "title": "Tekoäly – Finnish"
      },
      {
        "text": "Svenska",
        "url": "https://sv.wikipedia.org/wiki/Artificiell_intelligens",
        "title": "Artificiell intelligens – Swedish"
      },
      {
        "text": "Tagalog",
        "url": "https://tl.wikipedia.org/wiki/Artipisyal_na_katalinuhan",
        "title": "Artipisyal na katalinuhan – Tagalog"
      },
      {
        "text": "தமிழ்",
        "url": "https://ta.wikipedia.org/wiki/%E0%AE%9A%E0%AF%86%E0%AE%AF%E0%AE%B1%E0%AF%8D%E0%AE%95%E0%AF%88_%E0%AE%A8%E0%AF%81%E0%AE%A3%E0%AF%8D%E0%AE%A3%E0%AE%B1%E0%AE%BF%E0%AE%B5%E0%AF%81",
        "title": "செயற்கை நுண்ணறிவு – Tamil"
      },
      {
        "text": "Татарча / tatarça",
        "url": "https://tt.wikipedia.org/wiki/%D0%AF%D1%81%D0%B0%D0%BB%D0%BC%D0%B0_%D0%B8%D0%BD%D1%82%D0%B5%D0%BB%D0%BB%D0%B5%D0%BA%D1%82",
        "title": "Ясалма интеллект – Tatar"
      },
      {
        "text": "తెలుగు",
        "url": "https://te.wikipedia.org/wiki/%E0%B0%95%E0%B1%83%E0%B0%A4%E0%B1%8D%E0%B0%B0%E0%B0%BF%E0%B0%AE_%E0%B0%AE%E0%B1%87%E0%B0%A7%E0%B0%B8%E0%B1%8D%E0%B0%B8%E0%B1%81",
        "title": "కృత్రిమ మేధస్సు – Telugu"
      },
      {
        "text": "ไทย",
        "url": "https://th.wikipedia.org/wiki/%E0%B8%9B%E0%B8%B1%E0%B8%8D%E0%B8%8D%E0%B8%B2%E0%B8%9B%E0%B8%A3%E0%B8%B0%E0%B8%94%E0%B8%B4%E0%B8%A9%E0%B8%90%E0%B9%8C",
        "title": "ปัญญาประดิษฐ์ – Thai"
      },
      {
        "text": "Тоҷикӣ",
        "url": "https://tg.wikipedia.org/wiki/%D2%B2%D1%83%D1%88%D0%B8_%D0%BC%D0%B0%D1%81%D0%BD%D3%AF%D1%8A%D3%A3",
        "title": "Ҳуши маснӯъӣ – Tajik"
      },
      {
        "text": "Türkçe",
        "url": "https://tr.wikipedia.org/wiki/Yapay_zek%C3%A2",
        "title": "Yapay zekâ – Turkish"
      },
      {
        "text": "Türkmençe",
        "url": "https://tk.wikipedia.org/wiki/%C3%9Dasama_akyl",
        "title": "Ýasama akyl – Turkmen"
      },
      {
        "text": "Українська",
        "url": "https://uk.wikipedia.org/wiki/%D0%A8%D1%82%D1%83%D1%87%D0%BD%D0%B8%D0%B9_%D1%96%D0%BD%D1%82%D0%B5%D0%BB%D0%B5%D0%BA%D1%82",
        "title": "Штучний інтелект – Ukrainian"
      },
      {
        "text": "اردو",
        "url": "https://ur.wikipedia.org/wiki/%D9%85%D8%B5%D9%86%D9%88%D8%B9%DB%8C_%D8%B0%DB%81%D8%A7%D9%86%D8%AA",
        "title": "مصنوعی ذہانت – Urdu"
      },
      {
        "text": "ئۇيغۇرچە / Uyghurche",
        "url": "https://ug.wikipedia.org/wiki/%D8%B3%DB%88%D9%86%D8%A6%D9%89_%D8%A6%D9%89%D8%AF%D9%89%D8%B1%D8%A7%D9%83",
        "title": "سۈنئى ئىدىراك – Uyghur"
      },
      {
        "text": "Vèneto",
        "url": "https://vec.wikipedia.org/wiki/Inte%C5%82ijensa_artifisa%C5%82e",
        "title": "Intełijensa artifisałe – Venetian"
      },
      {
        "text": "Tiếng Việt",
        "url": "https://vi.wikipedia.org/wiki/Tr%C3%AD_tu%E1%BB%87_nh%C3%A2n_t%E1%BA%A1o",
        "title": "Trí tuệ nhân tạo – Vietnamese"
      },
      {
        "text": "Võro",
        "url": "https://fiu-vro.wikipedia.org/wiki/Kunstm%C3%B5istus",
        "title": "Kunstmõistus – Võro"
      },
      {
        "text": "Walon",
        "url": "https://wa.wikipedia.org/wiki/S%C3%BBtist%C3%A9_%C3%A9ndjolike",
        "title": "Sûtisté éndjolike – Walloon"
      },
      {
        "text": "Winaray",
        "url": "https://war.wikipedia.org/wiki/Intelihensya_artipisyal",
        "title": "Intelihensya artipisyal – Waray"
      },
      {
        "text": "吴语",
        "url": "https://wuu.wikipedia.org/wiki/%E4%BA%BA%E5%B7%A5%E6%99%BA%E8%83%BD",
        "title": "人工智能 – Wu"
      },
      {
        "text": "ייִדיש",
        "url": "https://yi.wikipedia.org/wiki/%D7%A7%D7%99%D7%A0%D7%A1%D7%98%D7%9C%D7%A2%D7%9B%D7%A2_%D7%90%D7%99%D7%A0%D7%98%D7%A2%D7%9C%D7%99%D7%92%D7%A2%D7%A0%D7%A5",
        "title": "קינסטלעכע אינטעליגענץ – Yiddish"
      },
      {
        "text": "粵語",
        "url": "https://zh-yue.wikipedia.org/wiki/%E4%BA%BA%E5%B7%A5%E6%99%BA%E8%83%BD",
        "title": "人工智能 – Cantonese"
      },
      {
        "text": "Zazaki",
        "url": "https://diq.wikipedia.org/wiki/Viro_v%C4%B1ra%C5%9Ft%C4%B1k%C3%AAn",
        "title": "Viro vıraştıkên – Dimli"
      },
      {
        "text": "Žemaitėška",
        "url": "https://bat-smg.wikipedia.org/wiki/D%C4%97rbt%C4%97ns_intelekts",
        "title": "Dėrbtėns intelekts – Samogitian"
      },
      {
        "text": "中文",
        "url": "https://zh.wikipedia.org/wiki/%E4%BA%BA%E5%B7%A5%E6%99%BA%E8%83%BD",
        "title": "人工智能 – Chinese"
      },
      {
        "text": "Betawi",
        "url": "https://bew.wikipedia.org/wiki/Calakan_bikinan",
        "title": "Calakan bikinan – Betawi"
      },
      {
        "text": "Kadazandusun",
        "url": "https://dtp.wikipedia.org/wiki/Kabaalan_Tinanda",
        "title": "Kabaalan Tinanda – Central Dusun"
      },
      {
        "text": "Fɔ̀ngbè",
        "url": "https://fon.wikipedia.org/wiki/N%C7%94nyw%C9%9B_gb%C9%9Bt%C9%94_%C9%96%C9%94hun_t%C9%94n",
        "title": "Nǔnywɛ gbɛtɔ ɖɔhun tɔn – Fon"
      },
      {
        "text": "ꠍꠤꠟꠐꠤ",
        "url": "https://syl.wikipedia.org/wiki/%EA%A0%80%EA%A0%89%EA%A0%86%EA%A0%9F%EA%A0%A3_%EA%A0%80%EA%A0%87%EA%A0%9F%EA%A0%96%EA%A0%A3%EA%A0%9E",
        "title": "ꠀꠉ꠆ꠟꠣ ꠀꠇꠟꠖꠣꠞ – Sylheti"
      },
      {
        "text": "ⵜⴰⵎⴰⵣⵉⵖⵜ ⵜⴰⵏⴰⵡⴰⵢⵜ",
        "url": "https://zgh.wikipedia.org/wiki/%E2%B5%9C%E2%B5%89%E2%B5%96%E2%B5%89%E2%B5%99%E2%B5%9C_%E2%B5%9C%E2%B4%B0%E2%B5%99%E2%B5%8E%E2%B4%B3%E2%B5%93%E2%B5%94%E2%B5%9C",
        "title": "ⵜⵉⵖⵉⵙⵜ ⵜⴰⵙⵎⴳⵓⵔⵜ – Standard Moroccan Tamazight"
      },
      {
        "text": "Edit links",
        "url": "https://www.wikidata.org/wiki/Special:EntityPage/Q11660#sitelinks-wikipedia",
        "title": "Edit interlanguage links"
      },
      {
        "text": "Article",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence",
        "title": "View the content page [c]"
      },
      {
        "text": "Talk",
        "url": "https://en.wikipedia.org/wiki/Talk:Artificial_intelligence",
        "title": "Discuss improvements to the content page [t]"
      },
      {
        "text": "Read",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence"
      },
      {
        "text": "View source",
        "url": "https://en.wikipedia.org/w/index.php?title=Artificial_intelligence&action=edit",
        "title": "This page is protected.\nYou can view its source [e]"
      },
      {
        "text": "View history",
        "url": "https://en.wikipedia.org/w/index.php?title=Artificial_intelligence&action=history",
        "title": "Past revisions of this page [h]"
      },
      {
        "text": "Read",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence"
      },
      {
        "text": "View source",
        "url": "https://en.wikipedia.org/w/index.php?title=Artificial_intelligence&action=edit"
      },
      {
        "text": "View history",
        "url": "https://en.wikipedia.org/w/index.php?title=Artificial_intelligence&action=history"
      },
      {
        "text": "What links here",
        "url": "https://en.wikipedia.org/wiki/Special:WhatLinksHere/Artificial_intelligence",
        "title": "List of all English Wikipedia pages containing links to this page [j]"
      },
      {
        "text": "Related changes",
        "url": "https://en.wikipedia.org/wiki/Special:RecentChangesLinked/Artificial_intelligence",
        "title": "Recent changes in pages linked from this page [k]"
      },
      {
        "text": "Upload file",
        "url": "https://en.wikipedia.org/wiki/Wikipedia:File_Upload_Wizard",
        "title": "Upload files [u]"
      },
      {
        "text": "Permanent link",
        "url": "https://en.wikipedia.org/w/index.php?title=Artificial_intelligence&oldid=1289722010",
        "title": "Permanent link to this revision of this page"
      },
      {
        "text": "Page information",
        "url": "https://en.wikipedia.org/w/index.php?title=Artificial_intelligence&action=info",
        "title": "More information about this page"
      },
      {
        "text": "Cite this page",
        "url": "https://en.wikipedia.org/w/index.php?title=Special:CiteThisPage&page=Artificial_intelligence&id=1289722010&wpFormIdentifier=titleform",
        "title": "Information on how to cite this page"
      },
      {
        "text": "Get shortened URL",
        "url": "https://en.wikipedia.org/w/index.php?title=Special:UrlShortener&url=https%3A%2F%2Fen.wikipedia.org%2Fwiki%2FArtificial_intelligence"
      },
      {
        "text": "Download QR code",
        "url": "https://en.wikipedia.org/w/index.php?title=Special:QrCode&url=https%3A%2F%2Fen.wikipedia.org%2Fwiki%2FArtificial_intelligence"
      },
      {
        "text": "Download as PDF",
        "url": "https://en.wikipedia.org/w/index.php?title=Special:DownloadAsPdf&page=Artificial_intelligence&action=show-download-screen",
        "title": "Download this page as a PDF file"
      },
      {
        "text": "Printable version",
        "url": "https://en.wikipedia.org/w/index.php?title=Artificial_intelligence&printable=yes",
        "title": "Printable version of this page [p]"
      },
      {
        "text": "Wikimedia Commons",
        "url": "https://commons.wikimedia.org/wiki/Category:Artificial_intelligence"
      },
      {
        "text": "Meta-Wiki",
        "url": "https://meta.wikimedia.org/wiki/Artificial_intelligence"
      },
      {
        "text": "Wikibooks",
        "url": "https://en.wikibooks.org/wiki/Artificial_Intelligence"
      },
      {
        "text": "Wikinews",
        "url": "https://en.wikinews.org/wiki/Category:Artificial_intelligence"
      },
      {
        "text": "Wikiquote",
        "url": "https://en.wikiquote.org/wiki/Artificial_intelligence"
      },
      {
        "text": "Wikiversity",
        "url": "https://en.wikiversity.org/wiki/Portal:Artificial_intelligence"
      },
      {
        "text": "Wikidata item",
        "url": "https://www.wikidata.org/wiki/Special:EntityPage/Q11660",
        "title": "Structured data on this page hosted by Wikidata [g]"
      },
      {
        "text": "AI (disambiguation)",
        "url": "https://en.wikipedia.org/wiki/AI_(disambiguation)",
        "title": "AI (disambiguation)"
      },
      {
        "text": "Artificial intelligence (disambiguation)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence_(disambiguation)",
        "title": "Artificial intelligence (disambiguation)"
      },
      {
        "text": "Major goals",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Goals"
      },
      {
        "text": "Artificial general intelligence",
        "url": "https://en.wikipedia.org/wiki/Artificial_general_intelligence",
        "title": "Artificial general intelligence"
      },
      {
        "text": "Intelligent agent",
        "url": "https://en.wikipedia.org/wiki/Intelligent_agent",
        "title": "Intelligent agent"
      },
      {
        "text": "Recursive self-improvement",
        "url": "https://en.wikipedia.org/wiki/Recursive_self-improvement",
        "title": "Recursive self-improvement"
      },
      {
        "text": "Planning",
        "url": "https://en.wikipedia.org/wiki/Automated_planning_and_scheduling",
        "title": "Automated planning and scheduling"
      },
      {
        "text": "Computer vision",
        "url": "https://en.wikipedia.org/wiki/Computer_vision",
        "title": "Computer vision"
      },
      {
        "text": "General game playing",
        "url": "https://en.wikipedia.org/wiki/General_game_playing",
        "title": "General game playing"
      },
      {
        "text": "Knowledge representation",
        "url": "https://en.wikipedia.org/wiki/Knowledge_representation_and_reasoning",
        "title": "Knowledge representation and reasoning"
      },
      {
        "text": "Natural language processing",
        "url": "https://en.wikipedia.org/wiki/Natural_language_processing",
        "title": "Natural language processing"
      },
      {
        "text": "Robotics",
        "url": "https://en.wikipedia.org/wiki/Robotics",
        "title": "Robotics"
      },
      {
        "text": "AI safety",
        "url": "https://en.wikipedia.org/wiki/AI_safety",
        "title": "AI safety"
      },
      {
        "text": "Machine learning",
        "url": "https://en.wikipedia.org/wiki/Machine_learning",
        "title": "Machine learning"
      },
      {
        "text": "Symbolic",
        "url": "https://en.wikipedia.org/wiki/Symbolic_artificial_intelligence",
        "title": "Symbolic artificial intelligence"
      },
      {
        "text": "Deep learning",
        "url": "https://en.wikipedia.org/wiki/Deep_learning",
        "title": "Deep learning"
      },
      {
        "text": "Bayesian networks",
        "url": "https://en.wikipedia.org/wiki/Bayesian_network",
        "title": "Bayesian network"
      },
      {
        "text": "Evolutionary algorithms",
        "url": "https://en.wikipedia.org/wiki/Evolutionary_algorithm",
        "title": "Evolutionary algorithm"
      },
      {
        "text": "Hybrid intelligent systems",
        "url": "https://en.wikipedia.org/wiki/Hybrid_intelligent_system",
        "title": "Hybrid intelligent system"
      },
      {
        "text": "Systems integration",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence_systems_integration",
        "title": "Artificial intelligence systems integration"
      },
      {
        "text": "Applications",
        "url": "https://en.wikipedia.org/wiki/Applications_of_artificial_intelligence",
        "title": "Applications of artificial intelligence"
      },
      {
        "text": "Bioinformatics",
        "url": "https://en.wikipedia.org/wiki/Machine_learning_in_bioinformatics",
        "title": "Machine learning in bioinformatics"
      },
      {
        "text": "Deepfake",
        "url": "https://en.wikipedia.org/wiki/Deepfake",
        "title": "Deepfake"
      },
      {
        "text": "Earth sciences",
        "url": "https://en.wikipedia.org/wiki/Machine_learning_in_earth_sciences",
        "title": "Machine learning in earth sciences"
      },
      {
        "text": "Finance",
        "url": "https://en.wikipedia.org/wiki/Applications_of_artificial_intelligence#Finance",
        "title": "Applications of artificial intelligence"
      },
      {
        "text": "Generative AI",
        "url": "https://en.wikipedia.org/wiki/Generative_artificial_intelligence",
        "title": "Generative artificial intelligence"
      },
      {
        "text": "Art",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence_art",
        "title": "Artificial intelligence art"
      },
      {
        "text": "Audio",
        "url": "https://en.wikipedia.org/wiki/Generative_audio",
        "title": "Generative audio"
      },
      {
        "text": "Music",
        "url": "https://en.wikipedia.org/wiki/Music_and_artificial_intelligence",
        "title": "Music and artificial intelligence"
      },
      {
        "text": "Government",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence_in_government",
        "title": "Artificial intelligence in government"
      },
      {
        "text": "Healthcare",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence_in_healthcare",
        "title": "Artificial intelligence in healthcare"
      },
      {
        "text": "Mental health",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence_in_mental_health",
        "title": "Artificial intelligence in mental health"
      },
      {
        "text": "Industry",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence_in_industry",
        "title": "Artificial intelligence in industry"
      },
      {
        "text": "Translation",
        "url": "https://en.wikipedia.org/wiki/Machine_translation",
        "title": "Machine translation"
      },
      {
        "text": "Military",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence_arms_race",
        "title": "Artificial intelligence arms race"
      },
      {
        "text": "Physics",
        "url": "https://en.wikipedia.org/wiki/Machine_learning_in_physics",
        "title": "Machine learning in physics"
      },
      {
        "text": "Projects",
        "url": "https://en.wikipedia.org/wiki/List_of_artificial_intelligence_projects",
        "title": "List of artificial intelligence projects"
      },
      {
        "text": "Philosophy",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_artificial_intelligence",
        "title": "Philosophy of artificial intelligence"
      },
      {
        "text": "Artificial consciousness",
        "url": "https://en.wikipedia.org/wiki/Artificial_consciousness",
        "title": "Artificial consciousness"
      },
      {
        "text": "Chinese room",
        "url": "https://en.wikipedia.org/wiki/Chinese_room",
        "title": "Chinese room"
      },
      {
        "text": "Friendly AI",
        "url": "https://en.wikipedia.org/wiki/Friendly_artificial_intelligence",
        "title": "Friendly artificial intelligence"
      },
      {
        "text": "Control problem",
        "url": "https://en.wikipedia.org/wiki/AI_control_problem",
        "title": "AI control problem"
      },
      {
        "text": "Takeover",
        "url": "https://en.wikipedia.org/wiki/AI_takeover",
        "title": "AI takeover"
      },
      {
        "text": "Ethics",
        "url": "https://en.wikipedia.org/wiki/Ethics_of_artificial_intelligence",
        "title": "Ethics of artificial intelligence"
      },
      {
        "text": "Existential risk",
        "url": "https://en.wikipedia.org/wiki/Existential_risk_from_artificial_general_intelligence",
        "title": "Existential risk from artificial general intelligence"
      },
      {
        "text": "Turing test",
        "url": "https://en.wikipedia.org/wiki/Turing_test",
        "title": "Turing test"
      },
      {
        "text": "Uncanny valley",
        "url": "https://en.wikipedia.org/wiki/Uncanny_valley",
        "title": "Uncanny valley"
      },
      {
        "text": "History",
        "url": "https://en.wikipedia.org/wiki/History_of_artificial_intelligence",
        "title": "History of artificial intelligence"
      },
      {
        "text": "Timeline",
        "url": "https://en.wikipedia.org/wiki/Timeline_of_artificial_intelligence",
        "title": "Timeline of artificial intelligence"
      },
      {
        "text": "Progress",
        "url": "https://en.wikipedia.org/wiki/Progress_in_artificial_intelligence",
        "title": "Progress in artificial intelligence"
      },
      {
        "text": "AI winter",
        "url": "https://en.wikipedia.org/wiki/AI_winter",
        "title": "AI winter"
      },
      {
        "text": "AI boom",
        "url": "https://en.wikipedia.org/wiki/AI_boom",
        "title": "AI boom"
      },
      {
        "text": "Glossary",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_artificial_intelligence",
        "title": "Glossary of artificial intelligence"
      },
      {
        "text": "v",
        "url": "https://en.wikipedia.org/wiki/Template:Artificial_intelligence",
        "title": "Template:Artificial intelligence"
      },
      {
        "text": "t",
        "url": "https://en.wikipedia.org/wiki/Template_talk:Artificial_intelligence",
        "title": "Template talk:Artificial intelligence"
      },
      {
        "text": "e",
        "url": "https://en.wikipedia.org/wiki/Special:EditPage/Template:Artificial_intelligence",
        "title": "Special:EditPage/Template:Artificial intelligence"
      },
      {
        "text": "computational systems",
        "url": "https://en.wikipedia.org/wiki/Computer",
        "title": "Computer"
      },
      {
        "text": "human intelligence",
        "url": "https://en.wikipedia.org/wiki/Human_intelligence",
        "title": "Human intelligence"
      },
      {
        "text": "field of research",
        "url": "https://en.wikipedia.org/wiki/Field_of_research",
        "title": "Field of research"
      },
      {
        "text": "computer science",
        "url": "https://en.wikipedia.org/wiki/Computer_science",
        "title": "Computer science"
      },
      {
        "text": "software",
        "url": "https://en.wikipedia.org/wiki/Software",
        "title": "Software"
      },
      {
        "text": "perceive their environment",
        "url": "https://en.wikipedia.org/wiki/Machine_perception",
        "title": "Machine perception"
      },
      {
        "text": "learning",
        "url": "https://en.wikipedia.org/wiki/Machine_learning",
        "title": "Machine learning"
      },
      {
        "text": "intelligence",
        "url": "https://en.wikipedia.org/wiki/Intelligence",
        "title": "Intelligence"
      },
      {
        "text": "[1]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig20211–4-1"
      },
      {
        "text": "applications of AI",
        "url": "https://en.wikipedia.org/wiki/Applications_of_AI",
        "title": "Applications of AI"
      },
      {
        "text": "web search engines",
        "url": "https://en.wikipedia.org/wiki/Web_search_engine",
        "title": "Web search engine"
      },
      {
        "text": "Google Search",
        "url": "https://en.wikipedia.org/wiki/Google_Search",
        "title": "Google Search"
      },
      {
        "text": "recommendation systems",
        "url": "https://en.wikipedia.org/wiki/Recommendation_systems",
        "title": "Recommendation systems"
      },
      {
        "text": "YouTube",
        "url": "https://en.wikipedia.org/wiki/YouTube",
        "title": "YouTube"
      },
      {
        "text": "Amazon",
        "url": "https://en.wikipedia.org/wiki/Amazon_(company)",
        "title": "Amazon (company)"
      },
      {
        "text": "Netflix",
        "url": "https://en.wikipedia.org/wiki/Netflix",
        "title": "Netflix"
      },
      {
        "text": "virtual assistants",
        "url": "https://en.wikipedia.org/wiki/Virtual_assistant",
        "title": "Virtual assistant"
      },
      {
        "text": "Google Assistant",
        "url": "https://en.wikipedia.org/wiki/Google_Assistant",
        "title": "Google Assistant"
      },
      {
        "text": "Siri",
        "url": "https://en.wikipedia.org/wiki/Siri",
        "title": "Siri"
      },
      {
        "text": "Alexa",
        "url": "https://en.wikipedia.org/wiki/Amazon_Alexa",
        "title": "Amazon Alexa"
      },
      {
        "text": "autonomous vehicles",
        "url": "https://en.wikipedia.org/wiki/Autonomous_vehicles",
        "title": "Autonomous vehicles"
      },
      {
        "text": "Waymo",
        "url": "https://en.wikipedia.org/wiki/Waymo",
        "title": "Waymo"
      },
      {
        "text": "generative",
        "url": "https://en.wikipedia.org/wiki/Generative_artificial_intelligence",
        "title": "Generative artificial intelligence"
      },
      {
        "text": "creative",
        "url": "https://en.wikipedia.org/wiki/Computational_creativity",
        "title": "Computational creativity"
      },
      {
        "text": "ChatGPT",
        "url": "https://en.wikipedia.org/wiki/ChatGPT",
        "title": "ChatGPT"
      },
      {
        "text": "AI art",
        "url": "https://en.wikipedia.org/wiki/AI_art",
        "title": "AI art"
      },
      {
        "text": "superhuman",
        "url": "https://en.wikipedia.org/wiki/Superintelligence",
        "title": "Superintelligence"
      },
      {
        "text": "strategy games",
        "url": "https://en.wikipedia.org/wiki/Strategy_game",
        "title": "Strategy game"
      },
      {
        "text": "chess",
        "url": "https://en.wikipedia.org/wiki/Chess",
        "title": "Chess"
      },
      {
        "text": "Go",
        "url": "https://en.wikipedia.org/wiki/Go_(game)",
        "title": "Go (game)"
      },
      {
        "text": "not labeled AI anymore",
        "url": "https://en.wikipedia.org/wiki/AI_effect",
        "title": "AI effect"
      },
      {
        "text": "[2]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-2"
      },
      {
        "text": "[3]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-3"
      },
      {
        "text": "reasoning",
        "url": "https://en.wikipedia.org/wiki/Automated_reasoning",
        "title": "Automated reasoning"
      },
      {
        "text": "knowledge representation",
        "url": "https://en.wikipedia.org/wiki/Knowledge_representation",
        "title": "Knowledge representation"
      },
      {
        "text": "planning",
        "url": "https://en.wikipedia.org/wiki/Automated_planning_and_scheduling",
        "title": "Automated planning and scheduling"
      },
      {
        "text": "natural language processing",
        "url": "https://en.wikipedia.org/wiki/Natural_language_processing",
        "title": "Natural language processing"
      },
      {
        "text": "perception",
        "url": "https://en.wikipedia.org/wiki/Machine_perception",
        "title": "Machine perception"
      },
      {
        "text": "robotics",
        "url": "https://en.wikipedia.org/wiki/Robotics",
        "title": "Robotics"
      },
      {
        "text": "[a]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Problems_of_AI-4"
      },
      {
        "text": "General intelligence",
        "url": "https://en.wikipedia.org/wiki/Artificial_general_intelligence",
        "title": "Artificial general intelligence"
      },
      {
        "text": "[4]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Artificial_general_intelligence-5"
      },
      {
        "text": "search",
        "url": "https://en.wikipedia.org/wiki/State_space_search",
        "title": "State space search"
      },
      {
        "text": "mathematical optimization",
        "url": "https://en.wikipedia.org/wiki/Mathematical_optimization",
        "title": "Mathematical optimization"
      },
      {
        "text": "formal logic",
        "url": "https://en.wikipedia.org/wiki/Formal_logic",
        "title": "Formal logic"
      },
      {
        "text": "artificial neural networks",
        "url": "https://en.wikipedia.org/wiki/Artificial_neural_network",
        "title": "Artificial neural network"
      },
      {
        "text": "statistics",
        "url": "https://en.wikipedia.org/wiki/Statistics",
        "title": "Statistics"
      },
      {
        "text": "operations research",
        "url": "https://en.wikipedia.org/wiki/Operations_research",
        "title": "Operations research"
      },
      {
        "text": "economics",
        "url": "https://en.wikipedia.org/wiki/Economics",
        "title": "Economics"
      },
      {
        "text": "[b]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Tools_of_AI-6"
      },
      {
        "text": "psychology",
        "url": "https://en.wikipedia.org/wiki/Psychology",
        "title": "Psychology"
      },
      {
        "text": "linguistics",
        "url": "https://en.wikipedia.org/wiki/Linguistics",
        "title": "Linguistics"
      },
      {
        "text": "philosophy",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_artificial_intelligence",
        "title": "Philosophy of artificial intelligence"
      },
      {
        "text": "neuroscience",
        "url": "https://en.wikipedia.org/wiki/Neuroscience",
        "title": "Neuroscience"
      },
      {
        "text": "[5]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-7"
      },
      {
        "text": "[6]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Dartmouth_workshop-8"
      },
      {
        "text": "its history",
        "url": "https://en.wikipedia.org/wiki/History_of_artificial_intelligence",
        "title": "History of artificial intelligence"
      },
      {
        "text": "[7]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Succ1-9"
      },
      {
        "text": "[8]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Fund01-10"
      },
      {
        "text": "AI winters",
        "url": "https://en.wikipedia.org/wiki/AI_winter",
        "title": "AI winter"
      },
      {
        "text": "[9]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-First_AI_Winter-11"
      },
      {
        "text": "[10]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Second_AI_Winter-12"
      },
      {
        "text": "deep learning",
        "url": "https://en.wikipedia.org/wiki/Deep_learning",
        "title": "Deep learning"
      },
      {
        "text": "[11]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Deep_learning_revolution-13"
      },
      {
        "text": "transformer architecture",
        "url": "https://en.wikipedia.org/wiki/Transformer_architecture",
        "title": "Transformer architecture"
      },
      {
        "text": "[12]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEToews2023-14"
      },
      {
        "text": "progress",
        "url": "https://en.wikipedia.org/wiki/Progress_in_artificial_intelligence",
        "title": "Progress in artificial intelligence"
      },
      {
        "text": "AI boom",
        "url": "https://en.wikipedia.org/wiki/AI_boom",
        "title": "AI boom"
      },
      {
        "text": "risks of AI",
        "url": "https://en.wikipedia.org/wiki/AI_risk",
        "title": "AI risk"
      },
      {
        "text": "its long-term effects",
        "url": "https://en.wikipedia.org/wiki/AI_aftermath_scenarios",
        "title": "AI aftermath scenarios"
      },
      {
        "text": "regulatory policies",
        "url": "https://en.wikipedia.org/wiki/Regulation_of_artificial_intelligence",
        "title": "Regulation of artificial intelligence"
      },
      {
        "text": "safety and benefits of the technology",
        "url": "https://en.wikipedia.org/wiki/AI_safety",
        "title": "AI safety"
      },
      {
        "text": "[a]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Problems_of_AI-4"
      },
      {
        "text": "deductions",
        "url": "https://en.wikipedia.org/wiki/Deductive_reasoning",
        "title": "Deductive reasoning"
      },
      {
        "text": "[13]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-15"
      },
      {
        "text": "uncertain",
        "url": "https://en.wikipedia.org/wiki/Uncertainty",
        "title": "Uncertainty"
      },
      {
        "text": "probability",
        "url": "https://en.wikipedia.org/wiki/Probability",
        "title": "Probability"
      },
      {
        "text": "economics",
        "url": "https://en.wikipedia.org/wiki/Economics",
        "title": "Economics"
      },
      {
        "text": "[14]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-16"
      },
      {
        "text": "[15]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Intractability_and_efficiency_and_the_combinatorial_explosion-17"
      },
      {
        "text": "[16]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Psychological_evidence_of_the_prevalence_of_sub-18"
      },
      {
        "text": "Knowledge representation",
        "url": "https://en.wikipedia.org/wiki/Knowledge_representation",
        "title": "Knowledge representation"
      },
      {
        "text": "knowledge engineering",
        "url": "https://en.wikipedia.org/wiki/Knowledge_engineering",
        "title": "Knowledge engineering"
      },
      {
        "text": "[17]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-19"
      },
      {
        "text": "[18]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTESmoliarZhang1994-20"
      },
      {
        "text": "[19]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTENeumannMöller2008-21"
      },
      {
        "text": "[20]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEKupermanReichleyBailey2006-22"
      },
      {
        "text": "databases",
        "url": "https://en.wikipedia.org/wiki/Database",
        "title": "Database"
      },
      {
        "text": "[21]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEMcGarry2005-23"
      },
      {
        "text": "[22]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEBertiniDel_BimboTorniai2006-24"
      },
      {
        "text": "knowledge base",
        "url": "https://en.wikipedia.org/wiki/Knowledge_base",
        "title": "Knowledge base"
      },
      {
        "text": "ontology",
        "url": "https://en.wikipedia.org/wiki/Ontology_(information_science)",
        "title": "Ontology (information science)"
      },
      {
        "text": "[23]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021272-25"
      },
      {
        "text": "[24]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-26"
      },
      {
        "text": "[25]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-27"
      },
      {
        "text": "[26]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-28"
      },
      {
        "text": "[27]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-29"
      },
      {
        "text": "default reasoning",
        "url": "https://en.wikipedia.org/wiki/Default_reasoning",
        "title": "Default reasoning"
      },
      {
        "text": "[28]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Default_reasoning-30"
      },
      {
        "text": "[29]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Breadth_of_commonsense_knowledge-31"
      },
      {
        "text": "[16]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Psychological_evidence_of_the_prevalence_of_sub-18"
      },
      {
        "text": "knowledge acquisition",
        "url": "https://en.wikipedia.org/wiki/Knowledge_acquisition",
        "title": "Knowledge acquisition"
      },
      {
        "text": "[c]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-34"
      },
      {
        "text": "rational agent",
        "url": "https://en.wikipedia.org/wiki/Rational_agent",
        "title": "Rational agent"
      },
      {
        "text": "[d]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-35"
      },
      {
        "text": "[32]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021528-36"
      },
      {
        "text": "automated planning",
        "url": "https://en.wikipedia.org/wiki/Automated_planning",
        "title": "Automated planning"
      },
      {
        "text": "[33]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-37"
      },
      {
        "text": "automated decision-making",
        "url": "https://en.wikipedia.org/wiki/Automated_decision-making",
        "title": "Automated decision-making"
      },
      {
        "text": "utility",
        "url": "https://en.wikipedia.org/wiki/Utility",
        "title": "Utility"
      },
      {
        "text": "expected utility",
        "url": "https://en.wikipedia.org/wiki/Expected_utility",
        "title": "Expected utility"
      },
      {
        "text": "utility",
        "url": "https://en.wikipedia.org/wiki/Utility",
        "title": "Utility"
      },
      {
        "text": "[34]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-38"
      },
      {
        "text": "classical planning",
        "url": "https://en.wikipedia.org/wiki/Automated_planning_and_scheduling#classical_planning",
        "title": "Automated planning and scheduling"
      },
      {
        "text": "[35]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-39"
      },
      {
        "text": "[36]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-40"
      },
      {
        "text": "inverse reinforcement learning",
        "url": "https://en.wikipedia.org/wiki/Inverse_reinforcement_learning",
        "title": "Inverse reinforcement learning"
      },
      {
        "text": "[37]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-41"
      },
      {
        "text": "Information value theory",
        "url": "https://en.wikipedia.org/wiki/Information_value_theory",
        "title": "Information value theory"
      },
      {
        "text": "[38]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-42"
      },
      {
        "text": "intractably",
        "url": "https://en.wikipedia.org/wiki/Intractably",
        "title": "Intractably"
      },
      {
        "text": "Markov decision process",
        "url": "https://en.wikipedia.org/wiki/Markov_decision_process",
        "title": "Markov decision process"
      },
      {
        "text": "transition model",
        "url": "https://en.wikipedia.org/wiki/Finite-state_machine",
        "title": "Finite-state machine"
      },
      {
        "text": "reward function",
        "url": "https://en.wikipedia.org/wiki/Reward_function",
        "title": "Reward function"
      },
      {
        "text": "policy",
        "url": "https://en.wikipedia.org/wiki/Reinforcement_learning#Policy",
        "title": "Reinforcement learning"
      },
      {
        "text": "iteration",
        "url": "https://en.wikipedia.org/wiki/Policy_iteration",
        "title": "Policy iteration"
      },
      {
        "text": "heuristic",
        "url": "https://en.wikipedia.org/wiki/Heuristic",
        "title": "Heuristic"
      },
      {
        "text": "[39]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-43"
      },
      {
        "text": "Game theory",
        "url": "https://en.wikipedia.org/wiki/Game_theory",
        "title": "Game theory"
      },
      {
        "text": "[40]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-44"
      },
      {
        "text": "Machine learning",
        "url": "https://en.wikipedia.org/wiki/Machine_learning",
        "title": "Machine learning"
      },
      {
        "text": "[41]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-45"
      },
      {
        "text": "[e]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-48"
      },
      {
        "text": "Unsupervised learning",
        "url": "https://en.wikipedia.org/wiki/Unsupervised_learning",
        "title": "Unsupervised learning"
      },
      {
        "text": "[44]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-49"
      },
      {
        "text": "Supervised learning",
        "url": "https://en.wikipedia.org/wiki/Supervised_learning",
        "title": "Supervised learning"
      },
      {
        "text": "classification",
        "url": "https://en.wikipedia.org/wiki/Statistical_classification",
        "title": "Statistical classification"
      },
      {
        "text": "regression",
        "url": "https://en.wikipedia.org/wiki/Regression_analysis",
        "title": "Regression analysis"
      },
      {
        "text": "[45]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Supervised_learning-50"
      },
      {
        "text": "reinforcement learning",
        "url": "https://en.wikipedia.org/wiki/Reinforcement_learning",
        "title": "Reinforcement learning"
      },
      {
        "text": "[46]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-51"
      },
      {
        "text": "Transfer learning",
        "url": "https://en.wikipedia.org/wiki/Transfer_learning",
        "title": "Transfer learning"
      },
      {
        "text": "[47]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-52"
      },
      {
        "text": "Deep learning",
        "url": "https://en.wikipedia.org/wiki/Deep_learning",
        "title": "Deep learning"
      },
      {
        "text": "artificial neural networks",
        "url": "https://en.wikipedia.org/wiki/Artificial_neural_networks",
        "title": "Artificial neural networks"
      },
      {
        "text": "[48]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-53"
      },
      {
        "text": "Computational learning theory",
        "url": "https://en.wikipedia.org/wiki/Computational_learning_theory",
        "title": "Computational learning theory"
      },
      {
        "text": "computational complexity",
        "url": "https://en.wikipedia.org/wiki/Computational_complexity",
        "title": "Computational complexity"
      },
      {
        "text": "sample complexity",
        "url": "https://en.wikipedia.org/wiki/Sample_complexity",
        "title": "Sample complexity"
      },
      {
        "text": "optimization",
        "url": "https://en.wikipedia.org/wiki/Optimization",
        "title": "Optimization"
      },
      {
        "text": "[49]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-54"
      },
      {
        "text": "Natural language processing",
        "url": "https://en.wikipedia.org/wiki/Natural_language_processing",
        "title": "Natural language processing"
      },
      {
        "text": "[50]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-55"
      },
      {
        "text": "English",
        "url": "https://en.wikipedia.org/wiki/English_(language)",
        "title": "English (language)"
      },
      {
        "text": "speech recognition",
        "url": "https://en.wikipedia.org/wiki/Speech_recognition",
        "title": "Speech recognition"
      },
      {
        "text": "speech synthesis",
        "url": "https://en.wikipedia.org/wiki/Speech_synthesis",
        "title": "Speech synthesis"
      },
      {
        "text": "machine translation",
        "url": "https://en.wikipedia.org/wiki/Machine_translation",
        "title": "Machine translation"
      },
      {
        "text": "information extraction",
        "url": "https://en.wikipedia.org/wiki/Information_extraction",
        "title": "Information extraction"
      },
      {
        "text": "information retrieval",
        "url": "https://en.wikipedia.org/wiki/Information_retrieval",
        "title": "Information retrieval"
      },
      {
        "text": "question answering",
        "url": "https://en.wikipedia.org/wiki/Question_answering",
        "title": "Question answering"
      },
      {
        "text": "[51]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-56"
      },
      {
        "text": "Noam Chomsky",
        "url": "https://en.wikipedia.org/wiki/Noam_Chomsky",
        "title": "Noam Chomsky"
      },
      {
        "text": "generative grammar",
        "url": "https://en.wikipedia.org/wiki/Generative_grammar",
        "title": "Generative grammar"
      },
      {
        "text": "semantic networks",
        "url": "https://en.wikipedia.org/wiki/Semantic_network",
        "title": "Semantic network"
      },
      {
        "text": "word-sense disambiguation",
        "url": "https://en.wikipedia.org/wiki/Word-sense_disambiguation",
        "title": "Word-sense disambiguation"
      },
      {
        "text": "[f]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-57"
      },
      {
        "text": "micro-worlds",
        "url": "https://en.wikipedia.org/wiki/Blocks_world",
        "title": "Blocks world"
      },
      {
        "text": "[29]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Breadth_of_commonsense_knowledge-31"
      },
      {
        "text": "Margaret Masterman",
        "url": "https://en.wikipedia.org/wiki/Margaret_Masterman",
        "title": "Margaret Masterman"
      },
      {
        "text": "thesauri",
        "url": "https://en.wikipedia.org/wiki/Thesauri",
        "title": "Thesauri"
      },
      {
        "text": "word embedding",
        "url": "https://en.wikipedia.org/wiki/Word_embedding",
        "title": "Word embedding"
      },
      {
        "text": "vectors",
        "url": "https://en.wikipedia.org/wiki/Vector_space",
        "title": "Vector space"
      },
      {
        "text": "[52]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021856–858-58"
      },
      {
        "text": "transformers",
        "url": "https://en.wikipedia.org/wiki/Transformer_(machine_learning_model)",
        "title": "Transformer (machine learning model)"
      },
      {
        "text": "attention",
        "url": "https://en.wikipedia.org/wiki/Attention_(machine_learning)",
        "title": "Attention (machine learning)"
      },
      {
        "text": "[53]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEDickson2022-59"
      },
      {
        "text": "[54]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-60"
      },
      {
        "text": "generative pre-trained transformer",
        "url": "https://en.wikipedia.org/wiki/Generative_pre-trained_transformer",
        "title": "Generative pre-trained transformer"
      },
      {
        "text": "[55]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEVincent2019-61"
      },
      {
        "text": "[56]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021875–878-62"
      },
      {
        "text": "bar exam",
        "url": "https://en.wikipedia.org/wiki/Bar_exam",
        "title": "Bar exam"
      },
      {
        "text": "SAT",
        "url": "https://en.wikipedia.org/wiki/SAT",
        "title": "SAT"
      },
      {
        "text": "GRE",
        "url": "https://en.wikipedia.org/wiki/GRE",
        "title": "GRE"
      },
      {
        "text": "[57]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEBushwick2023-63"
      },
      {
        "text": "Machine perception",
        "url": "https://en.wikipedia.org/wiki/Machine_perception",
        "title": "Machine perception"
      },
      {
        "text": "lidar",
        "url": "https://en.wikipedia.org/wiki/Lidar",
        "title": "Lidar"
      },
      {
        "text": "tactile sensors",
        "url": "https://en.wikipedia.org/wiki/Tactile_sensor",
        "title": "Tactile sensor"
      },
      {
        "text": "Computer vision",
        "url": "https://en.wikipedia.org/wiki/Computer_vision",
        "title": "Computer vision"
      },
      {
        "text": "[58]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-64"
      },
      {
        "text": "speech recognition",
        "url": "https://en.wikipedia.org/wiki/Speech_recognition",
        "title": "Speech recognition"
      },
      {
        "text": "[59]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021849–850-65"
      },
      {
        "text": "image classification",
        "url": "https://en.wikipedia.org/wiki/Image_classification",
        "title": "Image classification"
      },
      {
        "text": "[60]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021895–899-66"
      },
      {
        "text": "facial recognition",
        "url": "https://en.wikipedia.org/wiki/Facial_recognition_system",
        "title": "Facial recognition system"
      },
      {
        "text": "object recognition",
        "url": "https://en.wikipedia.org/wiki/Object_recognition",
        "title": "Object recognition"
      },
      {
        "text": "[61]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021899–901-67"
      },
      {
        "text": "object tracking",
        "url": "https://en.wikipedia.org/wiki/Motion_capture",
        "title": "Motion capture"
      },
      {
        "text": "[62]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEChallaMorelandMušickiEvans2011-68"
      },
      {
        "text": "robotic perception",
        "url": "https://en.wikipedia.org/wiki/Robotic_perception",
        "title": "Robotic perception"
      },
      {
        "text": "[63]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021931–938-69"
      },
      {
        "text": "Kismet",
        "url": "https://en.wikipedia.org/wiki/Kismet_(robot)",
        "title": "Kismet (robot)"
      },
      {
        "text": "[64]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEMIT_AIL2014-70"
      },
      {
        "text": "Affective computing",
        "url": "https://en.wikipedia.org/wiki/Affective_computing",
        "title": "Affective computing"
      },
      {
        "text": "feeling, emotion, and mood",
        "url": "https://en.wikipedia.org/wiki/Affect_(psychology)",
        "title": "Affect (psychology)"
      },
      {
        "text": "[65]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-71"
      },
      {
        "text": "virtual assistants",
        "url": "https://en.wikipedia.org/wiki/Virtual_assistant",
        "title": "Virtual assistant"
      },
      {
        "text": "human–computer interaction",
        "url": "https://en.wikipedia.org/wiki/Human%E2%80%93computer_interaction",
        "title": "Human–computer interaction"
      },
      {
        "text": "[66]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEWaddell2018-72"
      },
      {
        "text": "sentiment analysis",
        "url": "https://en.wikipedia.org/wiki/Sentiment_analysis",
        "title": "Sentiment analysis"
      },
      {
        "text": "multimodal sentiment analysis",
        "url": "https://en.wikipedia.org/wiki/Multimodal_sentiment_analysis",
        "title": "Multimodal sentiment analysis"
      },
      {
        "text": "[67]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEPoriaCambriaBajpaiHussain2017-73"
      },
      {
        "text": "artificial general intelligence",
        "url": "https://en.wikipedia.org/wiki/Artificial_general_intelligence",
        "title": "Artificial general intelligence"
      },
      {
        "text": "human intelligence",
        "url": "https://en.wikipedia.org/wiki/Human_intelligence",
        "title": "Human intelligence"
      },
      {
        "text": "[4]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Artificial_general_intelligence-5"
      },
      {
        "text": "[b]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Tools_of_AI-6"
      },
      {
        "text": "[68]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-74"
      },
      {
        "text": "state space search",
        "url": "https://en.wikipedia.org/wiki/State_space_search",
        "title": "State space search"
      },
      {
        "text": "local search",
        "url": "https://en.wikipedia.org/wiki/Local_search_(optimization)",
        "title": "Local search (optimization)"
      },
      {
        "text": "State space search",
        "url": "https://en.wikipedia.org/wiki/State_space_search",
        "title": "State space search"
      },
      {
        "text": "[69]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-75"
      },
      {
        "text": "planning",
        "url": "https://en.wikipedia.org/wiki/Automated_planning_and_scheduling",
        "title": "Automated planning and scheduling"
      },
      {
        "text": "means-ends analysis",
        "url": "https://en.wikipedia.org/wiki/Means-ends_analysis",
        "title": "Means-ends analysis"
      },
      {
        "text": "[70]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021sect._11.2-76"
      },
      {
        "text": "Simple exhaustive searches",
        "url": "https://en.wikipedia.org/wiki/Brute_force_search",
        "title": "Brute force search"
      },
      {
        "text": "[71]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-77"
      },
      {
        "text": "search space",
        "url": "https://en.wikipedia.org/wiki/Search_algorithm",
        "title": "Search algorithm"
      },
      {
        "text": "astronomical numbers",
        "url": "https://en.wikipedia.org/wiki/Astronomically_large",
        "title": "Astronomically large"
      },
      {
        "text": "too slow",
        "url": "https://en.wikipedia.org/wiki/Computation_time",
        "title": "Computation time"
      },
      {
        "text": "[15]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Intractability_and_efficiency_and_the_combinatorial_explosion-17"
      },
      {
        "text": "Heuristics",
        "url": "https://en.wikipedia.org/wiki/Heuristics",
        "title": "Heuristics"
      },
      {
        "text": "[72]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-78"
      },
      {
        "text": "Adversarial search",
        "url": "https://en.wikipedia.org/wiki/Adversarial_search",
        "title": "Adversarial search"
      },
      {
        "text": "game-playing",
        "url": "https://en.wikipedia.org/wiki/Game_AI",
        "title": "Game AI"
      },
      {
        "text": "tree",
        "url": "https://en.wikipedia.org/wiki/Game_tree",
        "title": "Game tree"
      },
      {
        "text": "[73]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-79"
      },
      {
        "text": "gradient descent",
        "url": "https://en.wikipedia.org/wiki/Gradient_descent",
        "title": "Gradient descent"
      },
      {
        "text": "loss function",
        "url": "https://en.wikipedia.org/wiki/Loss_function",
        "title": "Loss function"
      },
      {
        "text": "Local search",
        "url": "https://en.wikipedia.org/wiki/Local_search_(optimization)",
        "title": "Local search (optimization)"
      },
      {
        "text": "mathematical optimization",
        "url": "https://en.wikipedia.org/wiki/Mathematical_optimization",
        "title": "Mathematical optimization"
      },
      {
        "text": "[74]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-80"
      },
      {
        "text": "Gradient descent",
        "url": "https://en.wikipedia.org/wiki/Gradient_descent",
        "title": "Gradient descent"
      },
      {
        "text": "loss function",
        "url": "https://en.wikipedia.org/wiki/Loss_function",
        "title": "Loss function"
      },
      {
        "text": "neural networks",
        "url": "https://en.wikipedia.org/wiki/Artificial_neural_network",
        "title": "Artificial neural network"
      },
      {
        "text": "[75]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-81"
      },
      {
        "text": "backpropagation",
        "url": "https://en.wikipedia.org/wiki/Backpropagation",
        "title": "Backpropagation"
      },
      {
        "text": "evolutionary computation",
        "url": "https://en.wikipedia.org/wiki/Evolutionary_computation",
        "title": "Evolutionary computation"
      },
      {
        "text": "selecting",
        "url": "https://en.wikipedia.org/wiki/Artificial_selection",
        "title": "Artificial selection"
      },
      {
        "text": "[76]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-82"
      },
      {
        "text": "swarm intelligence",
        "url": "https://en.wikipedia.org/wiki/Swarm_intelligence",
        "title": "Swarm intelligence"
      },
      {
        "text": "particle swarm optimization",
        "url": "https://en.wikipedia.org/wiki/Particle_swarm_optimization",
        "title": "Particle swarm optimization"
      },
      {
        "text": "flocking",
        "url": "https://en.wikipedia.org/wiki/Flocking",
        "title": "Flocking"
      },
      {
        "text": "ant colony optimization",
        "url": "https://en.wikipedia.org/wiki/Ant_colony_optimization",
        "title": "Ant colony optimization"
      },
      {
        "text": "ant trails",
        "url": "https://en.wikipedia.org/wiki/Ant_trail",
        "title": "Ant trail"
      },
      {
        "text": "[77]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEMerkleMiddendorf2013-83"
      },
      {
        "text": "logic",
        "url": "https://en.wikipedia.org/wiki/Logic",
        "title": "Logic"
      },
      {
        "text": "reasoning",
        "url": "https://en.wikipedia.org/wiki/Automatic_reasoning",
        "title": "Automatic reasoning"
      },
      {
        "text": "knowledge representation",
        "url": "https://en.wikipedia.org/wiki/Knowledge_representation",
        "title": "Knowledge representation"
      },
      {
        "text": "[78]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-84"
      },
      {
        "text": "propositional logic",
        "url": "https://en.wikipedia.org/wiki/Propositional_logic",
        "title": "Propositional logic"
      },
      {
        "text": "logical connectives",
        "url": "https://en.wikipedia.org/wiki/Logical_connective",
        "title": "Logical connective"
      },
      {
        "text": "[79]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-85"
      },
      {
        "text": "predicate logic",
        "url": "https://en.wikipedia.org/wiki/Predicate_logic",
        "title": "Predicate logic"
      },
      {
        "text": "quantifiers",
        "url": "https://en.wikipedia.org/wiki/Quantifier_(logic)",
        "title": "Quantifier (logic)"
      },
      {
        "text": "[80]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-86"
      },
      {
        "text": "Deductive reasoning",
        "url": "https://en.wikipedia.org/wiki/Deductive_reasoning",
        "title": "Deductive reasoning"
      },
      {
        "text": "proving",
        "url": "https://en.wikipedia.org/wiki/Logical_proof",
        "title": "Logical proof"
      },
      {
        "text": "conclusion",
        "url": "https://en.wikipedia.org/wiki/Logical_consequence",
        "title": "Logical consequence"
      },
      {
        "text": "premises",
        "url": "https://en.wikipedia.org/wiki/Premise",
        "title": "Premise"
      },
      {
        "text": "[81]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-87"
      },
      {
        "text": "trees",
        "url": "https://en.wikipedia.org/wiki/Tree_structure",
        "title": "Tree structure"
      },
      {
        "text": "inference rules",
        "url": "https://en.wikipedia.org/wiki/Inference_rule",
        "title": "Inference rule"
      },
      {
        "text": "leaf nodes",
        "url": "https://en.wikipedia.org/wiki/Leaf_nodes",
        "title": "Leaf nodes"
      },
      {
        "text": "axioms",
        "url": "https://en.wikipedia.org/wiki/Axiom",
        "title": "Axiom"
      },
      {
        "text": "Horn clauses",
        "url": "https://en.wikipedia.org/wiki/Horn_clause",
        "title": "Horn clause"
      },
      {
        "text": "forwards",
        "url": "https://en.wikipedia.org/wiki/Forward_chaining",
        "title": "Forward chaining"
      },
      {
        "text": "backwards",
        "url": "https://en.wikipedia.org/wiki/Backward_chaining",
        "title": "Backward chaining"
      },
      {
        "text": "[82]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-88"
      },
      {
        "text": "first-order logic",
        "url": "https://en.wikipedia.org/wiki/First-order_logic",
        "title": "First-order logic"
      },
      {
        "text": "resolution",
        "url": "https://en.wikipedia.org/wiki/Resolution_(logic)",
        "title": "Resolution (logic)"
      },
      {
        "text": "[83]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-89"
      },
      {
        "text": "undecidable",
        "url": "https://en.wikipedia.org/wiki/Undecidable_problem",
        "title": "Undecidable problem"
      },
      {
        "text": "intractable",
        "url": "https://en.wikipedia.org/wiki/Intractable_problem",
        "title": "Intractable problem"
      },
      {
        "text": "logic programming",
        "url": "https://en.wikipedia.org/wiki/Logic_programming",
        "title": "Logic programming"
      },
      {
        "text": "Prolog",
        "url": "https://en.wikipedia.org/wiki/Prolog",
        "title": "Prolog"
      },
      {
        "text": "Turing complete",
        "url": "https://en.wikipedia.org/wiki/Turing_complete",
        "title": "Turing complete"
      },
      {
        "text": "symbolic programming",
        "url": "https://en.wikipedia.org/wiki/Symbolic_programming",
        "title": "Symbolic programming"
      },
      {
        "text": "[84]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-90"
      },
      {
        "text": "Fuzzy logic",
        "url": "https://en.wikipedia.org/wiki/Fuzzy_logic",
        "title": "Fuzzy logic"
      },
      {
        "text": "[85]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-91"
      },
      {
        "text": "Non-monotonic logics",
        "url": "https://en.wikipedia.org/wiki/Non-monotonic_logic",
        "title": "Non-monotonic logic"
      },
      {
        "text": "negation as failure",
        "url": "https://en.wikipedia.org/wiki/Negation_as_failure",
        "title": "Negation as failure"
      },
      {
        "text": "default reasoning",
        "url": "https://en.wikipedia.org/wiki/Default_reasoning",
        "title": "Default reasoning"
      },
      {
        "text": "[28]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Default_reasoning-30"
      },
      {
        "text": "Bayesian network",
        "url": "https://en.wikipedia.org/wiki/Bayesian_network",
        "title": "Bayesian network"
      },
      {
        "text": "conditional probability tables",
        "url": "https://en.wikipedia.org/wiki/Conditional_probability_table",
        "title": "Conditional probability table"
      },
      {
        "text": "probability",
        "url": "https://en.wikipedia.org/wiki/Probability",
        "title": "Probability"
      },
      {
        "text": "[86]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Stoch-92"
      },
      {
        "text": "decision theory",
        "url": "https://en.wikipedia.org/wiki/Decision_theory",
        "title": "Decision theory"
      },
      {
        "text": "decision analysis",
        "url": "https://en.wikipedia.org/wiki/Decision_analysis",
        "title": "Decision analysis"
      },
      {
        "text": "[87]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-93"
      },
      {
        "text": "information value theory",
        "url": "https://en.wikipedia.org/wiki/Information_value_theory",
        "title": "Information value theory"
      },
      {
        "text": "[88]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-94"
      },
      {
        "text": "Markov decision processes",
        "url": "https://en.wikipedia.org/wiki/Markov_decision_process",
        "title": "Markov decision process"
      },
      {
        "text": "[89]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-95"
      },
      {
        "text": "decision networks",
        "url": "https://en.wikipedia.org/wiki/Decision_network",
        "title": "Decision network"
      },
      {
        "text": "[90]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Stochastic_temporal_models-96"
      },
      {
        "text": "game theory",
        "url": "https://en.wikipedia.org/wiki/Game_theory",
        "title": "Game theory"
      },
      {
        "text": "mechanism design",
        "url": "https://en.wikipedia.org/wiki/Mechanism_design",
        "title": "Mechanism design"
      },
      {
        "text": "[91]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-97"
      },
      {
        "text": "Bayesian networks",
        "url": "https://en.wikipedia.org/wiki/Bayesian_network",
        "title": "Bayesian network"
      },
      {
        "text": "[92]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-98"
      },
      {
        "text": "reasoning",
        "url": "https://en.wikipedia.org/wiki/Automated_reasoning",
        "title": "Automated reasoning"
      },
      {
        "text": "Bayesian inference",
        "url": "https://en.wikipedia.org/wiki/Bayesian_inference",
        "title": "Bayesian inference"
      },
      {
        "text": "[g]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-100"
      },
      {
        "text": "[94]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-101"
      },
      {
        "text": "learning",
        "url": "https://en.wikipedia.org/wiki/Machine_learning",
        "title": "Machine learning"
      },
      {
        "text": "expectation–maximization algorithm",
        "url": "https://en.wikipedia.org/wiki/Expectation%E2%80%93maximization_algorithm",
        "title": "Expectation–maximization algorithm"
      },
      {
        "text": "[h]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-103"
      },
      {
        "text": "[96]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-104"
      },
      {
        "text": "planning",
        "url": "https://en.wikipedia.org/wiki/Automated_planning_and_scheduling",
        "title": "Automated planning and scheduling"
      },
      {
        "text": "decision networks",
        "url": "https://en.wikipedia.org/wiki/Decision_network",
        "title": "Decision network"
      },
      {
        "text": "[97]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-105"
      },
      {
        "text": "perception",
        "url": "https://en.wikipedia.org/wiki/Machine_perception",
        "title": "Machine perception"
      },
      {
        "text": "dynamic Bayesian networks",
        "url": "https://en.wikipedia.org/wiki/Dynamic_Bayesian_network",
        "title": "Dynamic Bayesian network"
      },
      {
        "text": "[90]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Stochastic_temporal_models-96"
      },
      {
        "text": "hidden Markov models",
        "url": "https://en.wikipedia.org/wiki/Hidden_Markov_model",
        "title": "Hidden Markov model"
      },
      {
        "text": "Kalman filters",
        "url": "https://en.wikipedia.org/wiki/Kalman_filter",
        "title": "Kalman filter"
      },
      {
        "text": "[90]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Stochastic_temporal_models-96"
      },
      {
        "text": "Expectation–maximization",
        "url": "https://en.wikipedia.org/wiki/Expectation%E2%80%93maximization_algorithm",
        "title": "Expectation–maximization algorithm"
      },
      {
        "text": "clustering",
        "url": "https://en.wikipedia.org/wiki/Cluster_analysis",
        "title": "Cluster analysis"
      },
      {
        "text": "Old Faithful",
        "url": "https://en.wikipedia.org/wiki/Old_Faithful",
        "title": "Old Faithful"
      },
      {
        "text": "Classifiers",
        "url": "https://en.wikipedia.org/wiki/Classifier_(mathematics)",
        "title": "Classifier (mathematics)"
      },
      {
        "text": "[98]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-106"
      },
      {
        "text": "pattern matching",
        "url": "https://en.wikipedia.org/wiki/Pattern_matching",
        "title": "Pattern matching"
      },
      {
        "text": "supervised learning",
        "url": "https://en.wikipedia.org/wiki/Supervised_learning",
        "title": "Supervised learning"
      },
      {
        "text": "observation",
        "url": "https://en.wikipedia.org/wiki/Random_variate",
        "title": "Random variate"
      },
      {
        "text": "data set",
        "url": "https://en.wikipedia.org/wiki/Data_set",
        "title": "Data set"
      },
      {
        "text": "[45]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Supervised_learning-50"
      },
      {
        "text": "[99]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-107"
      },
      {
        "text": "decision tree",
        "url": "https://en.wikipedia.org/wiki/Decision_tree",
        "title": "Decision tree"
      },
      {
        "text": "[100]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-108"
      },
      {
        "text": "K-nearest neighbor",
        "url": "https://en.wikipedia.org/wiki/K-nearest_neighbor",
        "title": "K-nearest neighbor"
      },
      {
        "text": "Kernel methods",
        "url": "https://en.wikipedia.org/wiki/Kernel_methods",
        "title": "Kernel methods"
      },
      {
        "text": "support vector machine",
        "url": "https://en.wikipedia.org/wiki/Support_vector_machine",
        "title": "Support vector machine"
      },
      {
        "text": "[101]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-109"
      },
      {
        "text": "naive Bayes classifier",
        "url": "https://en.wikipedia.org/wiki/Naive_Bayes_classifier",
        "title": "Naive Bayes classifier"
      },
      {
        "text": "[102]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEDomingos2015152-110"
      },
      {
        "text": "[103]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-111"
      },
      {
        "text": "Neural networks",
        "url": "https://en.wikipedia.org/wiki/Artificial_neural_network",
        "title": "Artificial neural network"
      },
      {
        "text": "[104]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Neural_networks-112"
      },
      {
        "text": "neurons",
        "url": "https://en.wikipedia.org/wiki/Neuron",
        "title": "Neuron"
      },
      {
        "text": "human brain",
        "url": "https://en.wikipedia.org/wiki/Human_brain",
        "title": "Human brain"
      },
      {
        "text": "artificial neurons",
        "url": "https://en.wikipedia.org/wiki/Artificial_neurons",
        "title": "Artificial neurons"
      },
      {
        "text": "neurons",
        "url": "https://en.wikipedia.org/wiki/Neurons",
        "title": "Neurons"
      },
      {
        "text": "weight",
        "url": "https://en.wikipedia.org/wiki/Weighting",
        "title": "Weighting"
      },
      {
        "text": "[104]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Neural_networks-112"
      },
      {
        "text": "local search",
        "url": "https://en.wikipedia.org/wiki/Local_search_(optimization)",
        "title": "Local search (optimization)"
      },
      {
        "text": "backpropagation",
        "url": "https://en.wikipedia.org/wiki/Backpropagation",
        "title": "Backpropagation"
      },
      {
        "text": "[105]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-113"
      },
      {
        "text": "find patterns",
        "url": "https://en.wikipedia.org/wiki/Pattern_recognition",
        "title": "Pattern recognition"
      },
      {
        "text": "[106]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-114"
      },
      {
        "text": "feedforward neural networks",
        "url": "https://en.wikipedia.org/wiki/Feedforward_neural_network",
        "title": "Feedforward neural network"
      },
      {
        "text": "[107]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-115"
      },
      {
        "text": "Recurrent neural networks",
        "url": "https://en.wikipedia.org/wiki/Recurrent_neural_network",
        "title": "Recurrent neural network"
      },
      {
        "text": "Long short term memory",
        "url": "https://en.wikipedia.org/wiki/Long_short_term_memory",
        "title": "Long short term memory"
      },
      {
        "text": "[108]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-116"
      },
      {
        "text": "Perceptrons",
        "url": "https://en.wikipedia.org/wiki/Perceptron",
        "title": "Perceptron"
      },
      {
        "text": "[109]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-117"
      },
      {
        "text": "[110]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Deep_learning-118"
      },
      {
        "text": "Convolutional neural networks",
        "url": "https://en.wikipedia.org/wiki/Convolutional_neural_network",
        "title": "Convolutional neural network"
      },
      {
        "text": "image processing",
        "url": "https://en.wikipedia.org/wiki/Image_processing",
        "title": "Image processing"
      },
      {
        "text": "identify an \"edge\"",
        "url": "https://en.wikipedia.org/wiki/Edge_detection",
        "title": "Edge detection"
      },
      {
        "text": "[111]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-119"
      },
      {
        "text": "Deep learning",
        "url": "https://en.wikipedia.org/wiki/Deep_learning",
        "title": "Deep learning"
      },
      {
        "text": "[110]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Deep_learning-118"
      },
      {
        "text": "image processing",
        "url": "https://en.wikipedia.org/wiki/Image_processing",
        "title": "Image processing"
      },
      {
        "text": "[112]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEDengYu2014199–200-120"
      },
      {
        "text": "computer vision",
        "url": "https://en.wikipedia.org/wiki/Computer_vision",
        "title": "Computer vision"
      },
      {
        "text": "speech recognition",
        "url": "https://en.wikipedia.org/wiki/Speech_recognition",
        "title": "Speech recognition"
      },
      {
        "text": "natural language processing",
        "url": "https://en.wikipedia.org/wiki/Natural_language_processing",
        "title": "Natural language processing"
      },
      {
        "text": "image classification",
        "url": "https://en.wikipedia.org/wiki/Image_classification",
        "title": "Image classification"
      },
      {
        "text": "[113]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTECiresanMeierSchmidhuber2012-121"
      },
      {
        "text": "[114]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021750-122"
      },
      {
        "text": "[i]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-129"
      },
      {
        "text": "GPUs",
        "url": "https://en.wikipedia.org/wiki/GPU",
        "title": "GPU"
      },
      {
        "text": "curated datasets",
        "url": "https://en.wikipedia.org/wiki/List_of_datasets_for_machine-learning_research",
        "title": "List of datasets for machine-learning research"
      },
      {
        "text": "ImageNet",
        "url": "https://en.wikipedia.org/wiki/ImageNet",
        "title": "ImageNet"
      },
      {
        "text": "[j]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-131"
      },
      {
        "text": "Generative pre-trained transformers",
        "url": "https://en.wikipedia.org/wiki/Generative_pre-trained_transformer",
        "title": "Generative pre-trained transformer"
      },
      {
        "text": "large language models",
        "url": "https://en.wikipedia.org/wiki/Large_language_model",
        "title": "Large language model"
      },
      {
        "text": "corpus of text",
        "url": "https://en.wikipedia.org/wiki/Corpus_of_text",
        "title": "Corpus of text"
      },
      {
        "text": "token",
        "url": "https://en.wikipedia.org/wiki/Lexical_analysis",
        "title": "Lexical analysis"
      },
      {
        "text": "reinforcement learning from human feedback",
        "url": "https://en.wikipedia.org/wiki/Reinforcement_learning_from_human_feedback",
        "title": "Reinforcement learning from human feedback"
      },
      {
        "text": "hallucinations",
        "url": "https://en.wikipedia.org/wiki/Hallucination_(artificial_intelligence)",
        "title": "Hallucination (artificial intelligence)"
      },
      {
        "text": "[122]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-132"
      },
      {
        "text": "chatbots",
        "url": "https://en.wikipedia.org/wiki/Chatbot",
        "title": "Chatbot"
      },
      {
        "text": "[123]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTESmith2023-133"
      },
      {
        "text": "[124]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-134"
      },
      {
        "text": "Gemini",
        "url": "https://en.wikipedia.org/wiki/Gemini_(chatbot)",
        "title": "Gemini (chatbot)"
      },
      {
        "text": "ChatGPT",
        "url": "https://en.wikipedia.org/wiki/ChatGPT",
        "title": "ChatGPT"
      },
      {
        "text": "Grok",
        "url": "https://en.wikipedia.org/wiki/Grok_(chatbot)",
        "title": "Grok (chatbot)"
      },
      {
        "text": "Claude",
        "url": "https://en.wikipedia.org/wiki/Anthropic#Claude",
        "title": "Anthropic"
      },
      {
        "text": "Copilot",
        "url": "https://en.wikipedia.org/wiki/Microsoft_Copilot",
        "title": "Microsoft Copilot"
      },
      {
        "text": "LLaMA",
        "url": "https://en.wikipedia.org/wiki/LLaMA",
        "title": "LLaMA"
      },
      {
        "text": "[125]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-135"
      },
      {
        "text": "Multimodal",
        "url": "https://en.wikipedia.org/wiki/Multimodal_learning",
        "title": "Multimodal learning"
      },
      {
        "text": "modalities",
        "url": "https://en.wikipedia.org/wiki/Modality_(human%E2%80%93computer_interaction)",
        "title": "Modality (human–computer interaction)"
      },
      {
        "text": "[126]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEMarmouyet2023-136"
      },
      {
        "text": "Programming languages for artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Programming_languages_for_artificial_intelligence",
        "title": "Programming languages for artificial intelligence"
      },
      {
        "text": "Hardware for artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Hardware_for_artificial_intelligence",
        "title": "Hardware for artificial intelligence"
      },
      {
        "text": "graphics processing units",
        "url": "https://en.wikipedia.org/wiki/Graphics_processing_unit",
        "title": "Graphics processing unit"
      },
      {
        "text": "TensorFlow",
        "url": "https://en.wikipedia.org/wiki/TensorFlow",
        "title": "TensorFlow"
      },
      {
        "text": "central processing unit",
        "url": "https://en.wikipedia.org/wiki/Central_processing_unit",
        "title": "Central processing unit"
      },
      {
        "text": "machine learning",
        "url": "https://en.wikipedia.org/wiki/Machine_learning",
        "title": "Machine learning"
      },
      {
        "text": "[127]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEKobielus2019-137"
      },
      {
        "text": "programming languages",
        "url": "https://en.wikipedia.org/wiki/Programming_language",
        "title": "Programming language"
      },
      {
        "text": "Prolog",
        "url": "https://en.wikipedia.org/wiki/Prolog",
        "title": "Prolog"
      },
      {
        "text": "[128]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-138"
      },
      {
        "text": "general-purpose programming languages",
        "url": "https://en.wikipedia.org/wiki/General-purpose_programming_language",
        "title": "General-purpose programming language"
      },
      {
        "text": "Python",
        "url": "https://en.wikipedia.org/wiki/Python_(programming_language)",
        "title": "Python (programming language)"
      },
      {
        "text": "[129]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-139"
      },
      {
        "text": "integrated circuits",
        "url": "https://en.wikipedia.org/wiki/Integrated_circuit",
        "title": "Integrated circuit"
      },
      {
        "text": "Moore's law",
        "url": "https://en.wikipedia.org/wiki/Moore%27s_law",
        "title": "Moore's law"
      },
      {
        "text": "Intel",
        "url": "https://en.wikipedia.org/wiki/Intel",
        "title": "Intel"
      },
      {
        "text": "Gordon Moore",
        "url": "https://en.wikipedia.org/wiki/Gordon_Moore",
        "title": "Gordon Moore"
      },
      {
        "text": "GPUs",
        "url": "https://en.wikipedia.org/wiki/GPUs",
        "title": "GPUs"
      },
      {
        "text": "[130]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-140"
      },
      {
        "text": "Huang's law",
        "url": "https://en.wikipedia.org/wiki/Huang%27s_law",
        "title": "Huang's law"
      },
      {
        "text": "[131]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-141"
      },
      {
        "text": "Nvidia",
        "url": "https://en.wikipedia.org/wiki/Nvidia",
        "title": "Nvidia"
      },
      {
        "text": "Jensen Huang",
        "url": "https://en.wikipedia.org/wiki/Jensen_Huang",
        "title": "Jensen Huang"
      },
      {
        "text": "Applications of artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Applications_of_artificial_intelligence",
        "title": "Applications of artificial intelligence"
      },
      {
        "text": "search engines",
        "url": "https://en.wikipedia.org/wiki/Search_engines",
        "title": "Search engines"
      },
      {
        "text": "Google Search",
        "url": "https://en.wikipedia.org/wiki/Google_Search",
        "title": "Google Search"
      },
      {
        "text": "targeting online advertisements",
        "url": "https://en.wikipedia.org/wiki/Targeted_advertising",
        "title": "Targeted advertising"
      },
      {
        "text": "recommendation systems",
        "url": "https://en.wikipedia.org/wiki/Recommendation_systems",
        "title": "Recommendation systems"
      },
      {
        "text": "Netflix",
        "url": "https://en.wikipedia.org/wiki/Netflix",
        "title": "Netflix"
      },
      {
        "text": "YouTube",
        "url": "https://en.wikipedia.org/wiki/YouTube",
        "title": "YouTube"
      },
      {
        "text": "Amazon",
        "url": "https://en.wikipedia.org/wiki/Amazon_(company)",
        "title": "Amazon (company)"
      },
      {
        "text": "internet traffic",
        "url": "https://en.wikipedia.org/wiki/Internet_traffic",
        "title": "Internet traffic"
      },
      {
        "text": "targeted advertising",
        "url": "https://en.wikipedia.org/wiki/Marketing_and_artificial_intelligence",
        "title": "Marketing and artificial intelligence"
      },
      {
        "text": "AdSense",
        "url": "https://en.wikipedia.org/wiki/AdSense",
        "title": "AdSense"
      },
      {
        "text": "Facebook",
        "url": "https://en.wikipedia.org/wiki/Facebook",
        "title": "Facebook"
      },
      {
        "text": "virtual assistants",
        "url": "https://en.wikipedia.org/wiki/Virtual_assistant",
        "title": "Virtual assistant"
      },
      {
        "text": "Siri",
        "url": "https://en.wikipedia.org/wiki/Siri",
        "title": "Siri"
      },
      {
        "text": "Alexa",
        "url": "https://en.wikipedia.org/wiki/Amazon_Alexa",
        "title": "Amazon Alexa"
      },
      {
        "text": "autonomous vehicles",
        "url": "https://en.wikipedia.org/wiki/Autonomous_vehicles",
        "title": "Autonomous vehicles"
      },
      {
        "text": "drones",
        "url": "https://en.wikipedia.org/wiki/Unmanned_aerial_vehicle",
        "title": "Unmanned aerial vehicle"
      },
      {
        "text": "ADAS",
        "url": "https://en.wikipedia.org/wiki/Advanced_driver-assistance_system",
        "title": "Advanced driver-assistance system"
      },
      {
        "text": "self-driving cars",
        "url": "https://en.wikipedia.org/wiki/Self-driving_cars",
        "title": "Self-driving cars"
      },
      {
        "text": "automatic language translation",
        "url": "https://en.wikipedia.org/wiki/Automatic_language_translation",
        "title": "Automatic language translation"
      },
      {
        "text": "Microsoft Translator",
        "url": "https://en.wikipedia.org/wiki/Microsoft_Translator",
        "title": "Microsoft Translator"
      },
      {
        "text": "Google Translate",
        "url": "https://en.wikipedia.org/wiki/Google_Translate",
        "title": "Google Translate"
      },
      {
        "text": "facial recognition",
        "url": "https://en.wikipedia.org/wiki/Facial_recognition_system",
        "title": "Facial recognition system"
      },
      {
        "text": "Apple",
        "url": "https://en.wikipedia.org/wiki/Apple_Computer",
        "title": "Apple Computer"
      },
      {
        "text": "Face ID",
        "url": "https://en.wikipedia.org/wiki/Face_ID",
        "title": "Face ID"
      },
      {
        "text": "Microsoft",
        "url": "https://en.wikipedia.org/wiki/Microsoft",
        "title": "Microsoft"
      },
      {
        "text": "DeepFace",
        "url": "https://en.wikipedia.org/wiki/DeepFace",
        "title": "DeepFace"
      },
      {
        "text": "Google",
        "url": "https://en.wikipedia.org/wiki/Google",
        "title": "Google"
      },
      {
        "text": "FaceNet",
        "url": "https://en.wikipedia.org/wiki/FaceNet",
        "title": "FaceNet"
      },
      {
        "text": "image labeling",
        "url": "https://en.wikipedia.org/wiki/Image_labeling",
        "title": "Image labeling"
      },
      {
        "text": "Facebook",
        "url": "https://en.wikipedia.org/wiki/Facebook",
        "title": "Facebook"
      },
      {
        "text": "iPhoto",
        "url": "https://en.wikipedia.org/wiki/IPhoto",
        "title": "IPhoto"
      },
      {
        "text": "TikTok",
        "url": "https://en.wikipedia.org/wiki/TikTok",
        "title": "TikTok"
      },
      {
        "text": "Chief automation officer",
        "url": "https://en.wikipedia.org/wiki/Chief_automation_officer",
        "title": "Chief automation officer"
      },
      {
        "text": "Artificial intelligence in healthcare",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence_in_healthcare",
        "title": "Artificial intelligence in healthcare"
      },
      {
        "text": "medicine",
        "url": "https://en.wikipedia.org/wiki/Medicine",
        "title": "Medicine"
      },
      {
        "text": "medical research",
        "url": "https://en.wikipedia.org/wiki/Medical_research",
        "title": "Medical research"
      },
      {
        "text": "[132]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-142"
      },
      {
        "text": "Hippocratic Oath",
        "url": "https://en.wikipedia.org/wiki/Hippocratic_Oath",
        "title": "Hippocratic Oath"
      },
      {
        "text": "[133]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-143"
      },
      {
        "text": "[134]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-144"
      },
      {
        "text": "big data",
        "url": "https://en.wikipedia.org/wiki/Big_data",
        "title": "Big data"
      },
      {
        "text": "organoid",
        "url": "https://en.wikipedia.org/wiki/Organoid",
        "title": "Organoid"
      },
      {
        "text": "tissue engineering",
        "url": "https://en.wikipedia.org/wiki/Tissue_engineering",
        "title": "Tissue engineering"
      },
      {
        "text": "microscopy",
        "url": "https://en.wikipedia.org/wiki/Microscopy",
        "title": "Microscopy"
      },
      {
        "text": "[135]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Bax-2023-145"
      },
      {
        "text": "[135]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Bax-2023-145"
      },
      {
        "text": "[136]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-146"
      },
      {
        "text": "AlphaFold 2",
        "url": "https://en.wikipedia.org/wiki/AlphaFold_2",
        "title": "AlphaFold 2"
      },
      {
        "text": "structure of a protein",
        "url": "https://en.wikipedia.org/wiki/Protein_structure",
        "title": "Protein structure"
      },
      {
        "text": "[137]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-147"
      },
      {
        "text": "[138]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-148"
      },
      {
        "text": "Parkinson's disease",
        "url": "https://en.wikipedia.org/wiki/Parkinson%27s_disease",
        "title": "Parkinson's disease"
      },
      {
        "text": "alpha-synuclein",
        "url": "https://en.wikipedia.org/wiki/Alpha-synuclein",
        "title": "Alpha-synuclein"
      },
      {
        "text": "[139]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-149"
      },
      {
        "text": "[140]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-150"
      },
      {
        "text": "Game artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Game_artificial_intelligence",
        "title": "Game artificial intelligence"
      },
      {
        "text": "Game playing",
        "url": "https://en.wikipedia.org/wiki/Game_AI",
        "title": "Game AI"
      },
      {
        "text": "[141]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-151"
      },
      {
        "text": "Deep Blue",
        "url": "https://en.wikipedia.org/wiki/IBM_Deep_Blue",
        "title": "IBM Deep Blue"
      },
      {
        "text": "Garry Kasparov",
        "url": "https://en.wikipedia.org/wiki/Garry_Kasparov",
        "title": "Garry Kasparov"
      },
      {
        "text": "[142]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-152"
      },
      {
        "text": "Jeopardy!",
        "url": "https://en.wikipedia.org/wiki/Jeopardy!",
        "title": "Jeopardy!"
      },
      {
        "text": "quiz show",
        "url": "https://en.wikipedia.org/wiki/Quiz_show",
        "title": "Quiz show"
      },
      {
        "text": "IBM",
        "url": "https://en.wikipedia.org/wiki/IBM",
        "title": "IBM"
      },
      {
        "text": "question answering system",
        "url": "https://en.wikipedia.org/wiki/Question_answering_system",
        "title": "Question answering system"
      },
      {
        "text": "Watson",
        "url": "https://en.wikipedia.org/wiki/Watson_(artificial_intelligence_software)",
        "title": "Watson (artificial intelligence software)"
      },
      {
        "text": "Brad Rutter",
        "url": "https://en.wikipedia.org/wiki/Brad_Rutter",
        "title": "Brad Rutter"
      },
      {
        "text": "Ken Jennings",
        "url": "https://en.wikipedia.org/wiki/Ken_Jennings",
        "title": "Ken Jennings"
      },
      {
        "text": "[143]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-153"
      },
      {
        "text": "AlphaGo",
        "url": "https://en.wikipedia.org/wiki/AlphaGo",
        "title": "AlphaGo"
      },
      {
        "text": "Go",
        "url": "https://en.wikipedia.org/wiki/Go_(game)",
        "title": "Go (game)"
      },
      {
        "text": "Lee Sedol",
        "url": "https://en.wikipedia.org/wiki/Lee_Sedol",
        "title": "Lee Sedol"
      },
      {
        "text": "computer Go",
        "url": "https://en.wikipedia.org/wiki/Computer_Go",
        "title": "Computer Go"
      },
      {
        "text": "handicaps",
        "url": "https://en.wikipedia.org/wiki/Go_handicaps",
        "title": "Go handicaps"
      },
      {
        "text": "defeated Ke Jie",
        "url": "https://en.wikipedia.org/wiki/AlphaGo_versus_Ke_Jie",
        "title": "AlphaGo versus Ke Jie"
      },
      {
        "text": "[144]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-154"
      },
      {
        "text": "imperfect-information",
        "url": "https://en.wikipedia.org/wiki/Imperfect_information",
        "title": "Imperfect information"
      },
      {
        "text": "poker",
        "url": "https://en.wikipedia.org/wiki/Poker",
        "title": "Poker"
      },
      {
        "text": "Pluribus",
        "url": "https://en.wikipedia.org/wiki/Pluribus_(poker_bot)",
        "title": "Pluribus (poker bot)"
      },
      {
        "text": "[145]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-155"
      },
      {
        "text": "DeepMind",
        "url": "https://en.wikipedia.org/wiki/DeepMind",
        "title": "DeepMind"
      },
      {
        "text": "reinforcement learning",
        "url": "https://en.wikipedia.org/wiki/Reinforcement_learning",
        "title": "Reinforcement learning"
      },
      {
        "text": "MuZero",
        "url": "https://en.wikipedia.org/wiki/MuZero",
        "title": "MuZero"
      },
      {
        "text": "Atari",
        "url": "https://en.wikipedia.org/wiki/Atari",
        "title": "Atari"
      },
      {
        "text": "[146]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-156"
      },
      {
        "text": "StarCraft II",
        "url": "https://en.wikipedia.org/wiki/StarCraft_II",
        "title": "StarCraft II"
      },
      {
        "text": "[147]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-157"
      },
      {
        "text": "Gran Turismo",
        "url": "https://en.wikipedia.org/wiki/Gran_Turismo_(series)",
        "title": "Gran Turismo (series)"
      },
      {
        "text": "[148]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-158"
      },
      {
        "text": "open-world",
        "url": "https://en.wikipedia.org/wiki/Open-world",
        "title": "Open-world"
      },
      {
        "text": "[149]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-159"
      },
      {
        "text": "GPT-4",
        "url": "https://en.wikipedia.org/wiki/GPT-4",
        "title": "GPT-4"
      },
      {
        "text": "Gemini",
        "url": "https://en.wikipedia.org/wiki/Gemini_(chatbot)",
        "title": "Gemini (chatbot)"
      },
      {
        "text": "Claude",
        "url": "https://en.wikipedia.org/wiki/Claude_(language_model)",
        "title": "Claude (language model)"
      },
      {
        "text": "LLaMa",
        "url": "https://en.wikipedia.org/wiki/Llama_(language_model)",
        "title": "Llama (language model)"
      },
      {
        "text": "Mistral",
        "url": "https://en.wikipedia.org/wiki/Mistral_AI",
        "title": "Mistral AI"
      },
      {
        "text": "hallucinations",
        "url": "https://en.wikipedia.org/wiki/Hallucination_(artificial_intelligence)",
        "title": "Hallucination (artificial intelligence)"
      },
      {
        "text": "supervised",
        "url": "https://en.wikipedia.org/wiki/Supervised_learning",
        "title": "Supervised learning"
      },
      {
        "text": "fine-tuning",
        "url": "https://en.wikipedia.org/wiki/Fine-tuning_(deep_learning)",
        "title": "Fine-tuning (deep learning)"
      },
      {
        "text": "[150]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-160"
      },
      {
        "text": "classifiers",
        "url": "https://en.wikipedia.org/wiki/Statistical_classification",
        "title": "Statistical classification"
      },
      {
        "text": "[151]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-161"
      },
      {
        "text": "[152]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-162"
      },
      {
        "text": "reasoning",
        "url": "https://en.wikipedia.org/wiki/Automated_reasoning",
        "title": "Automated reasoning"
      },
      {
        "text": "[153]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-163"
      },
      {
        "text": "Alibaba Group",
        "url": "https://en.wikipedia.org/wiki/Alibaba_Group",
        "title": "Alibaba Group"
      },
      {
        "text": "Qwen",
        "url": "https://en.wikipedia.org/wiki/Qwen",
        "title": "Qwen"
      },
      {
        "text": "[154]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-VentureBeat_8_August_2024-164"
      },
      {
        "text": "Monte Carlo tree search",
        "url": "https://en.wikipedia.org/wiki/Monte_Carlo_tree_search",
        "title": "Monte Carlo tree search"
      },
      {
        "text": "AIME",
        "url": "https://en.wikipedia.org/wiki/American_Invitational_Mathematics_Examination",
        "title": "American Invitational Mathematics Examination"
      },
      {
        "text": "[155]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-165"
      },
      {
        "text": "AlphaGeometry",
        "url": "https://en.wikipedia.org/wiki/AlphaGeometry",
        "title": "AlphaGeometry"
      },
      {
        "text": "Google DeepMind",
        "url": "https://en.wikipedia.org/wiki/Google_DeepMind",
        "title": "Google DeepMind"
      },
      {
        "text": "[156]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-166"
      },
      {
        "text": "EleutherAI",
        "url": "https://en.wikipedia.org/wiki/EleutherAI",
        "title": "EleutherAI"
      },
      {
        "text": "[157]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-167"
      },
      {
        "text": "[158]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-168"
      },
      {
        "text": "Lean",
        "url": "https://en.wikipedia.org/wiki/Lean_(proof_assistant)",
        "title": "Lean (proof assistant)"
      },
      {
        "text": "[159]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-169"
      },
      {
        "text": "Topological deep learning",
        "url": "https://en.wikipedia.org/wiki/Topological_deep_learning",
        "title": "Topological deep learning"
      },
      {
        "text": "topological",
        "url": "https://en.wikipedia.org/wiki/Topology",
        "title": "Topology"
      },
      {
        "text": "[160]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-170"
      },
      {
        "text": "World Pensions & Investments Forum",
        "url": "https://en.wikipedia.org/wiki/World_Pensions_%26_Investments_Forum",
        "title": "World Pensions & Investments Forum"
      },
      {
        "text": "[161]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-171"
      },
      {
        "text": "Military applications of artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Military_applications_of_artificial_intelligence",
        "title": "Military applications of artificial intelligence"
      },
      {
        "text": "[162]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-CRS-2019-172"
      },
      {
        "text": "command and control",
        "url": "https://en.wikipedia.org/wiki/Command_and_control",
        "title": "Command and control"
      },
      {
        "text": "[163]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Slyusar-2019-173"
      },
      {
        "text": "autonomous vehicles",
        "url": "https://en.wikipedia.org/wiki/Vehicular_automation",
        "title": "Vehicular automation"
      },
      {
        "text": "[162]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-CRS-2019-172"
      },
      {
        "text": "target acquisition",
        "url": "https://en.wikipedia.org/wiki/Target_acquisition",
        "title": "Target acquisition"
      },
      {
        "text": "Joint Fires",
        "url": "https://en.wikipedia.org/wiki/Forward_observers_in_the_U.S._military",
        "title": "Forward observers in the U.S. military"
      },
      {
        "text": "autonomous",
        "url": "https://en.wikipedia.org/wiki/Vehicular_automation",
        "title": "Vehicular automation"
      },
      {
        "text": "[163]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Slyusar-2019-173"
      },
      {
        "text": "[162]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-CRS-2019-172"
      },
      {
        "text": "[164]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-174"
      },
      {
        "text": "[165]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Davies-2023-175"
      },
      {
        "text": "[166]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-176"
      },
      {
        "text": "Vincent van Gogh",
        "url": "https://en.wikipedia.org/wiki/Vincent_van_Gogh",
        "title": "Vincent van Gogh"
      },
      {
        "text": "Generative artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Generative_artificial_intelligence",
        "title": "Generative artificial intelligence"
      },
      {
        "text": "edit",
        "url": "https://en.wikipedia.org/w/index.php?title=Generative_artificial_intelligence&action=edit"
      },
      {
        "text": "Generative artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Generative_artificial_intelligence",
        "title": "Generative artificial intelligence"
      },
      {
        "text": "[167]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-177"
      },
      {
        "text": "[168]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-178"
      },
      {
        "text": "[169]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-179"
      },
      {
        "text": "[170]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-180"
      },
      {
        "text": "learn",
        "url": "https://en.wikipedia.org/wiki/Machine_learning",
        "title": "Machine learning"
      },
      {
        "text": "training data",
        "url": "https://en.wikipedia.org/wiki/Training_data_set",
        "title": "Training data set"
      },
      {
        "text": "[171]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Generative_artificial_intelligence_:02-181"
      },
      {
        "text": "[172]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-182"
      },
      {
        "text": "prompts",
        "url": "https://en.wikipedia.org/wiki/Prompt_(natural_language)",
        "title": "Prompt (natural language)"
      },
      {
        "text": "[173]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Generative_artificial_intelligence_nytimes2-183"
      },
      {
        "text": "[174]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Generative_artificial_intelligence_bloomberg2-184"
      },
      {
        "text": "AI boom",
        "url": "https://en.wikipedia.org/wiki/AI_boom",
        "title": "AI boom"
      },
      {
        "text": "transformer",
        "url": "https://en.wikipedia.org/wiki/Transformer_(machine_learning_model)",
        "title": "Transformer (machine learning model)"
      },
      {
        "text": "deep",
        "url": "https://en.wikipedia.org/wiki/Deep_learning",
        "title": "Deep learning"
      },
      {
        "text": "neural networks",
        "url": "https://en.wikipedia.org/wiki/Neural_networks",
        "title": "Neural networks"
      },
      {
        "text": "large language models",
        "url": "https://en.wikipedia.org/wiki/Large_language_model",
        "title": "Large language model"
      },
      {
        "text": "chatbots",
        "url": "https://en.wikipedia.org/wiki/Chatbots",
        "title": "Chatbots"
      },
      {
        "text": "ChatGPT",
        "url": "https://en.wikipedia.org/wiki/ChatGPT",
        "title": "ChatGPT"
      },
      {
        "text": "DeepSeek",
        "url": "https://en.wikipedia.org/wiki/DeepSeek_(chatbot)",
        "title": "DeepSeek (chatbot)"
      },
      {
        "text": "Copilot",
        "url": "https://en.wikipedia.org/wiki/Microsoft_Copilot",
        "title": "Microsoft Copilot"
      },
      {
        "text": "Gemini",
        "url": "https://en.wikipedia.org/wiki/Gemini_(chatbot)",
        "title": "Gemini (chatbot)"
      },
      {
        "text": "LLaMA",
        "url": "https://en.wikipedia.org/wiki/LLaMA",
        "title": "LLaMA"
      },
      {
        "text": "text-to-image",
        "url": "https://en.wikipedia.org/wiki/Text-to-image",
        "title": "Text-to-image"
      },
      {
        "text": "artificial intelligence image generation",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence_art",
        "title": "Artificial intelligence art"
      },
      {
        "text": "Stable Diffusion",
        "url": "https://en.wikipedia.org/wiki/Stable_Diffusion",
        "title": "Stable Diffusion"
      },
      {
        "text": "Midjourney",
        "url": "https://en.wikipedia.org/wiki/Midjourney",
        "title": "Midjourney"
      },
      {
        "text": "DALL-E",
        "url": "https://en.wikipedia.org/wiki/DALL-E",
        "title": "DALL-E"
      },
      {
        "text": "text-to-video",
        "url": "https://en.wikipedia.org/wiki/Text-to-video_model",
        "title": "Text-to-video model"
      },
      {
        "text": "Sora",
        "url": "https://en.wikipedia.org/wiki/Sora_(text-to-video_model)",
        "title": "Sora (text-to-video model)"
      },
      {
        "text": "[175]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Generative_artificial_intelligence_nytimes-gpt4-185"
      },
      {
        "text": "[176]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-186"
      },
      {
        "text": "[177]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-187"
      },
      {
        "text": "[178]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Generative_artificial_intelligence_:4-188"
      },
      {
        "text": "OpenAI",
        "url": "https://en.wikipedia.org/wiki/OpenAI",
        "title": "OpenAI"
      },
      {
        "text": "Anthropic",
        "url": "https://en.wikipedia.org/wiki/Anthropic",
        "title": "Anthropic"
      },
      {
        "text": "Microsoft",
        "url": "https://en.wikipedia.org/wiki/Microsoft",
        "title": "Microsoft"
      },
      {
        "text": "Google",
        "url": "https://en.wikipedia.org/wiki/Google",
        "title": "Google"
      },
      {
        "text": "DeepSeek",
        "url": "https://en.wikipedia.org/wiki/DeepSeek",
        "title": "DeepSeek"
      },
      {
        "text": "Baidu",
        "url": "https://en.wikipedia.org/wiki/Baidu",
        "title": "Baidu"
      },
      {
        "text": "[179]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Generative_artificial_intelligence_nytimes-189"
      },
      {
        "text": "[180]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Generative_artificial_intelligence_economist1-190"
      },
      {
        "text": "[181]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-191"
      },
      {
        "text": "cybercrime",
        "url": "https://en.wikipedia.org/wiki/Cybercrime",
        "title": "Cybercrime"
      },
      {
        "text": "fake news",
        "url": "https://en.wikipedia.org/wiki/Fake_news",
        "title": "Fake news"
      },
      {
        "text": "deepfakes",
        "url": "https://en.wikipedia.org/wiki/Deepfake",
        "title": "Deepfake"
      },
      {
        "text": "[182]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-192"
      },
      {
        "text": "the mass replacement of human jobs",
        "url": "https://en.wikipedia.org/wiki/Technological_unemployment",
        "title": "Technological unemployment"
      },
      {
        "text": "[183]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-193"
      },
      {
        "text": "[184]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-194"
      },
      {
        "text": "virtual assistants",
        "url": "https://en.wikipedia.org/wiki/Virtual_assistant",
        "title": "Virtual assistant"
      },
      {
        "text": "chatbots",
        "url": "https://en.wikipedia.org/wiki/Chatbots",
        "title": "Chatbots"
      },
      {
        "text": "autonomous vehicles",
        "url": "https://en.wikipedia.org/wiki/Autonomous_vehicles",
        "title": "Autonomous vehicles"
      },
      {
        "text": "game-playing systems",
        "url": "https://en.wikipedia.org/wiki/Video_game_console",
        "title": "Video game console"
      },
      {
        "text": "industrial robotics",
        "url": "https://en.wikipedia.org/wiki/Industrial_robotics",
        "title": "Industrial robotics"
      },
      {
        "text": "[185]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-195"
      },
      {
        "text": "[186]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-196"
      },
      {
        "text": "[187]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-197"
      },
      {
        "text": "[188]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-198"
      },
      {
        "text": "teledildonics",
        "url": "https://en.wikipedia.org/wiki/Teledildonics",
        "title": "Teledildonics"
      },
      {
        "text": "[189]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-199"
      },
      {
        "text": "[190]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-200"
      },
      {
        "text": "Replika",
        "url": "https://en.wikipedia.org/wiki/Replika",
        "title": "Replika"
      },
      {
        "text": "[191]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-201"
      },
      {
        "text": "deepfake pornography",
        "url": "https://en.wikipedia.org/wiki/Deepfake_pornography",
        "title": "Deepfake pornography"
      },
      {
        "text": "[192]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-202"
      },
      {
        "text": "online gender-based violence",
        "url": "https://en.wikipedia.org/wiki/Online_gender-based_violence",
        "title": "Online gender-based violence"
      },
      {
        "text": "sexual grooming",
        "url": "https://en.wikipedia.org/wiki/Sexual_grooming",
        "title": "Sexual grooming"
      },
      {
        "text": "[193]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-203"
      },
      {
        "text": "[194]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-204"
      },
      {
        "text": "[195]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-205"
      },
      {
        "text": "energy storage",
        "url": "https://en.wikipedia.org/wiki/Energy_storage",
        "title": "Energy storage"
      },
      {
        "text": "foreign policy",
        "url": "https://en.wikipedia.org/wiki/Foreign_policy",
        "title": "Foreign policy"
      },
      {
        "text": "disaster",
        "url": "https://en.wikipedia.org/wiki/Disaster",
        "title": "Disaster"
      },
      {
        "text": "[196]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-206"
      },
      {
        "text": "[197]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-207"
      },
      {
        "text": "[198]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-208"
      },
      {
        "text": "predictive analytics",
        "url": "https://en.wikipedia.org/wiki/Predictive_analytics",
        "title": "Predictive analytics"
      },
      {
        "text": "2024 Indian elections",
        "url": "https://en.wikipedia.org/wiki/2024_Indian_general_election",
        "title": "2024 Indian general election"
      },
      {
        "text": "deepfakes",
        "url": "https://en.wikipedia.org/wiki/Deepfake",
        "title": "Deepfake"
      },
      {
        "text": "[199]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-209"
      },
      {
        "text": "Ethics of artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Ethics_of_artificial_intelligence",
        "title": "Ethics of artificial intelligence"
      },
      {
        "text": "[200]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-210"
      },
      {
        "text": "Demis Hassabis",
        "url": "https://en.wikipedia.org/wiki/Demis_Hassabis",
        "title": "Demis Hassabis"
      },
      {
        "text": "DeepMind",
        "url": "https://en.wikipedia.org/wiki/DeepMind",
        "title": "DeepMind"
      },
      {
        "text": "[201]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTESimonite2016-211"
      },
      {
        "text": "[202]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021987-212"
      },
      {
        "text": "[203]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTELaskowski2023-213"
      },
      {
        "text": "Information privacy",
        "url": "https://en.wikipedia.org/wiki/Information_privacy",
        "title": "Information privacy"
      },
      {
        "text": "Artificial intelligence and copyright",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence_and_copyright",
        "title": "Artificial intelligence and copyright"
      },
      {
        "text": "privacy",
        "url": "https://en.wikipedia.org/wiki/Privacy",
        "title": "Privacy"
      },
      {
        "text": "surveillance",
        "url": "https://en.wikipedia.org/wiki/Surveillance",
        "title": "Surveillance"
      },
      {
        "text": "copyright",
        "url": "https://en.wikipedia.org/wiki/Copyright",
        "title": "Copyright"
      },
      {
        "text": "[204]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEGAO2022-214"
      },
      {
        "text": "speech recognition",
        "url": "https://en.wikipedia.org/wiki/Speech_recognition",
        "title": "Speech recognition"
      },
      {
        "text": "Amazon",
        "url": "https://en.wikipedia.org/wiki/Amazon_(company)",
        "title": "Amazon (company)"
      },
      {
        "text": "temporary workers",
        "url": "https://en.wikipedia.org/wiki/Temporary_worker",
        "title": "Temporary worker"
      },
      {
        "text": "[205]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEValinsky2019-215"
      },
      {
        "text": "necessary evil",
        "url": "https://en.wikipedia.org/wiki/Necessary_evil",
        "title": "Necessary evil"
      },
      {
        "text": "unethical",
        "url": "https://en.wikipedia.org/wiki/Unethical",
        "title": "Unethical"
      },
      {
        "text": "right to privacy",
        "url": "https://en.wikipedia.org/wiki/Right_to_privacy",
        "title": "Right to privacy"
      },
      {
        "text": "[206]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021991-216"
      },
      {
        "text": "data aggregation",
        "url": "https://en.wikipedia.org/wiki/Data_aggregation",
        "title": "Data aggregation"
      },
      {
        "text": "de-identification",
        "url": "https://en.wikipedia.org/wiki/De-identification",
        "title": "De-identification"
      },
      {
        "text": "differential privacy",
        "url": "https://en.wikipedia.org/wiki/Differential_privacy",
        "title": "Differential privacy"
      },
      {
        "text": "[207]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021991–992-217"
      },
      {
        "text": "Cynthia Dwork",
        "url": "https://en.wikipedia.org/wiki/Cynthia_Dwork",
        "title": "Cynthia Dwork"
      },
      {
        "text": "fairness",
        "url": "https://en.wikipedia.org/wiki/Fairness_(machine_learning)",
        "title": "Fairness (machine learning)"
      },
      {
        "text": "Brian Christian",
        "url": "https://en.wikipedia.org/wiki/Brian_Christian",
        "title": "Brian Christian"
      },
      {
        "text": "[208]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEChristian202063-218"
      },
      {
        "text": "fair use",
        "url": "https://en.wikipedia.org/wiki/Fair_use",
        "title": "Fair use"
      },
      {
        "text": "[209]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEVincent2022-219"
      },
      {
        "text": "[210]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-220"
      },
      {
        "text": "robots.txt",
        "url": "https://en.wikipedia.org/wiki/Robots.txt",
        "title": "Robots.txt"
      },
      {
        "text": "[211]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-221"
      },
      {
        "text": "John Grisham",
        "url": "https://en.wikipedia.org/wiki/John_Grisham",
        "title": "John Grisham"
      },
      {
        "text": "Jonathan Franzen",
        "url": "https://en.wikipedia.org/wiki/Jonathan_Franzen",
        "title": "Jonathan Franzen"
      },
      {
        "text": "[212]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEReisner2023-222"
      },
      {
        "text": "[213]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEAlterHarris2023-223"
      },
      {
        "text": "sui generis",
        "url": "https://en.wikipedia.org/wiki/Sui_generis",
        "title": "Sui generis"
      },
      {
        "text": "[214]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-224"
      },
      {
        "text": "Big Tech",
        "url": "https://en.wikipedia.org/wiki/Big_Tech",
        "title": "Big Tech"
      },
      {
        "text": "Alphabet Inc.",
        "url": "https://en.wikipedia.org/wiki/Alphabet_Inc.",
        "title": "Alphabet Inc."
      },
      {
        "text": "Amazon",
        "url": "https://en.wikipedia.org/wiki/Amazon_(company)",
        "title": "Amazon (company)"
      },
      {
        "text": "Apple Inc.",
        "url": "https://en.wikipedia.org/wiki/Apple_Inc.",
        "title": "Apple Inc."
      },
      {
        "text": "Meta Platforms",
        "url": "https://en.wikipedia.org/wiki/Meta_Platforms",
        "title": "Meta Platforms"
      },
      {
        "text": "Microsoft",
        "url": "https://en.wikipedia.org/wiki/Microsoft",
        "title": "Microsoft"
      },
      {
        "text": "[215]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-225"
      },
      {
        "text": "[216]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-226"
      },
      {
        "text": "[217]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-227"
      },
      {
        "text": "cloud infrastructure",
        "url": "https://en.wikipedia.org/wiki/Cloud_computing",
        "title": "Cloud computing"
      },
      {
        "text": "computing",
        "url": "https://en.wikipedia.org/wiki/Computing",
        "title": "Computing"
      },
      {
        "text": "data centers",
        "url": "https://en.wikipedia.org/wiki/Data_center",
        "title": "Data center"
      },
      {
        "text": "[218]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-228"
      },
      {
        "text": "[219]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-229"
      },
      {
        "text": "Environmental impacts of artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Environmental_impacts_of_artificial_intelligence",
        "title": "Environmental impacts of artificial intelligence"
      },
      {
        "text": "International Energy Agency",
        "url": "https://en.wikipedia.org/wiki/International_Energy_Agency",
        "title": "International Energy Agency"
      },
      {
        "text": "[220]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-230"
      },
      {
        "text": "[221]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-231"
      },
      {
        "text": "[222]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-232"
      },
      {
        "text": "Goldman Sachs",
        "url": "https://en.wikipedia.org/wiki/Goldman_Sachs",
        "title": "Goldman Sachs"
      },
      {
        "text": "[223]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-233"
      },
      {
        "text": "[224]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-234"
      },
      {
        "text": "[225]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-235"
      },
      {
        "text": "Nvidia",
        "url": "https://en.wikipedia.org/wiki/Nvidia",
        "title": "Nvidia"
      },
      {
        "text": "Jen-Hsun Huang",
        "url": "https://en.wikipedia.org/wiki/Jen-Hsun_Huang",
        "title": "Jen-Hsun Huang"
      },
      {
        "text": "[226]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-236"
      },
      {
        "text": "Microsoft",
        "url": "https://en.wikipedia.org/wiki/Microsoft",
        "title": "Microsoft"
      },
      {
        "text": "Constellation Energy",
        "url": "https://en.wikipedia.org/wiki/Constellation_Energy",
        "title": "Constellation Energy"
      },
      {
        "text": "Three Mile Island",
        "url": "https://en.wikipedia.org/wiki/Three_Mile_Island",
        "title": "Three Mile Island"
      },
      {
        "text": "Nuclear Regulatory Commission",
        "url": "https://en.wikipedia.org/wiki/Nuclear_Regulatory_Commission",
        "title": "Nuclear Regulatory Commission"
      },
      {
        "text": "Inflation Reduction Act",
        "url": "https://en.wikipedia.org/wiki/Inflation_Reduction_Act",
        "title": "Inflation Reduction Act"
      },
      {
        "text": "[227]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-237"
      },
      {
        "text": "Palisades Nuclear",
        "url": "https://en.wikipedia.org/wiki/Palisades_Nuclear_Generating_Station",
        "title": "Palisades Nuclear Generating Station"
      },
      {
        "text": "Exelon",
        "url": "https://en.wikipedia.org/wiki/Exelon",
        "title": "Exelon"
      },
      {
        "text": "[228]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-238"
      },
      {
        "text": "Taiwan",
        "url": "https://en.wikipedia.org/wiki/Taiwan",
        "title": "Taiwan"
      },
      {
        "text": "Taoyuan",
        "url": "https://en.wikipedia.org/wiki/Taoyuan,_Taiwan",
        "title": "Taoyuan, Taiwan"
      },
      {
        "text": "[229]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-DatacenterDynamics-239"
      },
      {
        "text": "phase out nuclear power",
        "url": "https://en.wikipedia.org/wiki/Nuclear_power_phase-out",
        "title": "Nuclear power phase-out"
      },
      {
        "text": "[229]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-DatacenterDynamics-239"
      },
      {
        "text": "Singapore",
        "url": "https://en.wikipedia.org/wiki/Singapore",
        "title": "Singapore"
      },
      {
        "text": "[229]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-DatacenterDynamics-239"
      },
      {
        "text": "Fukushima nuclear accident",
        "url": "https://en.wikipedia.org/wiki/Fukushima_nuclear_accident",
        "title": "Fukushima nuclear accident"
      },
      {
        "text": "[230]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-bloombergjp-240"
      },
      {
        "text": "[230]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-bloombergjp-240"
      },
      {
        "text": "Federal Energy Regulatory Commission",
        "url": "https://en.wikipedia.org/wiki/Federal_Energy_Regulatory_Commission",
        "title": "Federal Energy Regulatory Commission"
      },
      {
        "text": "Talen Energy",
        "url": "https://en.wikipedia.org/wiki/Talen_Energy",
        "title": "Talen Energy"
      },
      {
        "text": "Susquehanna",
        "url": "https://en.wikipedia.org/wiki/Susquehanna_Steam_Electric_Station",
        "title": "Susquehanna Steam Electric Station"
      },
      {
        "text": "[231]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Bloomberg20241104-241"
      },
      {
        "text": "Willie L. Phillips",
        "url": "https://en.wikipedia.org/wiki/Willie_L._Phillips",
        "title": "Willie L. Phillips"
      },
      {
        "text": "[231]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Bloomberg20241104-241"
      },
      {
        "text": "greenhouse gas emissions",
        "url": "https://en.wikipedia.org/wiki/Greenhouse_gas_emissions",
        "title": "Greenhouse gas emissions"
      },
      {
        "text": "rebound effects",
        "url": "https://en.wikipedia.org/wiki/Rebound_effect_(conservation)",
        "title": "Rebound effect (conservation)"
      },
      {
        "text": "[232]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-242"
      },
      {
        "text": "YouTube § Moderation and offensive content",
        "url": "https://en.wikipedia.org/wiki/YouTube#Moderation_and_offensive_content",
        "title": "YouTube"
      },
      {
        "text": "YouTube",
        "url": "https://en.wikipedia.org/wiki/YouTube",
        "title": "YouTube"
      },
      {
        "text": "Facebook",
        "url": "https://en.wikipedia.org/wiki/Facebook",
        "title": "Facebook"
      },
      {
        "text": "recommender systems",
        "url": "https://en.wikipedia.org/wiki/Recommender_system",
        "title": "Recommender system"
      },
      {
        "text": "maximizing",
        "url": "https://en.wikipedia.org/wiki/Mathematical_optimization",
        "title": "Mathematical optimization"
      },
      {
        "text": "misinformation",
        "url": "https://en.wikipedia.org/wiki/Misinformation",
        "title": "Misinformation"
      },
      {
        "text": "conspiracy theories",
        "url": "https://en.wikipedia.org/wiki/Conspiracy_theories",
        "title": "Conspiracy theories"
      },
      {
        "text": "partisan",
        "url": "https://en.wikipedia.org/wiki/Partisan_(politics)",
        "title": "Partisan (politics)"
      },
      {
        "text": "filter bubbles",
        "url": "https://en.wikipedia.org/wiki/Filter_bubbles",
        "title": "Filter bubbles"
      },
      {
        "text": "[233]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTENicas2018-243"
      },
      {
        "text": "[234]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-244"
      },
      {
        "text": "[235]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-245"
      },
      {
        "text": "generative AI",
        "url": "https://en.wikipedia.org/wiki/Generative_AI",
        "title": "Generative AI"
      },
      {
        "text": "[236]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEWilliams2023-246"
      },
      {
        "text": "computational propaganda",
        "url": "https://en.wikipedia.org/wiki/Computational_propaganda",
        "title": "Computational propaganda"
      },
      {
        "text": "[237]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-247"
      },
      {
        "text": "Geoffrey Hinton",
        "url": "https://en.wikipedia.org/wiki/Geoffrey_Hinton",
        "title": "Geoffrey Hinton"
      },
      {
        "text": "[238]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTETaylorHern2023-248"
      },
      {
        "text": "Microsoft",
        "url": "https://en.wikipedia.org/wiki/Microsoft",
        "title": "Microsoft"
      },
      {
        "text": "OpenAI",
        "url": "https://en.wikipedia.org/wiki/OpenAI",
        "title": "OpenAI"
      },
      {
        "text": "personhood credentials",
        "url": "https://en.wikipedia.org/wiki/Proof_of_personhood#Approaches",
        "title": "Proof of personhood"
      },
      {
        "text": "[239]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-249"
      },
      {
        "text": "Algorithmic bias",
        "url": "https://en.wikipedia.org/wiki/Algorithmic_bias",
        "title": "Algorithmic bias"
      },
      {
        "text": "Fairness (machine learning)",
        "url": "https://en.wikipedia.org/wiki/Fairness_(machine_learning)",
        "title": "Fairness (machine learning)"
      },
      {
        "text": "biased",
        "url": "https://en.wikipedia.org/wiki/Algorithmic_bias",
        "title": "Algorithmic bias"
      },
      {
        "text": "[k]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-251"
      },
      {
        "text": "[241]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERose2023-252"
      },
      {
        "text": "[242]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTECNA2019-253"
      },
      {
        "text": "training data",
        "url": "https://en.wikipedia.org/wiki/Training_data",
        "title": "Training data"
      },
      {
        "text": "[243]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEGoffrey200817-254"
      },
      {
        "text": "[241]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERose2023-252"
      },
      {
        "text": "harm",
        "url": "https://en.wikipedia.org/wiki/Harm",
        "title": "Harm"
      },
      {
        "text": "medicine",
        "url": "https://en.wikipedia.org/wiki/Health_equity",
        "title": "Health equity"
      },
      {
        "text": "finance",
        "url": "https://en.wikipedia.org/wiki/Credit_rating",
        "title": "Credit rating"
      },
      {
        "text": "recruitment",
        "url": "https://en.wikipedia.org/wiki/Recruitment",
        "title": "Recruitment"
      },
      {
        "text": "housing",
        "url": "https://en.wikipedia.org/wiki/Public_housing",
        "title": "Public housing"
      },
      {
        "text": "policing",
        "url": "https://en.wikipedia.org/wiki/Policing",
        "title": "Policing"
      },
      {
        "text": "discrimination",
        "url": "https://en.wikipedia.org/wiki/Discrimination",
        "title": "Discrimination"
      },
      {
        "text": "[244]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-255"
      },
      {
        "text": "fairness",
        "url": "https://en.wikipedia.org/wiki/Fairness_(machine_learning)",
        "title": "Fairness (machine learning)"
      },
      {
        "text": "Google Photos",
        "url": "https://en.wikipedia.org/wiki/Google_Photos",
        "title": "Google Photos"
      },
      {
        "text": "[245]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEChristian202025-256"
      },
      {
        "text": "[246]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021995-257"
      },
      {
        "text": "[247]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEGrantHill2023-258"
      },
      {
        "text": "COMPAS",
        "url": "https://en.wikipedia.org/wiki/COMPAS_(software)",
        "title": "COMPAS (software)"
      },
      {
        "text": "U.S. courts",
        "url": "https://en.wikipedia.org/wiki/U.S._court",
        "title": "U.S. court"
      },
      {
        "text": "defendant",
        "url": "https://en.wikipedia.org/wiki/Defendant",
        "title": "Defendant"
      },
      {
        "text": "recidivist",
        "url": "https://en.wikipedia.org/wiki/Recidivist",
        "title": "Recidivist"
      },
      {
        "text": "Julia Angwin",
        "url": "https://en.wikipedia.org/wiki/Julia_Angwin",
        "title": "Julia Angwin"
      },
      {
        "text": "ProPublica",
        "url": "https://en.wikipedia.org/wiki/ProPublica",
        "title": "ProPublica"
      },
      {
        "text": "[248]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTELarsonAngwin2016-259"
      },
      {
        "text": "[l]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-261"
      },
      {
        "text": "[250]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-262"
      },
      {
        "text": "[251]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-263"
      },
      {
        "text": "[252]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-264"
      },
      {
        "text": "[253]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-265"
      },
      {
        "text": "[m]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-267"
      },
      {
        "text": "[246]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021995-257"
      },
      {
        "text": "distributive fairness",
        "url": "https://en.wikipedia.org/wiki/Distributive_justice",
        "title": "Distributive justice"
      },
      {
        "text": "stereotypes",
        "url": "https://en.wikipedia.org/wiki/Stereotype",
        "title": "Stereotype"
      },
      {
        "text": "anti-discrimination laws",
        "url": "https://en.wikipedia.org/wiki/Anti-discrimination_law",
        "title": "Anti-discrimination law"
      },
      {
        "text": "[240]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Samuel-2022-250"
      },
      {
        "text": "Conference on Fairness, Accountability, and Transparency",
        "url": "https://en.wikipedia.org/wiki/ACM_Conference_on_Fairness,_Accountability,_and_Transparency",
        "title": "ACM Conference on Fairness, Accountability, and Transparency"
      },
      {
        "text": "Association for Computing Machinery",
        "url": "https://en.wikipedia.org/wiki/Association_for_Computing_Machinery",
        "title": "Association for Computing Machinery"
      },
      {
        "text": "dubious",
        "url": "https://en.wikipedia.org/wiki/Wikipedia:Accuracy_dispute#Disputed_statement",
        "title": "Wikipedia:Accuracy dispute"
      },
      {
        "text": "discuss",
        "url": "https://en.wikipedia.org/wiki/Talk:Artificial_intelligence#Dubious",
        "title": "Talk:Artificial intelligence"
      },
      {
        "text": "[255]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEDockrill2022-268"
      },
      {
        "text": "Explainable AI",
        "url": "https://en.wikipedia.org/wiki/Explainable_AI",
        "title": "Explainable AI"
      },
      {
        "text": "Algorithmic transparency",
        "url": "https://en.wikipedia.org/wiki/Algorithmic_transparency",
        "title": "Algorithmic transparency"
      },
      {
        "text": "Right to explanation",
        "url": "https://en.wikipedia.org/wiki/Right_to_explanation",
        "title": "Right to explanation"
      },
      {
        "text": "[256]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTESample2017-269"
      },
      {
        "text": "deep neural networks",
        "url": "https://en.wikipedia.org/wiki/Deep_neural_networks",
        "title": "Deep neural networks"
      },
      {
        "text": "linear",
        "url": "https://en.wikipedia.org/wiki/Linear",
        "title": "Linear"
      },
      {
        "text": "[257]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-270"
      },
      {
        "text": "ruler",
        "url": "https://en.wikipedia.org/wiki/Ruler",
        "title": "Ruler"
      },
      {
        "text": "[258]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEChristian2020110-271"
      },
      {
        "text": "[259]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEChristian202088–91-272"
      },
      {
        "text": "[260]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-273"
      },
      {
        "text": "General Data Protection Regulation",
        "url": "https://en.wikipedia.org/wiki/General_Data_Protection_Regulation",
        "title": "General Data Protection Regulation"
      },
      {
        "text": "[n]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-274"
      },
      {
        "text": "[261]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEChristian202091-275"
      },
      {
        "text": "DARPA",
        "url": "https://en.wikipedia.org/wiki/DARPA",
        "title": "DARPA"
      },
      {
        "text": "XAI",
        "url": "https://en.wikipedia.org/wiki/Explainable_Artificial_Intelligence",
        "title": "Explainable Artificial Intelligence"
      },
      {
        "text": "[262]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEChristian202083-276"
      },
      {
        "text": "[263]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEVerma2021-277"
      },
      {
        "text": "[264]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERothman2020-278"
      },
      {
        "text": "Multitask learning",
        "url": "https://en.wikipedia.org/wiki/Multitask_learning",
        "title": "Multitask learning"
      },
      {
        "text": "[265]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEChristian2020105–108-279"
      },
      {
        "text": "Deconvolution",
        "url": "https://en.wikipedia.org/wiki/Deconvolution",
        "title": "Deconvolution"
      },
      {
        "text": "DeepDream",
        "url": "https://en.wikipedia.org/wiki/DeepDream",
        "title": "DeepDream"
      },
      {
        "text": "generative",
        "url": "https://en.wikipedia.org/wiki/Generative_AI",
        "title": "Generative AI"
      },
      {
        "text": "[266]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEChristian2020108–112-280"
      },
      {
        "text": "generative pre-trained transformers",
        "url": "https://en.wikipedia.org/wiki/Generative_pre-trained_transformer",
        "title": "Generative pre-trained transformer"
      },
      {
        "text": "Anthropic",
        "url": "https://en.wikipedia.org/wiki/Anthropic",
        "title": "Anthropic"
      },
      {
        "text": "dictionary learning",
        "url": "https://en.wikipedia.org/wiki/Dictionary_learning",
        "title": "Dictionary learning"
      },
      {
        "text": "[267]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-281"
      },
      {
        "text": "Lethal autonomous weapon",
        "url": "https://en.wikipedia.org/wiki/Lethal_autonomous_weapon",
        "title": "Lethal autonomous weapon"
      },
      {
        "text": "Artificial intelligence arms race",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence_arms_race",
        "title": "Artificial intelligence arms race"
      },
      {
        "text": "AI safety",
        "url": "https://en.wikipedia.org/wiki/AI_safety",
        "title": "AI safety"
      },
      {
        "text": "bad actors",
        "url": "https://en.wikipedia.org/wiki/Bad_actor",
        "title": "Bad actor"
      },
      {
        "text": "authoritarian governments",
        "url": "https://en.wikipedia.org/wiki/Authoritarian",
        "title": "Authoritarian"
      },
      {
        "text": "terrorists",
        "url": "https://en.wikipedia.org/wiki/Terrorist",
        "title": "Terrorist"
      },
      {
        "text": "criminals",
        "url": "https://en.wikipedia.org/wiki/Criminals",
        "title": "Criminals"
      },
      {
        "text": "rogue states",
        "url": "https://en.wikipedia.org/wiki/Rogue_states",
        "title": "Rogue states"
      },
      {
        "text": "[o]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-283"
      },
      {
        "text": "weapons of mass destruction",
        "url": "https://en.wikipedia.org/wiki/Weapons_of_mass_destruction",
        "title": "Weapons of mass destruction"
      },
      {
        "text": "[269]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021987–990-284"
      },
      {
        "text": "kill an innocent person",
        "url": "https://en.wikipedia.org/wiki/Murder",
        "title": "Murder"
      },
      {
        "text": "[269]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021987–990-284"
      },
      {
        "text": "United Nations",
        "url": "https://en.wikipedia.org/wiki/United_Nations",
        "title": "United Nations"
      },
      {
        "text": "Convention on Certain Conventional Weapons",
        "url": "https://en.wikipedia.org/wiki/Convention_on_Certain_Conventional_Weapons",
        "title": "Convention on Certain Conventional Weapons"
      },
      {
        "text": "United States",
        "url": "https://en.wikipedia.org/wiki/United_States",
        "title": "United States"
      },
      {
        "text": "[270]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021988-285"
      },
      {
        "text": "[271]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-286"
      },
      {
        "text": "authoritarian governments",
        "url": "https://en.wikipedia.org/wiki/Authoritarian",
        "title": "Authoritarian"
      },
      {
        "text": "Face",
        "url": "https://en.wikipedia.org/wiki/Facial_recognition_system",
        "title": "Facial recognition system"
      },
      {
        "text": "voice recognition",
        "url": "https://en.wikipedia.org/wiki/Speaker_recognition",
        "title": "Speaker recognition"
      },
      {
        "text": "surveillance",
        "url": "https://en.wikipedia.org/wiki/Surveillance",
        "title": "Surveillance"
      },
      {
        "text": "Machine learning",
        "url": "https://en.wikipedia.org/wiki/Machine_learning",
        "title": "Machine learning"
      },
      {
        "text": "classify",
        "url": "https://en.wikipedia.org/wiki/Classifier_(machine_learning)",
        "title": "Classifier (machine learning)"
      },
      {
        "text": "Recommendation systems",
        "url": "https://en.wikipedia.org/wiki/Recommendation_systems",
        "title": "Recommendation systems"
      },
      {
        "text": "propaganda",
        "url": "https://en.wikipedia.org/wiki/Propaganda",
        "title": "Propaganda"
      },
      {
        "text": "misinformation",
        "url": "https://en.wikipedia.org/wiki/Misinformation",
        "title": "Misinformation"
      },
      {
        "text": "Deepfakes",
        "url": "https://en.wikipedia.org/wiki/Deepfakes",
        "title": "Deepfakes"
      },
      {
        "text": "generative AI",
        "url": "https://en.wikipedia.org/wiki/Generative_AI",
        "title": "Generative AI"
      },
      {
        "text": "centralized decision making",
        "url": "https://en.wikipedia.org/wiki/Technocracy",
        "title": "Technocracy"
      },
      {
        "text": "markets",
        "url": "https://en.wikipedia.org/wiki/Market_(economics)",
        "title": "Market (economics)"
      },
      {
        "text": "digital warfare",
        "url": "https://en.wikipedia.org/wiki/Digital_warfare",
        "title": "Digital warfare"
      },
      {
        "text": "advanced spyware",
        "url": "https://en.wikipedia.org/wiki/Spyware",
        "title": "Spyware"
      },
      {
        "text": "[272]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEHarari2018-287"
      },
      {
        "text": "facial recognition systems",
        "url": "https://en.wikipedia.org/wiki/Facial_recognition_system",
        "title": "Facial recognition system"
      },
      {
        "text": "mass surveillance",
        "url": "https://en.wikipedia.org/wiki/Mass_surveillance",
        "title": "Mass surveillance"
      },
      {
        "text": "[273]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-288"
      },
      {
        "text": "[274]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-289"
      },
      {
        "text": "[275]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEUrbinaLentzosInvernizziEkins2022-290"
      },
      {
        "text": "Workplace impact of artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Workplace_impact_of_artificial_intelligence",
        "title": "Workplace impact of artificial intelligence"
      },
      {
        "text": "Technological unemployment",
        "url": "https://en.wikipedia.org/wiki/Technological_unemployment",
        "title": "Technological unemployment"
      },
      {
        "text": "[276]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-E-291"
      },
      {
        "text": "[277]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-292"
      },
      {
        "text": "unemployment",
        "url": "https://en.wikipedia.org/wiki/Unemployment",
        "title": "Unemployment"
      },
      {
        "text": "productivity",
        "url": "https://en.wikipedia.org/wiki/Productivity",
        "title": "Productivity"
      },
      {
        "text": "redistributed",
        "url": "https://en.wikipedia.org/wiki/Redistribution_of_income_and_wealth",
        "title": "Redistribution of income and wealth"
      },
      {
        "text": "[278]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEIGM_Chicago2017-293"
      },
      {
        "text": "Carl Benedikt Frey",
        "url": "https://en.wikipedia.org/wiki/Carl_Benedikt_Frey",
        "title": "Carl Benedikt Frey"
      },
      {
        "text": "[p]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-295"
      },
      {
        "text": "[280]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-296"
      },
      {
        "text": "[276]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-E-291"
      },
      {
        "text": "[281]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-297"
      },
      {
        "text": "[282]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-298"
      },
      {
        "text": "The Economist",
        "url": "https://en.wikipedia.org/wiki/The_Economist",
        "title": "The Economist"
      },
      {
        "text": "[283]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEMorgenstern2015-299"
      },
      {
        "text": "paralegals",
        "url": "https://en.wikipedia.org/wiki/Paralegal",
        "title": "Paralegal"
      },
      {
        "text": "[284]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-300"
      },
      {
        "text": "Joseph Weizenbaum",
        "url": "https://en.wikipedia.org/wiki/Joseph_Weizenbaum",
        "title": "Joseph Weizenbaum"
      },
      {
        "text": "[285]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-301"
      },
      {
        "text": "Existential risk from artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Existential_risk_from_artificial_intelligence",
        "title": "Existential risk from artificial intelligence"
      },
      {
        "text": "Stephen Hawking",
        "url": "https://en.wikipedia.org/wiki/Stephen_Hawking",
        "title": "Stephen Hawking"
      },
      {
        "text": "spell the end of the human race",
        "url": "https://en.wikipedia.org/wiki/Global_catastrophic_risk",
        "title": "Global catastrophic risk"
      },
      {
        "text": "[286]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTECellan-Jones2014-302"
      },
      {
        "text": "[q]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-304"
      },
      {
        "text": "sentience",
        "url": "https://en.wikipedia.org/wiki/Sentience",
        "title": "Sentience"
      },
      {
        "text": "Nick Bostrom",
        "url": "https://en.wikipedia.org/wiki/Nick_Bostrom",
        "title": "Nick Bostrom"
      },
      {
        "text": "paperclip factory manager",
        "url": "https://en.wikipedia.org/wiki/Instrumental_convergence#Paperclip_maximizer",
        "title": "Instrumental convergence"
      },
      {
        "text": "[288]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEBostrom2014-305"
      },
      {
        "text": "Stuart Russell",
        "url": "https://en.wikipedia.org/wiki/Stuart_J._Russell",
        "title": "Stuart J. Russell"
      },
      {
        "text": "[289]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussell2019-306"
      },
      {
        "text": "superintelligence",
        "url": "https://en.wikipedia.org/wiki/Superintelligence",
        "title": "Superintelligence"
      },
      {
        "text": "aligned",
        "url": "https://en.wikipedia.org/wiki/AI_alignment",
        "title": "AI alignment"
      },
      {
        "text": "[290]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-307"
      },
      {
        "text": "Yuval Noah Harari",
        "url": "https://en.wikipedia.org/wiki/Yuval_Noah_Harari",
        "title": "Yuval Noah Harari"
      },
      {
        "text": "ideologies",
        "url": "https://en.wikipedia.org/wiki/Ideologies",
        "title": "Ideologies"
      },
      {
        "text": "law",
        "url": "https://en.wikipedia.org/wiki/Law",
        "title": "Law"
      },
      {
        "text": "government",
        "url": "https://en.wikipedia.org/wiki/Government",
        "title": "Government"
      },
      {
        "text": "money",
        "url": "https://en.wikipedia.org/wiki/Money",
        "title": "Money"
      },
      {
        "text": "economy",
        "url": "https://en.wikipedia.org/wiki/Economy",
        "title": "Economy"
      },
      {
        "text": "language",
        "url": "https://en.wikipedia.org/wiki/Language",
        "title": "Language"
      },
      {
        "text": "misinformation",
        "url": "https://en.wikipedia.org/wiki/Misinformation",
        "title": "Misinformation"
      },
      {
        "text": "[291]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEHarari2023-308"
      },
      {
        "text": "[292]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEMüllerBostrom2014-309"
      },
      {
        "text": "Stephen Hawking",
        "url": "https://en.wikipedia.org/wiki/Stephen_Hawking",
        "title": "Stephen Hawking"
      },
      {
        "text": "Bill Gates",
        "url": "https://en.wikipedia.org/wiki/Bill_Gates",
        "title": "Bill Gates"
      },
      {
        "text": "Elon Musk",
        "url": "https://en.wikipedia.org/wiki/Elon_Musk",
        "title": "Elon Musk"
      },
      {
        "text": "[293]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-310"
      },
      {
        "text": "Yoshua Bengio",
        "url": "https://en.wikipedia.org/wiki/Yoshua_Bengio",
        "title": "Yoshua Bengio"
      },
      {
        "text": "Stuart Russell",
        "url": "https://en.wikipedia.org/wiki/Stuart_J._Russell",
        "title": "Stuart J. Russell"
      },
      {
        "text": "Demis Hassabis",
        "url": "https://en.wikipedia.org/wiki/Demis_Hassabis",
        "title": "Demis Hassabis"
      },
      {
        "text": "Sam Altman",
        "url": "https://en.wikipedia.org/wiki/Sam_Altman",
        "title": "Sam Altman"
      },
      {
        "text": "Geoffrey Hinton",
        "url": "https://en.wikipedia.org/wiki/Geoffrey_Hinton",
        "title": "Geoffrey Hinton"
      },
      {
        "text": "[294]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-311"
      },
      {
        "text": "AI takeover",
        "url": "https://en.wikipedia.org/wiki/AI_takeover",
        "title": "AI takeover"
      },
      {
        "text": "[295]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-312"
      },
      {
        "text": "[296]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-313"
      },
      {
        "text": "the joint statement",
        "url": "https://en.wikipedia.org/wiki/Statement_on_AI_risk_of_extinction",
        "title": "Statement on AI risk of extinction"
      },
      {
        "text": "[297]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEValance2023-314"
      },
      {
        "text": "Jürgen Schmidhuber",
        "url": "https://en.wikipedia.org/wiki/J%C3%BCrgen_Schmidhuber",
        "title": "Jürgen Schmidhuber"
      },
      {
        "text": "[298]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-315"
      },
      {
        "text": "[299]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-316"
      },
      {
        "text": "[300]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-317"
      },
      {
        "text": "Andrew Ng",
        "url": "https://en.wikipedia.org/wiki/Andrew_Ng",
        "title": "Andrew Ng"
      },
      {
        "text": "[301]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-318"
      },
      {
        "text": "Yann LeCun",
        "url": "https://en.wikipedia.org/wiki/Yann_LeCun",
        "title": "Yann LeCun"
      },
      {
        "text": "[302]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-319"
      },
      {
        "text": "[303]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-320"
      },
      {
        "text": "[304]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEChristian202067,_73-321"
      },
      {
        "text": "Machine ethics",
        "url": "https://en.wikipedia.org/wiki/Machine_ethics",
        "title": "Machine ethics"
      },
      {
        "text": "AI safety",
        "url": "https://en.wikipedia.org/wiki/AI_safety",
        "title": "AI safety"
      },
      {
        "text": "Friendly artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Friendly_artificial_intelligence",
        "title": "Friendly artificial intelligence"
      },
      {
        "text": "Artificial moral agents",
        "url": "https://en.wikipedia.org/wiki/Artificial_moral_agents",
        "title": "Artificial moral agents"
      },
      {
        "text": "Human Compatible",
        "url": "https://en.wikipedia.org/wiki/Human_Compatible",
        "title": "Human Compatible"
      },
      {
        "text": "Eliezer Yudkowsky",
        "url": "https://en.wikipedia.org/wiki/Eliezer_Yudkowsky",
        "title": "Eliezer Yudkowsky"
      },
      {
        "text": "[305]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEYudkowsky2008-322"
      },
      {
        "text": "[306]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEAndersonAnderson2011-323"
      },
      {
        "text": "[306]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEAndersonAnderson2011-323"
      },
      {
        "text": "AAAI",
        "url": "https://en.wikipedia.org/wiki/AAAI",
        "title": "AAAI"
      },
      {
        "text": "[307]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEAAAI2014-324"
      },
      {
        "text": "Wendell Wallach",
        "url": "https://en.wikipedia.org/wiki/Wendell_Wallach",
        "title": "Wendell Wallach"
      },
      {
        "text": "[308]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEWallach2010-325"
      },
      {
        "text": "Stuart J. Russell",
        "url": "https://en.wikipedia.org/wiki/Stuart_J._Russell",
        "title": "Stuart J. Russell"
      },
      {
        "text": "three principles",
        "url": "https://en.wikipedia.org/wiki/Human_Compatible#Russell's_three_principles",
        "title": "Human Compatible"
      },
      {
        "text": "[309]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussell2019173-326"
      },
      {
        "text": "Hugging Face",
        "url": "https://en.wikipedia.org/wiki/Hugging_Face",
        "title": "Hugging Face"
      },
      {
        "text": "[310]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-327"
      },
      {
        "text": "Google",
        "url": "https://en.wikipedia.org/wiki/Google",
        "title": "Google"
      },
      {
        "text": "[311]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-328"
      },
      {
        "text": "EleutherAI",
        "url": "https://en.wikipedia.org/wiki/EleutherAI",
        "title": "EleutherAI"
      },
      {
        "text": "Meta",
        "url": "https://en.wikipedia.org/wiki/Meta_Platforms",
        "title": "Meta Platforms"
      },
      {
        "text": "[312]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-329"
      },
      {
        "text": "Llama 2",
        "url": "https://en.wikipedia.org/wiki/LLaMA",
        "title": "LLaMA"
      },
      {
        "text": "Mistral",
        "url": "https://en.wikipedia.org/wiki/Mistral_AI",
        "title": "Mistral AI"
      },
      {
        "text": "Stable Diffusion",
        "url": "https://en.wikipedia.org/wiki/Stable_Diffusion",
        "title": "Stable Diffusion"
      },
      {
        "text": "[313]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-330"
      },
      {
        "text": "[314]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-331"
      },
      {
        "text": "fine-tuned",
        "url": "https://en.wikipedia.org/wiki/Fine-tuning_(deep_learning)",
        "title": "Fine-tuning (deep learning)"
      },
      {
        "text": "[315]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-332"
      },
      {
        "text": "bioterrorism",
        "url": "https://en.wikipedia.org/wiki/Bioterrorism",
        "title": "Bioterrorism"
      },
      {
        "text": "[316]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-333"
      },
      {
        "text": "Alan Turing Institute",
        "url": "https://en.wikipedia.org/wiki/Alan_Turing_Institute",
        "title": "Alan Turing Institute"
      },
      {
        "text": "[317]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-334"
      },
      {
        "text": "[318]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-335"
      },
      {
        "text": "Asilomar Conference",
        "url": "https://en.wikipedia.org/wiki/Asilomar_Conference_on_Beneficial_AI",
        "title": "Asilomar Conference on Beneficial AI"
      },
      {
        "text": "[319]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-336"
      },
      {
        "text": "[320]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-337"
      },
      {
        "text": "[321]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-338"
      },
      {
        "text": "UK AI Safety Institute",
        "url": "https://en.wikipedia.org/wiki/AI_Safety_Institute_(United_Kingdom)",
        "title": "AI Safety Institute (United Kingdom)"
      },
      {
        "text": "[322]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-339"
      },
      {
        "text": "Regulation of artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Regulation_of_artificial_intelligence",
        "title": "Regulation of artificial intelligence"
      },
      {
        "text": "Regulation of algorithms",
        "url": "https://en.wikipedia.org/wiki/Regulation_of_algorithms",
        "title": "Regulation of algorithms"
      },
      {
        "text": "AI safety",
        "url": "https://en.wikipedia.org/wiki/AI_safety",
        "title": "AI safety"
      },
      {
        "text": "AI Safety Summit",
        "url": "https://en.wikipedia.org/wiki/AI_Safety_Summit",
        "title": "AI Safety Summit"
      },
      {
        "text": "[323]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-340"
      },
      {
        "text": "[324]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTELaw_Library_of_Congress_(U.S.)._Global_Legal_Research_Directorate2019-341"
      },
      {
        "text": "Stanford",
        "url": "https://en.wikipedia.org/wiki/Stanford",
        "title": "Stanford"
      },
      {
        "text": "[325]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEVincent2023-342"
      },
      {
        "text": "[326]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEStanford_University2023-343"
      },
      {
        "text": "[327]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEUNESCO2021-344"
      },
      {
        "text": "[327]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEUNESCO2021-344"
      },
      {
        "text": "Global Partnership on Artificial Intelligence",
        "url": "https://en.wikipedia.org/wiki/Global_Partnership_on_Artificial_Intelligence",
        "title": "Global Partnership on Artificial Intelligence"
      },
      {
        "text": "[327]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEUNESCO2021-344"
      },
      {
        "text": "Henry Kissinger",
        "url": "https://en.wikipedia.org/wiki/Henry_Kissinger",
        "title": "Henry Kissinger"
      },
      {
        "text": "Eric Schmidt",
        "url": "https://en.wikipedia.org/wiki/Eric_Schmidt",
        "title": "Eric Schmidt"
      },
      {
        "text": "Daniel Huttenlocher",
        "url": "https://en.wikipedia.org/wiki/Daniel_Huttenlocher",
        "title": "Daniel Huttenlocher"
      },
      {
        "text": "[328]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEKissinger2021-345"
      },
      {
        "text": "[329]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEAltmanBrockmanSutskever2023-346"
      },
      {
        "text": "[330]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-347"
      },
      {
        "text": "Council of Europe",
        "url": "https://en.wikipedia.org/wiki/Council_of_Europe",
        "title": "Council of Europe"
      },
      {
        "text": "Framework Convention on Artificial Intelligence and Human Rights, Democracy and the Rule of Law",
        "url": "https://en.wikipedia.org/wiki/Framework_Convention_on_Artificial_Intelligence_and_Human_Rights,_Democracy_and_the_Rule_of_Law",
        "title": "Framework Convention on Artificial Intelligence and Human Rights, Democracy and the Rule of Law"
      },
      {
        "text": "[331]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-348"
      },
      {
        "text": "Ipsos",
        "url": "https://en.wikipedia.org/wiki/Ipsos",
        "title": "Ipsos"
      },
      {
        "text": "[325]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEVincent2023-342"
      },
      {
        "text": "Reuters",
        "url": "https://en.wikipedia.org/wiki/Reuters",
        "title": "Reuters"
      },
      {
        "text": "[332]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEEdwards2023-349"
      },
      {
        "text": "Fox News",
        "url": "https://en.wikipedia.org/wiki/Fox_News",
        "title": "Fox News"
      },
      {
        "text": "[333]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEKasperowicz2023-350"
      },
      {
        "text": "[334]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEFox_News2023-351"
      },
      {
        "text": "AI Safety Summit",
        "url": "https://en.wikipedia.org/wiki/AI_Safety_Summit",
        "title": "AI Safety Summit"
      },
      {
        "text": "Bletchley Park",
        "url": "https://en.wikipedia.org/wiki/Bletchley_Park",
        "title": "Bletchley Park"
      },
      {
        "text": "[335]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-352"
      },
      {
        "text": "[336]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-353"
      },
      {
        "text": "[337]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-354"
      },
      {
        "text": "AI Seoul Summit",
        "url": "https://en.wikipedia.org/wiki/AI_Seoul_Summit",
        "title": "AI Seoul Summit"
      },
      {
        "text": "[338]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-355"
      },
      {
        "text": "[339]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-356"
      },
      {
        "text": "History of artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/History_of_artificial_intelligence",
        "title": "History of artificial intelligence"
      },
      {
        "text": "Timeline of artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Timeline_of_artificial_intelligence",
        "title": "Timeline of artificial intelligence"
      },
      {
        "text": "[340]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-RandDworld_20241103-357"
      },
      {
        "text": "[340]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-RandDworld_20241103-357"
      },
      {
        "text": "Alan Turing",
        "url": "https://en.wikipedia.org/wiki/Alan_Turing",
        "title": "Alan Turing"
      },
      {
        "text": "theory of computation",
        "url": "https://en.wikipedia.org/wiki/Theory_of_computation",
        "title": "Theory of computation"
      },
      {
        "text": "[341]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig20219-358"
      },
      {
        "text": "[342]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Clarendon_Press-2004-359"
      },
      {
        "text": "cybernetics",
        "url": "https://en.wikipedia.org/wiki/Cybernetics",
        "title": "Cybernetics"
      },
      {
        "text": "information theory",
        "url": "https://en.wikipedia.org/wiki/Information_theory",
        "title": "Information theory"
      },
      {
        "text": "neurobiology",
        "url": "https://en.wikipedia.org/wiki/Neurobiology",
        "title": "Neurobiology"
      },
      {
        "text": "[r]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-361"
      },
      {
        "text": "[344]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-362"
      },
      {
        "text": "McCullouch",
        "url": "https://en.wikipedia.org/wiki/Warren_McCullouch",
        "title": "Warren McCullouch"
      },
      {
        "text": "Pitts",
        "url": "https://en.wikipedia.org/wiki/Walter_Pitts",
        "title": "Walter Pitts"
      },
      {
        "text": "[115]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig202117-123"
      },
      {
        "text": "Computing Machinery and Intelligence",
        "url": "https://en.wikipedia.org/wiki/Computing_Machinery_and_Intelligence",
        "title": "Computing Machinery and Intelligence"
      },
      {
        "text": "Turing test",
        "url": "https://en.wikipedia.org/wiki/Turing_test",
        "title": "Turing test"
      },
      {
        "text": "[345]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Turing-363"
      },
      {
        "text": "[342]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Clarendon_Press-2004-359"
      },
      {
        "text": "a workshop",
        "url": "https://en.wikipedia.org/wiki/Dartmouth_workshop",
        "title": "Dartmouth workshop"
      },
      {
        "text": "Dartmouth College",
        "url": "https://en.wikipedia.org/wiki/Dartmouth_College",
        "title": "Dartmouth College"
      },
      {
        "text": "[s]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-365"
      },
      {
        "text": "[6]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Dartmouth_workshop-8"
      },
      {
        "text": "[t]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-367"
      },
      {
        "text": "[u]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-369"
      },
      {
        "text": "checkers",
        "url": "https://en.wikipedia.org/wiki/Checkers",
        "title": "Checkers"
      },
      {
        "text": "logical theorems",
        "url": "https://en.wikipedia.org/wiki/Theorem",
        "title": "Theorem"
      },
      {
        "text": "[v]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-370"
      },
      {
        "text": "[7]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Succ1-9"
      },
      {
        "text": "[342]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Clarendon_Press-2004-359"
      },
      {
        "text": "general intelligence",
        "url": "https://en.wikipedia.org/wiki/Artificial_general_intelligence",
        "title": "Artificial general intelligence"
      },
      {
        "text": "[349]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTENewquist199486–86-371"
      },
      {
        "text": "Herbert Simon",
        "url": "https://en.wikipedia.org/wiki/Herbert_A._Simon",
        "title": "Herbert A. Simon"
      },
      {
        "text": "[350]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-372"
      },
      {
        "text": "Marvin Minsky",
        "url": "https://en.wikipedia.org/wiki/Marvin_Minsky",
        "title": "Marvin Minsky"
      },
      {
        "text": "[351]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-373"
      },
      {
        "text": "[w]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-375"
      },
      {
        "text": "criticism",
        "url": "https://en.wikipedia.org/wiki/Lighthill_report",
        "title": "Lighthill report"
      },
      {
        "text": "Sir James Lighthill",
        "url": "https://en.wikipedia.org/wiki/Sir_James_Lighthill",
        "title": "Sir James Lighthill"
      },
      {
        "text": "[353]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTELighthill1973-376"
      },
      {
        "text": "fund more productive projects",
        "url": "https://en.wikipedia.org/wiki/Mansfield_Amendment",
        "title": "Mansfield Amendment"
      },
      {
        "text": "[354]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTENRC1999212–213-377"
      },
      {
        "text": "Minsky",
        "url": "https://en.wikipedia.org/wiki/Marvin_Minsky",
        "title": "Marvin Minsky"
      },
      {
        "text": "Papert",
        "url": "https://en.wikipedia.org/wiki/Papert",
        "title": "Papert"
      },
      {
        "text": "Perceptrons",
        "url": "https://en.wikipedia.org/wiki/Perceptron",
        "title": "Perceptron"
      },
      {
        "text": "artificial neural networks",
        "url": "https://en.wikipedia.org/wiki/Artificial_neural_networks",
        "title": "Artificial neural networks"
      },
      {
        "text": "[355]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig202122-378"
      },
      {
        "text": "AI winter",
        "url": "https://en.wikipedia.org/wiki/AI_winter",
        "title": "AI winter"
      },
      {
        "text": "[9]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-First_AI_Winter-11"
      },
      {
        "text": "expert systems",
        "url": "https://en.wikipedia.org/wiki/Expert_system",
        "title": "Expert system"
      },
      {
        "text": "[356]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-379"
      },
      {
        "text": "fifth generation computer",
        "url": "https://en.wikipedia.org/wiki/Fifth_generation_computer",
        "title": "Fifth generation computer"
      },
      {
        "text": "academic research",
        "url": "https://en.wikipedia.org/wiki/Academic_research",
        "title": "Academic research"
      },
      {
        "text": "[8]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Fund01-10"
      },
      {
        "text": "Lisp Machine",
        "url": "https://en.wikipedia.org/wiki/Lisp_Machine",
        "title": "Lisp Machine"
      },
      {
        "text": "[10]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Second_AI_Winter-12"
      },
      {
        "text": "symbols",
        "url": "https://en.wikipedia.org/wiki/Symbolic_AI",
        "title": "Symbolic AI"
      },
      {
        "text": "mental objects",
        "url": "https://en.wikipedia.org/wiki/Mental_objects",
        "title": "Mental objects"
      },
      {
        "text": "perception",
        "url": "https://en.wikipedia.org/wiki/Machine_perception",
        "title": "Machine perception"
      },
      {
        "text": "robotics",
        "url": "https://en.wikipedia.org/wiki/Robotics",
        "title": "Robotics"
      },
      {
        "text": "learning",
        "url": "https://en.wikipedia.org/wiki/Machine_learning",
        "title": "Machine learning"
      },
      {
        "text": "pattern recognition",
        "url": "https://en.wikipedia.org/wiki/Pattern_recognition",
        "title": "Pattern recognition"
      },
      {
        "text": "[357]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig202124-380"
      },
      {
        "text": "[358]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTENilsson19987-381"
      },
      {
        "text": "Rodney Brooks",
        "url": "https://en.wikipedia.org/wiki/Rodney_Brooks",
        "title": "Rodney Brooks"
      },
      {
        "text": "[x]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-386"
      },
      {
        "text": "Judea Pearl",
        "url": "https://en.wikipedia.org/wiki/Judea_Pearl",
        "title": "Judea Pearl"
      },
      {
        "text": "Lofti Zadeh",
        "url": "https://en.wikipedia.org/wiki/Lofti_Zadeh",
        "title": "Lofti Zadeh"
      },
      {
        "text": "[86]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Stoch-92"
      },
      {
        "text": "[363]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig202125-387"
      },
      {
        "text": "connectionism",
        "url": "https://en.wikipedia.org/wiki/Connectionism",
        "title": "Connectionism"
      },
      {
        "text": "Geoffrey Hinton",
        "url": "https://en.wikipedia.org/wiki/Geoffrey_Hinton",
        "title": "Geoffrey Hinton"
      },
      {
        "text": "[364]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-388"
      },
      {
        "text": "Yann LeCun",
        "url": "https://en.wikipedia.org/wiki/Yann_LeCun",
        "title": "Yann LeCun"
      },
      {
        "text": "convolutional neural networks",
        "url": "https://en.wikipedia.org/wiki/Convolutional_neural_networks",
        "title": "Convolutional neural networks"
      },
      {
        "text": "[365]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig202126-389"
      },
      {
        "text": "narrow",
        "url": "https://en.wikipedia.org/wiki/Narrow_AI",
        "title": "Narrow AI"
      },
      {
        "text": "statistics",
        "url": "https://en.wikipedia.org/wiki/Statistics",
        "title": "Statistics"
      },
      {
        "text": "economics",
        "url": "https://en.wikipedia.org/wiki/Economics",
        "title": "Economics"
      },
      {
        "text": "mathematics",
        "url": "https://en.wikipedia.org/wiki/Mathematical_optimization",
        "title": "Mathematical optimization"
      },
      {
        "text": "[366]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Formal_and_narrow_methods_adopted_in_the_1990s-390"
      },
      {
        "text": "AI effect",
        "url": "https://en.wikipedia.org/wiki/AI_effect",
        "title": "AI effect"
      },
      {
        "text": "[367]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-391"
      },
      {
        "text": "artificial general intelligence",
        "url": "https://en.wikipedia.org/wiki/Artificial_general_intelligence",
        "title": "Artificial general intelligence"
      },
      {
        "text": "[4]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Artificial_general_intelligence-5"
      },
      {
        "text": "Deep learning",
        "url": "https://en.wikipedia.org/wiki/Deep_learning",
        "title": "Deep learning"
      },
      {
        "text": "[11]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Deep_learning_revolution-13"
      },
      {
        "text": "[y]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-393"
      },
      {
        "text": "faster computers",
        "url": "https://en.wikipedia.org/wiki/Moore%27s_law",
        "title": "Moore's law"
      },
      {
        "text": "[369]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-394"
      },
      {
        "text": "graphics processing units",
        "url": "https://en.wikipedia.org/wiki/Graphics_processing_unit",
        "title": "Graphics processing unit"
      },
      {
        "text": "cloud computing",
        "url": "https://en.wikipedia.org/wiki/Cloud_computing",
        "title": "Cloud computing"
      },
      {
        "text": "[370]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEClark2015b-395"
      },
      {
        "text": "large amounts of data",
        "url": "https://en.wikipedia.org/wiki/Big_data",
        "title": "Big data"
      },
      {
        "text": "[371]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-396"
      },
      {
        "text": "[370]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEClark2015b-395"
      },
      {
        "text": "ImageNet",
        "url": "https://en.wikipedia.org/wiki/ImageNet",
        "title": "ImageNet"
      },
      {
        "text": "[z]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-397"
      },
      {
        "text": "[327]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEUNESCO2021-344"
      },
      {
        "text": "fairness",
        "url": "https://en.wikipedia.org/wiki/Algorithmic_fairness",
        "title": "Algorithmic fairness"
      },
      {
        "text": "alignment problem",
        "url": "https://en.wikipedia.org/wiki/AI_alignment",
        "title": "AI alignment"
      },
      {
        "text": "[304]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEChristian202067,_73-321"
      },
      {
        "text": "AlphaGo",
        "url": "https://en.wikipedia.org/wiki/AlphaGo",
        "title": "AlphaGo"
      },
      {
        "text": "DeepMind",
        "url": "https://en.wikipedia.org/wiki/DeepMind",
        "title": "DeepMind"
      },
      {
        "text": "Go player",
        "url": "https://en.wikipedia.org/wiki/Go_player",
        "title": "Go player"
      },
      {
        "text": "GPT-3",
        "url": "https://en.wikipedia.org/wiki/GPT-3",
        "title": "GPT-3"
      },
      {
        "text": "large language model",
        "url": "https://en.wikipedia.org/wiki/Large_language_model",
        "title": "Large language model"
      },
      {
        "text": "OpenAI",
        "url": "https://en.wikipedia.org/wiki/OpenAI",
        "title": "OpenAI"
      },
      {
        "text": "[372]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-398"
      },
      {
        "text": "ChatGPT",
        "url": "https://en.wikipedia.org/wiki/ChatGPT",
        "title": "ChatGPT"
      },
      {
        "text": "[373]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-399"
      },
      {
        "text": "[374]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-400"
      },
      {
        "text": "AI boom",
        "url": "https://en.wikipedia.org/wiki/AI_boom",
        "title": "AI boom"
      },
      {
        "text": "[375]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEDiFeliciantonio2023-401"
      },
      {
        "text": "[376]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEGoswami2023-402"
      },
      {
        "text": "startups",
        "url": "https://en.wikipedia.org/wiki/Startup_company",
        "title": "Startup company"
      },
      {
        "text": "[377]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-403"
      },
      {
        "text": "Philosophy of artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_artificial_intelligence",
        "title": "Philosophy of artificial intelligence"
      },
      {
        "text": "[378]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-404"
      },
      {
        "text": "[379]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Jarow-2024-405"
      },
      {
        "text": "epistemology",
        "url": "https://en.wikipedia.org/wiki/Epistemology",
        "title": "Epistemology"
      },
      {
        "text": "free will",
        "url": "https://en.wikipedia.org/wiki/Free_will",
        "title": "Free will"
      },
      {
        "text": "[380]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-406"
      },
      {
        "text": "ethics of AI",
        "url": "https://en.wikipedia.org/wiki/Ethics_of_AI",
        "title": "Ethics of AI"
      },
      {
        "text": "[379]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Jarow-2024-405"
      },
      {
        "text": "Turing test",
        "url": "https://en.wikipedia.org/wiki/Turing_test",
        "title": "Turing test"
      },
      {
        "text": "Intelligent agent",
        "url": "https://en.wikipedia.org/wiki/Intelligent_agent",
        "title": "Intelligent agent"
      },
      {
        "text": "Dartmouth workshop",
        "url": "https://en.wikipedia.org/wiki/Dartmouth_workshop",
        "title": "Dartmouth workshop"
      },
      {
        "text": "Synthetic intelligence",
        "url": "https://en.wikipedia.org/wiki/Synthetic_intelligence",
        "title": "Synthetic intelligence"
      },
      {
        "text": "Alan Turing",
        "url": "https://en.wikipedia.org/wiki/Alan_Turing",
        "title": "Alan Turing"
      },
      {
        "text": "[381]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTETuring19501-407"
      },
      {
        "text": "[381]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTETuring19501-407"
      },
      {
        "text": "[345]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Turing-363"
      },
      {
        "text": "we can not determine these things about other people",
        "url": "https://en.wikipedia.org/wiki/Problem_of_other_minds",
        "title": "Problem of other minds"
      },
      {
        "text": "[382]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTETuring1950Under_\"The_Argument_from_Consciousness\"-408"
      },
      {
        "text": "[383]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-409"
      },
      {
        "text": "Russell",
        "url": "https://en.wikipedia.org/wiki/Stuart_J._Russell",
        "title": "Stuart J. Russell"
      },
      {
        "text": "Norvig",
        "url": "https://en.wikipedia.org/wiki/Norvig",
        "title": "Norvig"
      },
      {
        "text": "[1]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig20211–4-1"
      },
      {
        "text": "Aeronautical engineering",
        "url": "https://en.wikipedia.org/wiki/Aeronautics",
        "title": "Aeronautics"
      },
      {
        "text": "pigeons",
        "url": "https://en.wikipedia.org/wiki/Pigeon",
        "title": "Pigeon"
      },
      {
        "text": "[384]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig20213-410"
      },
      {
        "text": "John McCarthy",
        "url": "https://en.wikipedia.org/wiki/John_McCarthy_(computer_scientist)",
        "title": "John McCarthy (computer scientist)"
      },
      {
        "text": "[385]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEMaker2006-411"
      },
      {
        "text": "[386]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEMcCarthy1999-412"
      },
      {
        "text": "Marvin Minsky",
        "url": "https://en.wikipedia.org/wiki/Marvin_Minsky",
        "title": "Marvin Minsky"
      },
      {
        "text": "[387]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEMinsky1986-413"
      },
      {
        "text": "[1]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig20211–4-1"
      },
      {
        "text": "[388]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-414"
      },
      {
        "text": "[389]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-415"
      },
      {
        "text": "buzzword",
        "url": "https://en.wikipedia.org/wiki/Buzzword",
        "title": "Buzzword"
      },
      {
        "text": "[390]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-416"
      },
      {
        "text": "paradigm",
        "url": "https://en.wikipedia.org/wiki/Paradigm",
        "title": "Paradigm"
      },
      {
        "text": "[aa]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-418"
      },
      {
        "text": "sub-symbolic",
        "url": "https://en.wikipedia.org/wiki/Sub-symbolic",
        "title": "Sub-symbolic"
      },
      {
        "text": "soft",
        "url": "https://en.wikipedia.org/wiki/Soft_computing",
        "title": "Soft computing"
      },
      {
        "text": "narrow",
        "url": "https://en.wikipedia.org/wiki/Artificial_general_intelligence",
        "title": "Artificial general intelligence"
      },
      {
        "text": "Symbolic AI",
        "url": "https://en.wikipedia.org/wiki/Symbolic_AI",
        "title": "Symbolic AI"
      },
      {
        "text": "GOFAI",
        "url": "https://en.wikipedia.org/wiki/GOFAI",
        "title": "GOFAI"
      },
      {
        "text": "[392]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEHaugeland1985112–117-419"
      },
      {
        "text": "physical symbol systems hypothesis",
        "url": "https://en.wikipedia.org/wiki/Physical_symbol_systems_hypothesis",
        "title": "Physical symbol systems hypothesis"
      },
      {
        "text": "[393]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-420"
      },
      {
        "text": "Moravec's paradox",
        "url": "https://en.wikipedia.org/wiki/Moravec%27s_paradox",
        "title": "Moravec's paradox"
      },
      {
        "text": "[394]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-421"
      },
      {
        "text": "Hubert Dreyfus",
        "url": "https://en.wikipedia.org/wiki/Hubert_Dreyfus",
        "title": "Hubert Dreyfus"
      },
      {
        "text": "argued",
        "url": "https://en.wikipedia.org/wiki/Dreyfus%27_critique_of_AI",
        "title": "Dreyfus' critique of AI"
      },
      {
        "text": "[395]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-422"
      },
      {
        "text": "[ab]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-424"
      },
      {
        "text": "[16]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Psychological_evidence_of_the_prevalence_of_sub-18"
      },
      {
        "text": "sub-symbolic",
        "url": "https://en.wikipedia.org/wiki/Sub-symbolic",
        "title": "Sub-symbolic"
      },
      {
        "text": "algorithmic bias",
        "url": "https://en.wikipedia.org/wiki/Algorithmic_bias",
        "title": "Algorithmic bias"
      },
      {
        "text": "Noam Chomsky",
        "url": "https://en.wikipedia.org/wiki/Noam_Chomsky",
        "title": "Noam Chomsky"
      },
      {
        "text": "[397]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTELangley2011-425"
      },
      {
        "text": "[398]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEKatz2012-426"
      },
      {
        "text": "explainable AI",
        "url": "https://en.wikipedia.org/wiki/Explainable_AI",
        "title": "Explainable AI"
      },
      {
        "text": "neuro-symbolic artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Neuro-symbolic_AI",
        "title": "Neuro-symbolic AI"
      },
      {
        "text": "Neats and scruffies",
        "url": "https://en.wikipedia.org/wiki/Neats_and_scruffies",
        "title": "Neats and scruffies"
      },
      {
        "text": "logic",
        "url": "https://en.wikipedia.org/wiki/Logic",
        "title": "Logic"
      },
      {
        "text": "optimization",
        "url": "https://en.wikipedia.org/wiki/Optimization",
        "title": "Optimization"
      },
      {
        "text": "neural networks",
        "url": "https://en.wikipedia.org/wiki/Artificial_neural_network",
        "title": "Artificial neural network"
      },
      {
        "text": "[399]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-427"
      },
      {
        "text": "Soft computing",
        "url": "https://en.wikipedia.org/wiki/Soft_computing",
        "title": "Soft computing"
      },
      {
        "text": "intractable",
        "url": "https://en.wikipedia.org/wiki/Intractability_(complexity)",
        "title": "Intractability (complexity)"
      },
      {
        "text": "[15]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Intractability_and_efficiency_and_the_combinatorial_explosion-17"
      },
      {
        "text": "genetic algorithms",
        "url": "https://en.wikipedia.org/wiki/Genetic_algorithms",
        "title": "Genetic algorithms"
      },
      {
        "text": "fuzzy logic",
        "url": "https://en.wikipedia.org/wiki/Fuzzy_logic",
        "title": "Fuzzy logic"
      },
      {
        "text": "Weak artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Weak_artificial_intelligence",
        "title": "Weak artificial intelligence"
      },
      {
        "text": "Artificial general intelligence",
        "url": "https://en.wikipedia.org/wiki/Artificial_general_intelligence",
        "title": "Artificial general intelligence"
      },
      {
        "text": "superintelligence",
        "url": "https://en.wikipedia.org/wiki/Superintelligence",
        "title": "Superintelligence"
      },
      {
        "text": "[400]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEPennachinGoertzel2007-428"
      },
      {
        "text": "[401]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERoberts2016-429"
      },
      {
        "text": "Philosophy of artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_artificial_intelligence",
        "title": "Philosophy of artificial intelligence"
      },
      {
        "text": "Artificial consciousness",
        "url": "https://en.wikipedia.org/wiki/Artificial_consciousness",
        "title": "Artificial consciousness"
      },
      {
        "text": "philosophy of mind",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_mind",
        "title": "Philosophy of mind"
      },
      {
        "text": "mind",
        "url": "https://en.wikipedia.org/wiki/Mind",
        "title": "Mind"
      },
      {
        "text": "consciousness",
        "url": "https://en.wikipedia.org/wiki/Consciousness",
        "title": "Consciousness"
      },
      {
        "text": "mental states",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_mind",
        "title": "Philosophy of mind"
      },
      {
        "text": "Russell",
        "url": "https://en.wikipedia.org/wiki/Stuart_J._Russell",
        "title": "Stuart J. Russell"
      },
      {
        "text": "Norvig",
        "url": "https://en.wikipedia.org/wiki/Norvig",
        "title": "Norvig"
      },
      {
        "text": "[402]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021986-430"
      },
      {
        "text": "artificial intelligence in fiction",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence_in_fiction",
        "title": "Artificial intelligence in fiction"
      },
      {
        "text": "Hard problem of consciousness",
        "url": "https://en.wikipedia.org/wiki/Hard_problem_of_consciousness",
        "title": "Hard problem of consciousness"
      },
      {
        "text": "Theory of mind",
        "url": "https://en.wikipedia.org/wiki/Theory_of_mind",
        "title": "Theory of mind"
      },
      {
        "text": "David Chalmers",
        "url": "https://en.wikipedia.org/wiki/David_Chalmers",
        "title": "David Chalmers"
      },
      {
        "text": "[403]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEChalmers1995-431"
      },
      {
        "text": "information processing",
        "url": "https://en.wikipedia.org/wiki/Information_processing_(psychology)",
        "title": "Information processing (psychology)"
      },
      {
        "text": "subjective experience",
        "url": "https://en.wikipedia.org/wiki/Subjective_experience",
        "title": "Subjective experience"
      },
      {
        "text": "[404]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEDennett1991-432"
      },
      {
        "text": "Computational theory of mind",
        "url": "https://en.wikipedia.org/wiki/Computational_theory_of_mind",
        "title": "Computational theory of mind"
      },
      {
        "text": "Functionalism (philosophy of mind)",
        "url": "https://en.wikipedia.org/wiki/Functionalism_(philosophy_of_mind)",
        "title": "Functionalism (philosophy of mind)"
      },
      {
        "text": "philosophy of mind",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_mind",
        "title": "Philosophy of mind"
      },
      {
        "text": "mind–body problem",
        "url": "https://en.wikipedia.org/wiki/Mind%E2%80%93body_problem",
        "title": "Mind–body problem"
      },
      {
        "text": "Jerry Fodor",
        "url": "https://en.wikipedia.org/wiki/Jerry_Fodor",
        "title": "Jerry Fodor"
      },
      {
        "text": "Hilary Putnam",
        "url": "https://en.wikipedia.org/wiki/Hilary_Putnam",
        "title": "Hilary Putnam"
      },
      {
        "text": "[405]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEHorst2005-433"
      },
      {
        "text": "John Searle",
        "url": "https://en.wikipedia.org/wiki/John_Searle",
        "title": "John Searle"
      },
      {
        "text": "strong AI",
        "url": "https://en.wikipedia.org/wiki/Strong_AI_hypothesis",
        "title": "Strong AI hypothesis"
      },
      {
        "text": "[ac]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Searle's_strong_AI-437"
      },
      {
        "text": "Chinese room",
        "url": "https://en.wikipedia.org/wiki/Chinese_room",
        "title": "Chinese room"
      },
      {
        "text": "[409]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-438"
      },
      {
        "text": "AI is sentient",
        "url": "https://en.wikipedia.org/wiki/Sentient_AI",
        "title": "Sentient AI"
      },
      {
        "text": "[410]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-439"
      },
      {
        "text": "[411]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Thomson-2022-440"
      },
      {
        "text": "[412]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Kateman-2023-441"
      },
      {
        "text": "Sapience",
        "url": "https://en.wikipedia.org/wiki/Sapience",
        "title": "Sapience"
      },
      {
        "text": "self-awareness",
        "url": "https://en.wikipedia.org/wiki/Self-awareness",
        "title": "Self-awareness"
      },
      {
        "text": "[411]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Thomson-2022-440"
      },
      {
        "text": "Robot rights",
        "url": "https://en.wikipedia.org/wiki/Robot_rights",
        "title": "Robot rights"
      },
      {
        "text": "[413]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-442"
      },
      {
        "text": "[414]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-443"
      },
      {
        "text": "human rights",
        "url": "https://en.wikipedia.org/wiki/Human_rights",
        "title": "Human rights"
      },
      {
        "text": "[415]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-444"
      },
      {
        "text": "[416]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-445"
      },
      {
        "text": "moral blind spot",
        "url": "https://en.wikipedia.org/wiki/Moral_blindness",
        "title": "Moral blindness"
      },
      {
        "text": "slavery",
        "url": "https://en.wikipedia.org/wiki/Slavery",
        "title": "Slavery"
      },
      {
        "text": "factory farming",
        "url": "https://en.wikipedia.org/wiki/Factory_farming",
        "title": "Factory farming"
      },
      {
        "text": "large-scale suffering",
        "url": "https://en.wikipedia.org/wiki/Suffering_risks",
        "title": "Suffering risks"
      },
      {
        "text": "[412]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Kateman-2023-441"
      },
      {
        "text": "[411]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Thomson-2022-440"
      },
      {
        "text": "superintelligence",
        "url": "https://en.wikipedia.org/wiki/Superintelligence",
        "title": "Superintelligence"
      },
      {
        "text": "[401]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERoberts2016-429"
      },
      {
        "text": "artificial general intelligence",
        "url": "https://en.wikipedia.org/wiki/Artificial_general_intelligence",
        "title": "Artificial general intelligence"
      },
      {
        "text": "reprogram and improve itself",
        "url": "https://en.wikipedia.org/wiki/Recursive_self-improvement",
        "title": "Recursive self-improvement"
      },
      {
        "text": "I. J. Good",
        "url": "https://en.wikipedia.org/wiki/I._J._Good",
        "title": "I. J. Good"
      },
      {
        "text": "intelligence explosion",
        "url": "https://en.wikipedia.org/wiki/Intelligence_explosion",
        "title": "Intelligence explosion"
      },
      {
        "text": "Vernor Vinge",
        "url": "https://en.wikipedia.org/wiki/Vernor_Vinge",
        "title": "Vernor Vinge"
      },
      {
        "text": "singularity",
        "url": "https://en.wikipedia.org/wiki/Technological_singularity",
        "title": "Technological singularity"
      },
      {
        "text": "[417]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-446"
      },
      {
        "text": "S-shaped curve",
        "url": "https://en.wikipedia.org/wiki/S-shaped_curve",
        "title": "S-shaped curve"
      },
      {
        "text": "[418]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig20211005-447"
      },
      {
        "text": "Transhumanism",
        "url": "https://en.wikipedia.org/wiki/Transhumanism",
        "title": "Transhumanism"
      },
      {
        "text": "Hans Moravec",
        "url": "https://en.wikipedia.org/wiki/Hans_Moravec",
        "title": "Hans Moravec"
      },
      {
        "text": "Kevin Warwick",
        "url": "https://en.wikipedia.org/wiki/Kevin_Warwick",
        "title": "Kevin Warwick"
      },
      {
        "text": "Ray Kurzweil",
        "url": "https://en.wikipedia.org/wiki/Ray_Kurzweil",
        "title": "Ray Kurzweil"
      },
      {
        "text": "cyborgs",
        "url": "https://en.wikipedia.org/wiki/Cyborg",
        "title": "Cyborg"
      },
      {
        "text": "Aldous Huxley",
        "url": "https://en.wikipedia.org/wiki/Aldous_Huxley",
        "title": "Aldous Huxley"
      },
      {
        "text": "Robert Ettinger",
        "url": "https://en.wikipedia.org/wiki/Robert_Ettinger",
        "title": "Robert Ettinger"
      },
      {
        "text": "[419]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-448"
      },
      {
        "text": "Edward Fredkin",
        "url": "https://en.wikipedia.org/wiki/Edward_Fredkin",
        "title": "Edward Fredkin"
      },
      {
        "text": "Samuel Butler",
        "url": "https://en.wikipedia.org/wiki/Samuel_Butler_(novelist)",
        "title": "Samuel Butler (novelist)"
      },
      {
        "text": "Darwin among the Machines",
        "url": "https://en.wikipedia.org/wiki/Darwin_among_the_Machines",
        "title": "Darwin among the Machines"
      },
      {
        "text": "George Dyson",
        "url": "https://en.wikipedia.org/wiki/George_Dyson_(science_historian)",
        "title": "George Dyson (science historian)"
      },
      {
        "text": "Darwin Among the Machines: The Evolution of Global Intelligence",
        "url": "https://en.wikipedia.org/wiki/Darwin_Among_the_Machines#Evolution_of_Global_Intelligence",
        "title": "Darwin Among the Machines"
      },
      {
        "text": "[420]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-449"
      },
      {
        "text": "Dan McQuillan",
        "url": "https://en.wikipedia.org/wiki/Dan_McQuillan",
        "title": "Dan McQuillan"
      },
      {
        "text": "degrowth",
        "url": "https://en.wikipedia.org/wiki/Degrowth",
        "title": "Degrowth"
      },
      {
        "text": "[421]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-v935-450"
      },
      {
        "text": "Artificial intelligence in fiction",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence_in_fiction",
        "title": "Artificial intelligence in fiction"
      },
      {
        "text": "Karel Čapek",
        "url": "https://en.wikipedia.org/wiki/Karel_%C4%8Capek",
        "title": "Karel Čapek"
      },
      {
        "text": "R.U.R.",
        "url": "https://en.wikipedia.org/wiki/R.U.R.",
        "title": "R.U.R."
      },
      {
        "text": "[422]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-AI_in_myth-451"
      },
      {
        "text": "science fiction",
        "url": "https://en.wikipedia.org/wiki/Science_fiction",
        "title": "Science fiction"
      },
      {
        "text": "[423]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEMcCorduck2004340–400-452"
      },
      {
        "text": "trope",
        "url": "https://en.wikipedia.org/wiki/Trope_(literature)",
        "title": "Trope (literature)"
      },
      {
        "text": "Mary Shelley",
        "url": "https://en.wikipedia.org/wiki/Mary_Shelley",
        "title": "Mary Shelley"
      },
      {
        "text": "Frankenstein",
        "url": "https://en.wikipedia.org/wiki/Frankenstein",
        "title": "Frankenstein"
      },
      {
        "text": "Arthur C. Clarke's",
        "url": "https://en.wikipedia.org/wiki/2001:_A_Space_Odyssey_(novel)",
        "title": "2001: A Space Odyssey (novel)"
      },
      {
        "text": "Stanley Kubrick's",
        "url": "https://en.wikipedia.org/wiki/2001:_A_Space_Odyssey",
        "title": "2001: A Space Odyssey"
      },
      {
        "text": "HAL 9000",
        "url": "https://en.wikipedia.org/wiki/HAL_9000",
        "title": "HAL 9000"
      },
      {
        "text": "Discovery One",
        "url": "https://en.wikipedia.org/wiki/Discovery_One",
        "title": "Discovery One"
      },
      {
        "text": "The Terminator",
        "url": "https://en.wikipedia.org/wiki/The_Terminator",
        "title": "The Terminator"
      },
      {
        "text": "The Matrix",
        "url": "https://en.wikipedia.org/wiki/The_Matrix",
        "title": "The Matrix"
      },
      {
        "text": "The Day the Earth Stood Still",
        "url": "https://en.wikipedia.org/wiki/The_Day_the_Earth_Stood_Still",
        "title": "The Day the Earth Stood Still"
      },
      {
        "text": "Aliens",
        "url": "https://en.wikipedia.org/wiki/Aliens_(film)",
        "title": "Aliens (film)"
      },
      {
        "text": "[424]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEButtazzo2001-453"
      },
      {
        "text": "Isaac Asimov",
        "url": "https://en.wikipedia.org/wiki/Isaac_Asimov",
        "title": "Isaac Asimov"
      },
      {
        "text": "Three Laws of Robotics",
        "url": "https://en.wikipedia.org/wiki/Three_Laws_of_Robotics",
        "title": "Three Laws of Robotics"
      },
      {
        "text": "Multivac",
        "url": "https://en.wikipedia.org/wiki/Multivac",
        "title": "Multivac"
      },
      {
        "text": "[425]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEAnderson2008-454"
      },
      {
        "text": "[426]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEMcCauley2007-455"
      },
      {
        "text": "the ability to feel",
        "url": "https://en.wikipedia.org/wiki/Sentience",
        "title": "Sentience"
      },
      {
        "text": "Karel Čapek",
        "url": "https://en.wikipedia.org/wiki/Karel_%C4%8Capek",
        "title": "Karel Čapek"
      },
      {
        "text": "R.U.R.",
        "url": "https://en.wikipedia.org/wiki/R.U.R.",
        "title": "R.U.R."
      },
      {
        "text": "A.I. Artificial Intelligence",
        "url": "https://en.wikipedia.org/wiki/A.I._Artificial_Intelligence",
        "title": "A.I. Artificial Intelligence"
      },
      {
        "text": "Ex Machina",
        "url": "https://en.wikipedia.org/wiki/Ex_Machina_(film)",
        "title": "Ex Machina (film)"
      },
      {
        "text": "Do Androids Dream of Electric Sheep?",
        "url": "https://en.wikipedia.org/wiki/Do_Androids_Dream_of_Electric_Sheep%3F",
        "title": "Do Androids Dream of Electric Sheep?"
      },
      {
        "text": "Philip K. Dick",
        "url": "https://en.wikipedia.org/wiki/Philip_K._Dick",
        "title": "Philip K. Dick"
      },
      {
        "text": "[427]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEGalvan1997-456"
      },
      {
        "text": "Artificial consciousness",
        "url": "https://en.wikipedia.org/wiki/Artificial_consciousness",
        "title": "Artificial consciousness"
      },
      {
        "text": "Artificial intelligence and elections",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence_and_elections",
        "title": "Artificial intelligence and elections"
      },
      {
        "text": "Artificial intelligence content detection",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence_content_detection",
        "title": "Artificial intelligence content detection"
      },
      {
        "text": "Behavior selection algorithm",
        "url": "https://en.wikipedia.org/wiki/Behavior_selection_algorithm",
        "title": "Behavior selection algorithm"
      },
      {
        "text": "Business process automation",
        "url": "https://en.wikipedia.org/wiki/Business_process_automation",
        "title": "Business process automation"
      },
      {
        "text": "Case-based reasoning",
        "url": "https://en.wikipedia.org/wiki/Case-based_reasoning",
        "title": "Case-based reasoning"
      },
      {
        "text": "Computational intelligence",
        "url": "https://en.wikipedia.org/wiki/Computational_intelligence",
        "title": "Computational intelligence"
      },
      {
        "text": "Digital immortality",
        "url": "https://en.wikipedia.org/wiki/Digital_immortality",
        "title": "Digital immortality"
      },
      {
        "text": "Emergent algorithm",
        "url": "https://en.wikipedia.org/wiki/Emergent_algorithm",
        "title": "Emergent algorithm"
      },
      {
        "text": "Female gendering of AI technologies",
        "url": "https://en.wikipedia.org/wiki/Female_gendering_of_AI_technologies",
        "title": "Female gendering of AI technologies"
      },
      {
        "text": "Glossary of artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_artificial_intelligence",
        "title": "Glossary of artificial intelligence"
      },
      {
        "text": "Intelligence amplification",
        "url": "https://en.wikipedia.org/wiki/Intelligence_amplification",
        "title": "Intelligence amplification"
      },
      {
        "text": "Intelligent agent",
        "url": "https://en.wikipedia.org/wiki/Intelligent_agent",
        "title": "Intelligent agent"
      },
      {
        "text": "Intelligent automation",
        "url": "https://en.wikipedia.org/wiki/Intelligent_automation",
        "title": "Intelligent automation"
      },
      {
        "text": "Mind uploading",
        "url": "https://en.wikipedia.org/wiki/Mind_uploading",
        "title": "Mind uploading"
      },
      {
        "text": "Organoid intelligence",
        "url": "https://en.wikipedia.org/wiki/Organoid_intelligence",
        "title": "Organoid intelligence"
      },
      {
        "text": "Robotic process automation",
        "url": "https://en.wikipedia.org/wiki/Robotic_process_automation",
        "title": "Robotic process automation"
      },
      {
        "text": "The Last Day",
        "url": "https://en.wikipedia.org/wiki/The_Last_Day_(novel)",
        "title": "The Last Day (novel)"
      },
      {
        "text": "Wetware computer",
        "url": "https://en.wikipedia.org/wiki/Wetware_computer",
        "title": "Wetware computer"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Problems_of_AI_4-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Problems_of_AI_4-1"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Luger & Stubblefield (2004)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Nilsson (1998)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Tools_of_AI_6-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Tools_of_AI_6-1"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Luger & Stubblefield (2004)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Nilsson (1998)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-34"
      },
      {
        "text": "expert systems",
        "url": "https://en.wikipedia.org/wiki/Expert_system",
        "title": "Expert system"
      },
      {
        "text": "[30]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTENewquist1994296-32"
      },
      {
        "text": "[31]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTECrevier1993204–208-33"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-35"
      },
      {
        "text": "economics",
        "url": "https://en.wikipedia.org/wiki/Economics",
        "title": "Economics"
      },
      {
        "text": "philosophy",
        "url": "https://en.wikipedia.org/wiki/Philosophy",
        "title": "Philosophy"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-48"
      },
      {
        "text": "Alan Turing",
        "url": "https://en.wikipedia.org/wiki/Alan_Turing",
        "title": "Alan Turing"
      },
      {
        "text": "Computing Machinery and Intelligence",
        "url": "https://en.wikipedia.org/wiki/Computing_Machinery_and_Intelligence",
        "title": "Computing Machinery and Intelligence"
      },
      {
        "text": "[42]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTETuring1950-46"
      },
      {
        "text": "Ray Solomonoff",
        "url": "https://en.wikipedia.org/wiki/Ray_Solomonoff",
        "title": "Ray Solomonoff"
      },
      {
        "text": "[43]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTESolomonoff1956-47"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-57"
      },
      {
        "text": "AI winter § Machine translation and the ALPAC report of 1966",
        "url": "https://en.wikipedia.org/wiki/AI_winter#Machine_translation_and_the_ALPAC_report_of_1966",
        "title": "AI winter"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-100"
      },
      {
        "text": "conditionally independent",
        "url": "https://en.wikipedia.org/wiki/Conditionally_independent",
        "title": "Conditionally independent"
      },
      {
        "text": "AdSense",
        "url": "https://en.wikipedia.org/wiki/AdSense",
        "title": "AdSense"
      },
      {
        "text": "[93]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEDomingos2015chpt._6-99"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-103"
      },
      {
        "text": "latent variables",
        "url": "https://en.wikipedia.org/wiki/Latent_variables",
        "title": "Latent variables"
      },
      {
        "text": "[95]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEDomingos2015210-102"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-129"
      },
      {
        "text": "Warren S. McCulloch",
        "url": "https://en.wikipedia.org/wiki/Warren_S._McCulloch",
        "title": "Warren S. McCulloch"
      },
      {
        "text": "Walter Pitts",
        "url": "https://en.wikipedia.org/wiki/Walter_Pitts",
        "title": "Walter Pitts"
      },
      {
        "text": "[115]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig202117-123"
      },
      {
        "text": "Alan Turing",
        "url": "https://en.wikipedia.org/wiki/Alan_Turing",
        "title": "Alan Turing"
      },
      {
        "text": "[116]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021785-124"
      },
      {
        "text": "Karl Steinbuch",
        "url": "https://en.wikipedia.org/wiki/Karl_Steinbuch",
        "title": "Karl Steinbuch"
      },
      {
        "text": "Roger David Joseph",
        "url": "https://en.wikipedia.org/w/index.php?title=Roger_David_Joseph&action=edit&redlink=1",
        "title": "Roger David Joseph (page does not exist)"
      },
      {
        "text": "[117]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTESchmidhuber2022sect._5-125"
      },
      {
        "text": "Frank Rosenblatt",
        "url": "https://en.wikipedia.org/wiki/Frank_Rosenblatt",
        "title": "Frank Rosenblatt"
      },
      {
        "text": "[116]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021785-124"
      },
      {
        "text": "Oliver Selfridge",
        "url": "https://en.wikipedia.org/wiki/Oliver_Selfridge",
        "title": "Oliver Selfridge"
      },
      {
        "text": "[117]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTESchmidhuber2022sect._5-125"
      },
      {
        "text": "Alexey Ivakhnenko",
        "url": "https://en.wikipedia.org/wiki/Alexey_Ivakhnenko",
        "title": "Alexey Ivakhnenko"
      },
      {
        "text": "Valentin Lapa",
        "url": "https://en.wikipedia.org/w/index.php?title=Valentin_Lapa&action=edit&redlink=1",
        "title": "Valentin Lapa (page does not exist)"
      },
      {
        "text": "[118]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTESchmidhuber2022sect._6-126"
      },
      {
        "text": "Kaoru Nakano",
        "url": "https://en.wikipedia.org/w/index.php?title=Kaoru_Nakano&action=edit&redlink=1",
        "title": "Kaoru Nakano (page does not exist)"
      },
      {
        "text": "[119]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTESchmidhuber2022sect._7-127"
      },
      {
        "text": "Shun-Ichi Amari",
        "url": "https://en.wikipedia.org/wiki/Shun-Ichi_Amari",
        "title": "Shun-Ichi Amari"
      },
      {
        "text": "[119]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTESchmidhuber2022sect._7-127"
      },
      {
        "text": "John Joseph Hopfield",
        "url": "https://en.wikipedia.org/wiki/John_Joseph_Hopfield",
        "title": "John Joseph Hopfield"
      },
      {
        "text": "[119]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTESchmidhuber2022sect._7-127"
      },
      {
        "text": "Henry J. Kelley",
        "url": "https://en.wikipedia.org/wiki/Henry_J._Kelley",
        "title": "Henry J. Kelley"
      },
      {
        "text": "[116]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021785-124"
      },
      {
        "text": "Arthur E. Bryson",
        "url": "https://en.wikipedia.org/wiki/Arthur_E._Bryson",
        "title": "Arthur E. Bryson"
      },
      {
        "text": "[116]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021785-124"
      },
      {
        "text": "Stuart Dreyfus",
        "url": "https://en.wikipedia.org/wiki/Stuart_Dreyfus",
        "title": "Stuart Dreyfus"
      },
      {
        "text": "[116]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021785-124"
      },
      {
        "text": "Arthur E. Bryson",
        "url": "https://en.wikipedia.org/wiki/Arthur_E._Bryson",
        "title": "Arthur E. Bryson"
      },
      {
        "text": "Yu-Chi Ho",
        "url": "https://en.wikipedia.org/wiki/Yu-Chi_Ho",
        "title": "Yu-Chi Ho"
      },
      {
        "text": "[116]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021785-124"
      },
      {
        "text": "Seppo Linnainmaa",
        "url": "https://en.wikipedia.org/wiki/Seppo_Linnainmaa",
        "title": "Seppo Linnainmaa"
      },
      {
        "text": "[120]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTESchmidhuber2022sect._8-128"
      },
      {
        "text": "Paul Werbos",
        "url": "https://en.wikipedia.org/wiki/Paul_Werbos",
        "title": "Paul Werbos"
      },
      {
        "text": "[116]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021785-124"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-131"
      },
      {
        "text": "Geoffrey Hinton",
        "url": "https://en.wikipedia.org/wiki/Geoffrey_Hinton",
        "title": "Geoffrey Hinton"
      },
      {
        "text": "[121]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-130"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-251"
      },
      {
        "text": "bias",
        "url": "https://en.wikipedia.org/wiki/Bias_(statistics)",
        "title": "Bias (statistics)"
      },
      {
        "text": "fairness",
        "url": "https://en.wikipedia.org/wiki/Fairness_(machine_learning)",
        "title": "Fairness (machine learning)"
      },
      {
        "text": "[240]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-Samuel-2022-250"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-261"
      },
      {
        "text": "Jon Kleinberg",
        "url": "https://en.wikipedia.org/wiki/Jon_Kleinberg",
        "title": "Jon Kleinberg"
      },
      {
        "text": "Cornell University",
        "url": "https://en.wikipedia.org/wiki/Cornell_University",
        "title": "Cornell University"
      },
      {
        "text": "University of Chicago",
        "url": "https://en.wikipedia.org/wiki/University_of_Chicago",
        "title": "University of Chicago"
      },
      {
        "text": "Carnegie Mellon",
        "url": "https://en.wikipedia.org/wiki/Carnegie_Mellon",
        "title": "Carnegie Mellon"
      },
      {
        "text": "Stanford",
        "url": "https://en.wikipedia.org/wiki/Stanford",
        "title": "Stanford"
      },
      {
        "text": "[249]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEChristian202067–70-260"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-267"
      },
      {
        "text": "Max Planck Institute for Intelligent Systems",
        "url": "https://en.wikipedia.org/wiki/Max_Planck_Institute_for_Intelligent_Systems",
        "title": "Max Planck Institute for Intelligent Systems"
      },
      {
        "text": "[254]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-266"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-274"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-283"
      },
      {
        "text": "United Nations",
        "url": "https://en.wikipedia.org/wiki/United_Nations",
        "title": "United Nations"
      },
      {
        "text": "land mines",
        "url": "https://en.wikipedia.org/wiki/Land_mines",
        "title": "Land mines"
      },
      {
        "text": "[268]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig2021989-282"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-295"
      },
      {
        "text": "[279]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEArntzGregoryZierahn201633-294"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-304"
      },
      {
        "text": "robopocalypse",
        "url": "https://en.wikipedia.org/wiki/Robopocalypse",
        "title": "Robopocalypse"
      },
      {
        "text": "[287]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig20211001-303"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-361"
      },
      {
        "text": "[341]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig20219-358"
      },
      {
        "text": "[343]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-360"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-365"
      },
      {
        "text": "[346]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTECrevier199347–49-364"
      },
      {
        "text": "Russell",
        "url": "https://en.wikipedia.org/wiki/Stuart_J._Russell",
        "title": "Stuart J. Russell"
      },
      {
        "text": "Norvig",
        "url": "https://en.wikipedia.org/wiki/Norvig",
        "title": "Norvig"
      },
      {
        "text": "[115]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig202117-123"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-367"
      },
      {
        "text": "Russell",
        "url": "https://en.wikipedia.org/wiki/Stuart_J._Russell",
        "title": "Stuart J. Russell"
      },
      {
        "text": "Norvig",
        "url": "https://en.wikipedia.org/wiki/Norvig",
        "title": "Norvig"
      },
      {
        "text": "[347]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig200317-366"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-369"
      },
      {
        "text": "Russell",
        "url": "https://en.wikipedia.org/wiki/Stuart_J._Russell",
        "title": "Stuart J. Russell"
      },
      {
        "text": "Norvig",
        "url": "https://en.wikipedia.org/wiki/Norvig",
        "title": "Norvig"
      },
      {
        "text": "[348]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig200318-368"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-370"
      },
      {
        "text": "Arthur Samuel",
        "url": "https://en.wikipedia.org/wiki/Arthur_Samuel_(computer_scientist)",
        "title": "Arthur Samuel (computer scientist)"
      },
      {
        "text": "IBM 701",
        "url": "https://en.wikipedia.org/wiki/IBM_701",
        "title": "IBM 701"
      },
      {
        "text": "Daniel Bobrow",
        "url": "https://en.wikipedia.org/wiki/Daniel_Bobrow",
        "title": "Daniel Bobrow"
      },
      {
        "text": "STUDENT",
        "url": "https://en.wikipedia.org/wiki/STUDENT",
        "title": "STUDENT"
      },
      {
        "text": "Newell",
        "url": "https://en.wikipedia.org/wiki/Allen_Newell",
        "title": "Allen Newell"
      },
      {
        "text": "Simon",
        "url": "https://en.wikipedia.org/wiki/Herbert_A._Simon",
        "title": "Herbert A. Simon"
      },
      {
        "text": "Logic Theorist",
        "url": "https://en.wikipedia.org/wiki/Logic_Theorist",
        "title": "Logic Theorist"
      },
      {
        "text": "Terry Winograd",
        "url": "https://en.wikipedia.org/wiki/Terry_Winograd",
        "title": "Terry Winograd"
      },
      {
        "text": "SHRDLU",
        "url": "https://en.wikipedia.org/wiki/SHRDLU",
        "title": "SHRDLU"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-375"
      },
      {
        "text": "Russell",
        "url": "https://en.wikipedia.org/wiki/Stuart_J._Russell",
        "title": "Stuart J. Russell"
      },
      {
        "text": "Norvig",
        "url": "https://en.wikipedia.org/wiki/Norvig",
        "title": "Norvig"
      },
      {
        "text": "[352]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig202121-374"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-386"
      },
      {
        "text": "Embodied",
        "url": "https://en.wikipedia.org/wiki/Embodied_mind",
        "title": "Embodied mind"
      },
      {
        "text": "[359]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEMcCorduck2004454–462-382"
      },
      {
        "text": "Hans Moravec",
        "url": "https://en.wikipedia.org/wiki/Hans_Moravec",
        "title": "Hans Moravec"
      },
      {
        "text": "[360]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEMoravec1988-383"
      },
      {
        "text": "Rodney Brooks",
        "url": "https://en.wikipedia.org/wiki/Rodney_Brooks",
        "title": "Rodney Brooks"
      },
      {
        "text": "[361]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEBrooks1990-384"
      },
      {
        "text": "Nouvelle AI",
        "url": "https://en.wikipedia.org/wiki/Nouvelle_AI",
        "title": "Nouvelle AI"
      },
      {
        "text": "[361]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEBrooks1990-384"
      },
      {
        "text": "Developmental robotics",
        "url": "https://en.wikipedia.org/wiki/Developmental_robotics",
        "title": "Developmental robotics"
      },
      {
        "text": "[362]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-385"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-393"
      },
      {
        "text": "The Atlantic",
        "url": "https://en.wikipedia.org/wiki/The_Atlantic",
        "title": "The Atlantic"
      },
      {
        "text": "[368]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEWong2023-392"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-397"
      },
      {
        "text": "Bloomberg",
        "url": "https://en.wikipedia.org/wiki/Bloomberg_News",
        "title": "Bloomberg News"
      },
      {
        "text": "Google",
        "url": "https://en.wikipedia.org/wiki/Google",
        "title": "Google"
      },
      {
        "text": "[370]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTEClark2015b-395"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-418"
      },
      {
        "text": "Nils Nilsson",
        "url": "https://en.wikipedia.org/wiki/Nils_Nilsson_(researcher)",
        "title": "Nils Nilsson (researcher)"
      },
      {
        "text": "[391]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTENilsson198310-417"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-424"
      },
      {
        "text": "[396]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTECrevier1993125-423"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Searle's_strong_AI_437-0"
      },
      {
        "text": "[406]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTESearle1999-434"
      },
      {
        "text": "[407]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTESearle19801-435"
      },
      {
        "text": "Russell",
        "url": "https://en.wikipedia.org/wiki/Stuart_J._Russell",
        "title": "Stuart J. Russell"
      },
      {
        "text": "Norvig",
        "url": "https://en.wikipedia.org/wiki/Norvig",
        "title": "Norvig"
      },
      {
        "text": "[408]",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_note-FOOTNOTERussellNorvig20219817-436"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig20211–4_1-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig20211–4_1-1"
      },
      {
        "text": "c",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig20211–4_1-2"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-2"
      },
      {
        "text": "AI set to exceed human brain power",
        "url": "http://www.cnn.com/2006/TECH/science/07/24/ai.bostrom/"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20080219001624/http://www.cnn.com/2006/TECH/science/07/24/ai.bostrom/"
      },
      {
        "text": "Wayback Machine",
        "url": "https://en.wikipedia.org/wiki/Wayback_Machine",
        "title": "Wayback Machine"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-3"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1016/j.bushor.2018.08.004",
        "url": "https://doi.org/10.1016%2Fj.bushor.2018.08.004"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0007-6813",
        "url": "https://search.worldcat.org/issn/0007-6813"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "158433736",
        "url": "https://api.semanticscholar.org/CorpusID:158433736"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Artificial_general_intelligence_5-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Artificial_general_intelligence_5-1"
      },
      {
        "text": "c",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Artificial_general_intelligence_5-2"
      },
      {
        "text": "Artificial general intelligence",
        "url": "https://en.wikipedia.org/wiki/Artificial_general_intelligence",
        "title": "Artificial general intelligence"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Pennachin & Goertzel (2007)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPennachinGoertzel2007"
      },
      {
        "text": "Nilsson (1995)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1995"
      },
      {
        "text": "McCarthy (2007)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCarthy2007"
      },
      {
        "text": "Beal & Winston (2009)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFBealWinston2009"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-7"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Dartmouth_workshop_8-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Dartmouth_workshop_8-1"
      },
      {
        "text": "Dartmouth workshop",
        "url": "https://en.wikipedia.org/wiki/Dartmouth_workshop",
        "title": "Dartmouth workshop"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "McCorduck (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCorduck2004"
      },
      {
        "text": "NRC (1999",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNRC1999"
      },
      {
        "text": "McCarthy et al. (1955)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCarthyMinskyRochesterShannon1955"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Succ1_9-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Succ1_9-1"
      },
      {
        "text": "McCorduck (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCorduck2004"
      },
      {
        "text": "Crevier (1993",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "Moravec (1988",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMoravec1988"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Fund01_10-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Fund01_10-1"
      },
      {
        "text": "Fifth Generation Project",
        "url": "https://en.wikipedia.org/wiki/Fifth_Generation_Project",
        "title": "Fifth Generation Project"
      },
      {
        "text": "Alvey",
        "url": "https://en.wikipedia.org/wiki/Alvey",
        "title": "Alvey"
      },
      {
        "text": "Microelectronics and Computer Technology Corporation",
        "url": "https://en.wikipedia.org/wiki/Microelectronics_and_Computer_Technology_Corporation",
        "title": "Microelectronics and Computer Technology Corporation"
      },
      {
        "text": "Strategic Computing Initiative",
        "url": "https://en.wikipedia.org/wiki/Strategic_Computing_Initiative",
        "title": "Strategic Computing Initiative"
      },
      {
        "text": "McCorduck (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCorduck2004"
      },
      {
        "text": "Crevier (1993",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "NRC (1999",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNRC1999"
      },
      {
        "text": "Newquist (1994",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNewquist1994"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-First_AI_Winter_11-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-First_AI_Winter_11-1"
      },
      {
        "text": "AI Winter",
        "url": "https://en.wikipedia.org/wiki/AI_Winter",
        "title": "AI Winter"
      },
      {
        "text": "Lighthill report",
        "url": "https://en.wikipedia.org/wiki/Lighthill_report",
        "title": "Lighthill report"
      },
      {
        "text": "Mansfield Amendment",
        "url": "https://en.wikipedia.org/wiki/Mansfield_Amendment",
        "title": "Mansfield Amendment"
      },
      {
        "text": "Crevier (1993",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "NRC (1999",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNRC1999"
      },
      {
        "text": "Howe (1994)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFHowe1994"
      },
      {
        "text": "Newquist (1994",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNewquist1994"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Second_AI_Winter_12-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Second_AI_Winter_12-1"
      },
      {
        "text": "AI Winter",
        "url": "https://en.wikipedia.org/wiki/AI_Winter",
        "title": "AI Winter"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "McCorduck (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCorduck2004"
      },
      {
        "text": "Crevier (1993",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "NRC (1999",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNRC1999"
      },
      {
        "text": "Newquist (1994",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNewquist1994"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Deep_learning_revolution_13-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Deep_learning_revolution_13-1"
      },
      {
        "text": "Deep learning",
        "url": "https://en.wikipedia.org/wiki/Deep_learning",
        "title": "Deep learning"
      },
      {
        "text": "AlexNet",
        "url": "https://en.wikipedia.org/wiki/AlexNet",
        "title": "AlexNet"
      },
      {
        "text": "Goldman (2022)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFGoldman2022"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "McKinsey (2018)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcKinsey2018"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEToews2023_14-0"
      },
      {
        "text": "Toews (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFToews2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-15"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "constraint satisfaction",
        "url": "https://en.wikipedia.org/wiki/Constraint_satisfaction",
        "title": "Constraint satisfaction"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-16"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Intractability_and_efficiency_and_the_combinatorial_explosion_17-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Intractability_and_efficiency_and_the_combinatorial_explosion_17-1"
      },
      {
        "text": "c",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Intractability_and_efficiency_and_the_combinatorial_explosion_17-2"
      },
      {
        "text": "Intractability and efficiency",
        "url": "https://en.wikipedia.org/wiki/Intractably",
        "title": "Intractably"
      },
      {
        "text": "combinatorial explosion",
        "url": "https://en.wikipedia.org/wiki/Combinatorial_explosion",
        "title": "Combinatorial explosion"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Psychological_evidence_of_the_prevalence_of_sub_18-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Psychological_evidence_of_the_prevalence_of_sub_18-1"
      },
      {
        "text": "c",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Psychological_evidence_of_the_prevalence_of_sub_18-2"
      },
      {
        "text": "Kahneman (2011)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFKahneman2011"
      },
      {
        "text": "Dreyfus & Dreyfus (1986)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDreyfusDreyfus1986"
      },
      {
        "text": "Wason & Shapiro (1966)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFWasonShapiro1966"
      },
      {
        "text": "Kahneman, Slovic & Tversky (1982)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFKahnemanSlovicTversky1982"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-19"
      },
      {
        "text": "Knowledge representation",
        "url": "https://en.wikipedia.org/wiki/Knowledge_representation",
        "title": "Knowledge representation"
      },
      {
        "text": "knowledge engineering",
        "url": "https://en.wikipedia.org/wiki/Knowledge_engineering",
        "title": "Knowledge engineering"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTESmoliarZhang1994_20-0"
      },
      {
        "text": "Smoliar & Zhang (1994)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSmoliarZhang1994"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTENeumannMöller2008_21-0"
      },
      {
        "text": "Neumann & Möller (2008)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNeumannMöller2008"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEKupermanReichleyBailey2006_22-0"
      },
      {
        "text": "Kuperman, Reichley & Bailey (2006)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFKupermanReichleyBailey2006"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEMcGarry2005_23-0"
      },
      {
        "text": "McGarry (2005)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcGarry2005"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEBertiniDel_BimboTorniai2006_24-0"
      },
      {
        "text": "Bertini, Del Bimbo & Torniai (2006)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFBertiniDel_BimboTorniai2006"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021272_25-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-26"
      },
      {
        "text": "Semantic networks",
        "url": "https://en.wikipedia.org/wiki/Semantic_network",
        "title": "Semantic network"
      },
      {
        "text": "description logics",
        "url": "https://en.wikipedia.org/wiki/Description_logic",
        "title": "Description logic"
      },
      {
        "text": "inheritance",
        "url": "https://en.wikipedia.org/wiki/Inheritance_(object-oriented_programming)",
        "title": "Inheritance (object-oriented programming)"
      },
      {
        "text": "frames",
        "url": "https://en.wikipedia.org/wiki/Frame_(artificial_intelligence)",
        "title": "Frame (artificial intelligence)"
      },
      {
        "text": "scripts",
        "url": "https://en.wikipedia.org/wiki/Scripts_(artificial_intelligence)",
        "title": "Scripts (artificial intelligence)"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-27"
      },
      {
        "text": "Situation calculus",
        "url": "https://en.wikipedia.org/wiki/Situation_calculus",
        "title": "Situation calculus"
      },
      {
        "text": "event calculus",
        "url": "https://en.wikipedia.org/wiki/Event_calculus",
        "title": "Event calculus"
      },
      {
        "text": "fluent calculus",
        "url": "https://en.wikipedia.org/wiki/Fluent_calculus",
        "title": "Fluent calculus"
      },
      {
        "text": "frame problem",
        "url": "https://en.wikipedia.org/wiki/Frame_problem",
        "title": "Frame problem"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-28"
      },
      {
        "text": "Causal calculus",
        "url": "https://en.wikipedia.org/wiki/Causality#Causal_calculus",
        "title": "Causality"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-29"
      },
      {
        "text": "modal logics",
        "url": "https://en.wikipedia.org/wiki/Modal_logic",
        "title": "Modal logic"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Default_reasoning_30-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Default_reasoning_30-1"
      },
      {
        "text": "Default reasoning",
        "url": "https://en.wikipedia.org/wiki/Default_reasoning",
        "title": "Default reasoning"
      },
      {
        "text": "Frame problem",
        "url": "https://en.wikipedia.org/wiki/Frame_problem",
        "title": "Frame problem"
      },
      {
        "text": "default logic",
        "url": "https://en.wikipedia.org/wiki/Default_logic",
        "title": "Default logic"
      },
      {
        "text": "non-monotonic logics",
        "url": "https://en.wikipedia.org/wiki/Non-monotonic_logic",
        "title": "Non-monotonic logic"
      },
      {
        "text": "circumscription",
        "url": "https://en.wikipedia.org/wiki/Circumscription_(logic)",
        "title": "Circumscription (logic)"
      },
      {
        "text": "closed world assumption",
        "url": "https://en.wikipedia.org/wiki/Closed_world_assumption",
        "title": "Closed world assumption"
      },
      {
        "text": "abduction",
        "url": "https://en.wikipedia.org/wiki/Abductive_reasoning",
        "title": "Abductive reasoning"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Breadth_of_commonsense_knowledge_31-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Breadth_of_commonsense_knowledge_31-1"
      },
      {
        "text": "Lenat & Guha (1989",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLenatGuha1989"
      },
      {
        "text": "Crevier (1993",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "Moravec (1988",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMoravec1988"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "qualification problem",
        "url": "https://en.wikipedia.org/wiki/Qualification_problem",
        "title": "Qualification problem"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTENewquist1994296_32-0"
      },
      {
        "text": "Newquist (1994)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNewquist1994"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTECrevier1993204–208_33-0"
      },
      {
        "text": "Crevier (1993)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021528_36-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-37"
      },
      {
        "text": "Automated planning",
        "url": "https://en.wikipedia.org/wiki/Automated_planning",
        "title": "Automated planning"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-38"
      },
      {
        "text": "Automated decision making",
        "url": "https://en.wikipedia.org/wiki/Automated_decision_making",
        "title": "Automated decision making"
      },
      {
        "text": "Decision theory",
        "url": "https://en.wikipedia.org/wiki/Decision_theory",
        "title": "Decision theory"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-39"
      },
      {
        "text": "Classical planning",
        "url": "https://en.wikipedia.org/wiki/Automated_planning_and_scheduling#classical_planning",
        "title": "Automated planning and scheduling"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-40"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-41"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Inverse reinforcement learning",
        "url": "https://en.wikipedia.org/wiki/Inverse_reinforcement_learning",
        "title": "Inverse reinforcement learning"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-42"
      },
      {
        "text": "Information value theory",
        "url": "https://en.wikipedia.org/wiki/Information_value_theory",
        "title": "Information value theory"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-43"
      },
      {
        "text": "Markov decision process",
        "url": "https://en.wikipedia.org/wiki/Markov_decision_process",
        "title": "Markov decision process"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-44"
      },
      {
        "text": "Game theory",
        "url": "https://en.wikipedia.org/wiki/Game_theory",
        "title": "Game theory"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-45"
      },
      {
        "text": "Learning",
        "url": "https://en.wikipedia.org/wiki/Machine_learning",
        "title": "Machine learning"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTETuring1950_46-0"
      },
      {
        "text": "Turing (1950)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFTuring1950"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTESolomonoff1956_47-0"
      },
      {
        "text": "Solomonoff (1956)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSolomonoff1956"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-49"
      },
      {
        "text": "Unsupervised learning",
        "url": "https://en.wikipedia.org/wiki/Unsupervised_learning",
        "title": "Unsupervised learning"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "cluster analysis",
        "url": "https://en.wikipedia.org/wiki/Cluster_analysis",
        "title": "Cluster analysis"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "word embedding",
        "url": "https://en.wikipedia.org/wiki/Word_embedding",
        "title": "Word embedding"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Supervised_learning_50-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Supervised_learning_50-1"
      },
      {
        "text": "Supervised learning",
        "url": "https://en.wikipedia.org/wiki/Supervised_learning",
        "title": "Supervised learning"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-51"
      },
      {
        "text": "Reinforcement learning",
        "url": "https://en.wikipedia.org/wiki/Reinforcement_learning",
        "title": "Reinforcement learning"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-52"
      },
      {
        "text": "Transfer learning",
        "url": "https://en.wikipedia.org/wiki/Transfer_learning",
        "title": "Transfer learning"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "The Economist (2016)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFThe_Economist2016"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-53"
      },
      {
        "text": "\"Artificial Intelligence (AI): What Is AI and How Does It Work? | Built In\"",
        "url": "https://builtin.com/artificial-intelligence"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-54"
      },
      {
        "text": "Computational learning theory",
        "url": "https://en.wikipedia.org/wiki/Computational_learning_theory",
        "title": "Computational learning theory"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Jordan & Mitchell (2015)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFJordanMitchell2015"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-55"
      },
      {
        "text": "Natural language processing",
        "url": "https://en.wikipedia.org/wiki/Natural_language_processing",
        "title": "Natural language processing"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-56"
      },
      {
        "text": "NLP",
        "url": "https://en.wikipedia.org/wiki/Natural_language_processing",
        "title": "Natural language processing"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021856–858_58-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEDickson2022_59-0"
      },
      {
        "text": "Dickson (2022)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDickson2022"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-60"
      },
      {
        "text": "NLP",
        "url": "https://en.wikipedia.org/wiki/Natural_language_processing",
        "title": "Natural language processing"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Cambria & White (2014)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCambriaWhite2014"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEVincent2019_61-0"
      },
      {
        "text": "Vincent (2019)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFVincent2019"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021875–878_62-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEBushwick2023_63-0"
      },
      {
        "text": "Bushwick (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFBushwick2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-64"
      },
      {
        "text": "Computer vision",
        "url": "https://en.wikipedia.org/wiki/Computer_vision",
        "title": "Computer vision"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021849–850_65-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021895–899_66-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021899–901_67-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEChallaMorelandMušickiEvans2011_68-0"
      },
      {
        "text": "Challa et al. (2011)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChallaMorelandMušickiEvans2011"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021931–938_69-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEMIT_AIL2014_70-0"
      },
      {
        "text": "MIT AIL (2014)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMIT_AIL2014"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-71"
      },
      {
        "text": "Affective computing",
        "url": "https://en.wikipedia.org/wiki/Affective_computing",
        "title": "Affective computing"
      },
      {
        "text": "Thro (1993)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFThro1993"
      },
      {
        "text": "Edelson (1991)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFEdelson1991"
      },
      {
        "text": "Tao & Tan (2005)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFTaoTan2005"
      },
      {
        "text": "Scassellati (2002)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFScassellati2002"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEWaddell2018_72-0"
      },
      {
        "text": "Waddell (2018)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFWaddell2018"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEPoriaCambriaBajpaiHussain2017_73-0"
      },
      {
        "text": "Poria et al. (2017)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPoriaCambriaBajpaiHussain2017"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-74"
      },
      {
        "text": "Search algorithms",
        "url": "https://en.wikipedia.org/wiki/Search_algorithm",
        "title": "Search algorithm"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-75"
      },
      {
        "text": "State space search",
        "url": "https://en.wikipedia.org/wiki/State_space_search",
        "title": "State space search"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021sect._11.2_76-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-77"
      },
      {
        "text": "Uninformed searches",
        "url": "https://en.wikipedia.org/wiki/Uninformed_search",
        "title": "Uninformed search"
      },
      {
        "text": "breadth first search",
        "url": "https://en.wikipedia.org/wiki/Breadth_first_search",
        "title": "Breadth first search"
      },
      {
        "text": "depth-first search",
        "url": "https://en.wikipedia.org/wiki/Depth-first_search",
        "title": "Depth-first search"
      },
      {
        "text": "state space search",
        "url": "https://en.wikipedia.org/wiki/State_space_search",
        "title": "State space search"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-78"
      },
      {
        "text": "Heuristic",
        "url": "https://en.wikipedia.org/wiki/Heuristic",
        "title": "Heuristic"
      },
      {
        "text": "best first",
        "url": "https://en.wikipedia.org/wiki/Best-first_search",
        "title": "Best-first search"
      },
      {
        "text": "A*",
        "url": "https://en.wikipedia.org/wiki/A*_search_algorithm",
        "title": "A* search algorithm"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Poole & Mackworth (2017",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworth2017"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-79"
      },
      {
        "text": "Adversarial search",
        "url": "https://en.wikipedia.org/wiki/Adversarial_search",
        "title": "Adversarial search"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-80"
      },
      {
        "text": "Local",
        "url": "https://en.wikipedia.org/wiki/Local_search_(optimization)",
        "title": "Local search (optimization)"
      },
      {
        "text": "optimization",
        "url": "https://en.wikipedia.org/wiki/Optimization",
        "title": "Optimization"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-81"
      },
      {
        "text": "\"Optimization Algorithms in Neural Networks\"",
        "url": "https://www.kdnuggets.com/optimization-algorithms-in-neural-networks"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-82"
      },
      {
        "text": "Evolutionary computation",
        "url": "https://en.wikipedia.org/wiki/Evolutionary_computation",
        "title": "Evolutionary computation"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEMerkleMiddendorf2013_83-0"
      },
      {
        "text": "Merkle & Middendorf (2013)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMerkleMiddendorf2013"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-84"
      },
      {
        "text": "Logic",
        "url": "https://en.wikipedia.org/wiki/Logic",
        "title": "Logic"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-85"
      },
      {
        "text": "Propositional logic",
        "url": "https://en.wikipedia.org/wiki/Propositional_logic",
        "title": "Propositional logic"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-86"
      },
      {
        "text": "First-order logic",
        "url": "https://en.wikipedia.org/wiki/First-order_logic",
        "title": "First-order logic"
      },
      {
        "text": "equality",
        "url": "https://en.wikipedia.org/wiki/Equality_(mathematics)",
        "title": "Equality (mathematics)"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-87"
      },
      {
        "text": "Logical inference",
        "url": "https://en.wikipedia.org/wiki/Logical_inference",
        "title": "Logical inference"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-88"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-89"
      },
      {
        "text": "Resolution",
        "url": "https://en.wikipedia.org/wiki/Resolution_(logic)",
        "title": "Resolution (logic)"
      },
      {
        "text": "unification",
        "url": "https://en.wikipedia.org/wiki/Unification_(computer_science)",
        "title": "Unification (computer science)"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-90"
      },
      {
        "text": "ACM SIGPLAN Notices",
        "url": "https://en.wikipedia.org/wiki/ACM_SIGPLAN_Notices",
        "title": "ACM SIGPLAN Notices"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1145/872734.806939",
        "url": "https://doi.org/10.1145%2F872734.806939"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-91"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Scientific American (1999)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFScientific_American1999"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Stoch_92-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Stoch_92-1"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-93"
      },
      {
        "text": "decision theory",
        "url": "https://en.wikipedia.org/wiki/Decision_theory",
        "title": "Decision theory"
      },
      {
        "text": "decision analysis",
        "url": "https://en.wikipedia.org/wiki/Decision_analysis",
        "title": "Decision analysis"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-94"
      },
      {
        "text": "Information value theory",
        "url": "https://en.wikipedia.org/wiki/Information_value_theory",
        "title": "Information value theory"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-95"
      },
      {
        "text": "Markov decision processes",
        "url": "https://en.wikipedia.org/wiki/Markov_decision_process",
        "title": "Markov decision process"
      },
      {
        "text": "decision networks",
        "url": "https://en.wikipedia.org/wiki/Decision_network",
        "title": "Decision network"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Stochastic_temporal_models_96-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Stochastic_temporal_models_96-1"
      },
      {
        "text": "c",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Stochastic_temporal_models_96-2"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Hidden Markov model",
        "url": "https://en.wikipedia.org/wiki/Hidden_Markov_model",
        "title": "Hidden Markov model"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Kalman filters",
        "url": "https://en.wikipedia.org/wiki/Kalman_filter",
        "title": "Kalman filter"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Dynamic Bayesian networks",
        "url": "https://en.wikipedia.org/wiki/Dynamic_Bayesian_network",
        "title": "Dynamic Bayesian network"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-97"
      },
      {
        "text": "Game theory",
        "url": "https://en.wikipedia.org/wiki/Game_theory",
        "title": "Game theory"
      },
      {
        "text": "mechanism design",
        "url": "https://en.wikipedia.org/wiki/Mechanism_design",
        "title": "Mechanism design"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-98"
      },
      {
        "text": "Bayesian networks",
        "url": "https://en.wikipedia.org/wiki/Bayesian_network",
        "title": "Bayesian network"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEDomingos2015chpt._6_99-0"
      },
      {
        "text": "Domingos (2015)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDomingos2015"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-101"
      },
      {
        "text": "Bayesian inference",
        "url": "https://en.wikipedia.org/wiki/Bayesian_inference",
        "title": "Bayesian inference"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEDomingos2015210_102-0"
      },
      {
        "text": "Domingos (2015)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDomingos2015"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-104"
      },
      {
        "text": "Bayesian learning",
        "url": "https://en.wikipedia.org/wiki/Bayesian_learning",
        "title": "Bayesian learning"
      },
      {
        "text": "expectation–maximization algorithm",
        "url": "https://en.wikipedia.org/wiki/Expectation%E2%80%93maximization_algorithm",
        "title": "Expectation–maximization algorithm"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Poole, Mackworth & Goebel (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPooleMackworthGoebel1998"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "Domingos (2015",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDomingos2015"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-105"
      },
      {
        "text": "Bayesian decision theory",
        "url": "https://en.wikipedia.org/wiki/Bayesian_decision_theory",
        "title": "Bayesian decision theory"
      },
      {
        "text": "decision networks",
        "url": "https://en.wikipedia.org/wiki/Decision_network",
        "title": "Decision network"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-106"
      },
      {
        "text": "classifiers",
        "url": "https://en.wikipedia.org/wiki/Classifier_(mathematics)",
        "title": "Classifier (mathematics)"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-107"
      },
      {
        "text": "Ciaramella, Alberto",
        "url": "https://en.wikipedia.org/wiki/Alberto_Ciaramella",
        "title": "Alberto Ciaramella"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-8-8947-8760-3",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-8-8947-8760-3",
        "title": "Special:BookSources/978-8-8947-8760-3"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-108"
      },
      {
        "text": "Decision trees",
        "url": "https://en.wikipedia.org/wiki/Alternating_decision_tree",
        "title": "Alternating decision tree"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Domingos (2015",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDomingos2015"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-109"
      },
      {
        "text": "Non-parameteric",
        "url": "https://en.wikipedia.org/wiki/Nonparametric_statistics",
        "title": "Nonparametric statistics"
      },
      {
        "text": "K-nearest neighbor",
        "url": "https://en.wikipedia.org/wiki/K-nearest_neighbor",
        "title": "K-nearest neighbor"
      },
      {
        "text": "support vector machines",
        "url": "https://en.wikipedia.org/wiki/Support_vector_machines",
        "title": "Support vector machines"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Domingos (2015",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDomingos2015"
      },
      {
        "text": "Domingos (2015",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDomingos2015"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEDomingos2015152_110-0"
      },
      {
        "text": "Domingos (2015)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDomingos2015"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-111"
      },
      {
        "text": "Naive Bayes classifier",
        "url": "https://en.wikipedia.org/wiki/Naive_Bayes_classifier",
        "title": "Naive Bayes classifier"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Domingos (2015",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDomingos2015"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Neural_networks_112-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Neural_networks_112-1"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Domingos (2015",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDomingos2015"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-113"
      },
      {
        "text": "backpropagation",
        "url": "https://en.wikipedia.org/wiki/Backpropagation",
        "title": "Backpropagation"
      },
      {
        "text": "automatic differentiation",
        "url": "https://en.wikipedia.org/wiki/Automatic_differentiation",
        "title": "Automatic differentiation"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-114"
      },
      {
        "text": "Universal approximation theorem",
        "url": "https://en.wikipedia.org/wiki/Universal_approximation_theorem",
        "title": "Universal approximation theorem"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Cybenko (1988)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCybenko1988"
      },
      {
        "text": "Hornik, Stinchcombe & White (1989)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFHornikStinchcombeWhite1989"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-115"
      },
      {
        "text": "Feedforward neural networks",
        "url": "https://en.wikipedia.org/wiki/Feedforward_neural_network",
        "title": "Feedforward neural network"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-116"
      },
      {
        "text": "Recurrent neural networks",
        "url": "https://en.wikipedia.org/wiki/Recurrent_neural_network",
        "title": "Recurrent neural network"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-117"
      },
      {
        "text": "Perceptrons",
        "url": "https://en.wikipedia.org/wiki/Perceptron",
        "title": "Perceptron"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Deep_learning_118-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Deep_learning_118-1"
      },
      {
        "text": "Deep learning",
        "url": "https://en.wikipedia.org/wiki/Deep_learning",
        "title": "Deep learning"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Goodfellow, Bengio & Courville (2016)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFGoodfellowBengioCourville2016"
      },
      {
        "text": "Hinton et al. (2016)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFHinton_et_al.2016"
      },
      {
        "text": "Schmidhuber (2015)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSchmidhuber2015"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-119"
      },
      {
        "text": "Convolutional neural networks",
        "url": "https://en.wikipedia.org/wiki/Convolutional_neural_networks",
        "title": "Convolutional neural networks"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEDengYu2014199–200_120-0"
      },
      {
        "text": "Deng & Yu (2014)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDengYu2014"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTECiresanMeierSchmidhuber2012_121-0"
      },
      {
        "text": "Ciresan, Meier & Schmidhuber (2012)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCiresanMeierSchmidhuber2012"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021750_122-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig202117_123-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig202117_123-1"
      },
      {
        "text": "c",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig202117_123-2"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021785_124-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021785_124-1"
      },
      {
        "text": "c",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021785_124-2"
      },
      {
        "text": "d",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021785_124-3"
      },
      {
        "text": "e",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021785_124-4"
      },
      {
        "text": "f",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021785_124-5"
      },
      {
        "text": "g",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021785_124-6"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTESchmidhuber2022sect._5_125-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTESchmidhuber2022sect._5_125-1"
      },
      {
        "text": "Schmidhuber (2022)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSchmidhuber2022"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTESchmidhuber2022sect._6_126-0"
      },
      {
        "text": "Schmidhuber (2022)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSchmidhuber2022"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTESchmidhuber2022sect._7_127-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTESchmidhuber2022sect._7_127-1"
      },
      {
        "text": "c",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTESchmidhuber2022sect._7_127-2"
      },
      {
        "text": "Schmidhuber (2022)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSchmidhuber2022"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTESchmidhuber2022sect._8_128-0"
      },
      {
        "text": "Schmidhuber (2022)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSchmidhuber2022"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-130"
      },
      {
        "text": "Christian (2020",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-132"
      },
      {
        "text": "\"A.I. Hallucinations Are Getting Worse, Even as New Systems Become More Powerful\"",
        "url": "https://www.nytimes.com/2025/05/05/technology/ai-hallucinations-chatgpt-google.html"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0362-4331",
        "url": "https://search.worldcat.org/issn/0362-4331"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTESmith2023_133-0"
      },
      {
        "text": "Smith (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSmith2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-134"
      },
      {
        "text": "\"Explained: Generative AI\"",
        "url": "https://news.mit.edu/2023/explained-generative-ai-1109"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-135"
      },
      {
        "text": "\"AI Writing and Content Creation Tools\"",
        "url": "https://mitsloanedtech.mit.edu/ai/tools/writing"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231225232503/https://mitsloanedtech.mit.edu/ai/tools/writing/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEMarmouyet2023_136-0"
      },
      {
        "text": "Marmouyet (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMarmouyet2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEKobielus2019_137-0"
      },
      {
        "text": "Kobielus (2019)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFKobielus2019"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-138"
      },
      {
        "text": "\"Mojo Rising: The resurgence of AI-first programming languages\"",
        "url": "https://venturebeat.com/ai/mojo-rising-the-resurgence-of-ai-first-programming-languages"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240627143853/https://venturebeat.com/ai/mojo-rising-the-resurgence-of-ai-first-programming-languages/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-139"
      },
      {
        "text": "\"7 AI Programming Languages You Need to Know\"",
        "url": "https://aibusiness.com/verticals/7-ai-programming-languages-you-need-to-know"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240725164443/https://aibusiness.com/verticals/7-ai-programming-languages-you-need-to-know"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-140"
      },
      {
        "text": "\"Why Jensen Huang and Marc Benioff see 'gigantic' opportunity for agentic AI\"",
        "url": "https://venturebeat.com/ai/why-jensen-huang-and-marc-benioff-see-gigantic-opportunity-for-agentic-ai/"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005165649/https://venturebeat.com/ai/why-jensen-huang-and-marc-benioff-see-gigantic-opportunity-for-agentic-ai/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-141"
      },
      {
        "text": "\"Huang's Law Is the New Moore's Law, and Explains Why Nvidia Wants Arm\"",
        "url": "https://www.wsj.com/articles/huangs-law-is-the-new-moores-law-and-explains-why-nvidia-wants-arm-11600488001"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0099-9660",
        "url": "https://search.worldcat.org/issn/0099-9660"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231002080608/https://www.wsj.com/articles/huangs-law-is-the-new-moores-law-and-explains-why-nvidia-wants-arm-11600488001"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-142"
      },
      {
        "text": "\"The potential for artificial intelligence in healthcare\"",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC6616181"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.7861/futurehosp.6-2-94",
        "url": "https://doi.org/10.7861%2Ffuturehosp.6-2-94"
      },
      {
        "text": "PMC",
        "url": "https://en.wikipedia.org/wiki/PMC_(identifier)",
        "title": "PMC (identifier)"
      },
      {
        "text": "6616181",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC6616181"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "31363513",
        "url": "https://pubmed.ncbi.nlm.nih.gov/31363513"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-143"
      },
      {
        "text": "\"Systematic review of approaches to detection and classification of skin cancer using artificial intelligence: Development and prospects\"",
        "url": "https://linkinghub.elsevier.com/retrieve/pii/S0010482524008278"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1016/j.compbiomed.2024.108742",
        "url": "https://doi.org/10.1016%2Fj.compbiomed.2024.108742"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "38875908",
        "url": "https://pubmed.ncbi.nlm.nih.gov/38875908"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241203172502/https://linkinghub.elsevier.com/retrieve/pii/S0010482524008278"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-144"
      },
      {
        "text": "\"Cough Sound Detection and Diagnosis Using Artificial Intelligence Techniques: Challenges and Opportunities\"",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC8545201"
      },
      {
        "text": "Bibcode",
        "url": "https://en.wikipedia.org/wiki/Bibcode_(identifier)",
        "title": "Bibcode (identifier)"
      },
      {
        "text": "2021IEEEA...9j2327A",
        "url": "https://ui.adsabs.harvard.edu/abs/2021IEEEA...9j2327A"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1109/ACCESS.2021.3097559",
        "url": "https://doi.org/10.1109%2FACCESS.2021.3097559"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "2169-3536",
        "url": "https://search.worldcat.org/issn/2169-3536"
      },
      {
        "text": "PMC",
        "url": "https://en.wikipedia.org/wiki/PMC_(identifier)",
        "title": "PMC (identifier)"
      },
      {
        "text": "8545201",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC8545201"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "34786317",
        "url": "https://pubmed.ncbi.nlm.nih.gov/34786317"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Bax-2023_145-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Bax-2023_145-1"
      },
      {
        "text": "\"The future of personalized cardiovascular medicine demands 3D and 4D printing, stem cells, and artificial intelligence\"",
        "url": "https://doi.org/10.3389%2Ffsens.2023.1294721"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.3389/fsens.2023.1294721",
        "url": "https://doi.org/10.3389%2Ffsens.2023.1294721"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "2673-5067",
        "url": "https://search.worldcat.org/issn/2673-5067"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-146"
      },
      {
        "text": "\"Health Equity and Ethical Considerations in Using Artificial Intelligence in Public Health and Medicine\"",
        "url": "https://www.cdc.gov/pcd/issues/2024/24_0245.htm"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.5888/pcd21.240245",
        "url": "https://doi.org/10.5888%2Fpcd21.240245"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "1545-1151",
        "url": "https://search.worldcat.org/issn/1545-1151"
      },
      {
        "text": "PMC",
        "url": "https://en.wikipedia.org/wiki/PMC_(identifier)",
        "title": "PMC (identifier)"
      },
      {
        "text": "11364282",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC11364282"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "39173183",
        "url": "https://pubmed.ncbi.nlm.nih.gov/39173183"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-147"
      },
      {
        "text": "\"Highly accurate protein structure prediction with AlphaFold\"",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC8371605"
      },
      {
        "text": "Bibcode",
        "url": "https://en.wikipedia.org/wiki/Bibcode_(identifier)",
        "title": "Bibcode (identifier)"
      },
      {
        "text": "2021Natur.596..583J",
        "url": "https://ui.adsabs.harvard.edu/abs/2021Natur.596..583J"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1038/s41586-021-03819-2",
        "url": "https://doi.org/10.1038%2Fs41586-021-03819-2"
      },
      {
        "text": "PMC",
        "url": "https://en.wikipedia.org/wiki/PMC_(identifier)",
        "title": "PMC (identifier)"
      },
      {
        "text": "8371605",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC8371605"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "34265844",
        "url": "https://pubmed.ncbi.nlm.nih.gov/34265844"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-148"
      },
      {
        "text": "\"AI discovers new class of antibiotics to kill drug-resistant bacteria\"",
        "url": "https://www.newscientist.com/article/2409706-ai-discovers-new-class-of-antibiotics-to-kill-drug-resistant-bacteria/"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240916014421/https://www.newscientist.com/article/2409706-ai-discovers-new-class-of-antibiotics-to-kill-drug-resistant-bacteria/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-149"
      },
      {
        "text": "\"AI speeds up drug design for Parkinson's ten-fold\"",
        "url": "https://www.cam.ac.uk/research/news/ai-speeds-up-drug-design-for-parkinsons-ten-fold"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005165755/https://www.cam.ac.uk/research/news/ai-speeds-up-drug-design-for-parkinsons-ten-fold"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-150"
      },
      {
        "text": "\"Discovery of potent inhibitors of α-synuclein aggregation using structure-based iterative learning\"",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC11062903"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1038/s41589-024-01580-x",
        "url": "https://doi.org/10.1038%2Fs41589-024-01580-x"
      },
      {
        "text": "PMC",
        "url": "https://en.wikipedia.org/wiki/PMC_(identifier)",
        "title": "PMC (identifier)"
      },
      {
        "text": "11062903",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC11062903"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "38632492",
        "url": "https://pubmed.ncbi.nlm.nih.gov/38632492"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-151"
      },
      {
        "text": "\"The Talk of the Town – It\"",
        "url": "https://www.newyorker.com/magazine/1952/08/02/it"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0028-792X",
        "url": "https://search.worldcat.org/issn/0028-792X"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200216034025/https://www.newyorker.com/magazine/1952/08/02/it"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-152"
      },
      {
        "text": "\"Twenty years on from Deep Blue vs Kasparov: how a chess match started the big data revolution\"",
        "url": "https://theconversation.com/twenty-years-on-from-deep-blue-vs-kasparov-how-a-chess-match-started-the-big-data-revolution-76882"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240917000827/https://theconversation.com/twenty-years-on-from-deep-blue-vs-kasparov-how-a-chess-match-started-the-big-data-revolution-76882"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-153"
      },
      {
        "text": "\"Computer Wins on 'Jeopardy!': Trivial, It's Not\"",
        "url": "https://www.nytimes.com/2011/02/17/science/17jeopardy-watson.html"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0362-4331",
        "url": "https://search.worldcat.org/issn/0362-4331"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20141022023202/http://www.nytimes.com/2011/02/17/science/17jeopardy-watson.html"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-154"
      },
      {
        "text": "\"AlphaGo retires from competitive Go after defeating world number one 3–0\"",
        "url": "https://www.theverge.com/2017/5/27/15704088/alphago-ke-jie-game-3-result-retires-future"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20170607184301/https://www.theverge.com/2017/5/27/15704088/alphago-ke-jie-game-3-result-retires-future"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-155"
      },
      {
        "text": "\"Superhuman AI for multiplayer poker\"",
        "url": "https://www.science.org/doi/10.1126/science.aay2400"
      },
      {
        "text": "Bibcode",
        "url": "https://en.wikipedia.org/wiki/Bibcode_(identifier)",
        "title": "Bibcode (identifier)"
      },
      {
        "text": "2019Sci...365..885B",
        "url": "https://ui.adsabs.harvard.edu/abs/2019Sci...365..885B"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1126/science.aay2400",
        "url": "https://doi.org/10.1126%2Fscience.aay2400"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0036-8075",
        "url": "https://search.worldcat.org/issn/0036-8075"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "31296650",
        "url": "https://pubmed.ncbi.nlm.nih.gov/31296650"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-156"
      },
      {
        "text": "\"MuZero: Mastering Go, chess, shogi and Atari without rules\"",
        "url": "https://deepmind.google/discover/blog/muzero-mastering-go-chess-shogi-and-atari-without-rules"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-157"
      },
      {
        "text": "\"AI becomes grandmaster in 'fiendishly complex' StarCraft II\"",
        "url": "https://www.theguardian.com/technology/2019/oct/30/ai-becomes-grandmaster-in-fiendishly-complex-starcraft-ii"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0261-3077",
        "url": "https://search.worldcat.org/issn/0261-3077"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20201229185547/https://www.theguardian.com/technology/2019/oct/30/ai-becomes-grandmaster-in-fiendishly-complex-starcraft-ii"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-158"
      },
      {
        "text": "\"Outracing champion Gran Turismo drivers with deep reinforcement learning\"",
        "url": "https://www.researchsquare.com/article/rs-795954/latest.pdf"
      },
      {
        "text": "Bibcode",
        "url": "https://en.wikipedia.org/wiki/Bibcode_(identifier)",
        "title": "Bibcode (identifier)"
      },
      {
        "text": "2022Natur.602..223W",
        "url": "https://ui.adsabs.harvard.edu/abs/2022Natur.602..223W"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1038/s41586-021-04357-7",
        "url": "https://doi.org/10.1038%2Fs41586-021-04357-7"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "35140384",
        "url": "https://pubmed.ncbi.nlm.nih.gov/35140384"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-159"
      },
      {
        "text": "\"Google AI learns to play open-world video games by watching them\"",
        "url": "https://www.newscientist.com/article/2422101-google-ai-learns-to-play-open-world-video-games-by-watching-them"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240726182946/https://www.newscientist.com/article/2422101-google-ai-learns-to-play-open-world-video-games-by-watching-them/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-160"
      },
      {
        "text": "arXiv",
        "url": "https://en.wikipedia.org/wiki/ArXiv_(identifier)",
        "title": "ArXiv (identifier)"
      },
      {
        "text": "2404.03592",
        "url": "https://arxiv.org/abs/2404.03592"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-161"
      },
      {
        "text": "\"Improving mathematical reasoning with process supervision\"",
        "url": "https://openai.com/index/improving-mathematical-reasoning-with-process-supervision/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-162"
      },
      {
        "text": "arXiv",
        "url": "https://en.wikipedia.org/wiki/ArXiv_(identifier)",
        "title": "ArXiv (identifier)"
      },
      {
        "text": "2402.19450",
        "url": "https://arxiv.org/abs/2402.19450"
      },
      {
        "text": "cs.AI",
        "url": "https://arxiv.org/archive/cs.AI"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-163"
      },
      {
        "text": "arXiv",
        "url": "https://en.wikipedia.org/wiki/ArXiv_(identifier)",
        "title": "ArXiv (identifier)"
      },
      {
        "text": "2305.20050v1",
        "url": "https://arxiv.org/abs/2305.20050v1"
      },
      {
        "text": "cs.LG",
        "url": "https://arxiv.org/archive/cs.LG"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-VentureBeat_8_August_2024_164-0"
      },
      {
        "text": "\"Alibaba claims no. 1 spot in AI math models with Qwen2-Math\"",
        "url": "https://venturebeat.com/ai/alibaba-claims-no-1-spot-in-ai-math-models-with-qwen2-math/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-165"
      },
      {
        "text": "\"Microsoft's new rStar-Math technique upgrades small models to outperform OpenAI's o1-preview at math problems\"",
        "url": "https://venturebeat.com/ai/microsofts-new-rstar-math-technique-upgrades-small-models-to-outperform-openais-o1-preview-at-math-problems/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-166"
      },
      {
        "text": "\"AI achieves silver-medal standard solving International Mathematical Olympiad problems\"",
        "url": "https://www.nytimes.com/2024/07/25/science/ai-math-alphaproof-deepmind.html"
      },
      {
        "text": "The New York Times",
        "url": "https://en.wikipedia.org/wiki/The_New_York_Times",
        "title": "The New York Times"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240926131402/https://www.nytimes.com/2024/07/25/science/ai-math-alphaproof-deepmind.html"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-167"
      },
      {
        "text": "\"Llemma: An Open Language Model For Mathematics\"",
        "url": "https://blog.eleuther.ai/llemma/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-168"
      },
      {
        "text": "\"Julius AI\"",
        "url": "https://julius.ai/home/ai-math"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-169"
      },
      {
        "text": "\"8 Best AI for Math Tools (January 2025)\"",
        "url": "https://www.unite.ai/best-ai-for-math-tools/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-170"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-171"
      },
      {
        "text": "https://videovoice.org/ai-in-finance-innovation-entrepreneurship-vs-over-regulation-with-the-eus-artificial-intelligence-act-wont-work-as-intended/",
        "url": "https://videovoice.org/ai-in-finance-innovation-entrepreneurship-vs-over-regulation-with-the-eus-artificial-intelligence-act-wont-work-as-intended/"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240911125502/https://videovoice.org/ai-in-finance-innovation-entrepreneurship-vs-over-regulation-with-the-eus-artificial-intelligence-act-wont-work-as-intended/"
      },
      {
        "text": "Wayback Machine",
        "url": "https://en.wikipedia.org/wiki/Wayback_Machine",
        "title": "Wayback Machine"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-CRS-2019_172-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-CRS-2019_172-1"
      },
      {
        "text": "c",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-CRS-2019_172-2"
      },
      {
        "text": "Artificial Intelligence and National Security",
        "url": "https://fas.org/sgp/crs/natsec/R45178.pdf"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200508062631/https://fas.org/sgp/crs/natsec/R45178.pdf"
      },
      {
        "text": "PD-notice",
        "url": "https://en.wikipedia.org/wiki/Template:PD-notice",
        "title": "Template:PD-notice"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Slyusar-2019_173-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Slyusar-2019_173-1"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.13140/RG.2.2.30247.50087",
        "url": "https://doi.org/10.13140%2FRG.2.2.30247.50087"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-174"
      },
      {
        "text": "\"'Lavender': The AI machine directing Israel's bombing spree in Gaza\"",
        "url": "https://www.972mag.com/lavender-ai-israeli-army-gaza/"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241010022042/https://www.972mag.com/lavender-ai-israeli-army-gaza/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Davies-2023_175-0"
      },
      {
        "text": "\"'The Gospel': how Israel uses AI to select bombing targets in Gaza\"",
        "url": "https://www.theguardian.com/world/2023/dec/01/the-gospel-how-israel-uses-ai-to-select-bombing-targets"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231206213901/https://www.theguardian.com/world/2023/dec/01/the-gospel-how-israel-uses-ai-to-select-bombing-targets"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-176"
      },
      {
        "text": "\"Drohnen haben den Krieg in der Ukraine revolutioniert, doch sie sind empfindlich auf Störsender – deshalb sollen sie jetzt autonom operieren\"",
        "url": "https://www.nzz.ch/international/die-ukraine-setzt-auf-drohnen-die-autonom-navigieren-und-toeten-koennen-ld.1838731"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240810054043/https://www.nzz.ch/international/die-ukraine-setzt-auf-drohnen-die-autonom-navigieren-und-toeten-koennen-ld.1838731"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-177"
      },
      {
        "text": "\"Executive Order N-12-23\"",
        "url": "https://www.gov.ca.gov/wp-content/uploads/2023/09/AI-EO-No.12-_-GGN-Signed.pdf"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240221222035/https://www.gov.ca.gov/wp-content/uploads/2023/09/AI-EO-No.12-_-GGN-Signed.pdf"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-178"
      },
      {
        "text": "arXiv",
        "url": "https://en.wikipedia.org/wiki/ArXiv_(identifier)",
        "title": "ArXiv (identifier)"
      },
      {
        "text": "2307.15208",
        "url": "https://arxiv.org/abs/2307.15208"
      },
      {
        "text": "eess.IV",
        "url": "https://arxiv.org/archive/eess.IV"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-179"
      },
      {
        "text": "\"What is ChatGPT, DALL-E, and generative AI?\"",
        "url": "https://www.mckinsey.com/featured-insights/mckinsey-explainers/what-is-generative-ai"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230423114030/https://www.mckinsey.com/featured-insights/mckinsey-explainers/what-is-generative-ai"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-180"
      },
      {
        "text": "\"What is generative AI?\"",
        "url": "https://www.ibm.com/topics/generative-ai"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241213143644/https://www.ibm.com/topics/generative-ai"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Generative_artificial_intelligence_:02_181-0"
      },
      {
        "text": "\"Artificial Intelligence Glossary: Neural Networks and Other Terms Explained\"",
        "url": "https://www.nytimes.com/article/ai-artificial-intelligence-glossary.html"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0362-4331",
        "url": "https://search.worldcat.org/issn/0362-4331"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230901183440/https://www.nytimes.com/article/ai-artificial-intelligence-glossary.html"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-182"
      },
      {
        "text": "\"Generative models\"",
        "url": "https://openai.com/research/generative-models"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231117151617/https://openai.com/research/generative-models"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Generative_artificial_intelligence_nytimes2_183-0"
      },
      {
        "text": "\"Anthropic Said to Be Closing In on $300 Million in New A.I. Funding\"",
        "url": "https://www.nytimes.com/2023/01/27/technology/anthropic-ai-funding.html"
      },
      {
        "text": "The New York Times",
        "url": "https://en.wikipedia.org/wiki/The_New_York_Times",
        "title": "The New York Times"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231209074235/https://www.nytimes.com/2023/01/27/technology/anthropic-ai-funding.html"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Generative_artificial_intelligence_bloomberg2_184-0"
      },
      {
        "text": "\"A Cheat Sheet to AI Buzzwords and Their Meanings\"",
        "url": "https://news.bloomberglaw.com/tech-and-telecom-law/a-cheat-sheet-to-ai-buzzwords-and-their-meanings-quicktake"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231117140835/https://news.bloomberglaw.com/tech-and-telecom-law/a-cheat-sheet-to-ai-buzzwords-and-their-meanings-quicktake"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Generative_artificial_intelligence_nytimes-gpt4_185-0"
      },
      {
        "text": "\"OpenAI Plans to Up the Ante in Tech's A.I. Race\"",
        "url": "https://www.nytimes.com/2023/03/14/technology/openai-gpt4-chatgpt.html"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0362-4331",
        "url": "https://search.worldcat.org/issn/0362-4331"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230331011258/https://www.nytimes.com/2023/03/14/technology/openai-gpt4-chatgpt.html"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-186"
      },
      {
        "text": "arXiv",
        "url": "https://en.wikipedia.org/wiki/ArXiv_(identifier)",
        "title": "ArXiv (identifier)"
      },
      {
        "text": "2201.08239",
        "url": "https://arxiv.org/abs/2201.08239"
      },
      {
        "text": "cs.CL",
        "url": "https://arxiv.org/archive/cs.CL"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-187"
      },
      {
        "text": "\"A Coming-Out Party for Generative A.I., Silicon Valley's New Craze\"",
        "url": "https://www.nytimes.com/2022/10/21/technology/generative-ai.html"
      },
      {
        "text": "The New York Times",
        "url": "https://en.wikipedia.org/wiki/The_New_York_Times",
        "title": "The New York Times"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230215010524/https://www.nytimes.com/2022/10/21/technology/generative-ai.html"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Generative_artificial_intelligence_:4_188-0"
      },
      {
        "text": "\"OpenAI Unveils A.I. That Instantly Generates Eye-Popping Videos\"",
        "url": "https://www.nytimes.com/2024/02/15/technology/openai-sora-videos.html"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0362-4331",
        "url": "https://search.worldcat.org/issn/0362-4331"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240215220626/https://www.nytimes.com/2024/02/15/technology/openai-sora-videos.html"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Generative_artificial_intelligence_nytimes_189-0"
      },
      {
        "text": "\"Anthropic Said to Be Closing In on $300 Million in New A.I. Funding\"",
        "url": "https://www.nytimes.com/2023/01/27/technology/anthropic-ai-funding.html"
      },
      {
        "text": "The New York Times",
        "url": "https://en.wikipedia.org/wiki/The_New_York_Times",
        "title": "The New York Times"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231209074235/https://www.nytimes.com/2023/01/27/technology/anthropic-ai-funding.html"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Generative_artificial_intelligence_economist1_190-0"
      },
      {
        "text": "\"The race of the AI labs heats up\"",
        "url": "https://www.economist.com/business/2023/01/30/the-race-of-the-ai-labs-heats-up"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231117162947/https://www.economist.com/business/2023/01/30/the-race-of-the-ai-labs-heats-up"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-191"
      },
      {
        "text": "\"Google Cloud brings generative AI to developers, businesses, and governments\"",
        "url": "https://cloud.google.com/blog/products/ai-machine-learning/generative-ai-for-businesses-and-governments"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231117160059/https://cloud.google.com/blog/products/ai-machine-learning/generative-ai-for-businesses-and-governments"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-192"
      },
      {
        "text": "\"Misinformation reloaded? Fears about the impact of generative AI on misinformation are overblown\"",
        "url": "https://cnrs.hal.science/hal-04282032/file/simon_generative_AI_fears_20231018.pdf"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.37016/mr-2020-127",
        "url": "https://doi.org/10.37016%2Fmr-2020-127"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "264113883",
        "url": "https://api.semanticscholar.org/CorpusID:264113883"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-193"
      },
      {
        "text": "\"Transcript: Senate Judiciary Subcommittee Hearing on Oversight of AI\"",
        "url": "https://techpolicy.press/transcript-senate-judiciary-subcommittee-hearing-on-oversight-of-ai/"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231117160004/https://techpolicy.press/transcript-senate-judiciary-subcommittee-hearing-on-oversight-of-ai/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-194"
      },
      {
        "text": "\"New AI systems collide with copyright law\"",
        "url": "https://www.bbc.co.uk/news/business-66231268"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-195"
      },
      {
        "text": "Artificial Intelligence, Foundations of Computational Agents",
        "url": "https://doi.org/10.1017/9781009258227"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1017/9781009258227",
        "url": "https://doi.org/10.1017%2F9781009258227"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-1-0092-5819-7",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-1-0092-5819-7",
        "title": "Special:BookSources/978-1-0092-5819-7"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005165650/https://www.cambridge.org/highereducation/books/artificial-intelligence/C113F6CE284AB00F5489EBA5A59B93B7#overview"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-196"
      },
      {
        "text": "Artificial Intelligence: A Modern Approach",
        "url": "https://en.wikipedia.org/wiki/Artificial_Intelligence:_A_Modern_Approach",
        "title": "Artificial Intelligence: A Modern Approach"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-1346-1099-3",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-1346-1099-3",
        "title": "Special:BookSources/978-0-1346-1099-3"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-197"
      },
      {
        "text": "\"Why agents are the next frontier of generative AI\"",
        "url": "https://www.mckinsey.com/capabilities/mckinsey-digital/our-insights/why-agents-are-the-next-frontier-of-generative-ai"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241003212335/https://www.mckinsey.com/capabilities/mckinsey-digital/our-insights/why-agents-are-the-next-frontier-of-generative-ai"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-198"
      },
      {
        "text": "\"Powered by AI: Examining How AI Descriptions Influence Perceptions of Fertility Tracking Applications\"",
        "url": "https://dl.acm.org/doi/10.1145/3631414"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1145/3631414",
        "url": "https://doi.org/10.1145%2F3631414"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-199"
      },
      {
        "text": "\"Smart Sex Toys: A Narrative Review of Recent Research on Cultural, Health and Safety Considerations\"",
        "url": "https://doi.org/10.1007%2Fs11930-024-00392-3"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1007/s11930-024-00392-3",
        "url": "https://doi.org/10.1007%2Fs11930-024-00392-3"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "1548-3592",
        "url": "https://search.worldcat.org/issn/1548-3592"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-200"
      },
      {
        "text": "\"Large Language Models in an App: Conducting a Qualitative Synthetic Data Analysis of How Snapchat's \"My AI\" Responds to Questions About Sexual Consent, Sexual Refusals, Sexual Assault, and Sexting\"",
        "url": "https://www.tandfonline.com/doi/full/10.1080/00224499.2024.2396457"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1080/00224499.2024.2396457",
        "url": "https://doi.org/10.1080%2F00224499.2024.2396457"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0022-4499",
        "url": "https://search.worldcat.org/issn/0022-4499"
      },
      {
        "text": "PMC",
        "url": "https://en.wikipedia.org/wiki/PMC_(identifier)",
        "title": "PMC (identifier)"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "39254628",
        "url": "https://pubmed.ncbi.nlm.nih.gov/39254628"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241209185843/https://www.tandfonline.com/doi/full/10.1080/00224499.2024.2396457"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-201"
      },
      {
        "text": "\"\"Replika Removing Erotic Role-Play Is Like Grand Theft Auto Removing Guns or Cars\": Reddit Discourse on Artificial Intelligence Chatbots and Sexual Technologies\"",
        "url": "https://doi.org/10.1177%2F23780231241259627"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1177/23780231241259627",
        "url": "https://doi.org/10.1177%2F23780231241259627"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "2378-0231",
        "url": "https://search.worldcat.org/issn/2378-0231"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-202"
      },
      {
        "text": "\"Legal Protection of Revenge and Deepfake Porn Victims in the European Union: Findings From a Comparative Legal Study\"",
        "url": "https://journals.sagepub.com/doi/abs/10.1177/15248380221143772?journalCode=tvaa"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1177/15248380221143772",
        "url": "https://doi.org/10.1177%2F15248380221143772"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "1524-8380",
        "url": "https://search.worldcat.org/issn/1524-8380"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "36565267",
        "url": "https://pubmed.ncbi.nlm.nih.gov/36565267"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-203"
      },
      {
        "text": "\"Role of Artificial Intelligence in the Prevention of Online Child Sexual Abuse: A Systematic Review of Literature\"",
        "url": "https://www.tandfonline.com/doi/full/10.1080/19361610.2024.2331885"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1080/19361610.2024.2331885",
        "url": "https://doi.org/10.1080%2F19361610.2024.2331885"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "1936-1610",
        "url": "https://search.worldcat.org/issn/1936-1610"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241209171923/https://www.tandfonline.com/doi/full/10.1080/19361610.2024.2331885"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-204"
      },
      {
        "text": "De Choudhury, Munmun",
        "url": "https://en.wikipedia.org/wiki/Munmun_De_Choudhury",
        "title": "Munmun De Choudhury"
      },
      {
        "text": "\"A Human-Centered Systematic Literature Review of the Computational Approaches for Online Sexual Risk Detection\"",
        "url": "https://dl.acm.org/doi/10.1145/3479609"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1145/3479609",
        "url": "https://doi.org/10.1145%2F3479609"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "2573-0142",
        "url": "https://search.worldcat.org/issn/2573-0142"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241209171735/https://dl.acm.org/doi/10.1145/3479609"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-205"
      },
      {
        "text": "\"Reshaping Business With Artificial Intelligence\"",
        "url": "https://sloanreview.mit.edu/projects/reshaping-business-with-artificial-intelligence"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240213070751/https://sloanreview.mit.edu/projects/reshaping-business-with-artificial-intelligence"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-206"
      },
      {
        "text": "\"8 – AI for large-scale evacuation modeling: promises and challenges\"",
        "url": "https://www.sciencedirect.com/science/article/pii/B9780128240731000149"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-1282-4073-1",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-1282-4073-1",
        "title": "Special:BookSources/978-0-1282-4073-1"
      },
      {
        "text": "archived",
        "url": "https://web.archive.org/web/20240519121547/https://www.sciencedirect.com/science/article/abs/pii/B9780128240731000149"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-207"
      },
      {
        "text": "\"A Framework for Intelligent Fire Detection and Evacuation System\"",
        "url": "https://doi.org/10.1007/s10694-021-01157-3"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1007/s10694-021-01157-3",
        "url": "https://doi.org/10.1007%2Fs10694-021-01157-3"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "1572-8099",
        "url": "https://search.worldcat.org/issn/1572-8099"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005165650/https://link.springer.com/article/10.1007/s10694-021-01157-3"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-208"
      },
      {
        "text": "\"Modelling and interpreting pre-evacuation decision-making using machine learning\"",
        "url": "https://www.sciencedirect.com/science/article/pii/S0926580519313184"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1016/j.autcon.2020.103140",
        "url": "https://doi.org/10.1016%2Fj.autcon.2020.103140"
      },
      {
        "text": "hdl",
        "url": "https://en.wikipedia.org/wiki/Hdl_(identifier)",
        "title": "Hdl (identifier)"
      },
      {
        "text": "10179/17315",
        "url": "https://hdl.handle.net/10179%2F17315"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0926-5805",
        "url": "https://search.worldcat.org/issn/0926-5805"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240519121548/https://www.sciencedirect.com/science/article/abs/pii/S0926580519313184"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-209"
      },
      {
        "text": "\"India's latest election embraced AI technology. Here are some ways it was used constructively\"",
        "url": "https://www.pbs.org/newshour/world/indias-latest-election-embraced-ai-technology-here-are-some-ways-it-was-used-constructively"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240917194950/https://www.pbs.org/newshour/world/indias-latest-election-embraced-ai-technology-here-are-some-ways-it-was-used-constructively"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-210"
      },
      {
        "text": "\"Ethics of Artificial Intelligence and Robotics\"",
        "url": "https://plato.stanford.edu/archives/fall2023/entries/ethics-ai/"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005165650/https://plato.stanford.edu/archives/fall2023/entries/ethics-ai/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTESimonite2016_211-0"
      },
      {
        "text": "Simonite (2016)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSimonite2016"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021987_212-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTELaskowski2023_213-0"
      },
      {
        "text": "Laskowski (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLaskowski2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEGAO2022_214-0"
      },
      {
        "text": "GAO (2022)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFGAO2022"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEValinsky2019_215-0"
      },
      {
        "text": "Valinsky (2019)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFValinsky2019"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021991_216-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021991–992_217-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEChristian202063_218-0"
      },
      {
        "text": "Christian (2020)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEVincent2022_219-0"
      },
      {
        "text": "Vincent (2022)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFVincent2022"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-220"
      },
      {
        "text": "\"Copyright Services: Fair Use\"",
        "url": "https://guides.library.cornell.edu/copyright/fair-use"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240926194057/https://guides.library.cornell.edu/copyright/fair-use"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-221"
      },
      {
        "text": "\"How to Stop Your Data From Being Used to Train AI\"",
        "url": "https://www.wired.com/story/how-to-stop-your-data-from-being-used-to-train-ai"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "1059-1028",
        "url": "https://search.worldcat.org/issn/1059-1028"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241003180100/https://www.wired.com/story/how-to-stop-your-data-from-being-used-to-train-ai/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEReisner2023_222-0"
      },
      {
        "text": "Reisner (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFReisner2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEAlterHarris2023_223-0"
      },
      {
        "text": "Alter & Harris (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFAlterHarris2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-224"
      },
      {
        "text": "\"Getting the Innovation Ecosystem Ready for AI. An IP policy toolkit\"",
        "url": "https://www.wipo.int/edocs/pubdocs/en/wipo-pub-2003-en-getting-the-innovation-ecosystem-ready-for-ai.pdf"
      },
      {
        "text": "WIPO",
        "url": "https://en.wikipedia.org/wiki/WIPO",
        "title": "WIPO"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-225"
      },
      {
        "text": "\"Big Tech is spending more than VC firms on AI startups\"",
        "url": "https://arstechnica.com/ai/2023/12/big-tech-is-spending-more-than-vc-firms-on-ai-startups"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240110195706/https://arstechnica.com/ai/2023/12/big-tech-is-spending-more-than-vc-firms-on-ai-startups"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-226"
      },
      {
        "text": "\"The Future of AI Is GOMA\"",
        "url": "https://www.theatlantic.com/technology/archive/2023/10/big-ai-silicon-valley-dominance/675752"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240105020744/https://www.theatlantic.com/technology/archive/2023/10/big-ai-silicon-valley-dominance/675752"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-227"
      },
      {
        "text": "\"Big tech and the pursuit of AI dominance\"",
        "url": "https://www.economist.com/business/2023/03/26/big-tech-and-the-pursuit-of-ai-dominance"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231229021351/https://www.economist.com/business/2023/03/26/big-tech-and-the-pursuit-of-ai-dominance"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-228"
      },
      {
        "text": "\"Where the battle to dominate AI may be won\"",
        "url": "https://www.cnn.com/2023/12/19/tech/cloud-competition-and-ai/index.html"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240113053332/https://www.cnn.com/2023/12/19/tech/cloud-competition-and-ai/index.html"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-229"
      },
      {
        "text": "\"In the Age of A.I., Tech's Little Guys Need Big Friends\"",
        "url": "https://www.nytimes.com/2023/07/05/business/artificial-intelligence-power-data-centers.html"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240708214644/https://www.nytimes.com/2023/07/05/business/artificial-intelligence-power-data-centers.html"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-230"
      },
      {
        "text": "\"Electricity 2024 – Analysis\"",
        "url": "https://www.iea.org/reports/electricity-2024"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-231"
      },
      {
        "text": "\"AI already uses as much energy as a small country. It's only the beginning\"",
        "url": "https://www.vox.com/climate/2024/3/28/24111721/ai-uses-a-lot-of-energy-experts-expect-it-to-double-in-just-a-few-years"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240703080555/https://www.vox.com/climate/2024/3/28/24111721/ai-uses-a-lot-of-energy-experts-expect-it-to-double-in-just-a-few-years"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-232"
      },
      {
        "text": "\"AI is exhausting the power grid. Tech firms are seeking a miracle solution\"",
        "url": "https://www.washingtonpost.com/business/2024/06/21/artificial-intelligence-nuclear-fusion-climate/?utm_campaign=wp_post_most&utm_medium=email&utm_source=newsletter&wpisrc=nl_most&carta-url=https%3A%2F%2Fs2.washingtonpost.com%2Fcar-ln-tr%2F3e0d678%2F6675a2d2c2c05472dd9ec0f4%2F596c09009bbc0f20865036e7%2F12%2F52%2F6675a2d2c2c05472dd9ec0f4"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-233"
      },
      {
        "text": "\"AI Data Centers and the Coming YS Power Demand Surge\"",
        "url": "https://web.archive.org/web/20240726080428/https://www.goldmansachs.com/intelligence/pages/gs-research/generational-growth-ai-data-centers-and-the-coming-us-power-surge/report.pdf"
      },
      {
        "text": "the original",
        "url": "https://www.goldmansachs.com/intelligence/pages/gs-research/generational-growth-ai-data-centers-and-the-coming-us-power-surge/report.pdf"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-234"
      },
      {
        "text": "\"Energy-Guzzling AI Is Also the Future of Energy Savings\"",
        "url": "https://www.wsj.com/business/energy-oil/ai-data-centers-energy-savings-d602296e"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-235"
      },
      {
        "text": "\"Tech Industry Wants to Lock Up Nuclear Power for AI\"",
        "url": "https://www.wsj.com/business/energy-oil/tech-industry-wants-to-lock-up-nuclear-power-for-ai-6cb75316?mod=djem10point"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005165650/https://www.wsj.com/business/energy-oil/tech-industry-wants-to-lock-up-nuclear-power-for-ai-6cb75316?mod=djem10point"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-236"
      },
      {
        "text": "\"Nvidia's Huang Says Nuclear Power an Option to Feed Data Centers\"",
        "url": "https://www.bloomberg.com/news/articles/2024-09-27/nvidia-s-huang-says-nuclear-power-an-option-to-feed-data-centers"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-237"
      },
      {
        "text": "\"Microsoft deal would reopen Three Mile Island nuclear plant to power AI\"",
        "url": "https://www.washingtonpost.com/business/2024/09/20/microsoft-three-mile-island-nuclear-constellation"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-238"
      },
      {
        "text": "\"Three Mile Island's Nuclear Plant to Reopen, Help Power Microsoft's AI Centers\"",
        "url": "https://www.wsj.com/business/energy-oil/three-mile-islands-nuclear-plant-to-reopen-help-power-microsofts-ai-centers-aebfb3c8?mod=Searchresults_pos1&page=1"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005170152/https://www.wsj.com/business/energy-oil/three-mile-islands-nuclear-plant-to-reopen-help-power-microsofts-ai-centers-aebfb3c8?mod=Searchresults_pos1&page=1"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-DatacenterDynamics_239-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-DatacenterDynamics_239-1"
      },
      {
        "text": "c",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-DatacenterDynamics_239-2"
      },
      {
        "text": "\"Taiwan to stop large data centers in the North, cites insufficient power\"",
        "url": "https://www.datacenterdynamics.com/en/news/taiwan-to-stop-large-data-centers-in-the-north-cites-insufficient-power/"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241108213650/https://www.datacenterdynamics.com/en/news/taiwan-to-stop-large-data-centers-in-the-north-cites-insufficient-power/"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-bloombergjp_240-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-bloombergjp_240-1"
      },
      {
        "text": "\"エヌビディア出資の日本企業、原発近くでＡＩデータセンター新設検討\"",
        "url": "https://www.bloomberg.co.jp/news/articles/2024-10-18/SLHGKKT0AFB400"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241108213843/https://www.bloomberg.co.jp/news/articles/2024-10-18/SLHGKKT0AFB400"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Bloomberg20241104_241-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Bloomberg20241104_241-1"
      },
      {
        "text": "\"Nuclear-Hungry AI Campuses Need New Plan to Find Power Fast\"",
        "url": "https://www.bloomberg.com/news/articles/2024-11-04/nuclear-hungry-ai-campuses-need-new-strategy-to-find-power-fast"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-242"
      },
      {
        "text": "\"Energy and AI Executive summary\"",
        "url": "https://www.iea.org/reports/energy-and-ai/executive-summary"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTENicas2018_243-0"
      },
      {
        "text": "Nicas (2018)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNicas2018"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-244"
      },
      {
        "text": "\"Trust and Distrust in America\"",
        "url": "https://www.pewresearch.org/politics/2019/07/22/trust-and-distrust-in-america"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240222000601/https://www.pewresearch.org/politics/2019/07/22/trust-and-distrust-in-america"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-245"
      },
      {
        "text": "\"YouTube Struggles to Contain Its Conspiracy Problem\"",
        "url": "https://www.vanityfair.com/news/2018/02/youtube-conspiracy-problem"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEWilliams2023_246-0"
      },
      {
        "text": "Williams (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFWilliams2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-247"
      },
      {
        "text": "\"Computational propaganda and misinformation: AI technologies as tools of media manipulation\"",
        "url": "https://journalwjarr.com/node/366"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.30574/wjarr.2025.25.1.0131",
        "url": "https://doi.org/10.30574%2Fwjarr.2025.25.1.0131"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "2581-9615",
        "url": "https://search.worldcat.org/issn/2581-9615"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTETaylorHern2023_248-0"
      },
      {
        "text": "Taylor & Hern (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFTaylorHern2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-249"
      },
      {
        "text": "\"To fight AI, we need 'personhood credentials,' say AI firms\"",
        "url": "http://web.archive.org/web/20250424232537/https://www.theregister.com/2024/09/03/ai_personhood_credentials/"
      },
      {
        "text": "the original",
        "url": "https://www.theregister.com/2024/09/03/ai_personhood_credentials/"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Samuel-2022_250-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Samuel-2022_250-1"
      },
      {
        "text": "\"Why it's so damn hard to make AI fair and unbiased\"",
        "url": "https://www.vox.com/future-perfect/22916602/ai-bias-fairness-tradeoffs-artificial-intelligence"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005170153/https://www.vox.com/future-perfect/22916602/ai-bias-fairness-tradeoffs-artificial-intelligence"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERose2023_252-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERose2023_252-1"
      },
      {
        "text": "Rose (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRose2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTECNA2019_253-0"
      },
      {
        "text": "CNA (2019)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCNA2019"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEGoffrey200817_254-0"
      },
      {
        "text": "Goffrey (2008)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFGoffrey2008"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-255"
      },
      {
        "text": "Berdahl et al. (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFBerdahlBakerMannOsoba2023"
      },
      {
        "text": "Goffrey (2008",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFGoffrey2008"
      },
      {
        "text": "Rose (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRose2023"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEChristian202025_256-0"
      },
      {
        "text": "Christian (2020)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021995_257-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021995_257-1"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEGrantHill2023_258-0"
      },
      {
        "text": "Grant & Hill (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFGrantHill2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTELarsonAngwin2016_259-0"
      },
      {
        "text": "Larson & Angwin (2016)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLarsonAngwin2016"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEChristian202067–70_260-0"
      },
      {
        "text": "Christian (2020)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-262"
      },
      {
        "text": "Christian (2020",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-263"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Lipartito (2011",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLipartito2011"
      },
      {
        "text": "Goodman & Flaxman (2017",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFGoodmanFlaxman2017"
      },
      {
        "text": "Christian (2020",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-264"
      },
      {
        "text": "Christian (2020",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-265"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Christian (2020",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-266"
      },
      {
        "text": "Christian (2020",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEDockrill2022_268-0"
      },
      {
        "text": "Dockrill (2022)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDockrill2022"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTESample2017_269-0"
      },
      {
        "text": "Sample (2017)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSample2017"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-270"
      },
      {
        "text": "\"Black Box AI\"",
        "url": "https://www.techopedia.com/definition/34940/black-box-ai"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240615100800/https://www.techopedia.com/definition/34940/black-box-ai"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEChristian2020110_271-0"
      },
      {
        "text": "Christian (2020)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEChristian202088–91_272-0"
      },
      {
        "text": "Christian (2020)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-273"
      },
      {
        "text": "Christian (2020",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEChristian202091_275-0"
      },
      {
        "text": "Christian (2020)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEChristian202083_276-0"
      },
      {
        "text": "Christian (2020)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEVerma2021_277-0"
      },
      {
        "text": "Verma (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFVerma2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERothman2020_278-0"
      },
      {
        "text": "Rothman (2020)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRothman2020"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEChristian2020105–108_279-0"
      },
      {
        "text": "Christian (2020)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEChristian2020108–112_280-0"
      },
      {
        "text": "Christian (2020)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-281"
      },
      {
        "text": "\"New Anthropic Research Sheds Light on AI's 'Black Box'\"",
        "url": "https://gizmodo.com/new-anthropic-research-sheds-light-on-ais-black-box-1851491333"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005170309/https://gizmodo.com/new-anthropic-research-sheds-light-on-ais-black-box-1851491333"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021989_282-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021987–990_284-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021987–990_284-1"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021988_285-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-286"
      },
      {
        "text": "Robitzski (2018)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRobitzski2018"
      },
      {
        "text": "Sainato (2015)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSainato2015"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEHarari2018_287-0"
      },
      {
        "text": "Harari (2018)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFHarari2018"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-288"
      },
      {
        "text": "\"How China Uses High-Tech Surveillance to Subdue Minorities\"",
        "url": "https://www.nytimes.com/2019/05/22/world/asia/china-surveillance-xinjiang.html"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20191125180459/https://www.nytimes.com/2019/05/22/world/asia/china-surveillance-xinjiang.html"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-289"
      },
      {
        "text": "\"Security lapse exposed a Chinese smart city surveillance system\"",
        "url": "https://techcrunch.com/2019/05/03/china-smart-city-exposed"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20210307203740/https://consent.yahoo.com/v2/collectConsent?sessionId=3_cc-session_c8562b93-9863-4915-8523-6c7b930a3efc"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEUrbinaLentzosInvernizziEkins2022_290-0"
      },
      {
        "text": "Urbina et al. (2022)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFUrbinaLentzosInvernizziEkins2022"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-E_291-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-E_291-1"
      },
      {
        "text": "51(3) Industrial Law Journal 511–559",
        "url": "https://academic.oup.com/ilj/article/51/3/511/6321008"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230527163045/https://academic.oup.com/ilj/article/51/3/511/6321008"
      },
      {
        "text": "Wayback Machine",
        "url": "https://en.wikipedia.org/wiki/Wayback_Machine",
        "title": "Wayback Machine"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-292"
      },
      {
        "text": "Ford & Colvin (2015)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFFordColvin2015"
      },
      {
        "text": "McGaughey (2022)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcGaughey2022"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEIGM_Chicago2017_293-0"
      },
      {
        "text": "IGM Chicago (2017)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFIGM_Chicago2017"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEArntzGregoryZierahn201633_294-0"
      },
      {
        "text": "Arntz, Gregory & Zierahn (2016)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFArntzGregoryZierahn2016"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-296"
      },
      {
        "text": "Lohr (2017)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLohr2017"
      },
      {
        "text": "Frey & Osborne (2017)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFFreyOsborne2017"
      },
      {
        "text": "Arntz, Gregory & Zierahn (2016",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFArntzGregoryZierahn2016"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-297"
      },
      {
        "text": "\"AI is already taking video game illustrators' jobs in China\"",
        "url": "https://restofworld.org/2023/ai-image-china-video-game-layoffs"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240221131748/https://restofworld.org/2023/ai-image-china-video-game-layoffs/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-298"
      },
      {
        "text": "\"China's game art industry reportedly decimated by growing AI use\"",
        "url": "https://www.gamedeveloper.com/art/china-s-game-art-industry-reportedly-decimated-ai-art-use"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230817010519/https://www.gamedeveloper.com/art/china-s-game-art-industry-reportedly-decimated-ai-art-use"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEMorgenstern2015_299-0"
      },
      {
        "text": "Morgenstern (2015)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMorgenstern2015"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-300"
      },
      {
        "text": "Mahdawi (2017)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMahdawi2017"
      },
      {
        "text": "Thompson (2014)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFThompson2014"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-301"
      },
      {
        "text": "The Guardian Weekly",
        "url": "https://en.wikipedia.org/wiki/The_Guardian_Weekly",
        "title": "The Guardian Weekly"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTECellan-Jones2014_302-0"
      },
      {
        "text": "Cellan-Jones (2014)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCellan-Jones2014"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig20211001_303-0"
      },
      {
        "text": "Russell & Norvig 2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEBostrom2014_305-0"
      },
      {
        "text": "Bostrom (2014)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFBostrom2014"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussell2019_306-0"
      },
      {
        "text": "Russell (2019)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussell2019"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-307"
      },
      {
        "text": "Bostrom (2014)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFBostrom2014"
      },
      {
        "text": "Müller & Bostrom (2014)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMüllerBostrom2014"
      },
      {
        "text": "Bostrom (2015)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFBostrom2015"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEHarari2023_308-0"
      },
      {
        "text": "Harari (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFHarari2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEMüllerBostrom2014_309-0"
      },
      {
        "text": "Müller & Bostrom (2014)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMüllerBostrom2014"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-310"
      },
      {
        "text": "Rawlinson (2015)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRawlinson2015"
      },
      {
        "text": "Holley (2015)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFHolley2015"
      },
      {
        "text": "Gibbs (2014)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFGibbs2014"
      },
      {
        "text": "Sainato (2015)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSainato2015"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-311"
      },
      {
        "text": "\"\"Godfather of artificial intelligence\" talks impact and potential of new AI\"",
        "url": "https://www.cbsnews.com/video/godfather-of-artificial-intelligence-talks-impact-and-potential-of-new-ai"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230328225221/https://www.cbsnews.com/video/godfather-of-artificial-intelligence-talks-impact-and-potential-of-new-ai"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-312"
      },
      {
        "text": "\"Canadian artificial intelligence leader Geoffrey Hinton piles on fears of computer takeover\"",
        "url": "https://www.cbc.ca/news/business/ai-doom-column-don-pittis-1.6829302"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240707032135/https://www.cbc.ca/news/business/ai-doom-column-don-pittis-1.6829302"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-313"
      },
      {
        "text": "\"'50–50 chance' that AI outsmarts humanity, Geoffrey Hinton says\"",
        "url": "https://www.bnnbloomberg.ca/50-50-chance-that-ai-outsmarts-humanity-geoffrey-hinton-says-1.2085394"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240614144506/https://www.bnnbloomberg.ca/50-50-chance-that-ai-outsmarts-humanity-geoffrey-hinton-says-1.2085394"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEValance2023_314-0"
      },
      {
        "text": "Valance (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFValance2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-315"
      },
      {
        "text": "\"Rise of artificial intelligence is inevitable but should not be feared, 'father of AI' says\"",
        "url": "https://www.theguardian.com/technology/2023/may/07/rise-of-artificial-intelligence-is-inevitable-but-should-not-be-feared-father-of-ai-says"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231023061228/https://www.theguardian.com/technology/2023/may/07/rise-of-artificial-intelligence-is-inevitable-but-should-not-be-feared-father-of-ai-says"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-316"
      },
      {
        "text": "\"'Father of AI' says tech fears misplaced: 'You cannot stop it'\"",
        "url": "https://www.foxnews.com/tech/father-ai-jurgen-schmidhuber-says-tech-fears-misplaced-cannot-stop"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230526162642/https://www.foxnews.com/tech/father-ai-jurgen-schmidhuber-says-tech-fears-misplaced-cannot-stop"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-317"
      },
      {
        "text": "\"Juergen Schmidhuber, Renowned 'Father Of Modern AI,' Says His Life's Work Won't Lead To Dystopia\"",
        "url": "https://www.forbes.com/sites/hessiejones/2023/05/23/juergen-schmidhuber-renowned-father-of-modern-ai-says-his-lifes-work-wont-lead-to-dystopia"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230526163102/https://www.forbes.com/sites/hessiejones/2023/05/23/juergen-schmidhuber-renowned-father-of-modern-ai-says-his-lifes-work-wont-lead-to-dystopia/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-318"
      },
      {
        "text": "\"Andrew Ng: 'Do we think the world is better off with more or less intelligence?'\"",
        "url": "https://www.ft.com/content/2dc07f9e-d2a9-4d98-b746-b051f9352be3"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240125014121/https://www.ft.com/content/2dc07f9e-d2a9-4d98-b746-b051f9352be3"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-319"
      },
      {
        "text": "\"How Not to Be Stupid About AI, With Yann LeCun\"",
        "url": "https://www.wired.com/story/artificial-intelligence-meta-yann-lecun-interview"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231228152443/https://www.wired.com/story/artificial-intelligence-meta-yann-lecun-interview/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-320"
      },
      {
        "text": "Brooks (2014)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFBrooks2014"
      },
      {
        "text": "Geist (2015)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFGeist2015"
      },
      {
        "text": "Madrigal (2015)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMadrigal2015"
      },
      {
        "text": "Lee (2014)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLee2014"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEChristian202067,_73_321-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEChristian202067,_73_321-1"
      },
      {
        "text": "Christian (2020)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChristian2020"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEYudkowsky2008_322-0"
      },
      {
        "text": "Yudkowsky (2008)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFYudkowsky2008"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEAndersonAnderson2011_323-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEAndersonAnderson2011_323-1"
      },
      {
        "text": "Anderson & Anderson (2011)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFAndersonAnderson2011"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEAAAI2014_324-0"
      },
      {
        "text": "AAAI (2014)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFAAAI2014"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEWallach2010_325-0"
      },
      {
        "text": "Wallach (2010)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFWallach2010"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussell2019173_326-0"
      },
      {
        "text": "Russell (2019)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussell2019"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-327"
      },
      {
        "text": "\"Hugging Face CEO says he's focused on building a 'sustainable model' for the $4.5 billion open-source-AI startup\"",
        "url": "https://www.businessinsider.com/hugging-face-open-source-ai-approach-2023-12"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240925013220/https://www.businessinsider.com/hugging-face-open-source-ai-approach-2023-12"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-328"
      },
      {
        "text": "\"Google open sources tools to support AI model development\"",
        "url": "https://techcrunch.com/2024/04/09/google-open-sources-tools-to-support-ai-model-development"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240910112401/https://techcrunch.com/2024/04/09/google-open-sources-tools-to-support-ai-model-development/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-329"
      },
      {
        "text": "\"The open-source AI boom is built on Big Tech's handouts. How long will it last?\"",
        "url": "https://www.technologyreview.com/2023/05/12/1072950/open-source-ai-google-openai-eleuther-meta"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-330"
      },
      {
        "text": "\"Mistral AI's New Language Model Aims for Open Source Supremacy\"",
        "url": "https://aibusiness.com/nlp/mistral-ai-s-new-language-model-aims-for-open-source-supremacy"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240905212607/https://aibusiness.com/nlp/mistral-ai-s-new-language-model-aims-for-open-source-supremacy"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-331"
      },
      {
        "text": "\"Stability announces Stable Diffusion 3, a next-gen AI image generator\"",
        "url": "https://arstechnica.com/information-technology/2024/02/stability-announces-stable-diffusion-3-a-next-gen-ai-image-generator"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005170201/https://arstechnica.com/information-technology/2024/02/stability-announces-stable-diffusion-3-a-next-gen-ai-image-generator/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-332"
      },
      {
        "text": "\"How enterprises are using open source LLMs: 16 examples\"",
        "url": "https://venturebeat.com/ai/how-enterprises-are-using-open-source-llms-16-examples"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240926171131/https://venturebeat.com/ai/how-enterprises-are-using-open-source-llms-16-examples/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-333"
      },
      {
        "text": "\"Should we make our most powerful AI models open source to all?\"",
        "url": "https://www.vox.com/future-perfect/2024/2/2/24058484/open-source-artificial-intelligence-ai-risk-meta-llama-2-chatgpt-openai-deepfake"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005170204/https://www.vox.com/future-perfect/2024/2/2/24058484/open-source-artificial-intelligence-ai-risk-meta-llama-2-chatgpt-openai-deepfake"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-334"
      },
      {
        "text": "\"Understanding artificial intelligence ethics and safety\"",
        "url": "https://www.turing.ac.uk/sites/default/files/2019-06/understanding_artificial_intelligence_ethics_and_safety.pdf"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240911131935/https://www.turing.ac.uk/sites/default/files/2019-06/understanding_artificial_intelligence_ethics_and_safety.pdf"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-335"
      },
      {
        "text": "\"AI Ethics and Governance in Practice\"",
        "url": "https://www.turing.ac.uk/sites/default/files/2023-12/aieg-ati-ai-ethics-an-intro_1.pdf"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240911125504/https://www.turing.ac.uk/sites/default/files/2023-12/aieg-ati-ai-ethics-an-intro_1.pdf"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-336"
      },
      {
        "text": "\"A Unified Framework of Five Principles for AI in Society\"",
        "url": "https://hdsr.mitpress.mit.edu/pub/l0jsh9d1"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1162/99608f92.8cd550d1",
        "url": "https://doi.org/10.1162%2F99608f92.8cd550d1"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "198775713",
        "url": "https://api.semanticscholar.org/CorpusID:198775713"
      },
      {
        "text": "Archived",
        "url": "https://archive.today/20190807202909/https://hdsr.mitpress.mit.edu/pub/l0jsh9d1"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-337"
      },
      {
        "text": "\"A critical perspective on guidelines for responsible and trustworthy artificial intelligence\"",
        "url": "https://doi.org/10.1007/s11019-020-09948-1"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1007/s11019-020-09948-1",
        "url": "https://doi.org/10.1007%2Fs11019-020-09948-1"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "1572-8633",
        "url": "https://search.worldcat.org/issn/1572-8633"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "32236794",
        "url": "https://pubmed.ncbi.nlm.nih.gov/32236794"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "214766800",
        "url": "https://api.semanticscholar.org/CorpusID:214766800"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005170206/https://link.springer.com/article/10.1007/s11019-020-09948-1"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-338"
      },
      {
        "text": "\"Ethical issues in the development of artificial intelligence: recognizing the risks\"",
        "url": "https://doi.org/10.1108/IJOES-05-2023-0107"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1108/IJOES-05-2023-0107",
        "url": "https://doi.org/10.1108%2FIJOES-05-2023-0107"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "2514-9369",
        "url": "https://search.worldcat.org/issn/2514-9369"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "259614124",
        "url": "https://api.semanticscholar.org/CorpusID:259614124"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005170207/https://www.emerald.com/insight/content/doi/10.1108/IJOES-05-2023-0107/full/html"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-339"
      },
      {
        "text": "\"AI Safety Institute releases new AI safety evaluations platform\"",
        "url": "https://www.gov.uk/government/news/ai-safety-institute-releases-new-ai-safety-evaluations-platform"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005170207/https://www.gov.uk/government/news/ai-safety-institute-releases-new-ai-safety-evaluations-platform"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-340"
      },
      {
        "text": "Berryhill et al. (2019)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFBerryhillHeangClogherMcBride2019"
      },
      {
        "text": "Barfield & Pagallo (2018)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFBarfieldPagallo2018"
      },
      {
        "text": "Iphofen & Kritikos (2019)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFIphofenKritikos2019"
      },
      {
        "text": "Wirtz, Weyerer & Geyer (2018)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFWirtzWeyererGeyer2018"
      },
      {
        "text": "Buiten (2019)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFBuiten2019"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTELaw_Library_of_Congress_(U.S.)._Global_Legal_Research_Directorate2019_341-0"
      },
      {
        "text": "Law Library of Congress (U.S.). Global Legal Research Directorate (2019)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLaw_Library_of_Congress_(U.S.)._Global_Legal_Research_Directorate2019"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEVincent2023_342-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEVincent2023_342-1"
      },
      {
        "text": "Vincent (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFVincent2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEStanford_University2023_343-0"
      },
      {
        "text": "Stanford University (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFStanford_University2023"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEUNESCO2021_344-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEUNESCO2021_344-1"
      },
      {
        "text": "c",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEUNESCO2021_344-2"
      },
      {
        "text": "d",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEUNESCO2021_344-3"
      },
      {
        "text": "UNESCO (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFUNESCO2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEKissinger2021_345-0"
      },
      {
        "text": "Kissinger (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFKissinger2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEAltmanBrockmanSutskever2023_346-0"
      },
      {
        "text": "Altman, Brockman & Sutskever (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFAltmanBrockmanSutskever2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-347"
      },
      {
        "text": "\"UN Announces Advisory Body on Artificial Intelligence\"",
        "url": "https://www.voanews.com/a/un-announces-advisory-body-on-artificial-intelligence-/7328732.html"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240918071530/https://www.voanews.com/a/un-announces-advisory-body-on-artificial-intelligence-/7328732.html"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-348"
      },
      {
        "text": "\"Council of Europe opens first ever global treaty on AI for signature\"",
        "url": "https://www.coe.int/en/web/portal/-/council-of-europe-opens-first-ever-global-treaty-on-ai-for-signature"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240917001330/https://www.coe.int/en/web/portal/-/council-of-europe-opens-first-ever-global-treaty-on-ai-for-signature"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEEdwards2023_349-0"
      },
      {
        "text": "Edwards (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFEdwards2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEKasperowicz2023_350-0"
      },
      {
        "text": "Kasperowicz (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFKasperowicz2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEFox_News2023_351-0"
      },
      {
        "text": "Fox News (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFFox_News2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-352"
      },
      {
        "text": "The Guardian Weekly",
        "url": "https://en.wikipedia.org/wiki/The_Guardian_Weekly",
        "title": "The Guardian Weekly"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-353"
      },
      {
        "text": "\"The Bletchley Declaration by Countries Attending the AI Safety Summit, 1–2 November 2023\"",
        "url": "https://web.archive.org/web/20231101123904/https://www.gov.uk/government/publications/ai-safety-summit-2023-the-bletchley-declaration/the-bletchley-declaration-by-countries-attending-the-ai-safety-summit-1-2-november-2023"
      },
      {
        "text": "the original",
        "url": "https://www.gov.uk/government/publications/ai-safety-summit-2023-the-bletchley-declaration/the-bletchley-declaration-by-countries-attending-the-ai-safety-summit-1-2-november-2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-354"
      },
      {
        "text": "\"Countries agree to safe and responsible development of frontier AI in landmark Bletchley Declaration\"",
        "url": "https://www.gov.uk/government/news/countries-agree-to-safe-and-responsible-development-of-frontier-ai-in-landmark-bletchley-declaration"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231101115016/https://www.gov.uk/government/news/countries-agree-to-safe-and-responsible-development-of-frontier-ai-in-landmark-bletchley-declaration"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-355"
      },
      {
        "text": "\"Second global AI summit secures safety commitments from companies\"",
        "url": "https://www.reuters.com/technology/global-ai-summit-seoul-aims-forge-new-regulatory-agreements-2024-05-21"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-356"
      },
      {
        "text": "\"Frontier AI Safety Commitments, AI Seoul Summit 2024\"",
        "url": "https://web.archive.org/web/20240523201611/https://www.gov.uk/government/publications/frontier-ai-safety-commitments-ai-seoul-summit-2024/frontier-ai-safety-commitments-ai-seoul-summit-2024"
      },
      {
        "text": "the original",
        "url": "https://www.gov.uk/government/publications/frontier-ai-safety-commitments-ai-seoul-summit-2024/frontier-ai-safety-commitments-ai-seoul-summit-2024"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-RandDworld_20241103_357-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-RandDworld_20241103_357-1"
      },
      {
        "text": "\"Quality vs. quantity: US and China chart different paths in global AI patent race in 2024 / Geographical breakdown of AI patents in 2024\"",
        "url": "https://www.rdworldonline.com/quality-vs-quantity-us-and-china-chart-different-paths-in-global-ai-patent-race-in-2024/"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241209072113/https://www.rdworldonline.com/quality-vs-quantity-us-and-china-chart-different-paths-in-global-ai-patent-race-in-2024/"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig20219_358-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig20219_358-1"
      },
      {
        "text": "Russell & Norvig 2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Clarendon_Press-2004_359-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Clarendon_Press-2004_359-1"
      },
      {
        "text": "c",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Clarendon_Press-2004_359-2"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "0-1982-5079-7",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/0-1982-5079-7",
        "title": "Special:BookSources/0-1982-5079-7"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-360"
      },
      {
        "text": "\"Google books ngram\"",
        "url": "https://books.google.com/ngrams/graph?content=electronic+brain&year_start=1930&year_end=2019&corpus=en-2019&smoothing=3"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005170209/https://books.google.com/ngrams/graph?content=electronic+brain&year_start=1930&year_end=2019&corpus=en-2019&smoothing=3"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-362"
      },
      {
        "text": "McCorduck (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCorduck2004"
      },
      {
        "text": "Crevier (1993",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Moravec (1988",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMoravec1988"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Turing_363-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Turing_363-1"
      },
      {
        "text": "Turing test",
        "url": "https://en.wikipedia.org/wiki/Turing_test",
        "title": "Turing test"
      },
      {
        "text": "Computing machinery and intelligence",
        "url": "https://en.wikipedia.org/wiki/Computing_machinery_and_intelligence",
        "title": "Computing machinery and intelligence"
      },
      {
        "text": "Turing (1950)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFTuring1950"
      },
      {
        "text": "Haugeland (1985",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFHaugeland1985"
      },
      {
        "text": "Crevier (1993",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "McCorduck (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCorduck2004"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTECrevier199347–49_364-0"
      },
      {
        "text": "Crevier (1993)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig200317_366-0"
      },
      {
        "text": "Russell & Norvig (2003)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2003"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig200318_368-0"
      },
      {
        "text": "Russell & Norvig (2003)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2003"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTENewquist199486–86_371-0"
      },
      {
        "text": "Newquist (1994)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNewquist1994"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-372"
      },
      {
        "text": "Simon (1965",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSimon1965"
      },
      {
        "text": "Crevier (1993",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-373"
      },
      {
        "text": "Minsky (1967",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMinsky1967"
      },
      {
        "text": "Crevier (1993",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig202121_374-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTELighthill1973_376-0"
      },
      {
        "text": "Lighthill (1973)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLighthill1973"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTENRC1999212–213_377-0"
      },
      {
        "text": "NRC 1999",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNRC1999"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig202122_378-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-379"
      },
      {
        "text": "Expert systems",
        "url": "https://en.wikipedia.org/wiki/Expert_systems",
        "title": "Expert systems"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Luger & Stubblefield (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLugerStubblefield2004"
      },
      {
        "text": "Nilsson (1998",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "McCorduck (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCorduck2004"
      },
      {
        "text": "Crevier (1993",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "Newquist (1994",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNewquist1994"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig202124_380-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTENilsson19987_381-0"
      },
      {
        "text": "Nilsson (1998)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEMcCorduck2004454–462_382-0"
      },
      {
        "text": "McCorduck (2004)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCorduck2004"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEMoravec1988_383-0"
      },
      {
        "text": "Moravec (1988)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMoravec1988"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEBrooks1990_384-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEBrooks1990_384-1"
      },
      {
        "text": "Brooks (1990)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFBrooks1990"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-385"
      },
      {
        "text": "Developmental robotics",
        "url": "https://en.wikipedia.org/wiki/Developmental_robotics",
        "title": "Developmental robotics"
      },
      {
        "text": "Weng et al. (2001)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFWengMcClellandPentlandSporns2001"
      },
      {
        "text": "Lungarella et al. (2003)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLungarellaMettaPfeiferSandini2003"
      },
      {
        "text": "Asada et al. (2009)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFAsadaHosodaKuniyoshiIshiguro2009"
      },
      {
        "text": "Oudeyer (2010)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFOudeyer2010"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig202125_387-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-388"
      },
      {
        "text": "Crevier (1993",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig202126_389-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Formal_and_narrow_methods_adopted_in_the_1990s_390-0"
      },
      {
        "text": "Formal",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Neat_vs._scruffy"
      },
      {
        "text": "narrow",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#Narrow_vs._general_AI"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "McCorduck (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCorduck2004"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-391"
      },
      {
        "text": "Kurzweil (2005",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFKurzweil2005"
      },
      {
        "text": "NRC (1999",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNRC1999"
      },
      {
        "text": "Newquist (1994",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNewquist1994"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEWong2023_392-0"
      },
      {
        "text": "Wong (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFWong2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-394"
      },
      {
        "text": "Moore's Law",
        "url": "https://en.wikipedia.org/wiki/Moore%27s_Law",
        "title": "Moore's Law"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEClark2015b_395-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEClark2015b_395-1"
      },
      {
        "text": "c",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEClark2015b_395-2"
      },
      {
        "text": "Clark (2015b)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFClark2015b"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-396"
      },
      {
        "text": "Big data",
        "url": "https://en.wikipedia.org/wiki/Big_data",
        "title": "Big data"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-398"
      },
      {
        "text": "\"OpenAI Releases GPT-3, The Largest Model So Far\"",
        "url": "https://analyticsindiamag.com/open-ai-gpt-3-language-model"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200804173452/https://analyticsindiamag.com/open-ai-gpt-3-language-model"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-399"
      },
      {
        "text": "\"ChatGPT reaches 100 million users two months after launch\"",
        "url": "https://www.theguardian.com/technology/2023/feb/02/chatgpt-100-million-users-open-ai-fastest-growing-app"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0261-3077",
        "url": "https://search.worldcat.org/issn/0261-3077"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230203051356/https://www.theguardian.com/technology/2023/feb/02/chatgpt-100-million-users-open-ai-fastest-growing-app"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-400"
      },
      {
        "text": "\"ChatGPT turns 1: AI chatbot's success says as much about humans as technology\"",
        "url": "https://theconversation.com/chatgpt-turns-1-ai-chatbots-success-says-as-much-about-humans-as-technology-218704"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241231073513/https://theconversation.com/chatgpt-turns-1-ai-chatbots-success-says-as-much-about-humans-as-technology-218704"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEDiFeliciantonio2023_401-0"
      },
      {
        "text": "DiFeliciantonio (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDiFeliciantonio2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEGoswami2023_402-0"
      },
      {
        "text": "Goswami (2023)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFGoswami2023"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-403"
      },
      {
        "text": "\"Nearly 1 in 4 new startups is an AI company\"",
        "url": "https://pitchbook.com/news/articles/nearly-1-in-4-new-startups-is-an-ai-company"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-404"
      },
      {
        "text": "\"Philosophy is crucial in the age of AI\"",
        "url": "https://theconversation.com/philosophy-is-crucial-in-the-age-of-ai-235907"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005170243/https://theconversation.com/philosophy-is-crucial-in-the-age-of-ai-235907"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Jarow-2024_405-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Jarow-2024_405-1"
      },
      {
        "text": "\"Will AI ever become conscious? It depends on how you think about biology\"",
        "url": "https://www.vox.com/future-perfect/351893/consciousness-ai-machines-neuroscience-mind"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240921035218/https://www.vox.com/future-perfect/351893/consciousness-ai-machines-neuroscience-mind"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-406"
      },
      {
        "text": "\"The Philosophy of AI and the AI of Philosophy\"",
        "url": "https://web.archive.org/web/20181023181725/http://jmc.stanford.edu/articles/aiphil2.html"
      },
      {
        "text": "the original",
        "url": "http://jmc.stanford.edu/articles/aiphil2.html"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTETuring19501_407-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTETuring19501_407-1"
      },
      {
        "text": "Turing (1950)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFTuring1950"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTETuring1950Under_\"The_Argument_from_Consciousness\"_408-0"
      },
      {
        "text": "Turing (1950)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFTuring1950"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-409"
      },
      {
        "text": "\"AI is closer than ever to passing the Turing test for 'intelligence'. What happens when it does?\"",
        "url": "https://theconversation.com/ai-is-closer-than-ever-to-passing-the-turing-test-for-intelligence-what-happens-when-it-does-214721"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240925040612/https://theconversation.com/ai-is-closer-than-ever-to-passing-the-turing-test-for-intelligence-what-happens-when-it-does-214721"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig20213_410-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEMaker2006_411-0"
      },
      {
        "text": "Maker (2006)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMaker2006"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEMcCarthy1999_412-0"
      },
      {
        "text": "McCarthy (1999)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCarthy1999"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEMinsky1986_413-0"
      },
      {
        "text": "Minsky (1986)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMinsky1986"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-414"
      },
      {
        "text": "\"What Is Artificial Intelligence (AI)?\"",
        "url": "https://cloud.google.com/learn/what-is-artificial-intelligence"
      },
      {
        "text": "Google Cloud Platform",
        "url": "https://en.wikipedia.org/wiki/Google_Cloud_Platform",
        "title": "Google Cloud Platform"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230731114802/https://cloud.google.com/learn/what-is-artificial-intelligence"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-415"
      },
      {
        "text": "\"One of the Biggest Problems in Regulating AI Is Agreeing on a Definition\"",
        "url": "https://carnegieendowment.org/posts/2022/10/one-of-the-biggest-problems-in-regulating-ai-is-agreeing-on-a-definition?lang=en"
      },
      {
        "text": "Carnegie Endowment for International Peace",
        "url": "https://en.wikipedia.org/wiki/Carnegie_Endowment_for_International_Peace",
        "title": "Carnegie Endowment for International Peace"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-416"
      },
      {
        "text": "\"AI or BS? How to tell if a marketing tool really uses artificial intelligence\"",
        "url": "https://www.thedrum.com/opinion/2023/03/30/ai-or-bs-how-tell-if-marketing-tool-really-uses-artificial-intelligence"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTENilsson198310_417-0"
      },
      {
        "text": "Nilsson (1983)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1983"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEHaugeland1985112–117_419-0"
      },
      {
        "text": "Haugeland (1985)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFHaugeland1985"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-420"
      },
      {
        "text": "Newell & Simon (1976",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNewellSimon1976"
      },
      {
        "text": "McCorduck (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCorduck2004"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-421"
      },
      {
        "text": "Moravec's paradox",
        "url": "https://en.wikipedia.org/wiki/Moravec%27s_paradox",
        "title": "Moravec's paradox"
      },
      {
        "text": "Moravec (1988",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMoravec1988"
      },
      {
        "text": "Minsky (1986",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMinsky1986"
      },
      {
        "text": "Pinker (2007",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPinker2007"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-422"
      },
      {
        "text": "Dreyfus' critique of AI",
        "url": "https://en.wikipedia.org/wiki/Dreyfus%27_critique_of_AI",
        "title": "Dreyfus' critique of AI"
      },
      {
        "text": "Dreyfus (1972)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDreyfus1972"
      },
      {
        "text": "Dreyfus & Dreyfus (1986)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDreyfusDreyfus1986"
      },
      {
        "text": "Crevier (1993",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "McCorduck (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCorduck2004"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Fearn (2007",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFFearn2007"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTECrevier1993125_423-0"
      },
      {
        "text": "Crevier (1993)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTELangley2011_425-0"
      },
      {
        "text": "Langley (2011)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFLangley2011"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEKatz2012_426-0"
      },
      {
        "text": "Katz (2012)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFKatz2012"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-427"
      },
      {
        "text": "Neats vs. scruffies",
        "url": "https://en.wikipedia.org/wiki/Neats_vs._scruffies",
        "title": "Neats vs. scruffies"
      },
      {
        "text": "McCorduck (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCorduck2004"
      },
      {
        "text": "Crevier (1993",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "Nilsson (1983",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFNilsson1983"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Minsky (1986)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMinsky1986"
      },
      {
        "text": "Domingos (2015)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDomingos2015"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEPennachinGoertzel2007_428-0"
      },
      {
        "text": "Pennachin & Goertzel (2007)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFPennachinGoertzel2007"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERoberts2016_429-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERoberts2016_429-1"
      },
      {
        "text": "Roberts (2016)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRoberts2016"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig2021986_430-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEChalmers1995_431-0"
      },
      {
        "text": "Chalmers (1995)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFChalmers1995"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEDennett1991_432-0"
      },
      {
        "text": "Dennett (1991)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDennett1991"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEHorst2005_433-0"
      },
      {
        "text": "Horst (2005)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFHorst2005"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTESearle1999_434-0"
      },
      {
        "text": "Searle (1999)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSearle1999"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTESearle19801_435-0"
      },
      {
        "text": "Searle (1980)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSearle1980"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig20219817_436-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-438"
      },
      {
        "text": "Chinese room",
        "url": "https://en.wikipedia.org/wiki/Chinese_room",
        "title": "Chinese room"
      },
      {
        "text": "Searle (1980)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSearle1980"
      },
      {
        "text": "Searle (1999)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFSearle1999"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "McCorduck (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCorduck2004"
      },
      {
        "text": "Crevier (1993",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFCrevier1993"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-439"
      },
      {
        "text": "\"Nick Bostrom: How can we be certain a machine isn't conscious?\"",
        "url": "https://www.spectator.co.uk/article/nick-bostrom-how-can-we-be-certain-a-machine-isnt-conscious"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240926155639/https://www.spectator.co.uk/article/nick-bostrom-how-can-we-be-certain-a-machine-isnt-conscious/"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Thomson-2022_440-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Thomson-2022_440-1"
      },
      {
        "text": "c",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Thomson-2022_440-2"
      },
      {
        "text": "\"Why don't robots have rights?\"",
        "url": "https://bigthink.com/thinking/why-dont-robots-have-rights"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240913055336/https://bigthink.com/thinking/why-dont-robots-have-rights/"
      },
      {
        "text": "a",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Kateman-2023_441-0"
      },
      {
        "text": "b",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-Kateman-2023_441-1"
      },
      {
        "text": "\"AI Should Be Terrified of Humans\"",
        "url": "https://time.com/6296234/ai-should-be-terrified-of-humans"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240925041601/https://time.com/6296234/ai-should-be-terrified-of-humans/"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-442"
      },
      {
        "text": "\"What leaders need to know about robot rights\"",
        "url": "https://www.fastcompany.com/90920769/what-leaders-need-to-know-about-robot-rights"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-443"
      },
      {
        "text": "\"Give robots 'personhood' status, EU committee argues\"",
        "url": "https://www.theguardian.com/technology/2017/jan/12/give-robots-personhood-status-eu-committee-argues"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0261-3077",
        "url": "https://search.worldcat.org/issn/0261-3077"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005171222/https://www.theguardian.com/technology/2017/jan/12/give-robots-personhood-status-eu-committee-argues"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-444"
      },
      {
        "text": "\"Experts Don't Think Robots Should Have Rights\"",
        "url": "https://www.newsweek.com/robots-human-rights-electronic-persons-humans-versus-machines-886075"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005171333/https://www.newsweek.com/robots-human-rights-electronic-persons-humans-versus-machines-886075"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-445"
      },
      {
        "text": "\"Robot rights violate human rights, experts warn EU\"",
        "url": "https://www.euronews.com/2018/04/13/robot-rights-violate-human-rights-experts-warn-eu"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240919022327/https://www.euronews.com/2018/04/13/robot-rights-violate-human-rights-experts-warn-eu"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-446"
      },
      {
        "text": "Intelligence explosion",
        "url": "https://en.wikipedia.org/wiki/Intelligence_explosion",
        "title": "Intelligence explosion"
      },
      {
        "text": "technological singularity",
        "url": "https://en.wikipedia.org/wiki/Technological_singularity",
        "title": "Technological singularity"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "Omohundro (2008)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFOmohundro2008"
      },
      {
        "text": "Kurzweil (2005)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFKurzweil2005"
      },
      {
        "text": "I. J. Good",
        "url": "https://en.wikipedia.org/wiki/I._J._Good",
        "title": "I. J. Good"
      },
      {
        "text": "Good (1965)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFGood1965"
      },
      {
        "text": "Vernor Vinge",
        "url": "https://en.wikipedia.org/wiki/Vernor_Vinge",
        "title": "Vernor Vinge"
      },
      {
        "text": "Vinge (1993)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFVinge1993"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTERussellNorvig20211005_447-0"
      },
      {
        "text": "Russell & Norvig (2021)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-448"
      },
      {
        "text": "Transhumanism",
        "url": "https://en.wikipedia.org/wiki/Transhumanism",
        "title": "Transhumanism"
      },
      {
        "text": "Moravec (1988)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMoravec1988"
      },
      {
        "text": "Kurzweil (2005)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFKurzweil2005"
      },
      {
        "text": "Russell & Norvig (2021",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFRussellNorvig2021"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-449"
      },
      {
        "text": "Edward Fredkin",
        "url": "https://en.wikipedia.org/wiki/Edward_Fredkin",
        "title": "Edward Fredkin"
      },
      {
        "text": "McCorduck (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCorduck2004"
      },
      {
        "text": "Butler (1863)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFButler1863"
      },
      {
        "text": "Dyson (1998)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFDyson1998"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-v935_450-0"
      },
      {
        "text": "\"a gift to the far right\"",
        "url": "https://www.computerweekly.com/opinion/Labours-AI-Action-Plan-a-gift-to-the-far-right"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-AI_in_myth_451-0"
      },
      {
        "text": "McCorduck (2004",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCorduck2004"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEMcCorduck2004340–400_452-0"
      },
      {
        "text": "McCorduck (2004)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCorduck2004"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEButtazzo2001_453-0"
      },
      {
        "text": "Buttazzo (2001)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFButtazzo2001"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEAnderson2008_454-0"
      },
      {
        "text": "Anderson (2008)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFAnderson2008"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEMcCauley2007_455-0"
      },
      {
        "text": "McCauley (2007)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFMcCauley2007"
      },
      {
        "text": "^",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#cite_ref-FOOTNOTEGalvan1997_456-0"
      },
      {
        "text": "Galvan (1997)",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence#CITEREFGalvan1997"
      },
      {
        "text": "Open Syllabus",
        "url": "https://explorer.opensyllabus.org/result/field?id=Computer+Science"
      },
      {
        "text": "Russell, Stuart J.",
        "url": "https://en.wikipedia.org/wiki/Stuart_J._Russell",
        "title": "Stuart J. Russell"
      },
      {
        "text": "Norvig, Peter",
        "url": "https://en.wikipedia.org/wiki/Peter_Norvig",
        "title": "Peter Norvig"
      },
      {
        "text": "Artificial Intelligence: A Modern Approach",
        "url": "https://en.wikipedia.org/wiki/Artificial_Intelligence:_A_Modern_Approach",
        "title": "Artificial Intelligence: A Modern Approach"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-1346-1099-3",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-1346-1099-3",
        "title": "Special:BookSources/978-0-1346-1099-3"
      },
      {
        "text": "LCCN",
        "url": "https://en.wikipedia.org/wiki/LCCN_(identifier)",
        "title": "LCCN (identifier)"
      },
      {
        "text": "20190474",
        "url": "https://lccn.loc.gov/20190474"
      },
      {
        "text": "Rich, Elaine",
        "url": "https://en.wikipedia.org/wiki/Elaine_Rich",
        "title": "Elaine Rich"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-0700-8770-5",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-0700-8770-5",
        "title": "Special:BookSources/978-0-0700-8770-5"
      },
      {
        "text": "Luger, George",
        "url": "https://en.wikipedia.org/w/index.php?title=George_Luger&action=edit&redlink=1",
        "title": "George Luger (page does not exist)"
      },
      {
        "text": "Stubblefield, William",
        "url": "https://en.wikipedia.org/wiki/William_Stubblefield",
        "title": "William Stubblefield"
      },
      {
        "text": "Artificial Intelligence: Structures and Strategies for Complex Problem Solving",
        "url": "https://archive.org/details/artificialintell0000luge"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-8053-4780-7",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-8053-4780-7",
        "title": "Special:BookSources/978-0-8053-4780-7"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200726220613/https://archive.org/details/artificialintell0000luge"
      },
      {
        "text": "Nilsson, Nils",
        "url": "https://en.wikipedia.org/wiki/Nils_Nilsson_(researcher)",
        "title": "Nils Nilsson (researcher)"
      },
      {
        "text": "Artificial Intelligence: A New Synthesis",
        "url": "https://archive.org/details/artificialintell0000nils"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-1-5586-0467-4",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-1-5586-0467-4",
        "title": "Special:BookSources/978-1-5586-0467-4"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200726131654/https://archive.org/details/artificialintell0000nils"
      },
      {
        "text": "Russell, Stuart J.",
        "url": "https://en.wikipedia.org/wiki/Stuart_J._Russell",
        "title": "Stuart J. Russell"
      },
      {
        "text": "Norvig, Peter",
        "url": "https://en.wikipedia.org/wiki/Peter_Norvig",
        "title": "Peter Norvig"
      },
      {
        "text": "Artificial Intelligence: A Modern Approach",
        "url": "http://aima.cs.berkeley.edu/"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "0-13-790395-2",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/0-13-790395-2",
        "title": "Special:BookSources/0-13-790395-2"
      },
      {
        "text": "Poole, David",
        "url": "https://en.wikipedia.org/w/index.php?title=David_Poole_(researcher)&action=edit&redlink=1",
        "title": "David Poole (researcher) (page does not exist)"
      },
      {
        "text": "Mackworth, Alan",
        "url": "https://en.wikipedia.org/wiki/Alan_Mackworth",
        "title": "Alan Mackworth"
      },
      {
        "text": "Goebel, Randy",
        "url": "https://en.wikipedia.org/w/index.php?title=Randy_Goebel&action=edit&redlink=1",
        "title": "Randy Goebel (page does not exist)"
      },
      {
        "text": "Computational Intelligence: A Logical Approach",
        "url": "https://archive.org/details/computationalint00pool"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-1951-0270-3",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-1951-0270-3",
        "title": "Special:BookSources/978-0-1951-0270-3"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200726131436/https://archive.org/details/computationalint00pool"
      },
      {
        "text": "Mackworth, Alan",
        "url": "https://en.wikipedia.org/wiki/Alan_Mackworth",
        "title": "Alan Mackworth"
      },
      {
        "text": "Artificial Intelligence: Foundations of Computational Agents",
        "url": "http://artint.info/index.html"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-1-1071-9539-4",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-1-1071-9539-4",
        "title": "Special:BookSources/978-1-1071-9539-4"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20171207013855/http://artint.info/index.html"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-3-3195-8486-7",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-3-3195-8486-7",
        "title": "Special:BookSources/978-3-3195-8486-7"
      },
      {
        "text": "Ciaramella, Alberto",
        "url": "https://en.wikipedia.org/wiki/Alberto_Ciaramella",
        "title": "Alberto Ciaramella"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-8-8947-8760-3",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-8-8947-8760-3",
        "title": "Special:BookSources/978-8-8947-8760-3"
      },
      {
        "text": "Crevier, Daniel",
        "url": "https://en.wikipedia.org/wiki/Daniel_Crevier",
        "title": "Daniel Crevier"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "0-465-02997-3",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/0-465-02997-3",
        "title": "Special:BookSources/0-465-02997-3"
      },
      {
        "text": "McCorduck, Pamela",
        "url": "https://en.wikipedia.org/wiki/Pamela_McCorduck",
        "title": "Pamela McCorduck"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "1-5688-1205-1",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/1-5688-1205-1",
        "title": "Special:BookSources/1-5688-1205-1"
      },
      {
        "text": "Newquist, H. P.",
        "url": "https://en.wikipedia.org/wiki/HP_Newquist",
        "title": "HP Newquist"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-6723-0412-5",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-6723-0412-5",
        "title": "Special:BookSources/978-0-6723-0412-5"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "0471614963",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/0471614963",
        "title": "Special:BookSources/0471614963"
      },
      {
        "text": "AI & ML in Fusion",
        "url": "https://suli.pppl.gov/2023/course/Rea-PPPL-SULI2023.pdf"
      },
      {
        "text": "AI & ML in Fusion, video lecture",
        "url": "https://drive.google.com/file/d/1npCTrJ8XJn20ZGDA_DfMpANuQZFMzKPh/view?usp=drive_link"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230702164332/https://drive.google.com/file/d/1npCTrJ8XJn20ZGDA_DfMpANuQZFMzKPh/view?usp=drive_link"
      },
      {
        "text": "Wayback Machine",
        "url": "https://en.wikipedia.org/wiki/Wayback_Machine",
        "title": "Wayback Machine"
      },
      {
        "text": "\"Franzen, Grisham and Other Prominent Authors Sue OpenAI\"",
        "url": "https://www.nytimes.com/2023/09/20/books/authors-openai-lawsuit-chatgpt-copyright.html?campaign_id=2&emc=edit_th_20230921&instance_id=103259&nl=todaysheadlines&regi_id=62816440&segment_id=145288&user_id=ad24f3545dae0ec44284a38bb4a88f1d"
      },
      {
        "text": "archived",
        "url": "https://web.archive.org/web/20240914155020/https://www.nytimes.com/2023/09/20/books/authors-openai-lawsuit-chatgpt-copyright.html?campaign_id=2&emc=edit_th_20230921&instance_id=103259&nl=todaysheadlines&regi_id=62816440&segment_id=145288&user_id=ad24f3545dae0ec44284a38bb4a88f1d"
      },
      {
        "text": "Altman, Sam",
        "url": "https://en.wikipedia.org/wiki/Sam_Altman",
        "title": "Sam Altman"
      },
      {
        "text": "Brockman, Greg",
        "url": "https://en.wikipedia.org/wiki/Greg_Brockman",
        "title": "Greg Brockman"
      },
      {
        "text": "Sutskever, Ilya",
        "url": "https://en.wikipedia.org/wiki/Ilya_Sutskever",
        "title": "Ilya Sutskever"
      },
      {
        "text": "\"Governance of Superintelligence\"",
        "url": "https://openai.com/blog/governance-of-superintelligence"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230527061619/https://openai.com/blog/governance-of-superintelligence"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1007/s00146-007-0094-5",
        "url": "https://doi.org/10.1007%2Fs00146-007-0094-5"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "1809459",
        "url": "https://api.semanticscholar.org/CorpusID:1809459"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1109/tamd.2009.2021702",
        "url": "https://doi.org/10.1109%2Ftamd.2009.2021702"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "10168773",
        "url": "https://api.semanticscholar.org/CorpusID:10168773"
      },
      {
        "text": "\"Ask the AI experts: What's driving today's progress in AI?\"",
        "url": "https://www.mckinsey.com/business-functions/mckinsey-analytics/our-insights/ask-the-ai-experts-whats-driving-todays-progress-in-ai"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20180413190018/https://www.mckinsey.com/business-functions/mckinsey-analytics/our-insights/ask-the-ai-experts-whats-driving-todays-progress-in-ai"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-1-7864-3904-8",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-1-7864-3904-8",
        "title": "Special:BookSources/978-1-7864-3904-8"
      },
      {
        "text": "OCLC",
        "url": "https://en.wikipedia.org/wiki/OCLC_(identifier)",
        "title": "OCLC (identifier)"
      },
      {
        "text": "1039480085",
        "url": "https://search.worldcat.org/oclc/1039480085"
      },
      {
        "text": "Winston, Patrick",
        "url": "https://en.wikipedia.org/wiki/Patrick_Winston",
        "title": "Patrick Winston"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1109/MIS.2009.75",
        "url": "https://doi.org/10.1109%2FMIS.2009.75"
      },
      {
        "text": "hdl",
        "url": "https://en.wikipedia.org/wiki/Hdl_(identifier)",
        "title": "Hdl (identifier)"
      },
      {
        "text": "1721.1/52357",
        "url": "https://hdl.handle.net/1721.1%2F52357"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "32437713",
        "url": "https://api.semanticscholar.org/CorpusID:32437713"
      },
      {
        "text": "\"Strategies to Improve the Impact of Artificial Intelligence on Health Equity: Scoping Review\"",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC11041459"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.2196/42936",
        "url": "https://doi.org/10.2196%2F42936"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "2817-1705",
        "url": "https://search.worldcat.org/issn/2817-1705"
      },
      {
        "text": "PMC",
        "url": "https://en.wikipedia.org/wiki/PMC_(identifier)",
        "title": "PMC (identifier)"
      },
      {
        "text": "11041459",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC11041459"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "38875587",
        "url": "https://pubmed.ncbi.nlm.nih.gov/38875587"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "256681439",
        "url": "https://api.semanticscholar.org/CorpusID:256681439"
      },
      {
        "text": "Hello, World: Artificial Intelligence and its Use in the Public Sector",
        "url": "https://oecd-opsi.org/wp-content/uploads/2019/11/AI-Report-Online.pdf"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20191220021331/https://oecd-opsi.org/wp-content/uploads/2019/11/AI-Report-Online.pdf"
      },
      {
        "text": "Bostrom, Nick",
        "url": "https://en.wikipedia.org/wiki/Nick_Bostrom",
        "title": "Nick Bostrom"
      },
      {
        "text": "Superintelligence: Paths, Dangers, Strategies",
        "url": "https://en.wikipedia.org/wiki/Superintelligence:_Paths,_Dangers,_Strategies",
        "title": "Superintelligence: Paths, Dangers, Strategies"
      },
      {
        "text": "\"What happens when our computers get smarter than we are?\"",
        "url": "https://www.ted.com/talks/nick_bostrom_what_happens_when_our_computers_get_smarter_than_we_are/transcript"
      },
      {
        "text": "TED (conference)",
        "url": "https://en.wikipedia.org/wiki/TED_(conference)",
        "title": "TED (conference)"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200725005719/https://www.ted.com/talks/nick_bostrom_what_happens_when_our_computers_get_smarter_than_we_are/transcript"
      },
      {
        "text": "\"artificial intelligence is a tool, not a threat\"",
        "url": "https://web.archive.org/web/20141112130954/http://www.rethinkrobotics.com/artificial-intelligence-tool-threat"
      },
      {
        "text": "the original",
        "url": "http://www.rethinkrobotics.com/artificial-intelligence-tool-threat"
      },
      {
        "text": "Brooks, Rodney",
        "url": "https://en.wikipedia.org/wiki/Rodney_Brooks",
        "title": "Rodney Brooks"
      },
      {
        "text": "\"Elephants Don't Play Chess\"",
        "url": "http://people.csail.mit.edu/brooks/papers/elephants.pdf"
      },
      {
        "text": "CiteSeerX",
        "url": "https://en.wikipedia.org/wiki/CiteSeerX_(identifier)",
        "title": "CiteSeerX (identifier)"
      },
      {
        "text": "10.1.1.588.7539",
        "url": "https://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.588.7539"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1016/S0921-8890(05)80025-9",
        "url": "https://doi.org/10.1016%2FS0921-8890%2805%2980025-9"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20070809020912/http://people.csail.mit.edu/brooks/papers/elephants.pdf"
      },
      {
        "text": "\"Towards Intelligent Regulation of Artificial Intelligence\"",
        "url": "https://doi.org/10.1017%2Ferr.2019.8"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1017/err.2019.8",
        "url": "https://doi.org/10.1017%2Ferr.2019.8"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "1867-299X",
        "url": "https://search.worldcat.org/issn/1867-299X"
      },
      {
        "text": "\"What the New GPT-4 AI Can Do\"",
        "url": "https://www.scientificamerican.com/article/what-the-new-gpt-4-ai-can-do/"
      },
      {
        "text": "archived",
        "url": "https://web.archive.org/web/20230822233655/https://www.scientificamerican.com/article/what-the-new-gpt-4-ai-can-do/"
      },
      {
        "text": "Butler, Samuel",
        "url": "https://en.wikipedia.org/wiki/Samuel_Butler_(novelist)",
        "title": "Samuel Butler (novelist)"
      },
      {
        "text": "\"Darwin among the Machines\"",
        "url": "https://nzetc.victoria.ac.nz/tm/scholarly/tei-ButFir-t1-g1-t1-g1-t4-body.html"
      },
      {
        "text": "The Press",
        "url": "https://en.wikipedia.org/wiki/The_Press",
        "title": "The Press"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20080919172551/http://www.nzetc.org/tm/scholarly/tei-ButFir-t1-g1-t1-g1-t4-body.html"
      },
      {
        "text": "Computer",
        "url": "https://en.wikipedia.org/wiki/Computer_(magazine)",
        "title": "Computer (magazine)"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1109/2.933500",
        "url": "https://doi.org/10.1109%2F2.933500"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1109/MCI.2014.2307227",
        "url": "https://doi.org/10.1109%2FMCI.2014.2307227"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "206451986",
        "url": "https://api.semanticscholar.org/CorpusID:206451986"
      },
      {
        "text": "\"Stephen Hawking warns artificial intelligence could end mankind\"",
        "url": "https://www.bbc.com/news/technology-30290540"
      },
      {
        "text": "BBC News",
        "url": "https://en.wikipedia.org/wiki/BBC_News",
        "title": "BBC News"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20151030054329/http://www.bbc.com/news/technology-30290540"
      },
      {
        "text": "Chalmers, David",
        "url": "https://en.wikipedia.org/wiki/David_Chalmers",
        "title": "David Chalmers"
      },
      {
        "text": "\"Facing up to the problem of consciousness\"",
        "url": "http://www.imprint.co.uk/chalmers.html"
      },
      {
        "text": "Journal of Consciousness Studies",
        "url": "https://en.wikipedia.org/wiki/Journal_of_Consciousness_Studies",
        "title": "Journal of Consciousness Studies"
      },
      {
        "text": "CiteSeerX",
        "url": "https://en.wikipedia.org/wiki/CiteSeerX_(identifier)",
        "title": "CiteSeerX (identifier)"
      },
      {
        "text": "10.1.1.103.8362",
        "url": "https://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.103.8362"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20050308163649/http://www.imprint.co.uk/chalmers.html"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1017/CBO9780511975837",
        "url": "https://doi.org/10.1017%2FCBO9780511975837"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-5218-7628-5",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-5218-7628-5",
        "title": "Special:BookSources/978-0-5218-7628-5"
      },
      {
        "text": "Christian, Brian",
        "url": "https://en.wikipedia.org/wiki/Brian_Christian",
        "title": "Brian Christian"
      },
      {
        "text": "The Alignment Problem",
        "url": "https://en.wikipedia.org/wiki/The_Alignment_Problem",
        "title": "The Alignment Problem"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-3938-6833-3",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-3938-6833-3",
        "title": "Special:BookSources/978-0-3938-6833-3"
      },
      {
        "text": "OCLC",
        "url": "https://en.wikipedia.org/wiki/OCLC_(identifier)",
        "title": "OCLC (identifier)"
      },
      {
        "text": "1233266753",
        "url": "https://search.worldcat.org/oclc/1233266753"
      },
      {
        "text": "arXiv",
        "url": "https://en.wikipedia.org/wiki/ArXiv_(identifier)",
        "title": "ArXiv (identifier)"
      },
      {
        "text": "1202.2745",
        "url": "https://arxiv.org/abs/1202.2745"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1109/cvpr.2012.6248110",
        "url": "https://doi.org/10.1109%2Fcvpr.2012.6248110"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-1-4673-1228-8",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-1-4673-1228-8",
        "title": "Special:BookSources/978-1-4673-1228-8"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "2161592",
        "url": "https://api.semanticscholar.org/CorpusID:2161592"
      },
      {
        "text": "\"Why 2015 Was a Breakthrough Year in Artificial Intelligence\"",
        "url": "https://www.bloomberg.com/news/articles/2015-12-08/why-2015-was-a-breakthrough-year-in-artificial-intelligence"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20161123053855/https://www.bloomberg.com/news/articles/2015-12-08/why-2015-was-a-breakthrough-year-in-artificial-intelligence"
      },
      {
        "text": "\"Commentary: Bad news. Artificial intelligence is biased\"",
        "url": "https://www.channelnewsasia.com/news/commentary/artificial-intelligence-big-data-bias-hiring-loans-key-challenge-11097374"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20190112104421/https://www.channelnewsasia.com/news/commentary/artificial-intelligence-big-data-bias-hiring-loans-key-challenge-11097374"
      },
      {
        "text": "Cybenko, G.",
        "url": "https://en.wikipedia.org/wiki/George_Cybenko",
        "title": "George Cybenko"
      },
      {
        "text": "\"Deep Learning: Methods and Applications\"",
        "url": "http://research.microsoft.com/pubs/209355/DeepLearning-NowPublishing-Vol7-SIG-039.pdf"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1561/2000000039",
        "url": "https://doi.org/10.1561%2F2000000039"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20160314152112/http://research.microsoft.com/pubs/209355/DeepLearning-NowPublishing-Vol7-SIG-039.pdf"
      },
      {
        "text": "Dennett, Daniel",
        "url": "https://en.wikipedia.org/wiki/Daniel_Dennett",
        "title": "Daniel Dennett"
      },
      {
        "text": "Consciousness Explained",
        "url": "https://en.wikipedia.org/wiki/Consciousness_Explained",
        "title": "Consciousness Explained"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-7139-9037-9",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-7139-9037-9",
        "title": "Special:BookSources/978-0-7139-9037-9"
      },
      {
        "text": "\"AI has already changed the world. This report shows how\"",
        "url": "https://www.sfchronicle.com/tech/article/ai-artificial-intelligence-report-stanford-17869558.php"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230619015309/https://www.sfchronicle.com/tech/article/ai-artificial-intelligence-report-stanford-17869558.php"
      },
      {
        "text": "\"Machine learning: What is the transformer architecture?\"",
        "url": "https://bdtechtalks.com/2022/05/02/what-is-the-transformer"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231122142948/https://bdtechtalks.com/2022/05/02/what-is-the-transformer/"
      },
      {
        "text": "\"Robots With Flawed AI Make Sexist And Racist Decisions, Experiment Shows\"",
        "url": "https://web.archive.org/web/20220627225827/https://www.sciencealert.com/robots-with-flawed-ai-make-sexist-racist-and-toxic-decisions-experiment-shows"
      },
      {
        "text": "the original",
        "url": "https://www.sciencealert.com/robots-with-flawed-ai-make-sexist-racist-and-toxic-decisions-experiment-shows"
      },
      {
        "text": "Domingos, Pedro",
        "url": "https://en.wikipedia.org/wiki/Pedro_Domingos",
        "title": "Pedro Domingos"
      },
      {
        "text": "Basic Books",
        "url": "https://en.wikipedia.org/wiki/Basic_Books",
        "title": "Basic Books"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-4650-6570-7",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-4650-6570-7",
        "title": "Special:BookSources/978-0-4650-6570-7"
      },
      {
        "text": "Dreyfus, Hubert",
        "url": "https://en.wikipedia.org/wiki/Hubert_Dreyfus",
        "title": "Hubert Dreyfus"
      },
      {
        "text": "What Computers Can't Do",
        "url": "https://en.wikipedia.org/wiki/What_Computers_Can%27t_Do",
        "title": "What Computers Can't Do"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-0601-1082-6",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-0601-1082-6",
        "title": "Special:BookSources/978-0-0601-1082-6"
      },
      {
        "text": "Dreyfus, Hubert",
        "url": "https://en.wikipedia.org/wiki/Hubert_Dreyfus",
        "title": "Hubert Dreyfus"
      },
      {
        "text": "Mind over Machine: The Power of Human Intuition and Expertise in the Era of the Computer",
        "url": "https://archive.org/details/mindovermachinep00drey"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-0290-8060-3",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-0290-8060-3",
        "title": "Special:BookSources/978-0-0290-8060-3"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200726131414/https://archive.org/details/mindovermachinep00drey"
      },
      {
        "text": "Dyson, George",
        "url": "https://en.wikipedia.org/wiki/George_Dyson_(science_historian)",
        "title": "George Dyson (science historian)"
      },
      {
        "text": "Darwin among the Machines",
        "url": "https://archive.org/details/darwinamongmachi00dyso"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-7382-0030-9",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-7382-0030-9",
        "title": "Special:BookSources/978-0-7382-0030-9"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200726131443/https://archive.org/details/darwinamongmachi00dyso"
      },
      {
        "text": "The Nervous System",
        "url": "https://archive.org/details/nervoussystem0000edel"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-7910-0464-7",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-7910-0464-7",
        "title": "Special:BookSources/978-0-7910-0464-7"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200726131758/https://archive.org/details/nervoussystem0000edel"
      },
      {
        "text": "\"Poll: AI poses risk to humanity, according to majority of Americans\"",
        "url": "https://arstechnica.com/information-technology/2023/05/poll-61-of-americans-say-ai-threatens-humanitys-future"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230619013608/https://arstechnica.com/information-technology/2023/05/poll-61-of-americans-say-ai-threatens-humanitys-future"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-8021-1839-4",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-8021-1839-4",
        "title": "Special:BookSources/978-0-8021-1839-4"
      },
      {
        "text": "\"Will robots create more jobs than they destroy?\"",
        "url": "https://www.theguardian.com/technology/2015/sep/06/will-robots-create-destroy-jobs"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20180616204119/https://www.theguardian.com/technology/2015/sep/06/will-robots-create-destroy-jobs"
      },
      {
        "text": "\"Fox News Poll\"",
        "url": "https://static.foxnews.com/foxnews.com/content/uploads/2023/05/Fox_April-21-24-2023_Complete_National_Topline_May-1-Release.pdf"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230512082712/https://static.foxnews.com/foxnews.com/content/uploads/2023/05/Fox_April-21-24-2023_Complete_National_Topline_May-1-Release.pdf"
      },
      {
        "text": "CiteSeerX",
        "url": "https://en.wikipedia.org/wiki/CiteSeerX_(identifier)",
        "title": "CiteSeerX (identifier)"
      },
      {
        "text": "10.1.1.395.416",
        "url": "https://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.395.416"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1016/j.techfore.2016.08.019",
        "url": "https://doi.org/10.1016%2Fj.techfore.2016.08.019"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0040-1625",
        "url": "https://search.worldcat.org/issn/0040-1625"
      },
      {
        "text": "\"From not working to neural networking\"",
        "url": "https://www.economist.com/news/special-report/21700756-artificial-intelligence-boom-based-old-idea-modern-twist-not"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20161231203934/https://www.economist.com/news/special-report/21700756-artificial-intelligence-boom-based-old-idea-modern-twist-not"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1525/sfs.24.3.0413",
        "url": "https://doi.org/10.1525%2Fsfs.24.3.0413"
      },
      {
        "text": "JSTOR",
        "url": "https://en.wikipedia.org/wiki/JSTOR_(identifier)",
        "title": "JSTOR (identifier)"
      },
      {
        "text": "4240644",
        "url": "https://www.jstor.org/stable/4240644"
      },
      {
        "text": "\"Is artificial intelligence really an existential threat to humanity?\"",
        "url": "http://thebulletin.org/artificial-intelligence-really-existential-threat-humanity8577"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20151030054330/http://thebulletin.org/artificial-intelligence-really-existential-threat-humanity8577"
      },
      {
        "text": "\"Elon Musk: artificial intelligence is our biggest existential threat\"",
        "url": "https://www.theguardian.com/technology/2014/oct/27/elon-musk-artificial-intelligence-ai-biggest-existential-threat"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20151030054330/http://www.theguardian.com/technology/2014/oct/27/elon-musk-artificial-intelligence-ai-biggest-existential-threat"
      },
      {
        "text": "Software studies: a lexicon",
        "url": "https://archive.org/details/softwarestudiesl00full_007"
      },
      {
        "text": "15",
        "url": "https://archive.org/details/softwarestudiesl00full_007/page/n29"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-1-4356-4787-9",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-1-4356-4787-9",
        "title": "Special:BookSources/978-1-4356-4787-9"
      },
      {
        "text": "\"10 years later, deep learning 'revolution' rages on, say AI pioneers Hinton, LeCun and Li\"",
        "url": "https://venturebeat.com/ai/10-years-on-ai-pioneers-hinton-lecun-li-say-deep-learning-revolution-will-continue"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005171338/https://venturebeat.com/ai/10-years-on-ai-pioneers-hinton-lecun-li-say-deep-learning-revolution-will-continue/"
      },
      {
        "text": "Good, I. J.",
        "url": "https://en.wikipedia.org/wiki/I._J._Good",
        "title": "I. J. Good"
      },
      {
        "text": "Speculations Concerning the First Ultraintelligent Machine",
        "url": "https://exhibits.stanford.edu/feigenbaum/catalog/gz727rg3869"
      },
      {
        "text": "archived",
        "url": "https://web.archive.org/web/20230710131733/https://exhibits.stanford.edu/feigenbaum/catalog/gz727rg3869"
      },
      {
        "text": "Deep Learning",
        "url": "https://web.archive.org/web/20160416111010/http://www.deeplearningbook.org"
      },
      {
        "text": "the original",
        "url": "http://www.deeplearningbook.org"
      },
      {
        "text": "arXiv",
        "url": "https://en.wikipedia.org/wiki/ArXiv_(identifier)",
        "title": "ArXiv (identifier)"
      },
      {
        "text": "1606.08813",
        "url": "https://arxiv.org/abs/1606.08813"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1609/aimag.v38i3.2741",
        "url": "https://doi.org/10.1609%2Faimag.v38i3.2741"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "7373959",
        "url": "https://api.semanticscholar.org/CorpusID:7373959"
      },
      {
        "text": "Government Accountability Office",
        "url": "https://en.wikipedia.org/wiki/Government_Accountability_Office",
        "title": "Government Accountability Office"
      },
      {
        "text": "Consumer Data: Increasing Use Poses Risks to Privacy",
        "url": "https://www.gao.gov/products/gao-22-106096"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240913011410/https://www.gao.gov/products/gao-22-106096"
      },
      {
        "text": "\"Google's Photo App Still Can't Find Gorillas. And Neither Can Apple's\"",
        "url": "https://www.nytimes.com/2023/05/22/technology/ai-photo-labels-google-apple.html"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240914155032/https://www.nytimes.com/2023/05/22/technology/ai-photo-labels-google-apple.html"
      },
      {
        "text": "\"Here's where the A.I. jobs are\"",
        "url": "https://www.cnbc.com/2023/04/05/ai-jobs-see-the-state-by-state-data-from-a-stanford-study.html"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230619015309/https://www.cnbc.com/2023/04/05/ai-jobs-see-the-state-by-state-data-from-a-stanford-study.html"
      },
      {
        "text": "Harari, Yuval Noah",
        "url": "https://en.wikipedia.org/wiki/Yuval_Noah_Harari",
        "title": "Yuval Noah Harari"
      },
      {
        "text": "\"Why Technology Favors Tyranny\"",
        "url": "https://www.theatlantic.com/magazine/archive/2018/10/yuval-noah-harari-technology-tyranny/568330"
      },
      {
        "text": "The Atlantic",
        "url": "https://en.wikipedia.org/wiki/The_Atlantic",
        "title": "The Atlantic"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20210925221449/https://www.theatlantic.com/magazine/archive/2018/10/yuval-noah-harari-technology-tyranny/568330"
      },
      {
        "text": "\"AI and the future of humanity\"",
        "url": "https://www.youtube.com/watch?v=LWiM-LuRe6w"
      },
      {
        "text": "YouTube",
        "url": "https://en.wikipedia.org/wiki/YouTube",
        "title": "YouTube"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240930110823/https://www.youtube.com/watch?v=LWiM-LuRe6w"
      },
      {
        "text": "Haugeland, John",
        "url": "https://en.wikipedia.org/wiki/John_Haugeland",
        "title": "John Haugeland"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-2620-8153-5",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-2620-8153-5",
        "title": "Special:BookSources/978-0-2620-8153-5"
      },
      {
        "text": "Sainath, T.",
        "url": "https://en.wikipedia.org/wiki/Tara_Sainath",
        "title": "Tara Sainath"
      },
      {
        "text": "Bibcode",
        "url": "https://en.wikipedia.org/wiki/Bibcode_(identifier)",
        "title": "Bibcode (identifier)"
      },
      {
        "text": "2012ISPM...29...82H",
        "url": "https://ui.adsabs.harvard.edu/abs/2012ISPM...29...82H"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1109/msp.2012.2205597",
        "url": "https://doi.org/10.1109%2Fmsp.2012.2205597"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "206485943",
        "url": "https://api.semanticscholar.org/CorpusID:206485943"
      },
      {
        "text": "\"Bill Gates on dangers of artificial intelligence: 'I don't understand why some people are not concerned'\"",
        "url": "https://www.washingtonpost.com/news/the-switch/wp/2015/01/28/bill-gates-on-dangers-of-artificial-intelligence-dont-understand-why-some-people-are-not-concerned"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0190-8286",
        "url": "https://search.worldcat.org/issn/0190-8286"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20151030054330/https://www.washingtonpost.com/news/the-switch/wp/2015/01/28/bill-gates-on-dangers-of-artificial-intelligence-dont-understand-why-some-people-are-not-concerned"
      },
      {
        "text": "Multilayer Feedforward Networks are Universal Approximators",
        "url": "http://cognitivemedium.com/magic_paper/assets/Hornik.pdf"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230421140436/https://cognitivemedium.com/magic_paper/assets/Hornik.pdf"
      },
      {
        "text": "\"The Computational Theory of Mind\"",
        "url": "http://plato.stanford.edu/entries/computational-mind"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20160306083748/http://plato.stanford.edu/entries/computational-mind"
      },
      {
        "text": "\"Artificial Intelligence at Edinburgh University: a Perspective\"",
        "url": "http://www.inf.ed.ac.uk/about/AIhistory.html"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20070515072641/http://www.inf.ed.ac.uk/about/AIhistory.html"
      },
      {
        "text": "\"Robots and Artificial Intelligence\"",
        "url": "http://www.igmchicago.org/surveys/robots-and-artificial-intelligence"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20190501114826/http://www.igmchicago.org/surveys/robots-and-artificial-intelligence"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1080/21582041.2018.1563803",
        "url": "https://doi.org/10.1080%2F21582041.2018.1563803"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "2158-2041",
        "url": "https://search.worldcat.org/issn/2158-2041"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "59298502",
        "url": "https://api.semanticscholar.org/CorpusID:59298502"
      },
      {
        "text": "Bibcode",
        "url": "https://en.wikipedia.org/wiki/Bibcode_(identifier)",
        "title": "Bibcode (identifier)"
      },
      {
        "text": "2015Sci...349..255J",
        "url": "https://ui.adsabs.harvard.edu/abs/2015Sci...349..255J"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1126/science.aaa8415",
        "url": "https://doi.org/10.1126%2Fscience.aaa8415"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "26185243",
        "url": "https://pubmed.ncbi.nlm.nih.gov/26185243"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "677218",
        "url": "https://api.semanticscholar.org/CorpusID:677218"
      },
      {
        "text": "Kahneman, Daniel",
        "url": "https://en.wikipedia.org/wiki/Daniel_Kahneman",
        "title": "Daniel Kahneman"
      },
      {
        "text": "Thinking, Fast and Slow",
        "url": "https://books.google.com/books?id=ZuKTvERuPG8C"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-1-4299-6935-2",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-1-4299-6935-2",
        "title": "Special:BookSources/978-1-4299-6935-2"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230315191803/https://books.google.com/books?id=ZuKTvERuPG8C"
      },
      {
        "text": "Kahneman, Daniel",
        "url": "https://en.wikipedia.org/wiki/Daniel_Kahneman",
        "title": "Daniel Kahneman"
      },
      {
        "text": "Tversky, Amos",
        "url": "https://en.wikipedia.org/wiki/Amos_Tversky",
        "title": "Amos Tversky"
      },
      {
        "text": "Bibcode",
        "url": "https://en.wikipedia.org/wiki/Bibcode_(identifier)",
        "title": "Bibcode (identifier)"
      },
      {
        "text": "1974Sci...185.1124T",
        "url": "https://ui.adsabs.harvard.edu/abs/1974Sci...185.1124T"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1126/science.185.4157.1124",
        "url": "https://doi.org/10.1126%2Fscience.185.4157.1124"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-5212-8414-1",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-5212-8414-1",
        "title": "Special:BookSources/978-0-5212-8414-1"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "17835457",
        "url": "https://pubmed.ncbi.nlm.nih.gov/17835457"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "143452957",
        "url": "https://api.semanticscholar.org/CorpusID:143452957"
      },
      {
        "text": "\"Regulate AI? GOP much more skeptical than Dems that government can do it right: poll\"",
        "url": "https://www.foxnews.com/politics/regulate-ai-gop-much-more-skeptical-than-dems-that-the-government-can-do-it-right-poll"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230619013616/https://www.foxnews.com/politics/regulate-ai-gop-much-more-skeptical-than-dems-that-the-government-can-do-it-right-poll"
      },
      {
        "text": "\"Noam Chomsky on Where Artificial Intelligence Went Wrong\"",
        "url": "https://www.theatlantic.com/technology/archive/2012/11/noam-chomsky-on-where-artificial-intelligence-went-wrong/261637/?single_page=true"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20190228154403/https://www.theatlantic.com/technology/archive/2012/11/noam-chomsky-on-where-artificial-intelligence-went-wrong/261637/?single_page=true"
      },
      {
        "text": "\"Kismet\"",
        "url": "http://www.ai.mit.edu/projects/humanoid-robotics-group/kismet/kismet.html"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20141017040432/http://www.ai.mit.edu/projects/humanoid-robotics-group/kismet/kismet.html"
      },
      {
        "text": "Kissinger, Henry",
        "url": "https://en.wikipedia.org/wiki/Henry_Kissinger",
        "title": "Henry Kissinger"
      },
      {
        "text": "\"The Challenge of Being Human in the Age of AI\"",
        "url": "https://www.wsj.com/articles/being-human-artifical-intelligence-ai-chess-antibiotic-philosophy-ethics-bill-of-rights-11635795271"
      },
      {
        "text": "The Wall Street Journal",
        "url": "https://en.wikipedia.org/wiki/The_Wall_Street_Journal",
        "title": "The Wall Street Journal"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20211104012825/https://www.wsj.com/articles/being-human-artifical-intelligence-ai-chess-antibiotic-philosophy-ethics-bill-of-rights-11635795271"
      },
      {
        "text": "\"GPUs Continue to Dominate the AI Accelerator Market for Now\"",
        "url": "https://www.informationweek.com/ai-or-machine-learning/gpus-continue-to-dominate-the-ai-accelerator-market-for-now"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20211019031104/https://www.informationweek.com/ai-or-machine-learning/gpus-continue-to-dominate-the-ai-accelerator-market-for-now"
      },
      {
        "text": "\"Using Commercial Knowledge Bases for Clinical Decision Support: Opportunities, Hurdles, and Recommendations\"",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC1513681"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1197/jamia.M2055",
        "url": "https://doi.org/10.1197%2Fjamia.M2055"
      },
      {
        "text": "PMC",
        "url": "https://en.wikipedia.org/wiki/PMC_(identifier)",
        "title": "PMC (identifier)"
      },
      {
        "text": "1513681",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC1513681"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "16622160",
        "url": "https://pubmed.ncbi.nlm.nih.gov/16622160"
      },
      {
        "text": "Kurzweil, Ray",
        "url": "https://en.wikipedia.org/wiki/Ray_Kurzweil",
        "title": "Ray Kurzweil"
      },
      {
        "text": "The Singularity is Near",
        "url": "https://en.wikipedia.org/wiki/The_Singularity_is_Near",
        "title": "The Singularity is Near"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-6700-3384-3",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-6700-3384-3",
        "title": "Special:BookSources/978-0-6700-3384-3"
      },
      {
        "text": "\"The changing science of machine learning\"",
        "url": "https://doi.org/10.1007%2Fs10994-011-5242-y"
      },
      {
        "text": "Machine Learning",
        "url": "https://en.wikipedia.org/wiki/Machine_Learning_(journal)",
        "title": "Machine Learning (journal)"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1007/s10994-011-5242-y",
        "url": "https://doi.org/10.1007%2Fs10994-011-5242-y"
      },
      {
        "text": "Angwin, Julia",
        "url": "https://en.wikipedia.org/wiki/Julia_Angwin",
        "title": "Julia Angwin"
      },
      {
        "text": "\"How We Analyzed the COMPAS Recidivism Algorithm\"",
        "url": "https://www.propublica.org/article/how-we-analyzed-the-compas-recidivism-algorithm"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20190429190950/https://www.propublica.org/article/how-we-analyzed-the-compas-recidivism-algorithm"
      },
      {
        "text": "\"What is Artificial Intelligence and How Does AI Work? TechTarget\"",
        "url": "https://www.techtarget.com/searchenterpriseai/definition/AI-Artificial-Intelligence"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005171229/https://www.techtarget.com/searchenterpriseai/definition/AI-Artificial-Intelligence"
      },
      {
        "text": "LCCN",
        "url": "https://en.wikipedia.org/wiki/LCCN_(identifier)",
        "title": "LCCN (identifier)"
      },
      {
        "text": "2019668143",
        "url": "https://lccn.loc.gov/2019668143"
      },
      {
        "text": "OCLC",
        "url": "https://en.wikipedia.org/wiki/OCLC_(identifier)",
        "title": "OCLC (identifier)"
      },
      {
        "text": "1110727808",
        "url": "https://search.worldcat.org/oclc/1110727808"
      },
      {
        "text": "\"Will artificial intelligence destroy humanity? Here are 5 reasons not to worry\"",
        "url": "https://www.vox.com/2014/8/22/6043635/5-reasons-we-shouldnt-worry-about-super-intelligent-computers-taking"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20151030092203/http://www.vox.com/2014/8/22/6043635/5-reasons-we-shouldnt-worry-about-super-intelligent-computers-taking"
      },
      {
        "text": "Lenat, Douglas",
        "url": "https://en.wikipedia.org/wiki/Douglas_Lenat",
        "title": "Douglas Lenat"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-2015-1752-1",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-2015-1752-1",
        "title": "Special:BookSources/978-0-2015-1752-1"
      },
      {
        "text": "Lighthill, James",
        "url": "https://en.wikipedia.org/wiki/James_Lighthill",
        "title": "James Lighthill"
      },
      {
        "text": "The Narrative and the Algorithm: Genres of Credit Reporting from the Nineteenth Century to Today",
        "url": "https://mpra.ub.uni-muenchen.de/28142/1/MPRA_paper_28142.pdf"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.2139/ssrn.1736283",
        "url": "https://doi.org/10.2139%2Fssrn.1736283"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "166742927",
        "url": "https://api.semanticscholar.org/CorpusID:166742927"
      },
      {
        "text": "archived",
        "url": "https://ghostarchive.org/archive/20221009/https://mpra.ub.uni-muenchen.de/28142/1/MPRA_paper_28142.pdf"
      },
      {
        "text": "\"Robots Will Take Jobs, but Not as Fast as Some Fear, New Report Says\"",
        "url": "https://www.nytimes.com/2017/01/12/technology/robots-will-take-jobs-but-not-as-fast-as-some-fear-new-report-says.html"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20180114073704/https://www.nytimes.com/2017/01/12/technology/robots-will-take-jobs-but-not-as-fast-as-some-fear-new-report-says.html"
      },
      {
        "text": "CiteSeerX",
        "url": "https://en.wikipedia.org/wiki/CiteSeerX_(identifier)",
        "title": "CiteSeerX (identifier)"
      },
      {
        "text": "10.1.1.83.7615",
        "url": "https://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.83.7615"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1080/09540090310001655110",
        "url": "https://doi.org/10.1080%2F09540090310001655110"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "1452734",
        "url": "https://api.semanticscholar.org/CorpusID:1452734"
      },
      {
        "text": "\"Machine Ethics\"",
        "url": "https://web.archive.org/web/20141129044821/http://www.aaai.org/Library/Symposia/Fall/fs05-06"
      },
      {
        "text": "the original",
        "url": "http://www.aaai.org/Library/Symposia/Fall/fs05-06"
      },
      {
        "text": "\"The case against killer robots, from a guy actually working on artificial intelligence\"",
        "url": "https://www.hrw.org/report/2012/11/19/losing-humanity/case-against-killer-robots"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20160204175716/http://fusion.net/story/54583/the-case-against-killer-robots-from-a-guy-actually-building-ai"
      },
      {
        "text": "\"What jobs will still be around in 20 years? Read this to prepare your future\"",
        "url": "https://www.theguardian.com/us-news/2017/jun/26/jobs-future-automation-robots-skills-creative-health"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20180114021804/https://www.theguardian.com/us-news/2017/jun/26/jobs-future-automation-robots-skills-creative-health"
      },
      {
        "text": "AI@50: AI Past, Present, Future",
        "url": "https://web.archive.org/web/20081008120238/http://www.engagingexperience.com/2006/07/ai50_ai_past_pr.html"
      },
      {
        "text": "the original",
        "url": "http://www.engagingexperience.com/2006/07/ai50_ai_past_pr.html"
      },
      {
        "text": "\"Google's Gemini: is the new AI model really better than ChatGPT?\"",
        "url": "https://theconversation.com/googles-gemini-is-the-new-ai-model-really-better-than-chatgpt-219526"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240304215625/https://theconversation.com/googles-gemini-is-the-new-ai-model-really-better-than-chatgpt-219526"
      },
      {
        "text": "Minsky, Marvin",
        "url": "https://en.wikipedia.org/wiki/Marvin_Minsky",
        "title": "Marvin Minsky"
      },
      {
        "text": "The Society of Mind",
        "url": "https://en.wikipedia.org/wiki/The_Society_of_Mind",
        "title": "The Society of Mind"
      },
      {
        "text": "McCarthy, John",
        "url": "https://en.wikipedia.org/wiki/John_McCarthy_(computer_scientist)",
        "title": "John McCarthy (computer scientist)"
      },
      {
        "text": "Minsky, Marvin",
        "url": "https://en.wikipedia.org/wiki/Marvin_Minsky",
        "title": "Marvin Minsky"
      },
      {
        "text": "Rochester, Nathan",
        "url": "https://en.wikipedia.org/wiki/Nathan_Rochester",
        "title": "Nathan Rochester"
      },
      {
        "text": "Shannon, Claude",
        "url": "https://en.wikipedia.org/wiki/Claude_Shannon",
        "title": "Claude Shannon"
      },
      {
        "text": "\"A Proposal for the Dartmouth Summer Research Project on Artificial Intelligence\"",
        "url": "https://web.archive.org/web/20070826230310/http://www-formal.stanford.edu/jmc/history/dartmouth/dartmouth.html"
      },
      {
        "text": "the original",
        "url": "http://www-formal.stanford.edu/jmc/history/dartmouth/dartmouth.html"
      },
      {
        "text": "McCarthy, John",
        "url": "https://en.wikipedia.org/wiki/John_McCarthy_(computer_scientist)",
        "title": "John McCarthy (computer scientist)"
      },
      {
        "text": "McCarthy, John",
        "url": "https://en.wikipedia.org/wiki/John_McCarthy_(computer_scientist)",
        "title": "John McCarthy (computer scientist)"
      },
      {
        "text": "What is AI?",
        "url": "http://jmc.stanford.edu/artificial-intelligence/what-is-ai/index.html"
      },
      {
        "text": "archived",
        "url": "https://web.archive.org/web/20221204051737/http://jmc.stanford.edu/artificial-intelligence/what-is-ai/index.html"
      },
      {
        "text": "CiteSeerX",
        "url": "https://en.wikipedia.org/wiki/CiteSeerX_(identifier)",
        "title": "CiteSeerX (identifier)"
      },
      {
        "text": "10.1.1.85.8904",
        "url": "https://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.85.8904"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1007/s10676-007-9138-2",
        "url": "https://doi.org/10.1007%2Fs10676-007-9138-2"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "37272949",
        "url": "https://api.semanticscholar.org/CorpusID:37272949"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1017/S0269888905000408",
        "url": "https://doi.org/10.1017%2FS0269888905000408"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "14987656",
        "url": "https://api.semanticscholar.org/CorpusID:14987656"
      },
      {
        "text": "Will Robots Automate Your Job Away? Full Employment, Basic Income, and Economic Democracy",
        "url": "https://papers.ssrn.com/sol3/papers.cfm?abstract_id=3044448"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.2139/ssrn.3044448",
        "url": "https://doi.org/10.2139%2Fssrn.3044448"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "219336439",
        "url": "https://api.semanticscholar.org/CorpusID:219336439"
      },
      {
        "text": "SSRN",
        "url": "https://en.wikipedia.org/wiki/SSRN_(identifier)",
        "title": "SSRN (identifier)"
      },
      {
        "text": "3044448",
        "url": "https://papers.ssrn.com/sol3/papers.cfm?abstract_id=3044448"
      },
      {
        "text": "archived",
        "url": "https://web.archive.org/web/20210131074722/https://papers.ssrn.com/sol3/papers.cfm?abstract_id=3044448"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-1-4614-6940-7",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-1-4614-6940-7",
        "title": "Special:BookSources/978-1-4614-6940-7"
      },
      {
        "text": "Minsky, Marvin",
        "url": "https://en.wikipedia.org/wiki/Marvin_Minsky",
        "title": "Marvin Minsky"
      },
      {
        "text": "Moravec, Hans",
        "url": "https://en.wikipedia.org/wiki/Hans_Moravec",
        "title": "Hans Moravec"
      },
      {
        "text": "Mind Children",
        "url": "https://archive.org/details/mindchildrenfutu00mora"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-6745-7616-2",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-6745-7616-2",
        "title": "Special:BookSources/978-0-6745-7616-2"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200726131644/https://archive.org/details/mindchildrenfutu00mora"
      },
      {
        "text": "\"Automation and anxiety\"",
        "url": "https://www.economist.com/news/special-report/21700758-will-smarter-machines-cause-mass-unemployment-automation-and-anxiety"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20180112214621/https://www.economist.com/news/special-report/21700758-will-smarter-machines-cause-mass-unemployment-automation-and-anxiety"
      },
      {
        "text": "\"Future Progress in Artificial Intelligence: A Poll Among Experts\"",
        "url": "http://www.sophia.de/pdf/2014_PT-AI_polls.pdf"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1145/2639475.2639478",
        "url": "https://doi.org/10.1145%2F2639475.2639478"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "8510016",
        "url": "https://api.semanticscholar.org/CorpusID:8510016"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20160115114604/http://www.sophia.de/pdf/2014_PT-AI_polls.pdf"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1016/j.imavis.2007.08.013",
        "url": "https://doi.org/10.1016%2Fj.imavis.2007.08.013"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "10767011",
        "url": "https://api.semanticscholar.org/CorpusID:10767011"
      },
      {
        "text": "Nilsson, Nils",
        "url": "https://en.wikipedia.org/wiki/Nils_John_Nilsson",
        "title": "Nils John Nilsson"
      },
      {
        "text": "Newell, Allen",
        "url": "https://en.wikipedia.org/wiki/Allen_Newell",
        "title": "Allen Newell"
      },
      {
        "text": "Simon, H. A.",
        "url": "https://en.wikipedia.org/wiki/Herbert_A._Simon",
        "title": "Herbert A. Simon"
      },
      {
        "text": "\"Computer Science as Empirical Inquiry: Symbols and Search\"",
        "url": "https://doi.org/10.1145%2F360018.360022"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1145/360018.360022",
        "url": "https://doi.org/10.1145%2F360018.360022"
      },
      {
        "text": "\"How YouTube Drives People to the Internet's Darkest Corners\"",
        "url": "https://www.wsj.com/articles/how-youtube-drives-viewers-to-the-internets-darkest-corners-1518020478"
      },
      {
        "text": "The Wall Street Journal",
        "url": "https://en.wikipedia.org/wiki/The_Wall_Street_Journal",
        "title": "The Wall Street Journal"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0099-9660",
        "url": "https://search.worldcat.org/issn/0099-9660"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005171230/https://www.wsj.com/articles/how-youtube-drives-viewers-to-the-internets-darkest-corners-1518020478"
      },
      {
        "text": "Nilsson, Nils",
        "url": "https://en.wikipedia.org/wiki/Nils_Nilsson_(researcher)",
        "title": "Nils Nilsson (researcher)"
      },
      {
        "text": "\"Artificial Intelligence Prepares for 2001\"",
        "url": "https://ai.stanford.edu/~nilsson/OnlinePubs-Nils/General%20Essays/AIMag04-04-002.pdf"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200817194457/http://ai.stanford.edu/~nilsson/OnlinePubs-Nils/General%20Essays/AIMag04-04-002.pdf"
      },
      {
        "text": "Association for the Advancement of Artificial Intelligence",
        "url": "https://en.wikipedia.org/wiki/Association_for_the_Advancement_of_Artificial_Intelligence",
        "title": "Association for the Advancement of Artificial Intelligence"
      },
      {
        "text": "NRC (United States National Research Council)",
        "url": "https://en.wikipedia.org/wiki/United_States_National_Research_Council",
        "title": "United States National Research Council"
      },
      {
        "text": "Omohundro, Steve",
        "url": "https://en.wikipedia.org/wiki/Steve_Omohundro",
        "title": "Steve Omohundro"
      },
      {
        "text": "\"On the impact of robotics in behavioral and cognitive sciences: from insect navigation to human cognitive development\"",
        "url": "http://www.pyoudeyer.com/IEEETAMDOudeyer10.pdf"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1109/tamd.2009.2039057",
        "url": "https://doi.org/10.1109%2Ftamd.2009.2039057"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "6362217",
        "url": "https://api.semanticscholar.org/CorpusID:6362217"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20181003202543/http://www.pyoudeyer.com/IEEETAMDOudeyer10.pdf"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1007/978-3-540-68677-4_1",
        "url": "https://doi.org/10.1007%2F978-3-540-68677-4_1"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-3-5402-3733-4",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-3-5402-3733-4",
        "title": "Special:BookSources/978-3-5402-3733-4"
      },
      {
        "text": "Pinker, Steven",
        "url": "https://en.wikipedia.org/wiki/Steven_Pinker",
        "title": "Steven Pinker"
      },
      {
        "text": "The Language Instinct",
        "url": "https://en.wikipedia.org/wiki/The_Language_Instinct",
        "title": "The Language Instinct"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-0613-3646-1",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-0613-3646-1",
        "title": "Special:BookSources/978-0-0613-3646-1"
      },
      {
        "text": "\"A review of affective computing: From unimodal analysis to multimodal fusion\"",
        "url": "http://researchrepository.napier.ac.uk/Output/1792429"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1016/j.inffus.2017.02.003",
        "url": "https://doi.org/10.1016%2Fj.inffus.2017.02.003"
      },
      {
        "text": "hdl",
        "url": "https://en.wikipedia.org/wiki/Hdl_(identifier)",
        "title": "Hdl (identifier)"
      },
      {
        "text": "1893/25490",
        "url": "https://hdl.handle.net/1893%2F25490"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "205433041",
        "url": "https://api.semanticscholar.org/CorpusID:205433041"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230323165407/https://www.napier.ac.uk/research-and-innovation/research-search/outputs/a-review-of-affective-computing-from-unimodal-analysis-to-multimodal-fusion"
      },
      {
        "text": "\"Microsoft's Bill Gates insists AI is a threat\"",
        "url": "https://www.bbc.co.uk/news/31047780"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20150129183607/http://www.bbc.co.uk/news/31047780"
      },
      {
        "text": "\"Revealed: The Authors Whose Pirated Books are Powering Generative AI\"",
        "url": "https://www.theatlantic.com/technology/archive/2023/08/books3-ai-meta-llama-pirated-books/675063/"
      },
      {
        "text": "archived",
        "url": "https://web.archive.org/web/20241003071505/https://www.theatlantic.com/technology/archive/2023/08/books3-ai-meta-llama-pirated-books/675063/"
      },
      {
        "text": "\"Thinking Machines: The Search for Artificial Intelligence\"",
        "url": "https://web.archive.org/web/20180819152455/https://www.sciencehistory.org/distillations/magazine/thinking-machines-the-search-for-artificial-intelligence"
      },
      {
        "text": "the original",
        "url": "https://www.sciencehistory.org/distillations/magazine/thinking-machines-the-search-for-artificial-intelligence"
      },
      {
        "text": "\"Five experts share what scares them the most about AI\"",
        "url": "https://futurism.com/artificial-intelligence-experts-fear/amp"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20191208094101/https://futurism.com/artificial-intelligence-experts-fear/amp"
      },
      {
        "text": "The Guardian Weekly",
        "url": "https://en.wikipedia.org/wiki/The_Guardian_Weekly",
        "title": "The Guardian Weekly"
      },
      {
        "text": "Russell, Stuart",
        "url": "https://en.wikipedia.org/wiki/Stuart_J._Russell",
        "title": "Stuart J. Russell"
      },
      {
        "text": "Human Compatible: Artificial Intelligence and the Problem of Control",
        "url": "https://en.wikipedia.org/wiki/Human_Compatible",
        "title": "Human Compatible"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-5255-5861-3",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-5255-5861-3",
        "title": "Special:BookSources/978-0-5255-5861-3"
      },
      {
        "text": "OCLC",
        "url": "https://en.wikipedia.org/wiki/OCLC_(identifier)",
        "title": "OCLC (identifier)"
      },
      {
        "text": "1083694322",
        "url": "https://search.worldcat.org/oclc/1083694322"
      },
      {
        "text": "\"Stephen Hawking, Elon Musk, and Bill Gates Warn About Artificial Intelligence\"",
        "url": "https://observer.com/2015/08/stephen-hawking-elon-musk-and-bill-gates-warn-about-artificial-intelligence"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20151030053323/http://observer.com/2015/08/stephen-hawking-elon-musk-and-bill-gates-warn-about-artificial-intelligence"
      },
      {
        "text": "\"Computer says no: why making AIs fair, accountable and transparent is crucial\"",
        "url": "https://www.theguardian.com/science/2017/nov/05/computer-says-no-why-making-ais-fair-accountable-and-transparent-is-crucial"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20221010134155/https://theguardian.com/science/2017/nov/05/computer-says-no-why-making-ais-fair-accountable-and-transparent-is-crucial"
      },
      {
        "text": "\"Exploring LIME Explanations and the Mathematics Behind It\"",
        "url": "https://www.codemotion.com/magazine/ai-ml/lime-explainable-ai"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231125045932/https://www.codemotion.com/magazine/ai-ml/lime-explainable-ai/"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1023/A:1013298507114",
        "url": "https://doi.org/10.1023%2FA%3A1013298507114"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "1979315",
        "url": "https://api.semanticscholar.org/CorpusID:1979315"
      },
      {
        "text": "Schmidhuber, J.",
        "url": "https://en.wikipedia.org/wiki/J%C3%BCrgen_Schmidhuber",
        "title": "Jürgen Schmidhuber"
      },
      {
        "text": "arXiv",
        "url": "https://en.wikipedia.org/wiki/ArXiv_(identifier)",
        "title": "ArXiv (identifier)"
      },
      {
        "text": "1404.7828",
        "url": "https://arxiv.org/abs/1404.7828"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1016/j.neunet.2014.09.003",
        "url": "https://doi.org/10.1016%2Fj.neunet.2014.09.003"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "25462637",
        "url": "https://pubmed.ncbi.nlm.nih.gov/25462637"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "11715509",
        "url": "https://api.semanticscholar.org/CorpusID:11715509"
      },
      {
        "text": "Schmidhuber, Jürgen",
        "url": "https://en.wikipedia.org/wiki/J%C3%BCrgen_Schmidhuber",
        "title": "Jürgen Schmidhuber"
      },
      {
        "text": "\"Annotated History of Modern AI and Deep Learning\"",
        "url": "https://people.idsia.ch/~juergen/"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230807173414/https://people.idsia.ch/~juergen/"
      },
      {
        "text": "Searle, John",
        "url": "https://en.wikipedia.org/wiki/John_Searle",
        "title": "John Searle"
      },
      {
        "text": "\"Minds, Brains and Programs\"",
        "url": "http://cogprints.org/7150/1/10.1.1.83.5248.pdf"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1017/S0140525X00005756",
        "url": "https://doi.org/10.1017%2FS0140525X00005756"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "55303721",
        "url": "https://api.semanticscholar.org/CorpusID:55303721"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20190317230215/http://cogprints.org/7150/1/10.1.1.83.5248.pdf"
      },
      {
        "text": "Searle, John",
        "url": "https://en.wikipedia.org/wiki/John_Searle",
        "title": "John Searle"
      },
      {
        "text": "Mind, language and society",
        "url": "https://archive.org/details/mindlanguagesoci00sear"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-4650-4521-1",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-4650-4521-1",
        "title": "Special:BookSources/978-0-4650-4521-1"
      },
      {
        "text": "OCLC",
        "url": "https://en.wikipedia.org/wiki/OCLC_(identifier)",
        "title": "OCLC (identifier)"
      },
      {
        "text": "231867665",
        "url": "https://search.worldcat.org/oclc/231867665"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200726220615/https://archive.org/details/mindlanguagesoci00sear"
      },
      {
        "text": "\"How Google Plans to Solve Artificial Intelligence\"",
        "url": "https://www.technologyreview.com/2016/03/31/161234/how-google-plans-to-solve-artificial-intelligence"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240916003430/https://www.technologyreview.com/2016/03/31/161234/how-google-plans-to-solve-artificial-intelligence/"
      },
      {
        "text": "\"ChatGPT-4 Creator Ilya Sutskever on AI Hallucinations and AI Democracy\"",
        "url": "https://www.forbes.com/sites/craigsmith/2023/03/15/gpt-4-creator-ilya-sutskever-on-ai-hallucinations-and-ai-democracy"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240918141325/https://www.forbes.com/sites/craigsmith/2023/03/15/gpt-4-creator-ilya-sutskever-on-ai-hallucinations-and-ai-democracy/"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1109/93.311653",
        "url": "https://doi.org/10.1109%2F93.311653"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "32710913",
        "url": "https://api.semanticscholar.org/CorpusID:32710913"
      },
      {
        "text": "Solomonoff, Ray",
        "url": "https://en.wikipedia.org/wiki/Ray_Solomonoff",
        "title": "Ray Solomonoff"
      },
      {
        "text": "An Inductive Inference Machine",
        "url": "http://world.std.com/~rjs/indinf56.pdf"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20110426161749/http://world.std.com/~rjs/indinf56.pdf"
      },
      {
        "text": "\"Artificial Intelligence Index Report 2023/Chapter 6: Policy and Governance\"",
        "url": "https://aiindex.stanford.edu/wp-content/uploads/2023/04/HAI_AI-Index-Report-2023_CHAPTER_6-1.pdf"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230619013609/https://aiindex.stanford.edu/wp-content/uploads/2023/04/HAI_AI-Index-Report-2023_CHAPTER_6-1.pdf"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1007/11573548",
        "url": "https://doi.org/10.1007%2F11573548"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-3-5402-9621-8",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-3-5402-9621-8",
        "title": "Special:BookSources/978-3-5402-9621-8"
      },
      {
        "text": "\"'Godfather of AI' Geoffrey Hinton quits Google and warns over dangers of misinformation\"",
        "url": "https://www.theguardian.com/technology/2023/may/02/geoffrey-hinton-godfather-of-ai-quits-google-warns-dangers-of-machine-learning"
      },
      {
        "text": "The Guardian",
        "url": "https://en.wikipedia.org/wiki/The_Guardian",
        "title": "The Guardian"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20241005171343/https://www.theguardian.com/technology/2023/may/02/geoffrey-hinton-godfather-of-ai-quits-google-warns-dangers-of-machine-learning"
      },
      {
        "text": "\"What Jobs Will the Robots Take?\"",
        "url": "https://www.theatlantic.com/business/archive/2014/01/what-jobs-will-the-robots-take/283239"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20180424202435/https://www.theatlantic.com/business/archive/2014/01/what-jobs-will-the-robots-take/283239"
      },
      {
        "text": "Robotics: The Marriage of Computers and Machines",
        "url": "https://archive.org/details/isbn_9780816026289"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-8160-2628-9",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-8160-2628-9",
        "title": "Special:BookSources/978-0-8160-2628-9"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200726131505/https://archive.org/details/isbn_9780816026289"
      },
      {
        "text": "\"Transformers Revolutionized AI. What Will Replace Them?\"",
        "url": "https://www.forbes.com/sites/robtoews/2023/09/03/transformers-revolutionized-ai-what-will-replace-them"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231208232145/https://www.forbes.com/sites/robtoews/2023/09/03/transformers-revolutionized-ai-what-will-replace-them/"
      },
      {
        "text": "Turing, Alan",
        "url": "https://en.wikipedia.org/wiki/Alan_Turing",
        "title": "Alan Turing"
      },
      {
        "text": "\"Computing Machinery and Intelligence\"",
        "url": "https://academic.oup.com/mind/article/LIX/236/433/986238"
      },
      {
        "text": "Mind",
        "url": "https://en.wikipedia.org/wiki/Mind_(journal)",
        "title": "Mind (journal)"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1093/mind/LIX.236.433",
        "url": "https://doi.org/10.1093%2Fmind%2FLIX.236.433"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "1460-2113",
        "url": "https://search.worldcat.org/issn/1460-2113"
      },
      {
        "text": "JSTOR",
        "url": "https://en.wikipedia.org/wiki/JSTOR_(identifier)",
        "title": "JSTOR (identifier)"
      },
      {
        "text": "2251299",
        "url": "https://www.jstor.org/stable/2251299"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "14636783",
        "url": "https://api.semanticscholar.org/CorpusID:14636783"
      },
      {
        "text": "UNESCO Science Report: the Race Against Time for Smarter Development",
        "url": "https://unesdoc.unesco.org/ark:/48223/pf0000377433/PDF/377433eng.pdf.multi"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-9-2310-0450-6",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-9-2310-0450-6",
        "title": "Special:BookSources/978-9-2310-0450-6"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20220618233752/https://unesdoc.unesco.org/ark:/48223/pf0000377433/PDF/377433eng.pdf.multi"
      },
      {
        "text": "\"Dual use of artificial-intelligence-powered drug discovery\"",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9544280"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1038/s42256-022-00465-9",
        "url": "https://doi.org/10.1038%2Fs42256-022-00465-9"
      },
      {
        "text": "PMC",
        "url": "https://en.wikipedia.org/wiki/PMC_(identifier)",
        "title": "PMC (identifier)"
      },
      {
        "text": "9544280",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9544280"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "36211133",
        "url": "https://pubmed.ncbi.nlm.nih.gov/36211133"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "247302391",
        "url": "https://api.semanticscholar.org/CorpusID:247302391"
      },
      {
        "text": "\"Artificial intelligence could lead to extinction, experts warn\"",
        "url": "https://www.bbc.com/news/uk-65746524"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230617200355/https://www.bbc.com/news/uk-65746524"
      },
      {
        "text": "\"Amazon reportedly employs thousands of people to listen to your Alexa conversations\"",
        "url": "https://www.cnn.com/2019/04/11/tech/amazon-alexa-listening/index.html"
      },
      {
        "text": "archived",
        "url": "https://web.archive.org/web/20240126033535/https://www.cnn.com/2019/04/11/tech/amazon-alexa-listening/index.html"
      },
      {
        "text": "\"A Complete Guide to SHAP – SHAPley Additive exPlanations for Practitioners\"",
        "url": "https://analyticsindiamag.com/a-complete-guide-to-shap-shapley-additive-explanations-for-practitioners"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20231125045938/https://analyticsindiamag.com/a-complete-guide-to-shap-shapley-additive-explanations-for-practitioners/"
      },
      {
        "text": "\"OpenAI has published the text-generating AI it said was too dangerous to share\"",
        "url": "https://www.theverge.com/2019/11/7/20953040/openai-text-generation-ai-gpt-2-full-model-release-1-5b-parameters"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200611054114/https://www.theverge.com/2019/11/7/20953040/openai-text-generation-ai-gpt-2-full-model-release-1-5b-parameters"
      },
      {
        "text": "\"The scary truth about AI copyright is nobody knows what will happen next\"",
        "url": "https://www.theverge.com/23444685/generative-ai-copyright-infringement-legal-fair-use-training-data"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230619055201/https://www.theverge.com/23444685/generative-ai-copyright-infringement-legal-fair-use-training-data"
      },
      {
        "text": "\"AI is entering an era of corporate control\"",
        "url": "https://www.theverge.com/23667752/ai-progress-2023-report-stanford-corporate-control"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230619005803/https://www.theverge.com/23667752/ai-progress-2023-report-stanford-corporate-control"
      },
      {
        "text": "Vinge, Vernor",
        "url": "https://en.wikipedia.org/wiki/Vernor_Vinge",
        "title": "Vernor Vinge"
      },
      {
        "text": "\"The Coming Technological Singularity: How to Survive in the Post-Human Era\"",
        "url": "https://web.archive.org/web/20070101133646/http://www-rohan.sdsu.edu/faculty/vinge/misc/singularity.html"
      },
      {
        "text": "Bibcode",
        "url": "https://en.wikipedia.org/wiki/Bibcode_(identifier)",
        "title": "Bibcode (identifier)"
      },
      {
        "text": "1993vise.nasa...11V",
        "url": "https://ui.adsabs.harvard.edu/abs/1993vise.nasa...11V"
      },
      {
        "text": "the original",
        "url": "http://www-rohan.sdsu.edu/faculty/vinge/misc/singularity.html"
      },
      {
        "text": "\"Chatbots Have Entered the Uncanny Valley\"",
        "url": "https://www.theatlantic.com/technology/archive/2017/04/uncanny-valley-digital-assistants/523806"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20180424202350/https://www.theatlantic.com/technology/archive/2017/04/uncanny-valley-digital-assistants/523806"
      },
      {
        "text": "Wason, P. C.",
        "url": "https://en.wikipedia.org/wiki/Peter_Cathcart_Wason",
        "title": "Peter Cathcart Wason"
      },
      {
        "text": "\"Reasoning\"",
        "url": "https://archive.org/details/newhorizonsinpsy0000foss"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200726131518/https://archive.org/details/newhorizonsinpsy0000foss"
      },
      {
        "text": "\"Autonomous mental development by robots and animals\"",
        "url": "http://www.cse.msu.edu/dl/SciencePaper.pdf"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1126/science.291.5504.599",
        "url": "https://doi.org/10.1126%2Fscience.291.5504.599"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "11229402",
        "url": "https://pubmed.ncbi.nlm.nih.gov/11229402"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "54131797",
        "url": "https://api.semanticscholar.org/CorpusID:54131797"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20130904235242/http://www.cse.msu.edu/dl/SciencePaper.pdf"
      },
      {
        "text": "\"What is 'fuzzy logic'? Are there computers that are inherently fuzzy and do not apply the usual binary logic?\"",
        "url": "https://www.scientificamerican.com/article/what-is-fuzzy-logic-are-t"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20180506035133/https://www.scientificamerican.com/article/what-is-fuzzy-logic-are-t"
      },
      {
        "text": "\"Humans may be more likely to believe disinformation generated by AI\"",
        "url": "https://www.technologyreview.com/2023/06/28/1075683/humans-may-be-more-likely-to-believe-disinformation-generated-by-ai/"
      },
      {
        "text": "MIT Technology Review",
        "url": "https://en.wikipedia.org/wiki/MIT_Technology_Review",
        "title": "MIT Technology Review"
      },
      {
        "text": "archived",
        "url": "https://web.archive.org/web/20240916014613/https://www.technologyreview.com/2023/06/28/1075683/humans-may-be-more-likely-to-believe-disinformation-generated-by-ai/"
      },
      {
        "text": "\"Artificial Intelligence and the Public Sector – Applications and Challenges\"",
        "url": "https://zenodo.org/record/3569435"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1080/01900692.2018.1498103",
        "url": "https://doi.org/10.1080%2F01900692.2018.1498103"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "0190-0692",
        "url": "https://search.worldcat.org/issn/0190-0692"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "158829602",
        "url": "https://api.semanticscholar.org/CorpusID:158829602"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200818131415/https://zenodo.org/record/3569435"
      },
      {
        "text": "\"ChatGPT Is Already Obsolete\"",
        "url": "https://www.theatlantic.com/technology/archive/2023/05/ai-advancements-multimodal-models/674113/"
      },
      {
        "text": "archived",
        "url": "https://web.archive.org/web/20240918022529/https://www.theatlantic.com/technology/archive/2023/05/ai-advancements-multimodal-models/674113/"
      },
      {
        "text": "\"Artificial Intelligence as a Positive and Negative Factor in Global Risk\"",
        "url": "http://intelligence.org/files/AIPosNegFactor.pdf"
      },
      {
        "text": "Bibcode",
        "url": "https://en.wikipedia.org/wiki/Bibcode_(identifier)",
        "title": "Bibcode (identifier)"
      },
      {
        "text": "2008gcr..book..303Y",
        "url": "https://ui.adsabs.harvard.edu/abs/2008gcr..book..303Y"
      },
      {
        "text": "archived",
        "url": "https://web.archive.org/web/20131019182403/http://intelligence.org/files/AIPosNegFactor.pdf"
      },
      {
        "text": "Autor, David H.",
        "url": "https://en.wikipedia.org/wiki/David_Autor",
        "title": "David Autor"
      },
      {
        "text": "Berlinski, David",
        "url": "https://en.wikipedia.org/wiki/David_Berlinski",
        "title": "David Berlinski"
      },
      {
        "text": "The Advent of the Algorithm",
        "url": "https://archive.org/details/adventofalgorith0000berl"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-1560-1391-8",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-1560-1391-8",
        "title": "Special:BookSources/978-0-1560-1391-8"
      },
      {
        "text": "OCLC",
        "url": "https://en.wikipedia.org/wiki/OCLC_(identifier)",
        "title": "OCLC (identifier)"
      },
      {
        "text": "46890682",
        "url": "https://search.worldcat.org/oclc/46890682"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200726215744/https://archive.org/details/adventofalgorith0000berl"
      },
      {
        "text": "The Line: AI and the Future of Personhood",
        "url": "https://direct.mit.edu/books/book/5859/The-LineAI-and-the-Future-of-Personhood"
      },
      {
        "text": "MIT Press",
        "url": "https://en.wikipedia.org/wiki/MIT_Press",
        "title": "MIT Press"
      },
      {
        "text": "Cukier, Kenneth",
        "url": "https://en.wikipedia.org/wiki/Kenneth_Cukier",
        "title": "Kenneth Cukier"
      },
      {
        "text": "Foreign Affairs",
        "url": "https://en.wikipedia.org/wiki/Foreign_Affairs",
        "title": "Foreign Affairs"
      },
      {
        "text": "George Dyson",
        "url": "https://en.wikipedia.org/wiki/George_Dyson_(science_historian)",
        "title": "George Dyson (science historian)"
      },
      {
        "text": "Alex Pentland",
        "url": "https://en.wikipedia.org/wiki/Alex_Pentland",
        "title": "Alex Pentland"
      },
      {
        "text": "AI machine-learning",
        "url": "https://en.wikipedia.org/wiki/Machine_learning",
        "title": "Machine learning"
      },
      {
        "text": "algorithms",
        "url": "https://en.wikipedia.org/wiki/Algorithm",
        "title": "Algorithm"
      },
      {
        "text": "Evans, Woody",
        "url": "https://en.wikipedia.org/wiki/Woody_Evans",
        "title": "Woody Evans"
      },
      {
        "text": "\"Posthuman Rights: Dimensions of Transhuman Worlds\"",
        "url": "https://doi.org/10.5209%2Frev_TK.2015.v12.n2.49072"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.5209/rev_TK.2015.v12.n2.49072",
        "url": "https://doi.org/10.5209%2Frev_TK.2015.v12.n2.49072"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "147612763",
        "url": "https://api.semanticscholar.org/CorpusID:147612763"
      },
      {
        "text": "\"US Leadership in Artificial Intelligence Can Shape the 21st Century Global Order\"",
        "url": "https://thediplomat.com/2023/09/us-leadership-in-artificial-intelligence-can-shape-the-21st-century-global-order"
      },
      {
        "text": "The Diplomat",
        "url": "https://en.wikipedia.org/wiki/The_Diplomat_(magazine)",
        "title": "The Diplomat (magazine)"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20240916014433/https://thediplomat.com/2023/09/us-leadership-in-artificial-intelligence-can-shape-the-21st-century-global-order/"
      },
      {
        "text": "online",
        "url": "https://www.nytimes.com/2023/07/18/magazine/wikipedia-ai-chatgpt.html"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230720125400/https://www.nytimes.com/2023/07/18/magazine/wikipedia-ai-chatgpt.html"
      },
      {
        "text": "Wayback Machine",
        "url": "https://en.wikipedia.org/wiki/Wayback_Machine",
        "title": "Wayback Machine"
      },
      {
        "text": "Gleick, James",
        "url": "https://en.wikipedia.org/wiki/Gleick,_James",
        "title": "Gleick, James"
      },
      {
        "text": "The New York Review of Books",
        "url": "https://en.wikipedia.org/wiki/The_New_York_Review_of_Books",
        "title": "The New York Review of Books"
      },
      {
        "text": "Agency",
        "url": "https://en.wikipedia.org/wiki/Agency_(philosophy)",
        "title": "Agency (philosophy)"
      },
      {
        "text": "reason",
        "url": "https://en.wikipedia.org/wiki/Reason",
        "title": "Reason"
      },
      {
        "text": "purpose",
        "url": "https://en.wikipedia.org/wiki/Motivation",
        "title": "Motivation"
      },
      {
        "text": "Verity Harding",
        "url": "https://en.wikipedia.org/wiki/Verity_Harding",
        "title": "Verity Harding"
      },
      {
        "text": "Gary Marcus",
        "url": "https://en.wikipedia.org/wiki/Gary_Marcus",
        "title": "Gary Marcus"
      },
      {
        "text": "Daniela Rus",
        "url": "https://en.wikipedia.org/wiki/Daniela_Rus",
        "title": "Daniela Rus"
      },
      {
        "text": "Gregory Mone",
        "url": "https://en.wikipedia.org/w/index.php?title=Gregory_Mone&action=edit&redlink=1",
        "title": "Gregory Mone (page does not exist)"
      },
      {
        "text": "Madhumita Murgia",
        "url": "https://en.wikipedia.org/wiki/Madhumita_Murgia",
        "title": "Madhumita Murgia"
      },
      {
        "text": "The New York Review of Books",
        "url": "https://en.wikipedia.org/wiki/The_New_York_Review_of_Books",
        "title": "The New York Review of Books"
      },
      {
        "text": "governments",
        "url": "https://en.wikipedia.org/wiki/Government",
        "title": "Government"
      },
      {
        "text": "campaign finance",
        "url": "https://en.wikipedia.org/wiki/Campaign_finance",
        "title": "Campaign finance"
      },
      {
        "text": "tech companies",
        "url": "https://en.wikipedia.org/wiki/Tech_company",
        "title": "Tech company"
      },
      {
        "text": "transparency",
        "url": "https://en.wikipedia.org/wiki/Transparency_(behavior)",
        "title": "Transparency (behavior)"
      },
      {
        "text": "large language model",
        "url": "https://en.wikipedia.org/wiki/Large_language_model",
        "title": "Large language model"
      },
      {
        "text": "Section 230",
        "url": "https://en.wikipedia.org/wiki/Section_230",
        "title": "Section 230"
      },
      {
        "text": "product liability",
        "url": "https://en.wikipedia.org/wiki/Product_liability",
        "title": "Product liability"
      },
      {
        "text": "FDA",
        "url": "https://en.wikipedia.org/wiki/FDA",
        "title": "FDA"
      },
      {
        "text": "FCC",
        "url": "https://en.wikipedia.org/wiki/FCC",
        "title": "FCC"
      },
      {
        "text": "FTC",
        "url": "https://en.wikipedia.org/wiki/Federal_Trade_Commission",
        "title": "Federal Trade Commission"
      },
      {
        "text": "Fordham",
        "url": "https://en.wikipedia.org/wiki/Fordham_University",
        "title": "Fordham University"
      },
      {
        "text": "Chinmayi Sharma",
        "url": "https://en.wikipedia.org/w/index.php?title=Chinmayi_Sharma&action=edit&redlink=1",
        "title": "Chinmayi Sharma (page does not exist)"
      },
      {
        "text": "medical licenses",
        "url": "https://en.wikipedia.org/wiki/Medical_license",
        "title": "Medical license"
      },
      {
        "text": "malpractice",
        "url": "https://en.wikipedia.org/wiki/Malpractice",
        "title": "Malpractice"
      },
      {
        "text": "Hippocratic oath",
        "url": "https://en.wikipedia.org/wiki/Hippocratic_oath",
        "title": "Hippocratic oath"
      },
      {
        "text": "do no harm",
        "url": "https://en.wikipedia.org/wiki/Primum_non_nocere",
        "title": "Primum non nocere"
      },
      {
        "text": "\"Human rights for robots? We're getting carried away\"",
        "url": "https://www.thetimes.com/uk/science/article/human-rights-for-robots-were-getting-carried-away-xfbdkpgwn0v"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20140531104850/http://www.thetimes.co.uk/tto/technology/article1966391.ece"
      },
      {
        "text": "Cain's Jawbone",
        "url": "https://en.wikipedia.org/wiki/Cain%27s_Jawbone",
        "title": "Cain's Jawbone"
      },
      {
        "text": "Scientific American",
        "url": "https://en.wikipedia.org/wiki/Scientific_American",
        "title": "Scientific American"
      },
      {
        "text": "natural-language processing",
        "url": "https://en.wikipedia.org/wiki/Natural-language_processing",
        "title": "Natural-language processing"
      },
      {
        "text": "context",
        "url": "https://en.wikipedia.org/wiki/Context_(linguistics)",
        "title": "Context (linguistics)"
      },
      {
        "text": "ancient languages",
        "url": "https://en.wikipedia.org/wiki/Ancient_language",
        "title": "Ancient language"
      },
      {
        "text": "civilizations",
        "url": "https://en.wikipedia.org/wiki/Civilization",
        "title": "Civilization"
      },
      {
        "text": "training data",
        "url": "https://en.wikipedia.org/wiki/Training_data",
        "title": "Training data"
      },
      {
        "text": "Immerwahr, Daniel",
        "url": "https://en.wikipedia.org/wiki/Immerwahr,_Daniel",
        "title": "Immerwahr, Daniel"
      },
      {
        "text": "The New Yorker",
        "url": "https://en.wikipedia.org/wiki/The_New_Yorker",
        "title": "The New Yorker"
      },
      {
        "text": "deepfakes",
        "url": "https://en.wikipedia.org/wiki/Deepfakes",
        "title": "Deepfakes"
      },
      {
        "text": "cartoons",
        "url": "https://en.wikipedia.org/wiki/Cartoon",
        "title": "Cartoon"
      },
      {
        "text": "\"Highly accurate protein structure prediction with AlphaFold\"",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC8371605"
      },
      {
        "text": "Bibcode",
        "url": "https://en.wikipedia.org/wiki/Bibcode_(identifier)",
        "title": "Bibcode (identifier)"
      },
      {
        "text": "2021Natur.596..583J",
        "url": "https://ui.adsabs.harvard.edu/abs/2021Natur.596..583J"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1038/s41586-021-03819-2",
        "url": "https://doi.org/10.1038%2Fs41586-021-03819-2"
      },
      {
        "text": "PMC",
        "url": "https://en.wikipedia.org/wiki/PMC_(identifier)",
        "title": "PMC (identifier)"
      },
      {
        "text": "8371605",
        "url": "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC8371605"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "34265844",
        "url": "https://pubmed.ncbi.nlm.nih.gov/34265844"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "235959867",
        "url": "https://api.semanticscholar.org/CorpusID:235959867"
      },
      {
        "text": "\"Deep learning\"",
        "url": "https://www.nature.com/articles/nature14539"
      },
      {
        "text": "Bibcode",
        "url": "https://en.wikipedia.org/wiki/Bibcode_(identifier)",
        "title": "Bibcode (identifier)"
      },
      {
        "text": "2015Natur.521..436L",
        "url": "https://ui.adsabs.harvard.edu/abs/2015Natur.521..436L"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1038/nature14539",
        "url": "https://doi.org/10.1038%2Fnature14539"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "26017442",
        "url": "https://pubmed.ncbi.nlm.nih.gov/26017442"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "3074096",
        "url": "https://api.semanticscholar.org/CorpusID:3074096"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230605235832/https://www.nature.com/articles/nature14539"
      },
      {
        "text": "Scientific American",
        "url": "https://en.wikipedia.org/wiki/Scientific_American",
        "title": "Scientific American"
      },
      {
        "text": "Lepore, Jill",
        "url": "https://en.wikipedia.org/wiki/Jill_Lepore",
        "title": "Jill Lepore"
      },
      {
        "text": "The New Yorker",
        "url": "https://en.wikipedia.org/wiki/The_New_Yorker",
        "title": "The New Yorker"
      },
      {
        "text": "\"Content: Plug & Pray Film – Artificial Intelligence – Robots\"",
        "url": "http://www.plugandpray-film.de/en/content.html"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20160212040134/http://www.plugandpray-film.de/en/content.html"
      },
      {
        "text": "Marcus, Gary",
        "url": "https://en.wikipedia.org/wiki/Marcus,_Gary",
        "title": "Marcus, Gary"
      },
      {
        "text": "Scientific American",
        "url": "https://en.wikipedia.org/wiki/Scientific_American",
        "title": "Scientific American"
      },
      {
        "text": "ISBN",
        "url": "https://en.wikipedia.org/wiki/ISBN_(identifier)",
        "title": "ISBN (identifier)"
      },
      {
        "text": "978-0-3742-5783-5",
        "url": "https://en.wikipedia.org/wiki/Special:BookSources/978-0-3742-5783-5",
        "title": "Special:BookSources/978-0-3742-5783-5"
      },
      {
        "text": "\"Human-level control through deep reinforcement learning\"",
        "url": "https://www.nature.com/articles/nature14236"
      },
      {
        "text": "Bibcode",
        "url": "https://en.wikipedia.org/wiki/Bibcode_(identifier)",
        "title": "Bibcode (identifier)"
      },
      {
        "text": "2015Natur.518..529M",
        "url": "https://ui.adsabs.harvard.edu/abs/2015Natur.518..529M"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1038/nature14236",
        "url": "https://doi.org/10.1038%2Fnature14236"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "25719670",
        "url": "https://pubmed.ncbi.nlm.nih.gov/25719670"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "205242740",
        "url": "https://api.semanticscholar.org/CorpusID:205242740"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230619055525/https://www.nature.com/articles/nature14236"
      },
      {
        "text": "DQN",
        "url": "https://en.wikipedia.org/wiki/Deep_Q-learning",
        "title": "Deep Q-learning"
      },
      {
        "text": "Press, Eyal",
        "url": "https://en.wikipedia.org/wiki/Eyal_Press",
        "title": "Eyal Press"
      },
      {
        "text": "The New Yorker",
        "url": "https://en.wikipedia.org/wiki/The_New_Yorker",
        "title": "The New Yorker"
      },
      {
        "text": "\"Robots could demand legal rights\"",
        "url": "http://news.bbc.co.uk/2/hi/technology/6200005.stm"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20191015042628/http://news.bbc.co.uk/2/hi/technology/6200005.stm"
      },
      {
        "text": "ChatGPT",
        "url": "https://en.wikipedia.org/wiki/ChatGPT",
        "title": "ChatGPT"
      },
      {
        "text": "intelligence",
        "url": "https://en.wikipedia.org/wiki/Intelligence",
        "title": "Intelligence"
      },
      {
        "text": "IQ",
        "url": "https://en.wikipedia.org/wiki/IQ",
        "title": "IQ"
      },
      {
        "text": "Scientific American",
        "url": "https://en.wikipedia.org/wiki/Scientific_American",
        "title": "Scientific American"
      },
      {
        "text": "ChatGPT",
        "url": "https://en.wikipedia.org/wiki/ChatGPT",
        "title": "ChatGPT"
      },
      {
        "text": "Foreign Affairs",
        "url": "https://en.wikipedia.org/wiki/Foreign_Affairs",
        "title": "Foreign Affairs"
      },
      {
        "text": "\"Deep Learning\"",
        "url": "https://www.researchgate.net/publication/230690795"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1007/s13218-012-0198-z",
        "url": "https://doi.org/10.1007%2Fs13218-012-0198-z"
      },
      {
        "text": "ISSN",
        "url": "https://en.wikipedia.org/wiki/ISSN_(identifier)",
        "title": "ISSN (identifier)"
      },
      {
        "text": "1610-1987",
        "url": "https://search.worldcat.org/issn/1610-1987"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "220523562",
        "url": "https://api.semanticscholar.org/CorpusID:220523562"
      },
      {
        "text": "\"Comparing the expert survey and citation impact journal ranking methods: Example from the field of Artificial Intelligence\"",
        "url": "http://www.aserenko.com/papers/JOI_AI_Journal_Ranking_Serenko.pdf"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1016/j.joi.2011.06.002",
        "url": "https://doi.org/10.1016%2Fj.joi.2011.06.002"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20131004212839/http://www.aserenko.com/papers/JOI_AI_Journal_Ranking_Serenko.pdf"
      },
      {
        "text": "\"Mastering the game of Go with deep neural networks and tree search\"",
        "url": "https://www.nature.com/articles/nature16961"
      },
      {
        "text": "Bibcode",
        "url": "https://en.wikipedia.org/wiki/Bibcode_(identifier)",
        "title": "Bibcode (identifier)"
      },
      {
        "text": "2016Natur.529..484S",
        "url": "https://ui.adsabs.harvard.edu/abs/2016Natur.529..484S"
      },
      {
        "text": "doi",
        "url": "https://en.wikipedia.org/wiki/Doi_(identifier)",
        "title": "Doi (identifier)"
      },
      {
        "text": "10.1038/nature16961",
        "url": "https://doi.org/10.1038%2Fnature16961"
      },
      {
        "text": "PMID",
        "url": "https://en.wikipedia.org/wiki/PMID_(identifier)",
        "title": "PMID (identifier)"
      },
      {
        "text": "26819042",
        "url": "https://pubmed.ncbi.nlm.nih.gov/26819042"
      },
      {
        "text": "S2CID",
        "url": "https://en.wikipedia.org/wiki/S2CID_(identifier)",
        "title": "S2CID (identifier)"
      },
      {
        "text": "515925",
        "url": "https://api.semanticscholar.org/CorpusID:515925"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20230618213059/https://www.nature.com/articles/nature16961"
      },
      {
        "text": "Tarnoff, Ben",
        "url": "https://en.wikipedia.org/w/index.php?title=Ben_Tarnoff&action=edit&redlink=1",
        "title": "Ben Tarnoff (page does not exist)"
      },
      {
        "text": "Matteo Pasquinelli",
        "url": "https://en.wikipedia.org/w/index.php?title=Matteo_Pasquinelli&action=edit&redlink=1",
        "title": "Matteo Pasquinelli (page does not exist)"
      },
      {
        "text": "The New York Review of Books",
        "url": "https://en.wikipedia.org/wiki/The_New_York_Review_of_Books",
        "title": "The New York Review of Books"
      },
      {
        "text": "generative AI",
        "url": "https://en.wikipedia.org/wiki/Generative_AI",
        "title": "Generative AI"
      },
      {
        "text": "large language models",
        "url": "https://en.wikipedia.org/wiki/Large_language_model",
        "title": "Large language model"
      },
      {
        "text": "ChatGPT",
        "url": "https://en.wikipedia.org/wiki/ChatGPT",
        "title": "ChatGPT"
      },
      {
        "text": "data",
        "url": "https://en.wikipedia.org/wiki/Data",
        "title": "Data"
      },
      {
        "text": "prediction",
        "url": "https://en.wikipedia.org/wiki/Prediction",
        "title": "Prediction"
      },
      {
        "text": "computations",
        "url": "https://en.wikipedia.org/wiki/Computation",
        "title": "Computation"
      },
      {
        "text": "Vaswani, Ashish",
        "url": "https://en.wikipedia.org/wiki/Ashish_Vaswani",
        "title": "Ashish Vaswani"
      },
      {
        "text": "Attention is all you need",
        "url": "https://en.wikipedia.org/wiki/Attention_is_all_you_need",
        "title": "Attention is all you need"
      },
      {
        "text": "transformers",
        "url": "https://en.wikipedia.org/wiki/Transformer_(machine_learning_model)",
        "title": "Transformer (machine learning model)"
      },
      {
        "text": "London Review of Books",
        "url": "https://en.wikipedia.org/wiki/London_Review_of_Books",
        "title": "London Review of Books"
      },
      {
        "text": "anthropomorphise",
        "url": "https://en.wikipedia.org/wiki/Anthropomorphise",
        "title": "Anthropomorphise"
      },
      {
        "text": "White Paper: On Artificial Intelligence – A European approach to excellence and trust",
        "url": "https://ec.europa.eu/info/sites/info/files/commission-white-paper-artificial-intelligence-feb2020_en.pdf"
      },
      {
        "text": "Archived",
        "url": "https://web.archive.org/web/20200220173419/https://ec.europa.eu/info/sites/info/files/commission-white-paper-artificial-intelligence-feb2020_en.pdf"
      },
      {
        "text": "sister projects",
        "url": "https://en.wikipedia.org/wiki/Wikipedia:Wikimedia_sister_projects",
        "title": "Wikipedia:Wikimedia sister projects"
      },
      {
        "text": "Definitions",
        "url": "https://en.wiktionary.org/wiki/artificial_intelligence",
        "title": "wikt:artificial intelligence"
      },
      {
        "text": "Media",
        "url": "https://commons.wikimedia.org/wiki/Category:Artificial_intelligence",
        "title": "c:Category:Artificial intelligence"
      },
      {
        "text": "Quotations",
        "url": "https://en.wikiquote.org/wiki/Artificial_intelligence",
        "title": "q:Artificial intelligence"
      },
      {
        "text": "Textbooks",
        "url": "https://en.wikibooks.org/wiki/Artificial_Intelligence",
        "title": "b:Artificial Intelligence"
      },
      {
        "text": "Resources",
        "url": "https://en.wikiversity.org/wiki/Portal:Artificial_intelligence",
        "title": "v:Portal:Artificial intelligence"
      },
      {
        "text": "Data",
        "url": "https://www.wikidata.org/wiki/Q11660",
        "title": "d:Q11660"
      },
      {
        "text": "Scholia",
        "url": "https://www.wikidata.org/wiki/Wikidata:Scholia",
        "title": "d:Wikidata:Scholia"
      },
      {
        "text": "Artificial intelligence",
        "url": "https://iw.toolforge.org/scholia/topic/Q11660",
        "title": "toolforge:scholia/topic/Q11660"
      },
      {
        "text": "\"Artificial Intelligence\"",
        "url": "http://www.iep.utm.edu/art-inte"
      },
      {
        "text": "Internet Encyclopedia of Philosophy",
        "url": "https://en.wikipedia.org/wiki/Internet_Encyclopedia_of_Philosophy",
        "title": "Internet Encyclopedia of Philosophy"
      },
      {
        "text": "v",
        "url": "https://en.wikipedia.org/wiki/Template:Artificial_intelligence_navbox",
        "title": "Template:Artificial intelligence navbox"
      },
      {
        "text": "t",
        "url": "https://en.wikipedia.org/wiki/Template_talk:Artificial_intelligence_navbox",
        "title": "Template talk:Artificial intelligence navbox"
      },
      {
        "text": "e",
        "url": "https://en.wikipedia.org/wiki/Special:EditPage/Template:Artificial_intelligence_navbox",
        "title": "Special:EditPage/Template:Artificial intelligence navbox"
      },
      {
        "text": "History",
        "url": "https://en.wikipedia.org/wiki/History_of_artificial_intelligence",
        "title": "History of artificial intelligence"
      },
      {
        "text": "timeline",
        "url": "https://en.wikipedia.org/wiki/Timeline_of_artificial_intelligence",
        "title": "Timeline of artificial intelligence"
      },
      {
        "text": "Parameter",
        "url": "https://en.wikipedia.org/wiki/Parameter",
        "title": "Parameter"
      },
      {
        "text": "Hyperparameter",
        "url": "https://en.wikipedia.org/wiki/Hyperparameter_(machine_learning)",
        "title": "Hyperparameter (machine learning)"
      },
      {
        "text": "Loss functions",
        "url": "https://en.wikipedia.org/wiki/Loss_functions_for_classification",
        "title": "Loss functions for classification"
      },
      {
        "text": "Regression",
        "url": "https://en.wikipedia.org/wiki/Regression_analysis",
        "title": "Regression analysis"
      },
      {
        "text": "Bias–variance tradeoff",
        "url": "https://en.wikipedia.org/wiki/Bias%E2%80%93variance_tradeoff",
        "title": "Bias–variance tradeoff"
      },
      {
        "text": "Double descent",
        "url": "https://en.wikipedia.org/wiki/Double_descent",
        "title": "Double descent"
      },
      {
        "text": "Overfitting",
        "url": "https://en.wikipedia.org/wiki/Overfitting",
        "title": "Overfitting"
      },
      {
        "text": "Clustering",
        "url": "https://en.wikipedia.org/wiki/Cluster_analysis",
        "title": "Cluster analysis"
      },
      {
        "text": "Gradient descent",
        "url": "https://en.wikipedia.org/wiki/Gradient_descent",
        "title": "Gradient descent"
      },
      {
        "text": "SGD",
        "url": "https://en.wikipedia.org/wiki/Stochastic_gradient_descent",
        "title": "Stochastic gradient descent"
      },
      {
        "text": "Quasi-Newton method",
        "url": "https://en.wikipedia.org/wiki/Quasi-Newton_method",
        "title": "Quasi-Newton method"
      },
      {
        "text": "Conjugate gradient method",
        "url": "https://en.wikipedia.org/wiki/Conjugate_gradient_method",
        "title": "Conjugate gradient method"
      },
      {
        "text": "Backpropagation",
        "url": "https://en.wikipedia.org/wiki/Backpropagation",
        "title": "Backpropagation"
      },
      {
        "text": "Attention",
        "url": "https://en.wikipedia.org/wiki/Attention_(machine_learning)",
        "title": "Attention (machine learning)"
      },
      {
        "text": "Convolution",
        "url": "https://en.wikipedia.org/wiki/Convolution",
        "title": "Convolution"
      },
      {
        "text": "Normalization",
        "url": "https://en.wikipedia.org/wiki/Normalization_(machine_learning)",
        "title": "Normalization (machine learning)"
      },
      {
        "text": "Batchnorm",
        "url": "https://en.wikipedia.org/wiki/Batch_normalization",
        "title": "Batch normalization"
      },
      {
        "text": "Activation",
        "url": "https://en.wikipedia.org/wiki/Activation_function",
        "title": "Activation function"
      },
      {
        "text": "Softmax",
        "url": "https://en.wikipedia.org/wiki/Softmax_function",
        "title": "Softmax function"
      },
      {
        "text": "Sigmoid",
        "url": "https://en.wikipedia.org/wiki/Sigmoid_function",
        "title": "Sigmoid function"
      },
      {
        "text": "Rectifier",
        "url": "https://en.wikipedia.org/wiki/Rectifier_(neural_networks)",
        "title": "Rectifier (neural networks)"
      },
      {
        "text": "Gating",
        "url": "https://en.wikipedia.org/wiki/Gating_mechanism",
        "title": "Gating mechanism"
      },
      {
        "text": "Weight initialization",
        "url": "https://en.wikipedia.org/wiki/Weight_initialization",
        "title": "Weight initialization"
      },
      {
        "text": "Regularization",
        "url": "https://en.wikipedia.org/wiki/Regularization_(mathematics)",
        "title": "Regularization (mathematics)"
      },
      {
        "text": "Datasets",
        "url": "https://en.wikipedia.org/wiki/Training,_validation,_and_test_data_sets",
        "title": "Training, validation, and test data sets"
      },
      {
        "text": "Augmentation",
        "url": "https://en.wikipedia.org/wiki/Data_augmentation",
        "title": "Data augmentation"
      },
      {
        "text": "Prompt engineering",
        "url": "https://en.wikipedia.org/wiki/Prompt_engineering",
        "title": "Prompt engineering"
      },
      {
        "text": "Reinforcement learning",
        "url": "https://en.wikipedia.org/wiki/Reinforcement_learning",
        "title": "Reinforcement learning"
      },
      {
        "text": "Q-learning",
        "url": "https://en.wikipedia.org/wiki/Q-learning",
        "title": "Q-learning"
      },
      {
        "text": "SARSA",
        "url": "https://en.wikipedia.org/wiki/State%E2%80%93action%E2%80%93reward%E2%80%93state%E2%80%93action",
        "title": "State–action–reward–state–action"
      },
      {
        "text": "Imitation",
        "url": "https://en.wikipedia.org/wiki/Imitation_learning",
        "title": "Imitation learning"
      },
      {
        "text": "Policy gradient",
        "url": "https://en.wikipedia.org/wiki/Policy_gradient_method",
        "title": "Policy gradient method"
      },
      {
        "text": "Diffusion",
        "url": "https://en.wikipedia.org/wiki/Diffusion_process",
        "title": "Diffusion process"
      },
      {
        "text": "Latent diffusion model",
        "url": "https://en.wikipedia.org/wiki/Latent_diffusion_model",
        "title": "Latent diffusion model"
      },
      {
        "text": "Autoregression",
        "url": "https://en.wikipedia.org/wiki/Autoregressive_model",
        "title": "Autoregressive model"
      },
      {
        "text": "Adversary",
        "url": "https://en.wikipedia.org/wiki/Adversarial_machine_learning",
        "title": "Adversarial machine learning"
      },
      {
        "text": "RAG",
        "url": "https://en.wikipedia.org/wiki/Retrieval-augmented_generation",
        "title": "Retrieval-augmented generation"
      },
      {
        "text": "Uncanny valley",
        "url": "https://en.wikipedia.org/wiki/Uncanny_valley",
        "title": "Uncanny valley"
      },
      {
        "text": "RLHF",
        "url": "https://en.wikipedia.org/wiki/Reinforcement_learning_from_human_feedback",
        "title": "Reinforcement learning from human feedback"
      },
      {
        "text": "Self-supervised learning",
        "url": "https://en.wikipedia.org/wiki/Self-supervised_learning",
        "title": "Self-supervised learning"
      },
      {
        "text": "Recursive self-improvement",
        "url": "https://en.wikipedia.org/wiki/Recursive_self-improvement",
        "title": "Recursive self-improvement"
      },
      {
        "text": "Word embedding",
        "url": "https://en.wikipedia.org/wiki/Word_embedding",
        "title": "Word embedding"
      },
      {
        "text": "Hallucination",
        "url": "https://en.wikipedia.org/wiki/Hallucination_(artificial_intelligence)",
        "title": "Hallucination (artificial intelligence)"
      },
      {
        "text": "Machine learning",
        "url": "https://en.wikipedia.org/wiki/Machine_learning",
        "title": "Machine learning"
      },
      {
        "text": "In-context learning",
        "url": "https://en.wikipedia.org/wiki/Prompt_engineering#In-context_learning",
        "title": "Prompt engineering"
      },
      {
        "text": "Artificial neural network",
        "url": "https://en.wikipedia.org/wiki/Neural_network_(machine_learning)",
        "title": "Neural network (machine learning)"
      },
      {
        "text": "Deep learning",
        "url": "https://en.wikipedia.org/wiki/Deep_learning",
        "title": "Deep learning"
      },
      {
        "text": "Language model",
        "url": "https://en.wikipedia.org/wiki/Language_model",
        "title": "Language model"
      },
      {
        "text": "Large language model",
        "url": "https://en.wikipedia.org/wiki/Large_language_model",
        "title": "Large language model"
      },
      {
        "text": "NMT",
        "url": "https://en.wikipedia.org/wiki/Neural_machine_translation",
        "title": "Neural machine translation"
      },
      {
        "text": "Agentic AI",
        "url": "https://en.wikipedia.org/wiki/Agentic_AI",
        "title": "Agentic AI"
      },
      {
        "text": "Intelligent agent",
        "url": "https://en.wikipedia.org/wiki/Intelligent_agent",
        "title": "Intelligent agent"
      },
      {
        "text": "Artificial general intelligence (AGI)",
        "url": "https://en.wikipedia.org/wiki/Artificial_general_intelligence",
        "title": "Artificial general intelligence"
      },
      {
        "text": "AlexNet",
        "url": "https://en.wikipedia.org/wiki/AlexNet",
        "title": "AlexNet"
      },
      {
        "text": "WaveNet",
        "url": "https://en.wikipedia.org/wiki/WaveNet",
        "title": "WaveNet"
      },
      {
        "text": "Human image synthesis",
        "url": "https://en.wikipedia.org/wiki/Human_image_synthesis",
        "title": "Human image synthesis"
      },
      {
        "text": "HWR",
        "url": "https://en.wikipedia.org/wiki/Handwriting_recognition",
        "title": "Handwriting recognition"
      },
      {
        "text": "OCR",
        "url": "https://en.wikipedia.org/wiki/Optical_character_recognition",
        "title": "Optical character recognition"
      },
      {
        "text": "Speech synthesis",
        "url": "https://en.wikipedia.org/wiki/Deep_learning_speech_synthesis",
        "title": "Deep learning speech synthesis"
      },
      {
        "text": "15.ai",
        "url": "https://en.wikipedia.org/wiki/15.ai",
        "title": "15.ai"
      },
      {
        "text": "ElevenLabs",
        "url": "https://en.wikipedia.org/wiki/ElevenLabs",
        "title": "ElevenLabs"
      },
      {
        "text": "Speech recognition",
        "url": "https://en.wikipedia.org/wiki/Speech_recognition",
        "title": "Speech recognition"
      },
      {
        "text": "Whisper",
        "url": "https://en.wikipedia.org/wiki/Whisper_(speech_recognition_system)",
        "title": "Whisper (speech recognition system)"
      },
      {
        "text": "Facial recognition",
        "url": "https://en.wikipedia.org/wiki/Facial_recognition_system",
        "title": "Facial recognition system"
      },
      {
        "text": "AlphaFold",
        "url": "https://en.wikipedia.org/wiki/AlphaFold",
        "title": "AlphaFold"
      },
      {
        "text": "Text-to-image models",
        "url": "https://en.wikipedia.org/wiki/Text-to-image_model",
        "title": "Text-to-image model"
      },
      {
        "text": "Aurora",
        "url": "https://en.wikipedia.org/wiki/Aurora_(text-to-image_model)",
        "title": "Aurora (text-to-image model)"
      },
      {
        "text": "DALL-E",
        "url": "https://en.wikipedia.org/wiki/DALL-E",
        "title": "DALL-E"
      },
      {
        "text": "Firefly",
        "url": "https://en.wikipedia.org/wiki/Adobe_Firefly",
        "title": "Adobe Firefly"
      },
      {
        "text": "Flux",
        "url": "https://en.wikipedia.org/wiki/Flux_(text-to-image_model)",
        "title": "Flux (text-to-image model)"
      },
      {
        "text": "Ideogram",
        "url": "https://en.wikipedia.org/wiki/Ideogram_(text-to-image_model)",
        "title": "Ideogram (text-to-image model)"
      },
      {
        "text": "Imagen",
        "url": "https://en.wikipedia.org/wiki/Imagen_(text-to-image_model)",
        "title": "Imagen (text-to-image model)"
      },
      {
        "text": "Midjourney",
        "url": "https://en.wikipedia.org/wiki/Midjourney",
        "title": "Midjourney"
      },
      {
        "text": "Stable Diffusion",
        "url": "https://en.wikipedia.org/wiki/Stable_Diffusion",
        "title": "Stable Diffusion"
      },
      {
        "text": "Text-to-video models",
        "url": "https://en.wikipedia.org/wiki/Text-to-video_model",
        "title": "Text-to-video model"
      },
      {
        "text": "Dream Machine",
        "url": "https://en.wikipedia.org/wiki/Dream_Machine_(text-to-video_model)",
        "title": "Dream Machine (text-to-video model)"
      },
      {
        "text": "Runway Gen",
        "url": "https://en.wikipedia.org/wiki/Runway_(company)",
        "title": "Runway (company)"
      },
      {
        "text": "Hailuo AI",
        "url": "https://en.wikipedia.org/wiki/MiniMax_(company)#Hailuo_AI",
        "title": "MiniMax (company)"
      },
      {
        "text": "Kling",
        "url": "https://en.wikipedia.org/wiki/Kling_(text-to-video_model)",
        "title": "Kling (text-to-video model)"
      },
      {
        "text": "Sora",
        "url": "https://en.wikipedia.org/wiki/Sora_(text-to-video_model)",
        "title": "Sora (text-to-video model)"
      },
      {
        "text": "Veo",
        "url": "https://en.wikipedia.org/wiki/Google_DeepMind#Video_generation",
        "title": "Google DeepMind"
      },
      {
        "text": "Music generation",
        "url": "https://en.wikipedia.org/wiki/Music_and_artificial_intelligence",
        "title": "Music and artificial intelligence"
      },
      {
        "text": "Suno AI",
        "url": "https://en.wikipedia.org/wiki/Suno_AI",
        "title": "Suno AI"
      },
      {
        "text": "Udio",
        "url": "https://en.wikipedia.org/wiki/Udio",
        "title": "Udio"
      },
      {
        "text": "Word2vec",
        "url": "https://en.wikipedia.org/wiki/Word2vec",
        "title": "Word2vec"
      },
      {
        "text": "Seq2seq",
        "url": "https://en.wikipedia.org/wiki/Seq2seq",
        "title": "Seq2seq"
      },
      {
        "text": "GloVe",
        "url": "https://en.wikipedia.org/wiki/GloVe",
        "title": "GloVe"
      },
      {
        "text": "BERT",
        "url": "https://en.wikipedia.org/wiki/BERT_(language_model)",
        "title": "BERT (language model)"
      },
      {
        "text": "T5",
        "url": "https://en.wikipedia.org/wiki/T5_(language_model)",
        "title": "T5 (language model)"
      },
      {
        "text": "Llama",
        "url": "https://en.wikipedia.org/wiki/Llama_(language_model)",
        "title": "Llama (language model)"
      },
      {
        "text": "Chinchilla AI",
        "url": "https://en.wikipedia.org/wiki/Chinchilla_(language_model)",
        "title": "Chinchilla (language model)"
      },
      {
        "text": "PaLM",
        "url": "https://en.wikipedia.org/wiki/PaLM",
        "title": "PaLM"
      },
      {
        "text": "GPT",
        "url": "https://en.wikipedia.org/wiki/Generative_pre-trained_transformer",
        "title": "Generative pre-trained transformer"
      },
      {
        "text": "1",
        "url": "https://en.wikipedia.org/wiki/GPT-1",
        "title": "GPT-1"
      },
      {
        "text": "2",
        "url": "https://en.wikipedia.org/wiki/GPT-2",
        "title": "GPT-2"
      },
      {
        "text": "3",
        "url": "https://en.wikipedia.org/wiki/GPT-3",
        "title": "GPT-3"
      },
      {
        "text": "J",
        "url": "https://en.wikipedia.org/wiki/GPT-J",
        "title": "GPT-J"
      },
      {
        "text": "ChatGPT",
        "url": "https://en.wikipedia.org/wiki/ChatGPT",
        "title": "ChatGPT"
      },
      {
        "text": "4",
        "url": "https://en.wikipedia.org/wiki/GPT-4",
        "title": "GPT-4"
      },
      {
        "text": "4o",
        "url": "https://en.wikipedia.org/wiki/GPT-4o",
        "title": "GPT-4o"
      },
      {
        "text": "o1",
        "url": "https://en.wikipedia.org/wiki/OpenAI_o1",
        "title": "OpenAI o1"
      },
      {
        "text": "o3",
        "url": "https://en.wikipedia.org/wiki/OpenAI_o3",
        "title": "OpenAI o3"
      },
      {
        "text": "4.5",
        "url": "https://en.wikipedia.org/wiki/GPT-4.5",
        "title": "GPT-4.5"
      },
      {
        "text": "4.1",
        "url": "https://en.wikipedia.org/wiki/GPT-4.1",
        "title": "GPT-4.1"
      },
      {
        "text": "o4",
        "url": "https://en.wikipedia.org/wiki/OpenAI_o4-mini",
        "title": "OpenAI o4-mini"
      },
      {
        "text": "Claude",
        "url": "https://en.wikipedia.org/wiki/Claude_(language_model)",
        "title": "Claude (language model)"
      },
      {
        "text": "Gemini",
        "url": "https://en.wikipedia.org/wiki/Gemini_(language_model)",
        "title": "Gemini (language model)"
      },
      {
        "text": "chatbot",
        "url": "https://en.wikipedia.org/wiki/Gemini_(chatbot)",
        "title": "Gemini (chatbot)"
      },
      {
        "text": "Grok",
        "url": "https://en.wikipedia.org/wiki/Grok_(chatbot)",
        "title": "Grok (chatbot)"
      },
      {
        "text": "LaMDA",
        "url": "https://en.wikipedia.org/wiki/LaMDA",
        "title": "LaMDA"
      },
      {
        "text": "BLOOM",
        "url": "https://en.wikipedia.org/wiki/BLOOM_(language_model)",
        "title": "BLOOM (language model)"
      },
      {
        "text": "Project Debater",
        "url": "https://en.wikipedia.org/wiki/Project_Debater",
        "title": "Project Debater"
      },
      {
        "text": "IBM Watson",
        "url": "https://en.wikipedia.org/wiki/IBM_Watson",
        "title": "IBM Watson"
      },
      {
        "text": "IBM Watsonx",
        "url": "https://en.wikipedia.org/wiki/IBM_Watsonx",
        "title": "IBM Watsonx"
      },
      {
        "text": "Granite",
        "url": "https://en.wikipedia.org/wiki/IBM_Granite",
        "title": "IBM Granite"
      },
      {
        "text": "PanGu-Σ",
        "url": "https://en.wikipedia.org/wiki/Huawei_PanGu",
        "title": "Huawei PanGu"
      },
      {
        "text": "DeepSeek",
        "url": "https://en.wikipedia.org/wiki/DeepSeek_(chatbot)",
        "title": "DeepSeek (chatbot)"
      },
      {
        "text": "Qwen",
        "url": "https://en.wikipedia.org/wiki/Qwen",
        "title": "Qwen"
      },
      {
        "text": "AlphaGo",
        "url": "https://en.wikipedia.org/wiki/AlphaGo",
        "title": "AlphaGo"
      },
      {
        "text": "AlphaZero",
        "url": "https://en.wikipedia.org/wiki/AlphaZero",
        "title": "AlphaZero"
      },
      {
        "text": "OpenAI Five",
        "url": "https://en.wikipedia.org/wiki/OpenAI_Five",
        "title": "OpenAI Five"
      },
      {
        "text": "Self-driving car",
        "url": "https://en.wikipedia.org/wiki/Self-driving_car",
        "title": "Self-driving car"
      },
      {
        "text": "MuZero",
        "url": "https://en.wikipedia.org/wiki/MuZero",
        "title": "MuZero"
      },
      {
        "text": "Action selection",
        "url": "https://en.wikipedia.org/wiki/Action_selection",
        "title": "Action selection"
      },
      {
        "text": "AutoGPT",
        "url": "https://en.wikipedia.org/wiki/AutoGPT",
        "title": "AutoGPT"
      },
      {
        "text": "Robot control",
        "url": "https://en.wikipedia.org/wiki/Robot_control",
        "title": "Robot control"
      },
      {
        "text": "Alan Turing",
        "url": "https://en.wikipedia.org/wiki/Alan_Turing",
        "title": "Alan Turing"
      },
      {
        "text": "Warren Sturgis McCulloch",
        "url": "https://en.wikipedia.org/wiki/Warren_Sturgis_McCulloch",
        "title": "Warren Sturgis McCulloch"
      },
      {
        "text": "Walter Pitts",
        "url": "https://en.wikipedia.org/wiki/Walter_Pitts",
        "title": "Walter Pitts"
      },
      {
        "text": "John von Neumann",
        "url": "https://en.wikipedia.org/wiki/John_von_Neumann",
        "title": "John von Neumann"
      },
      {
        "text": "Claude Shannon",
        "url": "https://en.wikipedia.org/wiki/Claude_Shannon",
        "title": "Claude Shannon"
      },
      {
        "text": "Marvin Minsky",
        "url": "https://en.wikipedia.org/wiki/Marvin_Minsky",
        "title": "Marvin Minsky"
      },
      {
        "text": "John McCarthy",
        "url": "https://en.wikipedia.org/wiki/John_McCarthy_(computer_scientist)",
        "title": "John McCarthy (computer scientist)"
      },
      {
        "text": "Nathaniel Rochester",
        "url": "https://en.wikipedia.org/wiki/Nathaniel_Rochester_(computer_scientist)",
        "title": "Nathaniel Rochester (computer scientist)"
      },
      {
        "text": "Allen Newell",
        "url": "https://en.wikipedia.org/wiki/Allen_Newell",
        "title": "Allen Newell"
      },
      {
        "text": "Cliff Shaw",
        "url": "https://en.wikipedia.org/wiki/Cliff_Shaw",
        "title": "Cliff Shaw"
      },
      {
        "text": "Herbert A. Simon",
        "url": "https://en.wikipedia.org/wiki/Herbert_A._Simon",
        "title": "Herbert A. Simon"
      },
      {
        "text": "Oliver Selfridge",
        "url": "https://en.wikipedia.org/wiki/Oliver_Selfridge",
        "title": "Oliver Selfridge"
      },
      {
        "text": "Frank Rosenblatt",
        "url": "https://en.wikipedia.org/wiki/Frank_Rosenblatt",
        "title": "Frank Rosenblatt"
      },
      {
        "text": "Bernard Widrow",
        "url": "https://en.wikipedia.org/wiki/Bernard_Widrow",
        "title": "Bernard Widrow"
      },
      {
        "text": "Joseph Weizenbaum",
        "url": "https://en.wikipedia.org/wiki/Joseph_Weizenbaum",
        "title": "Joseph Weizenbaum"
      },
      {
        "text": "Seymour Papert",
        "url": "https://en.wikipedia.org/wiki/Seymour_Papert",
        "title": "Seymour Papert"
      },
      {
        "text": "Seppo Linnainmaa",
        "url": "https://en.wikipedia.org/wiki/Seppo_Linnainmaa",
        "title": "Seppo Linnainmaa"
      },
      {
        "text": "Paul Werbos",
        "url": "https://en.wikipedia.org/wiki/Paul_Werbos",
        "title": "Paul Werbos"
      },
      {
        "text": "Jürgen Schmidhuber",
        "url": "https://en.wikipedia.org/wiki/J%C3%BCrgen_Schmidhuber",
        "title": "Jürgen Schmidhuber"
      },
      {
        "text": "Yann LeCun",
        "url": "https://en.wikipedia.org/wiki/Yann_LeCun",
        "title": "Yann LeCun"
      },
      {
        "text": "Geoffrey Hinton",
        "url": "https://en.wikipedia.org/wiki/Geoffrey_Hinton",
        "title": "Geoffrey Hinton"
      },
      {
        "text": "John Hopfield",
        "url": "https://en.wikipedia.org/wiki/John_Hopfield",
        "title": "John Hopfield"
      },
      {
        "text": "Yoshua Bengio",
        "url": "https://en.wikipedia.org/wiki/Yoshua_Bengio",
        "title": "Yoshua Bengio"
      },
      {
        "text": "Lotfi A. Zadeh",
        "url": "https://en.wikipedia.org/wiki/Lotfi_A._Zadeh",
        "title": "Lotfi A. Zadeh"
      },
      {
        "text": "Stephen Grossberg",
        "url": "https://en.wikipedia.org/wiki/Stephen_Grossberg",
        "title": "Stephen Grossberg"
      },
      {
        "text": "Alex Graves",
        "url": "https://en.wikipedia.org/wiki/Alex_Graves_(computer_scientist)",
        "title": "Alex Graves (computer scientist)"
      },
      {
        "text": "Andrew Ng",
        "url": "https://en.wikipedia.org/wiki/Andrew_Ng",
        "title": "Andrew Ng"
      },
      {
        "text": "Fei-Fei Li",
        "url": "https://en.wikipedia.org/wiki/Fei-Fei_Li",
        "title": "Fei-Fei Li"
      },
      {
        "text": "Alex Krizhevsky",
        "url": "https://en.wikipedia.org/wiki/Alex_Krizhevsky",
        "title": "Alex Krizhevsky"
      },
      {
        "text": "Ilya Sutskever",
        "url": "https://en.wikipedia.org/wiki/Ilya_Sutskever",
        "title": "Ilya Sutskever"
      },
      {
        "text": "Demis Hassabis",
        "url": "https://en.wikipedia.org/wiki/Demis_Hassabis",
        "title": "Demis Hassabis"
      },
      {
        "text": "David Silver",
        "url": "https://en.wikipedia.org/wiki/David_Silver_(computer_scientist)",
        "title": "David Silver (computer scientist)"
      },
      {
        "text": "Ian Goodfellow",
        "url": "https://en.wikipedia.org/wiki/Ian_Goodfellow",
        "title": "Ian Goodfellow"
      },
      {
        "text": "Andrej Karpathy",
        "url": "https://en.wikipedia.org/wiki/Andrej_Karpathy",
        "title": "Andrej Karpathy"
      },
      {
        "text": "James Goodnight",
        "url": "https://en.wikipedia.org/wiki/James_Goodnight",
        "title": "James Goodnight"
      },
      {
        "text": "Neural Turing machine",
        "url": "https://en.wikipedia.org/wiki/Neural_Turing_machine",
        "title": "Neural Turing machine"
      },
      {
        "text": "Differentiable neural computer",
        "url": "https://en.wikipedia.org/wiki/Differentiable_neural_computer",
        "title": "Differentiable neural computer"
      },
      {
        "text": "Transformer",
        "url": "https://en.wikipedia.org/wiki/Transformer_(deep_learning_architecture)",
        "title": "Transformer (deep learning architecture)"
      },
      {
        "text": "Vision transformer (ViT)",
        "url": "https://en.wikipedia.org/wiki/Vision_transformer",
        "title": "Vision transformer"
      },
      {
        "text": "Recurrent neural network (RNN)",
        "url": "https://en.wikipedia.org/wiki/Recurrent_neural_network",
        "title": "Recurrent neural network"
      },
      {
        "text": "Long short-term memory (LSTM)",
        "url": "https://en.wikipedia.org/wiki/Long_short-term_memory",
        "title": "Long short-term memory"
      },
      {
        "text": "Gated recurrent unit (GRU)",
        "url": "https://en.wikipedia.org/wiki/Gated_recurrent_unit",
        "title": "Gated recurrent unit"
      },
      {
        "text": "Echo state network",
        "url": "https://en.wikipedia.org/wiki/Echo_state_network",
        "title": "Echo state network"
      },
      {
        "text": "Multilayer perceptron (MLP)",
        "url": "https://en.wikipedia.org/wiki/Multilayer_perceptron",
        "title": "Multilayer perceptron"
      },
      {
        "text": "Convolutional neural network (CNN)",
        "url": "https://en.wikipedia.org/wiki/Convolutional_neural_network",
        "title": "Convolutional neural network"
      },
      {
        "text": "Residual neural network (RNN)",
        "url": "https://en.wikipedia.org/wiki/Residual_neural_network",
        "title": "Residual neural network"
      },
      {
        "text": "Highway network",
        "url": "https://en.wikipedia.org/wiki/Highway_network",
        "title": "Highway network"
      },
      {
        "text": "Mamba",
        "url": "https://en.wikipedia.org/wiki/Mamba_(deep_learning_architecture)",
        "title": "Mamba (deep learning architecture)"
      },
      {
        "text": "Autoencoder",
        "url": "https://en.wikipedia.org/wiki/Autoencoder",
        "title": "Autoencoder"
      },
      {
        "text": "Variational autoencoder (VAE)",
        "url": "https://en.wikipedia.org/wiki/Variational_autoencoder",
        "title": "Variational autoencoder"
      },
      {
        "text": "Generative adversarial network (GAN)",
        "url": "https://en.wikipedia.org/wiki/Generative_adversarial_network",
        "title": "Generative adversarial network"
      },
      {
        "text": "Graph neural network (GNN)",
        "url": "https://en.wikipedia.org/wiki/Graph_neural_network",
        "title": "Graph neural network"
      },
      {
        "text": "Technology",
        "url": "https://en.wikipedia.org/wiki/Portal:Technology",
        "title": "Portal:Technology"
      },
      {
        "text": "Category",
        "url": "https://en.wikipedia.org/wiki/Category:Artificial_intelligence",
        "title": "Category:Artificial intelligence"
      },
      {
        "text": "Artificial neural networks",
        "url": "https://en.wikipedia.org/wiki/Category:Artificial_neural_networks",
        "title": "Category:Artificial neural networks"
      },
      {
        "text": "Machine learning",
        "url": "https://en.wikipedia.org/wiki/Category:Machine_learning",
        "title": "Category:Machine learning"
      },
      {
        "text": "Companies",
        "url": "https://en.wikipedia.org/wiki/List_of_artificial_intelligence_companies",
        "title": "List of artificial intelligence companies"
      },
      {
        "text": "Projects",
        "url": "https://en.wikipedia.org/wiki/List_of_artificial_intelligence_projects",
        "title": "List of artificial intelligence projects"
      },
      {
        "text": "v",
        "url": "https://en.wikipedia.org/wiki/Template:John_McCarthy",
        "title": "Template:John McCarthy"
      },
      {
        "text": "t",
        "url": "https://en.wikipedia.org/wiki/Template_talk:John_McCarthy",
        "title": "Template talk:John McCarthy"
      },
      {
        "text": "e",
        "url": "https://en.wikipedia.org/wiki/Special:EditPage/Template:John_McCarthy",
        "title": "Special:EditPage/Template:John McCarthy"
      },
      {
        "text": "John McCarthy",
        "url": "https://en.wikipedia.org/wiki/John_McCarthy_(computer_scientist)",
        "title": "John McCarthy (computer scientist)"
      },
      {
        "text": "Circumscription",
        "url": "https://en.wikipedia.org/wiki/Circumscription_(logic)",
        "title": "Circumscription (logic)"
      },
      {
        "text": "Dartmouth workshop",
        "url": "https://en.wikipedia.org/wiki/Dartmouth_workshop",
        "title": "Dartmouth workshop"
      },
      {
        "text": "Frame problem",
        "url": "https://en.wikipedia.org/wiki/Frame_problem",
        "title": "Frame problem"
      },
      {
        "text": "Garbage collection",
        "url": "https://en.wikipedia.org/wiki/Garbage_collection_(computer_science)",
        "title": "Garbage collection (computer science)"
      },
      {
        "text": "Lisp",
        "url": "https://en.wikipedia.org/wiki/Lisp_(programming_language)",
        "title": "Lisp (programming language)"
      },
      {
        "text": "ALGOL 60",
        "url": "https://en.wikipedia.org/wiki/ALGOL_60",
        "title": "ALGOL 60"
      },
      {
        "text": "McCarthy evaluation",
        "url": "https://en.wikipedia.org/wiki/Short-circuit_evaluation",
        "title": "Short-circuit evaluation"
      },
      {
        "text": "McCarthy Formalism",
        "url": "https://en.wikipedia.org/wiki/McCarthy_Formalism",
        "title": "McCarthy Formalism"
      },
      {
        "text": "McCarthy 91 function",
        "url": "https://en.wikipedia.org/wiki/McCarthy_91_function",
        "title": "McCarthy 91 function"
      },
      {
        "text": "Situation calculus",
        "url": "https://en.wikipedia.org/wiki/Situation_calculus",
        "title": "Situation calculus"
      },
      {
        "text": "Space fountain",
        "url": "https://en.wikipedia.org/wiki/Space_fountain",
        "title": "Space fountain"
      },
      {
        "text": "v",
        "url": "https://en.wikipedia.org/wiki/Template:Philosophy_of_mind",
        "title": "Template:Philosophy of mind"
      },
      {
        "text": "t",
        "url": "https://en.wikipedia.org/wiki/Template_talk:Philosophy_of_mind",
        "title": "Template talk:Philosophy of mind"
      },
      {
        "text": "e",
        "url": "https://en.wikipedia.org/wiki/Special:EditPage/Template:Philosophy_of_mind",
        "title": "Special:EditPage/Template:Philosophy of mind"
      },
      {
        "text": "Philosophy of mind",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_mind",
        "title": "Philosophy of mind"
      },
      {
        "text": "Philosophers",
        "url": "https://en.wikipedia.org/wiki/Category:Philosophers_of_mind",
        "title": "Category:Philosophers of mind"
      },
      {
        "text": "G. E. M. Anscombe",
        "url": "https://en.wikipedia.org/wiki/G._E._M._Anscombe",
        "title": "G. E. M. Anscombe"
      },
      {
        "text": "Aristotle",
        "url": "https://en.wikipedia.org/wiki/Aristotle",
        "title": "Aristotle"
      },
      {
        "text": "Armstrong",
        "url": "https://en.wikipedia.org/wiki/David_Malet_Armstrong",
        "title": "David Malet Armstrong"
      },
      {
        "text": "Thomas Aquinas",
        "url": "https://en.wikipedia.org/wiki/Thomas_Aquinas",
        "title": "Thomas Aquinas"
      },
      {
        "text": "J. L. Austin",
        "url": "https://en.wikipedia.org/wiki/J._L._Austin",
        "title": "J. L. Austin"
      },
      {
        "text": "Alexander Bain",
        "url": "https://en.wikipedia.org/wiki/Alexander_Bain_(philosopher)",
        "title": "Alexander Bain (philosopher)"
      },
      {
        "text": "George Berkeley",
        "url": "https://en.wikipedia.org/wiki/George_Berkeley",
        "title": "George Berkeley"
      },
      {
        "text": "Henri Bergson",
        "url": "https://en.wikipedia.org/wiki/Henri_Bergson",
        "title": "Henri Bergson"
      },
      {
        "text": "Ned Block",
        "url": "https://en.wikipedia.org/wiki/Ned_Block",
        "title": "Ned Block"
      },
      {
        "text": "Franz Brentano",
        "url": "https://en.wikipedia.org/wiki/Franz_Brentano",
        "title": "Franz Brentano"
      },
      {
        "text": "C. D. Broad",
        "url": "https://en.wikipedia.org/wiki/C._D._Broad",
        "title": "C. D. Broad"
      },
      {
        "text": "Tyler Burge",
        "url": "https://en.wikipedia.org/wiki/Tyler_Burge",
        "title": "Tyler Burge"
      },
      {
        "text": "David Chalmers",
        "url": "https://en.wikipedia.org/wiki/David_Chalmers",
        "title": "David Chalmers"
      },
      {
        "text": "Patricia Churchland",
        "url": "https://en.wikipedia.org/wiki/Patricia_Churchland",
        "title": "Patricia Churchland"
      },
      {
        "text": "Paul Churchland",
        "url": "https://en.wikipedia.org/wiki/Paul_Churchland",
        "title": "Paul Churchland"
      },
      {
        "text": "Andy Clark",
        "url": "https://en.wikipedia.org/wiki/Andy_Clark",
        "title": "Andy Clark"
      },
      {
        "text": "Dharmakirti",
        "url": "https://en.wikipedia.org/wiki/Dharmakirti",
        "title": "Dharmakirti"
      },
      {
        "text": "Donald Davidson",
        "url": "https://en.wikipedia.org/wiki/Donald_Davidson_(philosopher)",
        "title": "Donald Davidson (philosopher)"
      },
      {
        "text": "Daniel Dennett",
        "url": "https://en.wikipedia.org/wiki/Daniel_Dennett",
        "title": "Daniel Dennett"
      },
      {
        "text": "René Descartes",
        "url": "https://en.wikipedia.org/wiki/Ren%C3%A9_Descartes",
        "title": "René Descartes"
      },
      {
        "text": "Fred Dretske",
        "url": "https://en.wikipedia.org/wiki/Fred_Dretske",
        "title": "Fred Dretske"
      },
      {
        "text": "Fodor",
        "url": "https://en.wikipedia.org/wiki/Jerry_Fodor",
        "title": "Jerry Fodor"
      },
      {
        "text": "Goldman",
        "url": "https://en.wikipedia.org/wiki/Alvin_Goldman",
        "title": "Alvin Goldman"
      },
      {
        "text": "Martin Heidegger",
        "url": "https://en.wikipedia.org/wiki/Martin_Heidegger",
        "title": "Martin Heidegger"
      },
      {
        "text": "David Hume",
        "url": "https://en.wikipedia.org/wiki/David_Hume",
        "title": "David Hume"
      },
      {
        "text": "Edmund Husserl",
        "url": "https://en.wikipedia.org/wiki/Edmund_Husserl",
        "title": "Edmund Husserl"
      },
      {
        "text": "William James",
        "url": "https://en.wikipedia.org/wiki/William_James",
        "title": "William James"
      },
      {
        "text": "Frank Cameron Jackson",
        "url": "https://en.wikipedia.org/wiki/Frank_Cameron_Jackson",
        "title": "Frank Cameron Jackson"
      },
      {
        "text": "Immanuel Kant",
        "url": "https://en.wikipedia.org/wiki/Immanuel_Kant",
        "title": "Immanuel Kant"
      },
      {
        "text": "David Lewis (philosopher)",
        "url": "https://en.wikipedia.org/wiki/David_Lewis_(philosopher)",
        "title": "David Lewis (philosopher)"
      },
      {
        "text": "John Locke",
        "url": "https://en.wikipedia.org/wiki/John_Locke",
        "title": "John Locke"
      },
      {
        "text": "Gottfried Wilhelm Leibniz",
        "url": "https://en.wikipedia.org/wiki/Gottfried_Wilhelm_Leibniz",
        "title": "Gottfried Wilhelm Leibniz"
      },
      {
        "text": "Maurice Merleau-Ponty",
        "url": "https://en.wikipedia.org/wiki/Maurice_Merleau-Ponty",
        "title": "Maurice Merleau-Ponty"
      },
      {
        "text": "Marvin Minsky",
        "url": "https://en.wikipedia.org/wiki/Marvin_Minsky",
        "title": "Marvin Minsky"
      },
      {
        "text": "Thomas Nagel",
        "url": "https://en.wikipedia.org/wiki/Thomas_Nagel",
        "title": "Thomas Nagel"
      },
      {
        "text": "Alva Noë",
        "url": "https://en.wikipedia.org/wiki/Alva_No%C3%AB",
        "title": "Alva Noë"
      },
      {
        "text": "Derek Parfit",
        "url": "https://en.wikipedia.org/wiki/Derek_Parfit",
        "title": "Derek Parfit"
      },
      {
        "text": "Plato",
        "url": "https://en.wikipedia.org/wiki/Plato",
        "title": "Plato"
      },
      {
        "text": "Hilary Putnam",
        "url": "https://en.wikipedia.org/wiki/Hilary_Putnam",
        "title": "Hilary Putnam"
      },
      {
        "text": "Richard Rorty",
        "url": "https://en.wikipedia.org/wiki/Richard_Rorty",
        "title": "Richard Rorty"
      },
      {
        "text": "Gilbert Ryle",
        "url": "https://en.wikipedia.org/wiki/Gilbert_Ryle",
        "title": "Gilbert Ryle"
      },
      {
        "text": "John Searle",
        "url": "https://en.wikipedia.org/wiki/John_Searle",
        "title": "John Searle"
      },
      {
        "text": "Wilfrid Sellars",
        "url": "https://en.wikipedia.org/wiki/Wilfrid_Sellars",
        "title": "Wilfrid Sellars"
      },
      {
        "text": "Baruch Spinoza",
        "url": "https://en.wikipedia.org/wiki/Baruch_Spinoza",
        "title": "Baruch Spinoza"
      },
      {
        "text": "Alan Turing",
        "url": "https://en.wikipedia.org/wiki/Alan_Turing",
        "title": "Alan Turing"
      },
      {
        "text": "Michael Tye",
        "url": "https://en.wikipedia.org/wiki/Michael_Tye_(philosopher)",
        "title": "Michael Tye (philosopher)"
      },
      {
        "text": "Vasubandhu",
        "url": "https://en.wikipedia.org/wiki/Vasubandhu",
        "title": "Vasubandhu"
      },
      {
        "text": "Ludwig Wittgenstein",
        "url": "https://en.wikipedia.org/wiki/Ludwig_Wittgenstein",
        "title": "Ludwig Wittgenstein"
      },
      {
        "text": "Stephen Yablo",
        "url": "https://en.wikipedia.org/wiki/Stephen_Yablo",
        "title": "Stephen Yablo"
      },
      {
        "text": "Zhuangzi",
        "url": "https://en.wikipedia.org/wiki/Zhuang_Zhou",
        "title": "Zhuang Zhou"
      },
      {
        "text": "more...",
        "url": "https://en.wikipedia.org/wiki/List_of_philosophers_of_mind",
        "title": "List of philosophers of mind"
      },
      {
        "text": "Behaviorism",
        "url": "https://en.wikipedia.org/wiki/Behaviorism",
        "title": "Behaviorism"
      },
      {
        "text": "Biological naturalism",
        "url": "https://en.wikipedia.org/wiki/Biological_naturalism",
        "title": "Biological naturalism"
      },
      {
        "text": "Dualism",
        "url": "https://en.wikipedia.org/wiki/Mind%E2%80%93body_dualism",
        "title": "Mind–body dualism"
      },
      {
        "text": "Eliminative materialism",
        "url": "https://en.wikipedia.org/wiki/Eliminative_materialism",
        "title": "Eliminative materialism"
      },
      {
        "text": "Emergent materialism",
        "url": "https://en.wikipedia.org/wiki/Emergent_materialism",
        "title": "Emergent materialism"
      },
      {
        "text": "Epiphenomenalism",
        "url": "https://en.wikipedia.org/wiki/Epiphenomenalism",
        "title": "Epiphenomenalism"
      },
      {
        "text": "Functionalism",
        "url": "https://en.wikipedia.org/wiki/Functionalism_(philosophy_of_mind)",
        "title": "Functionalism (philosophy of mind)"
      },
      {
        "text": "Interactionism",
        "url": "https://en.wikipedia.org/wiki/Interactionism_(philosophy_of_mind)",
        "title": "Interactionism (philosophy of mind)"
      },
      {
        "text": "Naïve realism",
        "url": "https://en.wikipedia.org/wiki/Na%C3%AFve_realism",
        "title": "Naïve realism"
      },
      {
        "text": "Neurophenomenology",
        "url": "https://en.wikipedia.org/wiki/Neurophenomenology",
        "title": "Neurophenomenology"
      },
      {
        "text": "Neutral monism",
        "url": "https://en.wikipedia.org/wiki/Neutral_monism",
        "title": "Neutral monism"
      },
      {
        "text": "New mysterianism",
        "url": "https://en.wikipedia.org/wiki/New_mysterianism",
        "title": "New mysterianism"
      },
      {
        "text": "Nondualism",
        "url": "https://en.wikipedia.org/wiki/Nondualism",
        "title": "Nondualism"
      },
      {
        "text": "Occasionalism",
        "url": "https://en.wikipedia.org/wiki/Occasionalism",
        "title": "Occasionalism"
      },
      {
        "text": "Parallelism",
        "url": "https://en.wikipedia.org/wiki/Psychophysical_parallelism",
        "title": "Psychophysical parallelism"
      },
      {
        "text": "Phenomenalism",
        "url": "https://en.wikipedia.org/wiki/Phenomenalism",
        "title": "Phenomenalism"
      },
      {
        "text": "Phenomenology",
        "url": "https://en.wikipedia.org/wiki/Phenomenology_(philosophy)",
        "title": "Phenomenology (philosophy)"
      },
      {
        "text": "Physicalism",
        "url": "https://en.wikipedia.org/wiki/Physicalism",
        "title": "Physicalism"
      },
      {
        "text": "Type physicalism",
        "url": "https://en.wikipedia.org/wiki/Type_physicalism",
        "title": "Type physicalism"
      },
      {
        "text": "Property dualism",
        "url": "https://en.wikipedia.org/wiki/Property_dualism",
        "title": "Property dualism"
      },
      {
        "text": "Representational",
        "url": "https://en.wikipedia.org/wiki/Mental_representation",
        "title": "Mental representation"
      },
      {
        "text": "Solipsism",
        "url": "https://en.wikipedia.org/wiki/Solipsism",
        "title": "Solipsism"
      },
      {
        "text": "Substance dualism",
        "url": "https://en.wikipedia.org/wiki/Substance_dualism",
        "title": "Substance dualism"
      },
      {
        "text": "Abstract object",
        "url": "https://en.wikipedia.org/wiki/Abstract_and_concrete",
        "title": "Abstract and concrete"
      },
      {
        "text": "Chinese room",
        "url": "https://en.wikipedia.org/wiki/Chinese_room",
        "title": "Chinese room"
      },
      {
        "text": "Creativity",
        "url": "https://en.wikipedia.org/wiki/Creativity",
        "title": "Creativity"
      },
      {
        "text": "Cognition",
        "url": "https://en.wikipedia.org/wiki/Cognition",
        "title": "Cognition"
      },
      {
        "text": "Cognitive closure",
        "url": "https://en.wikipedia.org/wiki/Cognitive_closure_(philosophy)",
        "title": "Cognitive closure (philosophy)"
      },
      {
        "text": "Concept",
        "url": "https://en.wikipedia.org/wiki/Concept",
        "title": "Concept"
      },
      {
        "text": "Consciousness",
        "url": "https://en.wikipedia.org/wiki/Consciousness",
        "title": "Consciousness"
      },
      {
        "text": "Hard problem of consciousness",
        "url": "https://en.wikipedia.org/wiki/Hard_problem_of_consciousness",
        "title": "Hard problem of consciousness"
      },
      {
        "text": "Hypostatic abstraction",
        "url": "https://en.wikipedia.org/wiki/Hypostatic_abstraction",
        "title": "Hypostatic abstraction"
      },
      {
        "text": "Idea",
        "url": "https://en.wikipedia.org/wiki/Idea",
        "title": "Idea"
      },
      {
        "text": "Identity",
        "url": "https://en.wikipedia.org/wiki/Identity_(philosophy)",
        "title": "Identity (philosophy)"
      },
      {
        "text": "Intelligence",
        "url": "https://en.wikipedia.org/wiki/Intelligence",
        "title": "Intelligence"
      },
      {
        "text": "Human",
        "url": "https://en.wikipedia.org/wiki/Human_intelligence",
        "title": "Human intelligence"
      },
      {
        "text": "Intentionality",
        "url": "https://en.wikipedia.org/wiki/Intentionality",
        "title": "Intentionality"
      },
      {
        "text": "Introspection",
        "url": "https://en.wikipedia.org/wiki/Introspection",
        "title": "Introspection"
      },
      {
        "text": "Intuition",
        "url": "https://en.wikipedia.org/wiki/Intuition",
        "title": "Intuition"
      },
      {
        "text": "Language of thought",
        "url": "https://en.wikipedia.org/wiki/Language_of_thought_hypothesis",
        "title": "Language of thought hypothesis"
      },
      {
        "text": "Mental event",
        "url": "https://en.wikipedia.org/wiki/Mental_event",
        "title": "Mental event"
      },
      {
        "text": "Mental image",
        "url": "https://en.wikipedia.org/wiki/Mental_image",
        "title": "Mental image"
      },
      {
        "text": "Mental process",
        "url": "https://en.wikipedia.org/wiki/Template:Mental_processes",
        "title": "Template:Mental processes"
      },
      {
        "text": "Mental property",
        "url": "https://en.wikipedia.org/wiki/Mental_state",
        "title": "Mental state"
      },
      {
        "text": "Mental representation",
        "url": "https://en.wikipedia.org/wiki/Mental_representation",
        "title": "Mental representation"
      },
      {
        "text": "Mind",
        "url": "https://en.wikipedia.org/wiki/Mind",
        "title": "Mind"
      },
      {
        "text": "Mind–body problem",
        "url": "https://en.wikipedia.org/wiki/Mind%E2%80%93body_problem",
        "title": "Mind–body problem"
      },
      {
        "text": "Pain",
        "url": "https://en.wikipedia.org/wiki/Pain_(philosophy)",
        "title": "Pain (philosophy)"
      },
      {
        "text": "Problem of other minds",
        "url": "https://en.wikipedia.org/wiki/Problem_of_other_minds",
        "title": "Problem of other minds"
      },
      {
        "text": "Propositional attitude",
        "url": "https://en.wikipedia.org/wiki/Propositional_attitude",
        "title": "Propositional attitude"
      },
      {
        "text": "Qualia",
        "url": "https://en.wikipedia.org/wiki/Qualia",
        "title": "Qualia"
      },
      {
        "text": "Tabula rasa",
        "url": "https://en.wikipedia.org/wiki/Tabula_rasa",
        "title": "Tabula rasa"
      },
      {
        "text": "Understanding",
        "url": "https://en.wikipedia.org/wiki/Understanding",
        "title": "Understanding"
      },
      {
        "text": "Zombie",
        "url": "https://en.wikipedia.org/wiki/Philosophical_zombie",
        "title": "Philosophical zombie"
      },
      {
        "text": "Metaphysics",
        "url": "https://en.wikipedia.org/wiki/Metaphysics",
        "title": "Metaphysics"
      },
      {
        "text": "Philosophy of artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_artificial_intelligence",
        "title": "Philosophy of artificial intelligence"
      },
      {
        "text": "information",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_information",
        "title": "Philosophy of information"
      },
      {
        "text": "perception",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_perception",
        "title": "Philosophy of perception"
      },
      {
        "text": "self",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_self",
        "title": "Philosophy of self"
      },
      {
        "text": "Category",
        "url": "https://en.wikipedia.org/wiki/Category:Philosophy_of_mind",
        "title": "Category:Philosophy of mind"
      },
      {
        "text": "Philosophers category",
        "url": "https://en.wikipedia.org/wiki/Category:Philosophers_of_mind",
        "title": "Category:Philosophers of mind"
      },
      {
        "text": "Project",
        "url": "https://en.wikipedia.org/wiki/Wikipedia:WikiProject_Philosophy",
        "title": "Wikipedia:WikiProject Philosophy"
      },
      {
        "text": "Task Force",
        "url": "https://en.wikipedia.org/wiki/Wikipedia:WikiProject_Philosophy/Mind",
        "title": "Wikipedia:WikiProject Philosophy/Mind"
      },
      {
        "text": "v",
        "url": "https://en.wikipedia.org/wiki/Template:Philosophy_of_science",
        "title": "Template:Philosophy of science"
      },
      {
        "text": "t",
        "url": "https://en.wikipedia.org/wiki/Template_talk:Philosophy_of_science",
        "title": "Template talk:Philosophy of science"
      },
      {
        "text": "e",
        "url": "https://en.wikipedia.org/wiki/Special:EditPage/Template:Philosophy_of_science",
        "title": "Special:EditPage/Template:Philosophy of science"
      },
      {
        "text": "Philosophy of science",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_science",
        "title": "Philosophy of science"
      },
      {
        "text": "Analysis",
        "url": "https://en.wikipedia.org/wiki/Philosophical_analysis",
        "title": "Philosophical analysis"
      },
      {
        "text": "Analytic–synthetic distinction",
        "url": "https://en.wikipedia.org/wiki/Analytic%E2%80%93synthetic_distinction",
        "title": "Analytic–synthetic distinction"
      },
      {
        "text": "A priori and a posteriori",
        "url": "https://en.wikipedia.org/wiki/A_priori_and_a_posteriori",
        "title": "A priori and a posteriori"
      },
      {
        "text": "Causality",
        "url": "https://en.wikipedia.org/wiki/Causality",
        "title": "Causality"
      },
      {
        "text": "Mill's Methods",
        "url": "https://en.wikipedia.org/wiki/Mill%27s_Methods",
        "title": "Mill's Methods"
      },
      {
        "text": "Commensurability",
        "url": "https://en.wikipedia.org/wiki/Commensurability_(philosophy_of_science)",
        "title": "Commensurability (philosophy of science)"
      },
      {
        "text": "Consilience",
        "url": "https://en.wikipedia.org/wiki/Consilience",
        "title": "Consilience"
      },
      {
        "text": "Construct",
        "url": "https://en.wikipedia.org/wiki/Construct_(philosophy)",
        "title": "Construct (philosophy)"
      },
      {
        "text": "Correlation",
        "url": "https://en.wikipedia.org/wiki/Correlation",
        "title": "Correlation"
      },
      {
        "text": "function",
        "url": "https://en.wikipedia.org/wiki/Correlation_function",
        "title": "Correlation function"
      },
      {
        "text": "Creative synthesis",
        "url": "https://en.wikipedia.org/wiki/Creative_synthesis",
        "title": "Creative synthesis"
      },
      {
        "text": "Demarcation problem",
        "url": "https://en.wikipedia.org/wiki/Demarcation_problem",
        "title": "Demarcation problem"
      },
      {
        "text": "Empirical evidence",
        "url": "https://en.wikipedia.org/wiki/Empirical_evidence",
        "title": "Empirical evidence"
      },
      {
        "text": "Experiment",
        "url": "https://en.wikipedia.org/wiki/Experiment",
        "title": "Experiment"
      },
      {
        "text": "design",
        "url": "https://en.wikipedia.org/wiki/Design_of_experiments",
        "title": "Design of experiments"
      },
      {
        "text": "Explanatory power",
        "url": "https://en.wikipedia.org/wiki/Explanatory_power",
        "title": "Explanatory power"
      },
      {
        "text": "Fact",
        "url": "https://en.wikipedia.org/wiki/Fact",
        "title": "Fact"
      },
      {
        "text": "Falsifiability",
        "url": "https://en.wikipedia.org/wiki/Falsifiability",
        "title": "Falsifiability"
      },
      {
        "text": "Feminist method",
        "url": "https://en.wikipedia.org/wiki/Feminist_method",
        "title": "Feminist method"
      },
      {
        "text": "Functional contextualism",
        "url": "https://en.wikipedia.org/wiki/Functional_contextualism",
        "title": "Functional contextualism"
      },
      {
        "text": "Hypothesis",
        "url": "https://en.wikipedia.org/wiki/Hypothesis",
        "title": "Hypothesis"
      },
      {
        "text": "alternative",
        "url": "https://en.wikipedia.org/wiki/Alternative_hypothesis",
        "title": "Alternative hypothesis"
      },
      {
        "text": "null",
        "url": "https://en.wikipedia.org/wiki/Null_hypothesis",
        "title": "Null hypothesis"
      },
      {
        "text": "Ignoramus et ignorabimus",
        "url": "https://en.wikipedia.org/wiki/Ignoramus_et_ignorabimus",
        "title": "Ignoramus et ignorabimus"
      },
      {
        "text": "Inductive reasoning",
        "url": "https://en.wikipedia.org/wiki/Inductive_reasoning",
        "title": "Inductive reasoning"
      },
      {
        "text": "Intertheoretic reduction",
        "url": "https://en.wikipedia.org/wiki/Intertheoretic_reduction",
        "title": "Intertheoretic reduction"
      },
      {
        "text": "Inquiry",
        "url": "https://en.wikipedia.org/wiki/Inquiry",
        "title": "Inquiry"
      },
      {
        "text": "Measurement",
        "url": "https://en.wikipedia.org/wiki/Measurement",
        "title": "Measurement"
      },
      {
        "text": "Nature",
        "url": "https://en.wikipedia.org/wiki/Nature_(philosophy)",
        "title": "Nature (philosophy)"
      },
      {
        "text": "Objectivity",
        "url": "https://en.wikipedia.org/wiki/Objectivity_(philosophy)",
        "title": "Objectivity (philosophy)"
      },
      {
        "text": "Observation",
        "url": "https://en.wikipedia.org/wiki/Observation",
        "title": "Observation"
      },
      {
        "text": "Paradigm",
        "url": "https://en.wikipedia.org/wiki/Paradigm",
        "title": "Paradigm"
      },
      {
        "text": "Problem of induction",
        "url": "https://en.wikipedia.org/wiki/Problem_of_induction",
        "title": "Problem of induction"
      },
      {
        "text": "Scientific evidence",
        "url": "https://en.wikipedia.org/wiki/Scientific_evidence",
        "title": "Scientific evidence"
      },
      {
        "text": "Evidence-based practice",
        "url": "https://en.wikipedia.org/wiki/Evidence-based_practice",
        "title": "Evidence-based practice"
      },
      {
        "text": "Scientific law",
        "url": "https://en.wikipedia.org/wiki/Scientific_law",
        "title": "Scientific law"
      },
      {
        "text": "Scientific method",
        "url": "https://en.wikipedia.org/wiki/Scientific_method",
        "title": "Scientific method"
      },
      {
        "text": "Scientific pluralism",
        "url": "https://en.wikipedia.org/wiki/Scientific_pluralism",
        "title": "Scientific pluralism"
      },
      {
        "text": "Scientific Revolution",
        "url": "https://en.wikipedia.org/wiki/Scientific_Revolution",
        "title": "Scientific Revolution"
      },
      {
        "text": "Testability",
        "url": "https://en.wikipedia.org/wiki/Testability",
        "title": "Testability"
      },
      {
        "text": "Theory",
        "url": "https://en.wikipedia.org/wiki/Theory",
        "title": "Theory"
      },
      {
        "text": "choice",
        "url": "https://en.wikipedia.org/wiki/Theory_choice",
        "title": "Theory choice"
      },
      {
        "text": "ladenness",
        "url": "https://en.wikipedia.org/wiki/Theory-ladenness",
        "title": "Theory-ladenness"
      },
      {
        "text": "scientific",
        "url": "https://en.wikipedia.org/wiki/Scientific_theory",
        "title": "Scientific theory"
      },
      {
        "text": "Underdetermination",
        "url": "https://en.wikipedia.org/wiki/Underdetermination",
        "title": "Underdetermination"
      },
      {
        "text": "Unity of science",
        "url": "https://en.wikipedia.org/wiki/Unity_of_science",
        "title": "Unity of science"
      },
      {
        "text": "Variable",
        "url": "https://en.wikipedia.org/wiki/Variable_and_attribute_(research)",
        "title": "Variable and attribute (research)"
      },
      {
        "text": "control",
        "url": "https://en.wikipedia.org/wiki/Control_variable",
        "title": "Control variable"
      },
      {
        "text": "dependent and independent",
        "url": "https://en.wikipedia.org/wiki/Dependent_and_independent_variables",
        "title": "Dependent and independent variables"
      },
      {
        "text": "more...",
        "url": "https://en.wikipedia.org/wiki/Index_of_philosophy_of_science_articles",
        "title": "Index of philosophy of science articles"
      },
      {
        "text": "Coherentism",
        "url": "https://en.wikipedia.org/wiki/Coherentism",
        "title": "Coherentism"
      },
      {
        "text": "Confirmation holism",
        "url": "https://en.wikipedia.org/wiki/Confirmation_holism",
        "title": "Confirmation holism"
      },
      {
        "text": "Constructive empiricism",
        "url": "https://en.wikipedia.org/wiki/Constructive_empiricism",
        "title": "Constructive empiricism"
      },
      {
        "text": "Constructive realism",
        "url": "https://en.wikipedia.org/wiki/Constructive_realism",
        "title": "Constructive realism"
      },
      {
        "text": "Constructivist epistemology",
        "url": "https://en.wikipedia.org/wiki/Constructivist_epistemology",
        "title": "Constructivist epistemology"
      },
      {
        "text": "Contextualism",
        "url": "https://en.wikipedia.org/wiki/Contextualism",
        "title": "Contextualism"
      },
      {
        "text": "Conventionalism",
        "url": "https://en.wikipedia.org/wiki/Conventionalism",
        "title": "Conventionalism"
      },
      {
        "text": "Deductive-nomological model",
        "url": "https://en.wikipedia.org/wiki/Deductive-nomological_model",
        "title": "Deductive-nomological model"
      },
      {
        "text": "Epistemological anarchism",
        "url": "https://en.wikipedia.org/wiki/Epistemological_anarchism",
        "title": "Epistemological anarchism"
      },
      {
        "text": "Evolutionism",
        "url": "https://en.wikipedia.org/wiki/Evolutionism",
        "title": "Evolutionism"
      },
      {
        "text": "Fallibilism",
        "url": "https://en.wikipedia.org/wiki/Fallibilism",
        "title": "Fallibilism"
      },
      {
        "text": "Foundationalism",
        "url": "https://en.wikipedia.org/wiki/Foundationalism",
        "title": "Foundationalism"
      },
      {
        "text": "Hypothetico-deductive model",
        "url": "https://en.wikipedia.org/wiki/Hypothetico-deductive_model",
        "title": "Hypothetico-deductive model"
      },
      {
        "text": "Inductionism",
        "url": "https://en.wikipedia.org/wiki/Inductionism",
        "title": "Inductionism"
      },
      {
        "text": "Instrumentalism",
        "url": "https://en.wikipedia.org/wiki/Instrumentalism",
        "title": "Instrumentalism"
      },
      {
        "text": "Model-dependent realism",
        "url": "https://en.wikipedia.org/wiki/Model-dependent_realism",
        "title": "Model-dependent realism"
      },
      {
        "text": "Naturalism",
        "url": "https://en.wikipedia.org/wiki/Naturalism_(philosophy)",
        "title": "Naturalism (philosophy)"
      },
      {
        "text": "Physicalism",
        "url": "https://en.wikipedia.org/wiki/Physicalism",
        "title": "Physicalism"
      },
      {
        "text": "Positivism",
        "url": "https://en.wikipedia.org/wiki/Positivism",
        "title": "Positivism"
      },
      {
        "text": "Reductionism",
        "url": "https://en.wikipedia.org/wiki/Reductionism",
        "title": "Reductionism"
      },
      {
        "text": "Determinism",
        "url": "https://en.wikipedia.org/wiki/Determinism",
        "title": "Determinism"
      },
      {
        "text": "Pragmatism",
        "url": "https://en.wikipedia.org/wiki/Pragmatism",
        "title": "Pragmatism"
      },
      {
        "text": "Rationalism",
        "url": "https://en.wikipedia.org/wiki/Rationalism",
        "title": "Rationalism"
      },
      {
        "text": "Empiricism",
        "url": "https://en.wikipedia.org/wiki/Empiricism",
        "title": "Empiricism"
      },
      {
        "text": "Received view",
        "url": "https://en.wikipedia.org/wiki/Received_view_of_theories",
        "title": "Received view of theories"
      },
      {
        "text": "Semantic view of theories",
        "url": "https://en.wikipedia.org/wiki/Semantic_view_of_theories",
        "title": "Semantic view of theories"
      },
      {
        "text": "Scientific essentialism",
        "url": "https://en.wikipedia.org/wiki/Scientific_essentialism",
        "title": "Scientific essentialism"
      },
      {
        "text": "Scientific formalism",
        "url": "https://en.wikipedia.org/wiki/Scientific_formalism",
        "title": "Scientific formalism"
      },
      {
        "text": "Scientific realism",
        "url": "https://en.wikipedia.org/wiki/Scientific_realism",
        "title": "Scientific realism"
      },
      {
        "text": "Anti-realism",
        "url": "https://en.wikipedia.org/wiki/Anti-realism",
        "title": "Anti-realism"
      },
      {
        "text": "Scientific skepticism",
        "url": "https://en.wikipedia.org/wiki/Scientific_skepticism",
        "title": "Scientific skepticism"
      },
      {
        "text": "Scientism",
        "url": "https://en.wikipedia.org/wiki/Scientism",
        "title": "Scientism"
      },
      {
        "text": "Structuralism",
        "url": "https://en.wikipedia.org/wiki/Structuralism_(philosophy_of_science)",
        "title": "Structuralism (philosophy of science)"
      },
      {
        "text": "Uniformitarianism",
        "url": "https://en.wikipedia.org/wiki/Uniformitarianism",
        "title": "Uniformitarianism"
      },
      {
        "text": "Verificationism",
        "url": "https://en.wikipedia.org/wiki/Verificationism",
        "title": "Verificationism"
      },
      {
        "text": "Vitalism",
        "url": "https://en.wikipedia.org/wiki/Vitalism",
        "title": "Vitalism"
      },
      {
        "text": "Biology",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_biology",
        "title": "Philosophy of biology"
      },
      {
        "text": "Chemistry",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_chemistry",
        "title": "Philosophy of chemistry"
      },
      {
        "text": "Physics",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_physics",
        "title": "Philosophy of physics"
      },
      {
        "text": "Space and time",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_space_and_time",
        "title": "Philosophy of space and time"
      },
      {
        "text": "Social science",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_social_science",
        "title": "Philosophy of social science"
      },
      {
        "text": "Archaeology",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_archaeology",
        "title": "Philosophy of archaeology"
      },
      {
        "text": "Economics",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_economics",
        "title": "Philosophy of economics"
      },
      {
        "text": "Geography",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_geography",
        "title": "Philosophy of geography"
      },
      {
        "text": "History",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_history",
        "title": "Philosophy of history"
      },
      {
        "text": "Linguistics",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_linguistics",
        "title": "Philosophy of linguistics"
      },
      {
        "text": "Psychology",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_psychology",
        "title": "Philosophy of psychology"
      },
      {
        "text": "Criticism of science",
        "url": "https://en.wikipedia.org/wiki/Criticism_of_science",
        "title": "Criticism of science"
      },
      {
        "text": "Descriptive science",
        "url": "https://en.wikipedia.org/wiki/Descriptive_research",
        "title": "Descriptive research"
      },
      {
        "text": "Epistemology",
        "url": "https://en.wikipedia.org/wiki/Epistemology",
        "title": "Epistemology"
      },
      {
        "text": "Exact sciences",
        "url": "https://en.wikipedia.org/wiki/Exact_sciences",
        "title": "Exact sciences"
      },
      {
        "text": "Faith and rationality",
        "url": "https://en.wikipedia.org/wiki/Faith_and_rationality",
        "title": "Faith and rationality"
      },
      {
        "text": "Hard and soft science",
        "url": "https://en.wikipedia.org/wiki/Hard_and_soft_science",
        "title": "Hard and soft science"
      },
      {
        "text": "History and philosophy of science",
        "url": "https://en.wikipedia.org/wiki/History_and_philosophy_of_science",
        "title": "History and philosophy of science"
      },
      {
        "text": "Non-science",
        "url": "https://en.wikipedia.org/wiki/Non-science",
        "title": "Non-science"
      },
      {
        "text": "Pseudoscience",
        "url": "https://en.wikipedia.org/wiki/Pseudoscience",
        "title": "Pseudoscience"
      },
      {
        "text": "Normative science",
        "url": "https://en.wikipedia.org/wiki/Normative_science",
        "title": "Normative science"
      },
      {
        "text": "Protoscience",
        "url": "https://en.wikipedia.org/wiki/Protoscience",
        "title": "Protoscience"
      },
      {
        "text": "Questionable cause",
        "url": "https://en.wikipedia.org/wiki/Questionable_cause",
        "title": "Questionable cause"
      },
      {
        "text": "Relationship between religion and science",
        "url": "https://en.wikipedia.org/wiki/Relationship_between_religion_and_science",
        "title": "Relationship between religion and science"
      },
      {
        "text": "Rhetoric of science",
        "url": "https://en.wikipedia.org/wiki/Rhetoric_of_science",
        "title": "Rhetoric of science"
      },
      {
        "text": "Science studies",
        "url": "https://en.wikipedia.org/wiki/Science_studies",
        "title": "Science studies"
      },
      {
        "text": "Sociology of scientific ignorance",
        "url": "https://en.wikipedia.org/wiki/Sociology_of_scientific_ignorance",
        "title": "Sociology of scientific ignorance"
      },
      {
        "text": "Sociology of scientific knowledge",
        "url": "https://en.wikipedia.org/wiki/Sociology_of_scientific_knowledge",
        "title": "Sociology of scientific knowledge"
      },
      {
        "text": "Philosophers of science",
        "url": "https://en.wikipedia.org/wiki/List_of_philosophers_of_science",
        "title": "List of philosophers of science"
      },
      {
        "text": "Roger Bacon",
        "url": "https://en.wikipedia.org/wiki/Roger_Bacon",
        "title": "Roger Bacon"
      },
      {
        "text": "Francis Bacon",
        "url": "https://en.wikipedia.org/wiki/Francis_Bacon",
        "title": "Francis Bacon"
      },
      {
        "text": "Galileo Galilei",
        "url": "https://en.wikipedia.org/wiki/Galileo_Galilei",
        "title": "Galileo Galilei"
      },
      {
        "text": "Isaac Newton",
        "url": "https://en.wikipedia.org/wiki/Isaac_Newton",
        "title": "Isaac Newton"
      },
      {
        "text": "David Hume",
        "url": "https://en.wikipedia.org/wiki/David_Hume",
        "title": "David Hume"
      },
      {
        "text": "Auguste Comte",
        "url": "https://en.wikipedia.org/wiki/Auguste_Comte",
        "title": "Auguste Comte"
      },
      {
        "text": "Henri Poincaré",
        "url": "https://en.wikipedia.org/wiki/Henri_Poincar%C3%A9",
        "title": "Henri Poincaré"
      },
      {
        "text": "Pierre Duhem",
        "url": "https://en.wikipedia.org/wiki/Pierre_Duhem",
        "title": "Pierre Duhem"
      },
      {
        "text": "Rudolf Steiner",
        "url": "https://en.wikipedia.org/wiki/Rudolf_Steiner",
        "title": "Rudolf Steiner"
      },
      {
        "text": "Karl Pearson",
        "url": "https://en.wikipedia.org/wiki/Karl_Pearson",
        "title": "Karl Pearson"
      },
      {
        "text": "Charles Sanders Peirce",
        "url": "https://en.wikipedia.org/wiki/Charles_Sanders_Peirce",
        "title": "Charles Sanders Peirce"
      },
      {
        "text": "Wilhelm Windelband",
        "url": "https://en.wikipedia.org/wiki/Wilhelm_Windelband",
        "title": "Wilhelm Windelband"
      },
      {
        "text": "Alfred North Whitehead",
        "url": "https://en.wikipedia.org/wiki/Alfred_North_Whitehead",
        "title": "Alfred North Whitehead"
      },
      {
        "text": "Bertrand Russell",
        "url": "https://en.wikipedia.org/wiki/Bertrand_Russell",
        "title": "Bertrand Russell"
      },
      {
        "text": "Otto Neurath",
        "url": "https://en.wikipedia.org/wiki/Otto_Neurath",
        "title": "Otto Neurath"
      },
      {
        "text": "C. D. Broad",
        "url": "https://en.wikipedia.org/wiki/C._D._Broad",
        "title": "C. D. Broad"
      },
      {
        "text": "Michael Polanyi",
        "url": "https://en.wikipedia.org/wiki/Michael_Polanyi",
        "title": "Michael Polanyi"
      },
      {
        "text": "Hans Reichenbach",
        "url": "https://en.wikipedia.org/wiki/Hans_Reichenbach",
        "title": "Hans Reichenbach"
      },
      {
        "text": "Rudolf Carnap",
        "url": "https://en.wikipedia.org/wiki/Rudolf_Carnap",
        "title": "Rudolf Carnap"
      },
      {
        "text": "Karl Popper",
        "url": "https://en.wikipedia.org/wiki/Karl_Popper",
        "title": "Karl Popper"
      },
      {
        "text": "Carl Gustav Hempel",
        "url": "https://en.wikipedia.org/wiki/Carl_Gustav_Hempel",
        "title": "Carl Gustav Hempel"
      },
      {
        "text": "W. V. O. Quine",
        "url": "https://en.wikipedia.org/wiki/Willard_Van_Orman_Quine",
        "title": "Willard Van Orman Quine"
      },
      {
        "text": "Thomas Kuhn",
        "url": "https://en.wikipedia.org/wiki/Thomas_Kuhn",
        "title": "Thomas Kuhn"
      },
      {
        "text": "Imre Lakatos",
        "url": "https://en.wikipedia.org/wiki/Imre_Lakatos",
        "title": "Imre Lakatos"
      },
      {
        "text": "Paul Feyerabend",
        "url": "https://en.wikipedia.org/wiki/Paul_Feyerabend",
        "title": "Paul Feyerabend"
      },
      {
        "text": "Ian Hacking",
        "url": "https://en.wikipedia.org/wiki/Ian_Hacking",
        "title": "Ian Hacking"
      },
      {
        "text": "Bas van Fraassen",
        "url": "https://en.wikipedia.org/wiki/Bas_van_Fraassen",
        "title": "Bas van Fraassen"
      },
      {
        "text": "Larry Laudan",
        "url": "https://en.wikipedia.org/wiki/Larry_Laudan",
        "title": "Larry Laudan"
      },
      {
        "text": "Category",
        "url": "https://en.wikipedia.org/wiki/Category:Philosophy_of_science",
        "title": "Category:Philosophy of science"
      },
      {
        "text": "Philosophy portal",
        "url": "https://en.wikipedia.org/wiki/Portal:Philosophy",
        "title": "Portal:Philosophy"
      },
      {
        "text": "Science portal",
        "url": "https://en.wikipedia.org/wiki/Portal:Science",
        "title": "Portal:Science"
      },
      {
        "text": "v",
        "url": "https://en.wikipedia.org/wiki/Template:Evolutionary_computation",
        "title": "Template:Evolutionary computation"
      },
      {
        "text": "t",
        "url": "https://en.wikipedia.org/wiki/Template_talk:Evolutionary_computation",
        "title": "Template talk:Evolutionary computation"
      },
      {
        "text": "e",
        "url": "https://en.wikipedia.org/wiki/Special:EditPage/Template:Evolutionary_computation",
        "title": "Special:EditPage/Template:Evolutionary computation"
      },
      {
        "text": "Evolutionary computation",
        "url": "https://en.wikipedia.org/wiki/Evolutionary_computation",
        "title": "Evolutionary computation"
      },
      {
        "text": "Evolutionary algorithm",
        "url": "https://en.wikipedia.org/wiki/Evolutionary_algorithm",
        "title": "Evolutionary algorithm"
      },
      {
        "text": "Evolutionary data mining",
        "url": "https://en.wikipedia.org/wiki/Evolutionary_data_mining",
        "title": "Evolutionary data mining"
      },
      {
        "text": "Evolutionary multimodal optimization",
        "url": "https://en.wikipedia.org/wiki/Evolutionary_multimodal_optimization",
        "title": "Evolutionary multimodal optimization"
      },
      {
        "text": "Human-based evolutionary computation",
        "url": "https://en.wikipedia.org/wiki/Human-based_evolutionary_computation",
        "title": "Human-based evolutionary computation"
      },
      {
        "text": "Interactive evolutionary computation",
        "url": "https://en.wikipedia.org/wiki/Interactive_evolutionary_computation",
        "title": "Interactive evolutionary computation"
      },
      {
        "text": "Algorithms",
        "url": "https://en.wikipedia.org/wiki/Algorithm",
        "title": "Algorithm"
      },
      {
        "text": "Cellular evolutionary algorithm",
        "url": "https://en.wikipedia.org/wiki/Cellular_evolutionary_algorithm",
        "title": "Cellular evolutionary algorithm"
      },
      {
        "text": "Covariance Matrix Adaptation Evolution Strategy (CMA-ES)",
        "url": "https://en.wikipedia.org/wiki/CMA-ES",
        "title": "CMA-ES"
      },
      {
        "text": "Cultural algorithm",
        "url": "https://en.wikipedia.org/wiki/Cultural_algorithm",
        "title": "Cultural algorithm"
      },
      {
        "text": "Differential evolution",
        "url": "https://en.wikipedia.org/wiki/Differential_evolution",
        "title": "Differential evolution"
      },
      {
        "text": "Evolutionary programming",
        "url": "https://en.wikipedia.org/wiki/Evolutionary_programming",
        "title": "Evolutionary programming"
      },
      {
        "text": "Genetic algorithm",
        "url": "https://en.wikipedia.org/wiki/Genetic_algorithm",
        "title": "Genetic algorithm"
      },
      {
        "text": "Genetic programming",
        "url": "https://en.wikipedia.org/wiki/Genetic_programming",
        "title": "Genetic programming"
      },
      {
        "text": "Gene expression programming",
        "url": "https://en.wikipedia.org/wiki/Gene_expression_programming",
        "title": "Gene expression programming"
      },
      {
        "text": "Evolution strategy",
        "url": "https://en.wikipedia.org/wiki/Evolution_strategy",
        "title": "Evolution strategy"
      },
      {
        "text": "Natural evolution strategy",
        "url": "https://en.wikipedia.org/wiki/Natural_evolution_strategy",
        "title": "Natural evolution strategy"
      },
      {
        "text": "Neuroevolution",
        "url": "https://en.wikipedia.org/wiki/Neuroevolution",
        "title": "Neuroevolution"
      },
      {
        "text": "Learning classifier system",
        "url": "https://en.wikipedia.org/wiki/Learning_classifier_system",
        "title": "Learning classifier system"
      },
      {
        "text": "Swarm intelligence",
        "url": "https://en.wikipedia.org/wiki/Swarm_intelligence",
        "title": "Swarm intelligence"
      },
      {
        "text": "Ant colony optimization",
        "url": "https://en.wikipedia.org/wiki/Ant_colony_optimization",
        "title": "Ant colony optimization"
      },
      {
        "text": "Bees algorithm",
        "url": "https://en.wikipedia.org/wiki/Bees_algorithm",
        "title": "Bees algorithm"
      },
      {
        "text": "Cuckoo search",
        "url": "https://en.wikipedia.org/wiki/Cuckoo_search",
        "title": "Cuckoo search"
      },
      {
        "text": "Particle swarm optimization",
        "url": "https://en.wikipedia.org/wiki/Particle_swarm_optimization",
        "title": "Particle swarm optimization"
      },
      {
        "text": "Bacterial Colony Optimization",
        "url": "https://en.wikipedia.org/wiki/Bacterial_Colony_Optimization",
        "title": "Bacterial Colony Optimization"
      },
      {
        "text": "Metaheuristic methods",
        "url": "https://en.wikipedia.org/wiki/Metaheuristic",
        "title": "Metaheuristic"
      },
      {
        "text": "Firefly algorithm",
        "url": "https://en.wikipedia.org/wiki/Firefly_algorithm",
        "title": "Firefly algorithm"
      },
      {
        "text": "Harmony search",
        "url": "https://en.wikipedia.org/wiki/Harmony_search",
        "title": "Harmony search"
      },
      {
        "text": "Gaussian adaptation",
        "url": "https://en.wikipedia.org/wiki/Gaussian_adaptation",
        "title": "Gaussian adaptation"
      },
      {
        "text": "Memetic algorithm",
        "url": "https://en.wikipedia.org/wiki/Memetic_algorithm",
        "title": "Memetic algorithm"
      },
      {
        "text": "Artificial development",
        "url": "https://en.wikipedia.org/wiki/Artificial_development",
        "title": "Artificial development"
      },
      {
        "text": "Artificial life",
        "url": "https://en.wikipedia.org/wiki/Artificial_life",
        "title": "Artificial life"
      },
      {
        "text": "Digital organism",
        "url": "https://en.wikipedia.org/wiki/Digital_organism",
        "title": "Digital organism"
      },
      {
        "text": "Evolutionary robotics",
        "url": "https://en.wikipedia.org/wiki/Evolutionary_robotics",
        "title": "Evolutionary robotics"
      },
      {
        "text": "Fitness function",
        "url": "https://en.wikipedia.org/wiki/Fitness_function",
        "title": "Fitness function"
      },
      {
        "text": "Fitness landscape",
        "url": "https://en.wikipedia.org/wiki/Fitness_landscape",
        "title": "Fitness landscape"
      },
      {
        "text": "Fitness approximation",
        "url": "https://en.wikipedia.org/wiki/Fitness_approximation",
        "title": "Fitness approximation"
      },
      {
        "text": "Genetic operators",
        "url": "https://en.wikipedia.org/wiki/Genetic_operators",
        "title": "Genetic operators"
      },
      {
        "text": "Interactive evolutionary computation",
        "url": "https://en.wikipedia.org/wiki/Interactive_evolutionary_computation",
        "title": "Interactive evolutionary computation"
      },
      {
        "text": "No free lunch in search and optimization",
        "url": "https://en.wikipedia.org/wiki/No_free_lunch_in_search_and_optimization",
        "title": "No free lunch in search and optimization"
      },
      {
        "text": "Machine learning",
        "url": "https://en.wikipedia.org/wiki/Machine_learning",
        "title": "Machine learning"
      },
      {
        "text": "Mating pool",
        "url": "https://en.wikipedia.org/wiki/Mating_pool",
        "title": "Mating pool"
      },
      {
        "text": "Premature convergence",
        "url": "https://en.wikipedia.org/wiki/Premature_convergence",
        "title": "Premature convergence"
      },
      {
        "text": "Program synthesis",
        "url": "https://en.wikipedia.org/wiki/Program_synthesis",
        "title": "Program synthesis"
      },
      {
        "text": "Journals",
        "url": "https://en.wikipedia.org/wiki/Academic_journal",
        "title": "Academic journal"
      },
      {
        "text": "Evolutionary Computation (journal)",
        "url": "https://en.wikipedia.org/wiki/Evolutionary_Computation_(journal)",
        "title": "Evolutionary Computation (journal)"
      },
      {
        "text": "v",
        "url": "https://en.wikipedia.org/wiki/Template:Computer_science",
        "title": "Template:Computer science"
      },
      {
        "text": "t",
        "url": "https://en.wikipedia.org/wiki/Template_talk:Computer_science",
        "title": "Template talk:Computer science"
      },
      {
        "text": "e",
        "url": "https://en.wikipedia.org/wiki/Special:EditPage/Template:Computer_science",
        "title": "Special:EditPage/Template:Computer science"
      },
      {
        "text": "Computer science",
        "url": "https://en.wikipedia.org/wiki/Computer_science",
        "title": "Computer science"
      },
      {
        "text": "ACM Computing Classification System",
        "url": "https://en.wikipedia.org/wiki/ACM_Computing_Classification_System",
        "title": "ACM Computing Classification System"
      },
      {
        "text": "Hardware",
        "url": "https://en.wikipedia.org/wiki/Computer_hardware",
        "title": "Computer hardware"
      },
      {
        "text": "Printed circuit board",
        "url": "https://en.wikipedia.org/wiki/Printed_circuit_board",
        "title": "Printed circuit board"
      },
      {
        "text": "Peripheral",
        "url": "https://en.wikipedia.org/wiki/Peripheral",
        "title": "Peripheral"
      },
      {
        "text": "Integrated circuit",
        "url": "https://en.wikipedia.org/wiki/Integrated_circuit",
        "title": "Integrated circuit"
      },
      {
        "text": "Very Large Scale Integration",
        "url": "https://en.wikipedia.org/wiki/Very_Large_Scale_Integration",
        "title": "Very Large Scale Integration"
      },
      {
        "text": "Systems on Chip (SoCs)",
        "url": "https://en.wikipedia.org/wiki/System_on_a_chip",
        "title": "System on a chip"
      },
      {
        "text": "Energy consumption (Green computing)",
        "url": "https://en.wikipedia.org/wiki/Green_computing",
        "title": "Green computing"
      },
      {
        "text": "Electronic design automation",
        "url": "https://en.wikipedia.org/wiki/Electronic_design_automation",
        "title": "Electronic design automation"
      },
      {
        "text": "Hardware acceleration",
        "url": "https://en.wikipedia.org/wiki/Hardware_acceleration",
        "title": "Hardware acceleration"
      },
      {
        "text": "Processor",
        "url": "https://en.wikipedia.org/wiki/Processor_(computing)",
        "title": "Processor (computing)"
      },
      {
        "text": "Size",
        "url": "https://en.wikipedia.org/wiki/List_of_computer_size_categories",
        "title": "List of computer size categories"
      },
      {
        "text": "Form",
        "url": "https://en.wikipedia.org/wiki/Form_factor_(design)",
        "title": "Form factor (design)"
      },
      {
        "text": "Computer architecture",
        "url": "https://en.wikipedia.org/wiki/Computer_architecture",
        "title": "Computer architecture"
      },
      {
        "text": "Computational complexity",
        "url": "https://en.wikipedia.org/wiki/Computational_complexity",
        "title": "Computational complexity"
      },
      {
        "text": "Dependability",
        "url": "https://en.wikipedia.org/wiki/Dependability",
        "title": "Dependability"
      },
      {
        "text": "Embedded system",
        "url": "https://en.wikipedia.org/wiki/Embedded_system",
        "title": "Embedded system"
      },
      {
        "text": "Real-time computing",
        "url": "https://en.wikipedia.org/wiki/Real-time_computing",
        "title": "Real-time computing"
      },
      {
        "text": "Networks",
        "url": "https://en.wikipedia.org/wiki/Computer_network",
        "title": "Computer network"
      },
      {
        "text": "Network architecture",
        "url": "https://en.wikipedia.org/wiki/Network_architecture",
        "title": "Network architecture"
      },
      {
        "text": "Network protocol",
        "url": "https://en.wikipedia.org/wiki/Network_protocol",
        "title": "Network protocol"
      },
      {
        "text": "Network components",
        "url": "https://en.wikipedia.org/wiki/Networking_hardware",
        "title": "Networking hardware"
      },
      {
        "text": "Network scheduler",
        "url": "https://en.wikipedia.org/wiki/Network_scheduler",
        "title": "Network scheduler"
      },
      {
        "text": "Network performance evaluation",
        "url": "https://en.wikipedia.org/wiki/Network_performance",
        "title": "Network performance"
      },
      {
        "text": "Network service",
        "url": "https://en.wikipedia.org/wiki/Network_service",
        "title": "Network service"
      },
      {
        "text": "Interpreter",
        "url": "https://en.wikipedia.org/wiki/Interpreter_(computing)",
        "title": "Interpreter (computing)"
      },
      {
        "text": "Middleware",
        "url": "https://en.wikipedia.org/wiki/Middleware",
        "title": "Middleware"
      },
      {
        "text": "Virtual machine",
        "url": "https://en.wikipedia.org/wiki/Virtual_machine",
        "title": "Virtual machine"
      },
      {
        "text": "Operating system",
        "url": "https://en.wikipedia.org/wiki/Operating_system",
        "title": "Operating system"
      },
      {
        "text": "Software quality",
        "url": "https://en.wikipedia.org/wiki/Software_quality",
        "title": "Software quality"
      },
      {
        "text": "Software notations",
        "url": "https://en.wikipedia.org/wiki/Programming_language_theory",
        "title": "Programming language theory"
      },
      {
        "text": "tools",
        "url": "https://en.wikipedia.org/wiki/Programming_tool",
        "title": "Programming tool"
      },
      {
        "text": "Programming paradigm",
        "url": "https://en.wikipedia.org/wiki/Programming_paradigm",
        "title": "Programming paradigm"
      },
      {
        "text": "Programming language",
        "url": "https://en.wikipedia.org/wiki/Programming_language",
        "title": "Programming language"
      },
      {
        "text": "Compiler",
        "url": "https://en.wikipedia.org/wiki/Compiler_construction",
        "title": "Compiler construction"
      },
      {
        "text": "Domain-specific language",
        "url": "https://en.wikipedia.org/wiki/Domain-specific_language",
        "title": "Domain-specific language"
      },
      {
        "text": "Modeling language",
        "url": "https://en.wikipedia.org/wiki/Modeling_language",
        "title": "Modeling language"
      },
      {
        "text": "Software framework",
        "url": "https://en.wikipedia.org/wiki/Software_framework",
        "title": "Software framework"
      },
      {
        "text": "Integrated development environment",
        "url": "https://en.wikipedia.org/wiki/Integrated_development_environment",
        "title": "Integrated development environment"
      },
      {
        "text": "Software configuration management",
        "url": "https://en.wikipedia.org/wiki/Software_configuration_management",
        "title": "Software configuration management"
      },
      {
        "text": "Software library",
        "url": "https://en.wikipedia.org/wiki/Library_(computing)",
        "title": "Library (computing)"
      },
      {
        "text": "Software repository",
        "url": "https://en.wikipedia.org/wiki/Software_repository",
        "title": "Software repository"
      },
      {
        "text": "Software development",
        "url": "https://en.wikipedia.org/wiki/Software_development",
        "title": "Software development"
      },
      {
        "text": "Control variable",
        "url": "https://en.wikipedia.org/wiki/Control_variable_(programming)",
        "title": "Control variable (programming)"
      },
      {
        "text": "Software development process",
        "url": "https://en.wikipedia.org/wiki/Software_development_process",
        "title": "Software development process"
      },
      {
        "text": "Requirements analysis",
        "url": "https://en.wikipedia.org/wiki/Requirements_analysis",
        "title": "Requirements analysis"
      },
      {
        "text": "Software design",
        "url": "https://en.wikipedia.org/wiki/Software_design",
        "title": "Software design"
      },
      {
        "text": "Software construction",
        "url": "https://en.wikipedia.org/wiki/Software_construction",
        "title": "Software construction"
      },
      {
        "text": "Software deployment",
        "url": "https://en.wikipedia.org/wiki/Software_deployment",
        "title": "Software deployment"
      },
      {
        "text": "Software engineering",
        "url": "https://en.wikipedia.org/wiki/Software_engineering",
        "title": "Software engineering"
      },
      {
        "text": "Software maintenance",
        "url": "https://en.wikipedia.org/wiki/Software_maintenance",
        "title": "Software maintenance"
      },
      {
        "text": "Programming team",
        "url": "https://en.wikipedia.org/wiki/Programming_team",
        "title": "Programming team"
      },
      {
        "text": "Open-source model",
        "url": "https://en.wikipedia.org/wiki/Open-source_software",
        "title": "Open-source software"
      },
      {
        "text": "Theory of computation",
        "url": "https://en.wikipedia.org/wiki/Theory_of_computation",
        "title": "Theory of computation"
      },
      {
        "text": "Model of computation",
        "url": "https://en.wikipedia.org/wiki/Model_of_computation",
        "title": "Model of computation"
      },
      {
        "text": "Stochastic",
        "url": "https://en.wikipedia.org/wiki/Stochastic_computing",
        "title": "Stochastic computing"
      },
      {
        "text": "Formal language",
        "url": "https://en.wikipedia.org/wiki/Formal_language",
        "title": "Formal language"
      },
      {
        "text": "Automata theory",
        "url": "https://en.wikipedia.org/wiki/Automata_theory",
        "title": "Automata theory"
      },
      {
        "text": "Computability theory",
        "url": "https://en.wikipedia.org/wiki/Computability_theory",
        "title": "Computability theory"
      },
      {
        "text": "Computational complexity theory",
        "url": "https://en.wikipedia.org/wiki/Computational_complexity_theory",
        "title": "Computational complexity theory"
      },
      {
        "text": "Logic",
        "url": "https://en.wikipedia.org/wiki/Logic_in_computer_science",
        "title": "Logic in computer science"
      },
      {
        "text": "Semantics",
        "url": "https://en.wikipedia.org/wiki/Semantics_(computer_science)",
        "title": "Semantics (computer science)"
      },
      {
        "text": "Algorithms",
        "url": "https://en.wikipedia.org/wiki/Algorithm",
        "title": "Algorithm"
      },
      {
        "text": "Algorithm design",
        "url": "https://en.wikipedia.org/wiki/Algorithm_design",
        "title": "Algorithm design"
      },
      {
        "text": "Analysis of algorithms",
        "url": "https://en.wikipedia.org/wiki/Analysis_of_algorithms",
        "title": "Analysis of algorithms"
      },
      {
        "text": "Algorithmic efficiency",
        "url": "https://en.wikipedia.org/wiki/Algorithmic_efficiency",
        "title": "Algorithmic efficiency"
      },
      {
        "text": "Randomized algorithm",
        "url": "https://en.wikipedia.org/wiki/Randomized_algorithm",
        "title": "Randomized algorithm"
      },
      {
        "text": "Computational geometry",
        "url": "https://en.wikipedia.org/wiki/Computational_geometry",
        "title": "Computational geometry"
      },
      {
        "text": "computing",
        "url": "https://en.wikipedia.org/wiki/Computing",
        "title": "Computing"
      },
      {
        "text": "Discrete mathematics",
        "url": "https://en.wikipedia.org/wiki/Discrete_mathematics",
        "title": "Discrete mathematics"
      },
      {
        "text": "Probability",
        "url": "https://en.wikipedia.org/wiki/Probability",
        "title": "Probability"
      },
      {
        "text": "Statistics",
        "url": "https://en.wikipedia.org/wiki/Statistics",
        "title": "Statistics"
      },
      {
        "text": "Mathematical software",
        "url": "https://en.wikipedia.org/wiki/Mathematical_software",
        "title": "Mathematical software"
      },
      {
        "text": "Information theory",
        "url": "https://en.wikipedia.org/wiki/Information_theory",
        "title": "Information theory"
      },
      {
        "text": "Mathematical analysis",
        "url": "https://en.wikipedia.org/wiki/Mathematical_analysis",
        "title": "Mathematical analysis"
      },
      {
        "text": "Numerical analysis",
        "url": "https://en.wikipedia.org/wiki/Numerical_analysis",
        "title": "Numerical analysis"
      },
      {
        "text": "Theoretical computer science",
        "url": "https://en.wikipedia.org/wiki/Theoretical_computer_science",
        "title": "Theoretical computer science"
      },
      {
        "text": "Information systems",
        "url": "https://en.wikipedia.org/wiki/Information_system",
        "title": "Information system"
      },
      {
        "text": "Database management system",
        "url": "https://en.wikipedia.org/wiki/Database",
        "title": "Database"
      },
      {
        "text": "Information storage systems",
        "url": "https://en.wikipedia.org/wiki/Computer_data_storage",
        "title": "Computer data storage"
      },
      {
        "text": "Enterprise information system",
        "url": "https://en.wikipedia.org/wiki/Enterprise_information_system",
        "title": "Enterprise information system"
      },
      {
        "text": "Social information systems",
        "url": "https://en.wikipedia.org/wiki/Social_software",
        "title": "Social software"
      },
      {
        "text": "Geographic information system",
        "url": "https://en.wikipedia.org/wiki/Geographic_information_system",
        "title": "Geographic information system"
      },
      {
        "text": "Decision support system",
        "url": "https://en.wikipedia.org/wiki/Decision_support_system",
        "title": "Decision support system"
      },
      {
        "text": "Process control system",
        "url": "https://en.wikipedia.org/wiki/Process_control",
        "title": "Process control"
      },
      {
        "text": "Multimedia information system",
        "url": "https://en.wikipedia.org/wiki/Multimedia_database",
        "title": "Multimedia database"
      },
      {
        "text": "Data mining",
        "url": "https://en.wikipedia.org/wiki/Data_mining",
        "title": "Data mining"
      },
      {
        "text": "Digital library",
        "url": "https://en.wikipedia.org/wiki/Digital_library",
        "title": "Digital library"
      },
      {
        "text": "Computing platform",
        "url": "https://en.wikipedia.org/wiki/Computing_platform",
        "title": "Computing platform"
      },
      {
        "text": "Digital marketing",
        "url": "https://en.wikipedia.org/wiki/Digital_marketing",
        "title": "Digital marketing"
      },
      {
        "text": "World Wide Web",
        "url": "https://en.wikipedia.org/wiki/World_Wide_Web",
        "title": "World Wide Web"
      },
      {
        "text": "Information retrieval",
        "url": "https://en.wikipedia.org/wiki/Information_retrieval",
        "title": "Information retrieval"
      },
      {
        "text": "Security",
        "url": "https://en.wikipedia.org/wiki/Computer_security",
        "title": "Computer security"
      },
      {
        "text": "Cryptography",
        "url": "https://en.wikipedia.org/wiki/Cryptography",
        "title": "Cryptography"
      },
      {
        "text": "Formal methods",
        "url": "https://en.wikipedia.org/wiki/Formal_methods",
        "title": "Formal methods"
      },
      {
        "text": "Security hacker",
        "url": "https://en.wikipedia.org/wiki/Security_hacker",
        "title": "Security hacker"
      },
      {
        "text": "Security services",
        "url": "https://en.wikipedia.org/wiki/Security_service_(telecommunication)",
        "title": "Security service (telecommunication)"
      },
      {
        "text": "Intrusion detection system",
        "url": "https://en.wikipedia.org/wiki/Intrusion_detection_system",
        "title": "Intrusion detection system"
      },
      {
        "text": "Hardware security",
        "url": "https://en.wikipedia.org/wiki/Hardware_security",
        "title": "Hardware security"
      },
      {
        "text": "Network security",
        "url": "https://en.wikipedia.org/wiki/Network_security",
        "title": "Network security"
      },
      {
        "text": "Information security",
        "url": "https://en.wikipedia.org/wiki/Information_security",
        "title": "Information security"
      },
      {
        "text": "Application security",
        "url": "https://en.wikipedia.org/wiki/Application_security",
        "title": "Application security"
      },
      {
        "text": "Human–computer interaction",
        "url": "https://en.wikipedia.org/wiki/Human%E2%80%93computer_interaction",
        "title": "Human–computer interaction"
      },
      {
        "text": "Interaction design",
        "url": "https://en.wikipedia.org/wiki/Interaction_design",
        "title": "Interaction design"
      },
      {
        "text": "Augmented reality",
        "url": "https://en.wikipedia.org/wiki/Augmented_reality",
        "title": "Augmented reality"
      },
      {
        "text": "Virtual reality",
        "url": "https://en.wikipedia.org/wiki/Virtual_reality",
        "title": "Virtual reality"
      },
      {
        "text": "Social computing",
        "url": "https://en.wikipedia.org/wiki/Social_computing",
        "title": "Social computing"
      },
      {
        "text": "Ubiquitous computing",
        "url": "https://en.wikipedia.org/wiki/Ubiquitous_computing",
        "title": "Ubiquitous computing"
      },
      {
        "text": "Visualization",
        "url": "https://en.wikipedia.org/wiki/Visualization_(graphics)",
        "title": "Visualization (graphics)"
      },
      {
        "text": "Accessibility",
        "url": "https://en.wikipedia.org/wiki/Computer_accessibility",
        "title": "Computer accessibility"
      },
      {
        "text": "Concurrency",
        "url": "https://en.wikipedia.org/wiki/Concurrency_(computer_science)",
        "title": "Concurrency (computer science)"
      },
      {
        "text": "Concurrent computing",
        "url": "https://en.wikipedia.org/wiki/Concurrent_computing",
        "title": "Concurrent computing"
      },
      {
        "text": "Parallel computing",
        "url": "https://en.wikipedia.org/wiki/Parallel_computing",
        "title": "Parallel computing"
      },
      {
        "text": "Distributed computing",
        "url": "https://en.wikipedia.org/wiki/Distributed_computing",
        "title": "Distributed computing"
      },
      {
        "text": "Multithreading",
        "url": "https://en.wikipedia.org/wiki/Multithreading_(computer_architecture)",
        "title": "Multithreading (computer architecture)"
      },
      {
        "text": "Multiprocessing",
        "url": "https://en.wikipedia.org/wiki/Multiprocessing",
        "title": "Multiprocessing"
      },
      {
        "text": "Natural language processing",
        "url": "https://en.wikipedia.org/wiki/Natural_language_processing",
        "title": "Natural language processing"
      },
      {
        "text": "Knowledge representation and reasoning",
        "url": "https://en.wikipedia.org/wiki/Knowledge_representation_and_reasoning",
        "title": "Knowledge representation and reasoning"
      },
      {
        "text": "Computer vision",
        "url": "https://en.wikipedia.org/wiki/Computer_vision",
        "title": "Computer vision"
      },
      {
        "text": "Automated planning and scheduling",
        "url": "https://en.wikipedia.org/wiki/Automated_planning_and_scheduling",
        "title": "Automated planning and scheduling"
      },
      {
        "text": "Search methodology",
        "url": "https://en.wikipedia.org/wiki/Mathematical_optimization",
        "title": "Mathematical optimization"
      },
      {
        "text": "Control method",
        "url": "https://en.wikipedia.org/wiki/Control_theory",
        "title": "Control theory"
      },
      {
        "text": "Philosophy of artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Philosophy_of_artificial_intelligence",
        "title": "Philosophy of artificial intelligence"
      },
      {
        "text": "Distributed artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Distributed_artificial_intelligence",
        "title": "Distributed artificial intelligence"
      },
      {
        "text": "Machine learning",
        "url": "https://en.wikipedia.org/wiki/Machine_learning",
        "title": "Machine learning"
      },
      {
        "text": "Supervised learning",
        "url": "https://en.wikipedia.org/wiki/Supervised_learning",
        "title": "Supervised learning"
      },
      {
        "text": "Unsupervised learning",
        "url": "https://en.wikipedia.org/wiki/Unsupervised_learning",
        "title": "Unsupervised learning"
      },
      {
        "text": "Reinforcement learning",
        "url": "https://en.wikipedia.org/wiki/Reinforcement_learning",
        "title": "Reinforcement learning"
      },
      {
        "text": "Multi-task learning",
        "url": "https://en.wikipedia.org/wiki/Multi-task_learning",
        "title": "Multi-task learning"
      },
      {
        "text": "Cross-validation",
        "url": "https://en.wikipedia.org/wiki/Cross-validation_(statistics)",
        "title": "Cross-validation (statistics)"
      },
      {
        "text": "Graphics",
        "url": "https://en.wikipedia.org/wiki/Computer_graphics",
        "title": "Computer graphics"
      },
      {
        "text": "Animation",
        "url": "https://en.wikipedia.org/wiki/Computer_animation",
        "title": "Computer animation"
      },
      {
        "text": "Rendering",
        "url": "https://en.wikipedia.org/wiki/Rendering_(computer_graphics)",
        "title": "Rendering (computer graphics)"
      },
      {
        "text": "Photograph manipulation",
        "url": "https://en.wikipedia.org/wiki/Photograph_manipulation",
        "title": "Photograph manipulation"
      },
      {
        "text": "Graphics processing unit",
        "url": "https://en.wikipedia.org/wiki/Graphics_processing_unit",
        "title": "Graphics processing unit"
      },
      {
        "text": "Image compression",
        "url": "https://en.wikipedia.org/wiki/Image_compression",
        "title": "Image compression"
      },
      {
        "text": "Solid modeling",
        "url": "https://en.wikipedia.org/wiki/Solid_modeling",
        "title": "Solid modeling"
      },
      {
        "text": "Quantum Computing",
        "url": "https://en.wikipedia.org/wiki/Quantum_Computing",
        "title": "Quantum Computing"
      },
      {
        "text": "E-commerce",
        "url": "https://en.wikipedia.org/wiki/E-commerce",
        "title": "E-commerce"
      },
      {
        "text": "Enterprise software",
        "url": "https://en.wikipedia.org/wiki/Enterprise_software",
        "title": "Enterprise software"
      },
      {
        "text": "Computational mathematics",
        "url": "https://en.wikipedia.org/wiki/Computational_mathematics",
        "title": "Computational mathematics"
      },
      {
        "text": "Computational physics",
        "url": "https://en.wikipedia.org/wiki/Computational_physics",
        "title": "Computational physics"
      },
      {
        "text": "Computational chemistry",
        "url": "https://en.wikipedia.org/wiki/Computational_chemistry",
        "title": "Computational chemistry"
      },
      {
        "text": "Computational biology",
        "url": "https://en.wikipedia.org/wiki/Computational_biology",
        "title": "Computational biology"
      },
      {
        "text": "Computational social science",
        "url": "https://en.wikipedia.org/wiki/Computational_social_science",
        "title": "Computational social science"
      },
      {
        "text": "Computational engineering",
        "url": "https://en.wikipedia.org/wiki/Computational_engineering",
        "title": "Computational engineering"
      },
      {
        "text": "Differentiable computing",
        "url": "https://en.wikipedia.org/wiki/Template:Differentiable_computing",
        "title": "Template:Differentiable computing"
      },
      {
        "text": "Computational healthcare",
        "url": "https://en.wikipedia.org/wiki/Health_informatics",
        "title": "Health informatics"
      },
      {
        "text": "Digital art",
        "url": "https://en.wikipedia.org/wiki/Digital_art",
        "title": "Digital art"
      },
      {
        "text": "Electronic publishing",
        "url": "https://en.wikipedia.org/wiki/Electronic_publishing",
        "title": "Electronic publishing"
      },
      {
        "text": "Cyberwarfare",
        "url": "https://en.wikipedia.org/wiki/Cyberwarfare",
        "title": "Cyberwarfare"
      },
      {
        "text": "Electronic voting",
        "url": "https://en.wikipedia.org/wiki/Electronic_voting",
        "title": "Electronic voting"
      },
      {
        "text": "Video games",
        "url": "https://en.wikipedia.org/wiki/Video_game",
        "title": "Video game"
      },
      {
        "text": "Word processing",
        "url": "https://en.wikipedia.org/wiki/Word_processor",
        "title": "Word processor"
      },
      {
        "text": "Operations research",
        "url": "https://en.wikipedia.org/wiki/Operations_research",
        "title": "Operations research"
      },
      {
        "text": "Educational technology",
        "url": "https://en.wikipedia.org/wiki/Educational_technology",
        "title": "Educational technology"
      },
      {
        "text": "Document management",
        "url": "https://en.wikipedia.org/wiki/Document_management_system",
        "title": "Document management system"
      },
      {
        "text": "Category",
        "url": "https://en.wikipedia.org/wiki/Category:Computer_science",
        "title": "Category:Computer science"
      },
      {
        "text": "Outline",
        "url": "https://en.wikipedia.org/wiki/Outline_of_computer_science",
        "title": "Outline of computer science"
      },
      {
        "text": "Glossaries",
        "url": "https://en.wikipedia.org/wiki/Template:Glossaries_of_computers",
        "title": "Template:Glossaries of computers"
      },
      {
        "text": "v",
        "url": "https://en.wikipedia.org/wiki/Template:Emerging_technologies",
        "title": "Template:Emerging technologies"
      },
      {
        "text": "t",
        "url": "https://en.wikipedia.org/wiki/Template_talk:Emerging_technologies",
        "title": "Template talk:Emerging technologies"
      },
      {
        "text": "e",
        "url": "https://en.wikipedia.org/wiki/Special:EditPage/Template:Emerging_technologies",
        "title": "Special:EditPage/Template:Emerging technologies"
      },
      {
        "text": "Emerging technologies",
        "url": "https://en.wikipedia.org/wiki/Emerging_technologies",
        "title": "Emerging technologies"
      },
      {
        "text": "Information andcommunications",
        "url": "https://en.wikipedia.org/wiki/Information_and_communications_technology",
        "title": "Information and communications technology"
      },
      {
        "text": "Ambient intelligence",
        "url": "https://en.wikipedia.org/wiki/Ambient_intelligence",
        "title": "Ambient intelligence"
      },
      {
        "text": "Internet of things",
        "url": "https://en.wikipedia.org/wiki/Internet_of_things",
        "title": "Internet of things"
      },
      {
        "text": "Applications of artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Applications_of_artificial_intelligence",
        "title": "Applications of artificial intelligence"
      },
      {
        "text": "Machine translation",
        "url": "https://en.wikipedia.org/wiki/Machine_translation",
        "title": "Machine translation"
      },
      {
        "text": "Machine vision",
        "url": "https://en.wikipedia.org/wiki/Machine_vision",
        "title": "Machine vision"
      },
      {
        "text": "Mobile translation",
        "url": "https://en.wikipedia.org/wiki/Mobile_translation",
        "title": "Mobile translation"
      },
      {
        "text": "Progress in artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Progress_in_artificial_intelligence",
        "title": "Progress in artificial intelligence"
      },
      {
        "text": "Semantic Web",
        "url": "https://en.wikipedia.org/wiki/Semantic_Web",
        "title": "Semantic Web"
      },
      {
        "text": "Speech recognition",
        "url": "https://en.wikipedia.org/wiki/Speech_recognition",
        "title": "Speech recognition"
      },
      {
        "text": "Atomtronics",
        "url": "https://en.wikipedia.org/wiki/Atomtronics",
        "title": "Atomtronics"
      },
      {
        "text": "Carbon nanotube field-effect transistor",
        "url": "https://en.wikipedia.org/wiki/Carbon_nanotube_field-effect_transistor",
        "title": "Carbon nanotube field-effect transistor"
      },
      {
        "text": "Cybermethodology",
        "url": "https://en.wikipedia.org/wiki/Cybermethodology",
        "title": "Cybermethodology"
      },
      {
        "text": "Augmented reality",
        "url": "https://en.wikipedia.org/wiki/Augmented_reality",
        "title": "Augmented reality"
      },
      {
        "text": "Fourth-generation optical discs",
        "url": "https://en.wikipedia.org/wiki/Optical_disc#Fourth-generation",
        "title": "Optical disc"
      },
      {
        "text": "3D optical data storage",
        "url": "https://en.wikipedia.org/wiki/3D_optical_data_storage",
        "title": "3D optical data storage"
      },
      {
        "text": "Holographic data storage",
        "url": "https://en.wikipedia.org/wiki/Holographic_data_storage",
        "title": "Holographic data storage"
      },
      {
        "text": "GPGPU",
        "url": "https://en.wikipedia.org/wiki/General-purpose_computing_on_graphics_processing_units",
        "title": "General-purpose computing on graphics processing units"
      },
      {
        "text": "CBRAM",
        "url": "https://en.wikipedia.org/wiki/Programmable_metallization_cell",
        "title": "Programmable metallization cell"
      },
      {
        "text": "ECRAM",
        "url": "https://en.wikipedia.org/wiki/Electrochemical_RAM",
        "title": "Electrochemical RAM"
      },
      {
        "text": "FRAM",
        "url": "https://en.wikipedia.org/wiki/Ferroelectric_RAM",
        "title": "Ferroelectric RAM"
      },
      {
        "text": "Millipede",
        "url": "https://en.wikipedia.org/wiki/Millipede_memory",
        "title": "Millipede memory"
      },
      {
        "text": "MRAM",
        "url": "https://en.wikipedia.org/wiki/Magnetoresistive_RAM",
        "title": "Magnetoresistive RAM"
      },
      {
        "text": "NRAM",
        "url": "https://en.wikipedia.org/wiki/Nano-RAM",
        "title": "Nano-RAM"
      },
      {
        "text": "PRAM",
        "url": "https://en.wikipedia.org/wiki/Phase-change_memory",
        "title": "Phase-change memory"
      },
      {
        "text": "Racetrack memory",
        "url": "https://en.wikipedia.org/wiki/Racetrack_memory",
        "title": "Racetrack memory"
      },
      {
        "text": "RRAM",
        "url": "https://en.wikipedia.org/wiki/Resistive_random-access_memory",
        "title": "Resistive random-access memory"
      },
      {
        "text": "SONOS",
        "url": "https://en.wikipedia.org/wiki/SONOS",
        "title": "SONOS"
      },
      {
        "text": "UltraRAM",
        "url": "https://en.wikipedia.org/wiki/UltraRAM",
        "title": "UltraRAM"
      },
      {
        "text": "Optical computing",
        "url": "https://en.wikipedia.org/wiki/Optical_computing",
        "title": "Optical computing"
      },
      {
        "text": "RFID",
        "url": "https://en.wikipedia.org/wiki/Radio-frequency_identification",
        "title": "Radio-frequency identification"
      },
      {
        "text": "Chipless RFID",
        "url": "https://en.wikipedia.org/wiki/Chipless_RFID",
        "title": "Chipless RFID"
      },
      {
        "text": "Software-defined radio",
        "url": "https://en.wikipedia.org/wiki/Software-defined_radio",
        "title": "Software-defined radio"
      },
      {
        "text": "Three-dimensional integrated circuit",
        "url": "https://en.wikipedia.org/wiki/Three-dimensional_integrated_circuit",
        "title": "Three-dimensional integrated circuit"
      },
      {
        "text": "Automation",
        "url": "https://en.wikipedia.org/wiki/Automation",
        "title": "Automation"
      },
      {
        "text": "Collingridge dilemma",
        "url": "https://en.wikipedia.org/wiki/Collingridge_dilemma",
        "title": "Collingridge dilemma"
      },
      {
        "text": "Differential technological development",
        "url": "https://en.wikipedia.org/wiki/Differential_technological_development",
        "title": "Differential technological development"
      },
      {
        "text": "Disruptive innovation",
        "url": "https://en.wikipedia.org/wiki/Disruptive_innovation",
        "title": "Disruptive innovation"
      },
      {
        "text": "Ephemeralization",
        "url": "https://en.wikipedia.org/wiki/Ephemeralization",
        "title": "Ephemeralization"
      },
      {
        "text": "Ethics",
        "url": "https://en.wikipedia.org/wiki/Ethics_of_technology",
        "title": "Ethics of technology"
      },
      {
        "text": "Bioethics",
        "url": "https://en.wikipedia.org/wiki/Bioethics",
        "title": "Bioethics"
      },
      {
        "text": "Cyberethics",
        "url": "https://en.wikipedia.org/wiki/Cyberethics",
        "title": "Cyberethics"
      },
      {
        "text": "Neuroethics",
        "url": "https://en.wikipedia.org/wiki/Neuroethics",
        "title": "Neuroethics"
      },
      {
        "text": "Robot ethics",
        "url": "https://en.wikipedia.org/wiki/Robot_ethics",
        "title": "Robot ethics"
      },
      {
        "text": "Exploratory engineering",
        "url": "https://en.wikipedia.org/wiki/Exploratory_engineering",
        "title": "Exploratory engineering"
      },
      {
        "text": "Proactionary principle",
        "url": "https://en.wikipedia.org/wiki/Proactionary_principle",
        "title": "Proactionary principle"
      },
      {
        "text": "Technological change",
        "url": "https://en.wikipedia.org/wiki/Technological_change",
        "title": "Technological change"
      },
      {
        "text": "Technological unemployment",
        "url": "https://en.wikipedia.org/wiki/Technological_unemployment",
        "title": "Technological unemployment"
      },
      {
        "text": "Technological convergence",
        "url": "https://en.wikipedia.org/wiki/Technological_convergence",
        "title": "Technological convergence"
      },
      {
        "text": "Technological evolution",
        "url": "https://en.wikipedia.org/wiki/Technological_evolution",
        "title": "Technological evolution"
      },
      {
        "text": "Technological paradigm",
        "url": "https://en.wikipedia.org/wiki/Technological_paradigm",
        "title": "Technological paradigm"
      },
      {
        "text": "Technology forecasting",
        "url": "https://en.wikipedia.org/wiki/Technology_forecasting",
        "title": "Technology forecasting"
      },
      {
        "text": "Accelerating change",
        "url": "https://en.wikipedia.org/wiki/Accelerating_change",
        "title": "Accelerating change"
      },
      {
        "text": "Future-oriented technology analysis",
        "url": "https://en.wikipedia.org/wiki/Future-oriented_technology_analysis",
        "title": "Future-oriented technology analysis"
      },
      {
        "text": "Horizon scanning",
        "url": "https://en.wikipedia.org/wiki/Horizon_scanning",
        "title": "Horizon scanning"
      },
      {
        "text": "Moore's law",
        "url": "https://en.wikipedia.org/wiki/Moore%27s_law",
        "title": "Moore's law"
      },
      {
        "text": "Technological singularity",
        "url": "https://en.wikipedia.org/wiki/Technological_singularity",
        "title": "Technological singularity"
      },
      {
        "text": "Technology scouting",
        "url": "https://en.wikipedia.org/wiki/Technology_scouting",
        "title": "Technology scouting"
      },
      {
        "text": "Technology in science fiction",
        "url": "https://en.wikipedia.org/wiki/Technology_in_science_fiction",
        "title": "Technology in science fiction"
      },
      {
        "text": "Technology readiness level",
        "url": "https://en.wikipedia.org/wiki/Technology_readiness_level",
        "title": "Technology readiness level"
      },
      {
        "text": "Technology roadmap",
        "url": "https://en.wikipedia.org/wiki/Technology_roadmap",
        "title": "Technology roadmap"
      },
      {
        "text": "Transhumanism",
        "url": "https://en.wikipedia.org/wiki/Transhumanism",
        "title": "Transhumanism"
      },
      {
        "text": "List",
        "url": "https://en.wikipedia.org/wiki/List_of_emerging_technologies",
        "title": "List of emerging technologies"
      },
      {
        "text": "v",
        "url": "https://en.wikipedia.org/wiki/Template:Robotics",
        "title": "Template:Robotics"
      },
      {
        "text": "t",
        "url": "https://en.wikipedia.org/wiki/Template_talk:Robotics",
        "title": "Template talk:Robotics"
      },
      {
        "text": "e",
        "url": "https://en.wikipedia.org/wiki/Special:EditPage/Template:Robotics",
        "title": "Special:EditPage/Template:Robotics"
      },
      {
        "text": "Robotics",
        "url": "https://en.wikipedia.org/wiki/Robotics",
        "title": "Robotics"
      },
      {
        "text": "Outline",
        "url": "https://en.wikipedia.org/wiki/Outline_of_robotics",
        "title": "Outline of robotics"
      },
      {
        "text": "Glossary",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_robotics",
        "title": "Glossary of robotics"
      },
      {
        "text": "Index",
        "url": "https://en.wikipedia.org/wiki/Index_of_robotics_articles",
        "title": "Index of robotics articles"
      },
      {
        "text": "History",
        "url": "https://en.wikipedia.org/wiki/History_of_robots",
        "title": "History of robots"
      },
      {
        "text": "Geography",
        "url": "https://en.wikipedia.org/wiki/Geography_of_robotics",
        "title": "Geography of robotics"
      },
      {
        "text": "Hall of Fame",
        "url": "https://en.wikipedia.org/wiki/Robot_Hall_of_Fame",
        "title": "Robot Hall of Fame"
      },
      {
        "text": "Ethics",
        "url": "https://en.wikipedia.org/wiki/Robot_ethics",
        "title": "Robot ethics"
      },
      {
        "text": "Laws",
        "url": "https://en.wikipedia.org/wiki/Laws_of_robotics",
        "title": "Laws of robotics"
      },
      {
        "text": "Competitions",
        "url": "https://en.wikipedia.org/wiki/Robot_competition",
        "title": "Robot competition"
      },
      {
        "text": "AI competitions",
        "url": "https://en.wikipedia.org/wiki/Competitions_and_prizes_in_artificial_intelligence",
        "title": "Competitions and prizes in artificial intelligence"
      },
      {
        "text": "Types",
        "url": "https://en.wikipedia.org/wiki/Robot",
        "title": "Robot"
      },
      {
        "text": "Aerobot",
        "url": "https://en.wikipedia.org/wiki/Aerobot",
        "title": "Aerobot"
      },
      {
        "text": "Anthropomorphic",
        "url": "https://en.wikipedia.org/wiki/Anthropomorphic",
        "title": "Anthropomorphic"
      },
      {
        "text": "Humanoid",
        "url": "https://en.wikipedia.org/wiki/Humanoid_robot",
        "title": "Humanoid robot"
      },
      {
        "text": "Android",
        "url": "https://en.wikipedia.org/wiki/Android_(robot)",
        "title": "Android (robot)"
      },
      {
        "text": "Cyborg",
        "url": "https://en.wikipedia.org/wiki/Cyborg",
        "title": "Cyborg"
      },
      {
        "text": "Gynoid",
        "url": "https://en.wikipedia.org/wiki/Gynoid",
        "title": "Gynoid"
      },
      {
        "text": "Claytronics",
        "url": "https://en.wikipedia.org/wiki/Claytronics",
        "title": "Claytronics"
      },
      {
        "text": "Companion",
        "url": "https://en.wikipedia.org/wiki/Companion_robot",
        "title": "Companion robot"
      },
      {
        "text": "Automaton",
        "url": "https://en.wikipedia.org/wiki/Automaton",
        "title": "Automaton"
      },
      {
        "text": "Animatronic",
        "url": "https://en.wikipedia.org/wiki/Animatronics",
        "title": "Animatronics"
      },
      {
        "text": "Audio-Animatronics",
        "url": "https://en.wikipedia.org/wiki/Audio-Animatronics",
        "title": "Audio-Animatronics"
      },
      {
        "text": "Industrial",
        "url": "https://en.wikipedia.org/wiki/Industrial_robot",
        "title": "Industrial robot"
      },
      {
        "text": "Articulated",
        "url": "https://en.wikipedia.org/wiki/Articulated_robot",
        "title": "Articulated robot"
      },
      {
        "text": "arm",
        "url": "https://en.wikipedia.org/wiki/Robotic_arm",
        "title": "Robotic arm"
      },
      {
        "text": "Domestic",
        "url": "https://en.wikipedia.org/wiki/Domestic_robot",
        "title": "Domestic robot"
      },
      {
        "text": "Educational",
        "url": "https://en.wikipedia.org/wiki/Educational_robotics",
        "title": "Educational robotics"
      },
      {
        "text": "Entertainment",
        "url": "https://en.wikipedia.org/wiki/Entertainment_robot",
        "title": "Entertainment robot"
      },
      {
        "text": "Juggling",
        "url": "https://en.wikipedia.org/wiki/Juggling_robot",
        "title": "Juggling robot"
      },
      {
        "text": "Military",
        "url": "https://en.wikipedia.org/wiki/Military_robot",
        "title": "Military robot"
      },
      {
        "text": "Medical",
        "url": "https://en.wikipedia.org/wiki/Medical_robot",
        "title": "Medical robot"
      },
      {
        "text": "Service",
        "url": "https://en.wikipedia.org/wiki/Service_robot",
        "title": "Service robot"
      },
      {
        "text": "Disability",
        "url": "https://en.wikipedia.org/wiki/Disability_robot",
        "title": "Disability robot"
      },
      {
        "text": "Agricultural",
        "url": "https://en.wikipedia.org/wiki/Agricultural_robot",
        "title": "Agricultural robot"
      },
      {
        "text": "Food service",
        "url": "https://en.wikipedia.org/wiki/Automated_restaurant",
        "title": "Automated restaurant"
      },
      {
        "text": "Retail",
        "url": "https://en.wikipedia.org/wiki/Automated_retail",
        "title": "Automated retail"
      },
      {
        "text": "BEAM robotics",
        "url": "https://en.wikipedia.org/wiki/BEAM_robotics",
        "title": "BEAM robotics"
      },
      {
        "text": "Soft robotics",
        "url": "https://en.wikipedia.org/wiki/Soft_robotics",
        "title": "Soft robotics"
      },
      {
        "text": "Biorobotics",
        "url": "https://en.wikipedia.org/wiki/Biorobotics",
        "title": "Biorobotics"
      },
      {
        "text": "Cloud robotics",
        "url": "https://en.wikipedia.org/wiki/Cloud_robotics",
        "title": "Cloud robotics"
      },
      {
        "text": "Continuum robot",
        "url": "https://en.wikipedia.org/wiki/Continuum_robot",
        "title": "Continuum robot"
      },
      {
        "text": "Unmanned vehicle",
        "url": "https://en.wikipedia.org/wiki/Unmanned_vehicle",
        "title": "Unmanned vehicle"
      },
      {
        "text": "aerial",
        "url": "https://en.wikipedia.org/wiki/Unmanned_aerial_vehicle",
        "title": "Unmanned aerial vehicle"
      },
      {
        "text": "ground",
        "url": "https://en.wikipedia.org/wiki/Unmanned_ground_vehicle",
        "title": "Unmanned ground vehicle"
      },
      {
        "text": "Mobile robot",
        "url": "https://en.wikipedia.org/wiki/Mobile_robot",
        "title": "Mobile robot"
      },
      {
        "text": "Microbotics",
        "url": "https://en.wikipedia.org/wiki/Microbotics",
        "title": "Microbotics"
      },
      {
        "text": "Nanorobotics",
        "url": "https://en.wikipedia.org/wiki/Nanorobotics",
        "title": "Nanorobotics"
      },
      {
        "text": "Necrobotics",
        "url": "https://en.wikipedia.org/wiki/Necrobotics",
        "title": "Necrobotics"
      },
      {
        "text": "Robotic spacecraft",
        "url": "https://en.wikipedia.org/wiki/Robotic_spacecraft",
        "title": "Robotic spacecraft"
      },
      {
        "text": "Space probe",
        "url": "https://en.wikipedia.org/wiki/Space_probe",
        "title": "Space probe"
      },
      {
        "text": "Swarm",
        "url": "https://en.wikipedia.org/wiki/Swarm_robotics",
        "title": "Swarm robotics"
      },
      {
        "text": "Telerobotics",
        "url": "https://en.wikipedia.org/wiki/Telerobotics",
        "title": "Telerobotics"
      },
      {
        "text": "Underwater",
        "url": "https://en.wikipedia.org/wiki/Autonomous_underwater_vehicle",
        "title": "Autonomous underwater vehicle"
      },
      {
        "text": "remotely-operated",
        "url": "https://en.wikipedia.org/wiki/Remotely_operated_underwater_vehicle",
        "title": "Remotely operated underwater vehicle"
      },
      {
        "text": "Robotic fish",
        "url": "https://en.wikipedia.org/wiki/Robotic_fish",
        "title": "Robotic fish"
      },
      {
        "text": "Locomotion",
        "url": "https://en.wikipedia.org/wiki/Robot_locomotion",
        "title": "Robot locomotion"
      },
      {
        "text": "Tracks",
        "url": "https://en.wikipedia.org/wiki/Continuous_track",
        "title": "Continuous track"
      },
      {
        "text": "Walking",
        "url": "https://en.wikipedia.org/wiki/Legged_robot",
        "title": "Legged robot"
      },
      {
        "text": "Hexapod",
        "url": "https://en.wikipedia.org/wiki/Hexapod_(robotics)",
        "title": "Hexapod (robotics)"
      },
      {
        "text": "Climbing",
        "url": "https://en.wikipedia.org/wiki/Climber_(BEAM)",
        "title": "Climber (BEAM)"
      },
      {
        "text": "Electric unicycle",
        "url": "https://en.wikipedia.org/wiki/Electric_unicycle",
        "title": "Electric unicycle"
      },
      {
        "text": "Robotic fins",
        "url": "https://en.wikipedia.org/wiki/Robotic_fin",
        "title": "Robotic fin"
      },
      {
        "text": "Navigation",
        "url": "https://en.wikipedia.org/wiki/Robotic_navigation",
        "title": "Robotic navigation"
      },
      {
        "text": "mapping",
        "url": "https://en.wikipedia.org/wiki/Robotic_mapping",
        "title": "Robotic mapping"
      },
      {
        "text": "Motion planning",
        "url": "https://en.wikipedia.org/wiki/Motion_planning",
        "title": "Motion planning"
      },
      {
        "text": "Simultaneous localization and mapping",
        "url": "https://en.wikipedia.org/wiki/Simultaneous_localization_and_mapping",
        "title": "Simultaneous localization and mapping"
      },
      {
        "text": "Visual odometry",
        "url": "https://en.wikipedia.org/wiki/Visual_odometry",
        "title": "Visual odometry"
      },
      {
        "text": "Vision-guided robot systems",
        "url": "https://en.wikipedia.org/wiki/Vision-guided_robot_systems",
        "title": "Vision-guided robot systems"
      },
      {
        "text": "Evolutionary",
        "url": "https://en.wikipedia.org/wiki/Evolutionary_robotics",
        "title": "Evolutionary robotics"
      },
      {
        "text": "Kits",
        "url": "https://en.wikipedia.org/wiki/Robot_kit",
        "title": "Robot kit"
      },
      {
        "text": "Simulator",
        "url": "https://en.wikipedia.org/wiki/Robotics_simulator",
        "title": "Robotics simulator"
      },
      {
        "text": "Suite",
        "url": "https://en.wikipedia.org/wiki/Robotics_suite",
        "title": "Robotics suite"
      },
      {
        "text": "Open-source",
        "url": "https://en.wikipedia.org/wiki/Open-source_robotics",
        "title": "Open-source robotics"
      },
      {
        "text": "Software",
        "url": "https://en.wikipedia.org/wiki/Robot_software",
        "title": "Robot software"
      },
      {
        "text": "Adaptable",
        "url": "https://en.wikipedia.org/wiki/Adaptable_robotics",
        "title": "Adaptable robotics"
      },
      {
        "text": "Developmental",
        "url": "https://en.wikipedia.org/wiki/Developmental_robotics",
        "title": "Developmental robotics"
      },
      {
        "text": "Human–robot interaction",
        "url": "https://en.wikipedia.org/wiki/Human%E2%80%93robot_interaction",
        "title": "Human–robot interaction"
      },
      {
        "text": "Paradigms",
        "url": "https://en.wikipedia.org/wiki/Robotic_paradigm",
        "title": "Robotic paradigm"
      },
      {
        "text": "Perceptual",
        "url": "https://en.wikipedia.org/wiki/Perceptual_robotics",
        "title": "Perceptual robotics"
      },
      {
        "text": "Situated",
        "url": "https://en.wikipedia.org/wiki/Situated_robotics",
        "title": "Situated robotics"
      },
      {
        "text": "Ubiquitous",
        "url": "https://en.wikipedia.org/wiki/Ubiquitous_robot",
        "title": "Ubiquitous robot"
      },
      {
        "text": "Companies",
        "url": "https://en.wikipedia.org/wiki/List_of_robotics_companies",
        "title": "List of robotics companies"
      },
      {
        "text": "ABB",
        "url": "https://en.wikipedia.org/wiki/ABB",
        "title": "ABB"
      },
      {
        "text": "Amazon Robotics",
        "url": "https://en.wikipedia.org/wiki/Amazon_Robotics",
        "title": "Amazon Robotics"
      },
      {
        "text": "Anybots",
        "url": "https://en.wikipedia.org/wiki/Anybots",
        "title": "Anybots"
      },
      {
        "text": "Barrett Technology",
        "url": "https://en.wikipedia.org/wiki/Barrett_Technology",
        "title": "Barrett Technology"
      },
      {
        "text": "Boston Dynamics",
        "url": "https://en.wikipedia.org/wiki/Boston_Dynamics",
        "title": "Boston Dynamics"
      },
      {
        "text": "Doosan Robotics",
        "url": "https://en.wikipedia.org/wiki/Doosan_Robotics",
        "title": "Doosan Robotics"
      },
      {
        "text": "Energid Technologies",
        "url": "https://en.wikipedia.org/wiki/Energid_Technologies",
        "title": "Energid Technologies"
      },
      {
        "text": "FarmWise",
        "url": "https://en.wikipedia.org/wiki/FarmWise",
        "title": "FarmWise"
      },
      {
        "text": "FANUC",
        "url": "https://en.wikipedia.org/wiki/FANUC",
        "title": "FANUC"
      },
      {
        "text": "Figure AI",
        "url": "https://en.wikipedia.org/wiki/Figure_AI",
        "title": "Figure AI"
      },
      {
        "text": "Foster-Miller",
        "url": "https://en.wikipedia.org/wiki/Foster-Miller",
        "title": "Foster-Miller"
      },
      {
        "text": "Harvest Automation",
        "url": "https://en.wikipedia.org/wiki/Harvest_Automation",
        "title": "Harvest Automation"
      },
      {
        "text": "HD Hyundai Robotics",
        "url": "https://en.wikipedia.org/wiki/HD_Hyundai_Robotics",
        "title": "HD Hyundai Robotics"
      },
      {
        "text": "Honeybee Robotics",
        "url": "https://en.wikipedia.org/wiki/Honeybee_Robotics",
        "title": "Honeybee Robotics"
      },
      {
        "text": "Intuitive Surgical",
        "url": "https://en.wikipedia.org/wiki/Intuitive_Surgical",
        "title": "Intuitive Surgical"
      },
      {
        "text": "IRobot",
        "url": "https://en.wikipedia.org/wiki/IRobot",
        "title": "IRobot"
      },
      {
        "text": "KUKA",
        "url": "https://en.wikipedia.org/wiki/KUKA",
        "title": "KUKA"
      },
      {
        "text": "Rainbow Robotics",
        "url": "https://en.wikipedia.org/wiki/Rainbow_Robotics",
        "title": "Rainbow Robotics"
      },
      {
        "text": "Starship Technologies",
        "url": "https://en.wikipedia.org/wiki/Starship_Technologies",
        "title": "Starship Technologies"
      },
      {
        "text": "Symbotic",
        "url": "https://en.wikipedia.org/wiki/Symbotic",
        "title": "Symbotic"
      },
      {
        "text": "Universal Robotics",
        "url": "https://en.wikipedia.org/wiki/Universal_Robotics",
        "title": "Universal Robotics"
      },
      {
        "text": "Wolf Robotics",
        "url": "https://en.wikipedia.org/wiki/Wolf_Robotics",
        "title": "Wolf Robotics"
      },
      {
        "text": "Yaskawa",
        "url": "https://en.wikipedia.org/wiki/Yaskawa_Electric_Corporation",
        "title": "Yaskawa Electric Corporation"
      },
      {
        "text": "Critique of work",
        "url": "https://en.wikipedia.org/wiki/Critique_of_work",
        "title": "Critique of work"
      },
      {
        "text": "Powered exoskeleton",
        "url": "https://en.wikipedia.org/wiki/Powered_exoskeleton",
        "title": "Powered exoskeleton"
      },
      {
        "text": "Workplace robotics safety",
        "url": "https://en.wikipedia.org/wiki/Workplace_robotics_safety",
        "title": "Workplace robotics safety"
      },
      {
        "text": "Robotic tech vest",
        "url": "https://en.wikipedia.org/wiki/Robotic_tech_vest",
        "title": "Robotic tech vest"
      },
      {
        "text": "Technological unemployment",
        "url": "https://en.wikipedia.org/wiki/Technological_unemployment",
        "title": "Technological unemployment"
      },
      {
        "text": "Terrainability",
        "url": "https://en.wikipedia.org/wiki/Terrainability",
        "title": "Terrainability"
      },
      {
        "text": "Fictional robots",
        "url": "https://en.wikipedia.org/wiki/List_of_fictional_robots_and_androids",
        "title": "List of fictional robots and androids"
      },
      {
        "text": "Category",
        "url": "https://en.wikipedia.org/wiki/Category:Robotics",
        "title": "Category:Robotics"
      },
      {
        "text": "Outline",
        "url": "https://en.wikipedia.org/wiki/Outline_of_robotics",
        "title": "Outline of robotics"
      },
      {
        "text": "v",
        "url": "https://en.wikipedia.org/wiki/Template:Existential_risk_from_artificial_intelligence",
        "title": "Template:Existential risk from artificial intelligence"
      },
      {
        "text": "t",
        "url": "https://en.wikipedia.org/wiki/Template_talk:Existential_risk_from_artificial_intelligence",
        "title": "Template talk:Existential risk from artificial intelligence"
      },
      {
        "text": "e",
        "url": "https://en.wikipedia.org/wiki/Special:EditPage/Template:Existential_risk_from_artificial_intelligence",
        "title": "Special:EditPage/Template:Existential risk from artificial intelligence"
      },
      {
        "text": "Existential risk",
        "url": "https://en.wikipedia.org/wiki/Existential_risk_from_artificial_intelligence",
        "title": "Existential risk from artificial intelligence"
      },
      {
        "text": "AGI",
        "url": "https://en.wikipedia.org/wiki/Artificial_general_intelligence",
        "title": "Artificial general intelligence"
      },
      {
        "text": "AI alignment",
        "url": "https://en.wikipedia.org/wiki/AI_alignment",
        "title": "AI alignment"
      },
      {
        "text": "AI capability control",
        "url": "https://en.wikipedia.org/wiki/AI_capability_control",
        "title": "AI capability control"
      },
      {
        "text": "AI safety",
        "url": "https://en.wikipedia.org/wiki/AI_safety",
        "title": "AI safety"
      },
      {
        "text": "AI takeover",
        "url": "https://en.wikipedia.org/wiki/AI_takeover",
        "title": "AI takeover"
      },
      {
        "text": "Consequentialism",
        "url": "https://en.wikipedia.org/wiki/Consequentialism",
        "title": "Consequentialism"
      },
      {
        "text": "Effective accelerationism",
        "url": "https://en.wikipedia.org/wiki/Effective_accelerationism",
        "title": "Effective accelerationism"
      },
      {
        "text": "Ethics of artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Ethics_of_artificial_intelligence",
        "title": "Ethics of artificial intelligence"
      },
      {
        "text": "Existential risk from artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Existential_risk_from_artificial_intelligence",
        "title": "Existential risk from artificial intelligence"
      },
      {
        "text": "Friendly artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Friendly_artificial_intelligence",
        "title": "Friendly artificial intelligence"
      },
      {
        "text": "Instrumental convergence",
        "url": "https://en.wikipedia.org/wiki/Instrumental_convergence",
        "title": "Instrumental convergence"
      },
      {
        "text": "Vulnerable world hypothesis",
        "url": "https://en.wikipedia.org/wiki/Vulnerable_world_hypothesis",
        "title": "Vulnerable world hypothesis"
      },
      {
        "text": "Intelligence explosion",
        "url": "https://en.wikipedia.org/wiki/Intelligence_explosion",
        "title": "Intelligence explosion"
      },
      {
        "text": "Longtermism",
        "url": "https://en.wikipedia.org/wiki/Longtermism",
        "title": "Longtermism"
      },
      {
        "text": "Machine ethics",
        "url": "https://en.wikipedia.org/wiki/Machine_ethics",
        "title": "Machine ethics"
      },
      {
        "text": "Suffering risks",
        "url": "https://en.wikipedia.org/wiki/Risk_of_astronomical_suffering",
        "title": "Risk of astronomical suffering"
      },
      {
        "text": "Superintelligence",
        "url": "https://en.wikipedia.org/wiki/Superintelligence",
        "title": "Superintelligence"
      },
      {
        "text": "Technological singularity",
        "url": "https://en.wikipedia.org/wiki/Technological_singularity",
        "title": "Technological singularity"
      },
      {
        "text": "Alignment Research Center",
        "url": "https://en.wikipedia.org/wiki/Alignment_Research_Center",
        "title": "Alignment Research Center"
      },
      {
        "text": "Center for AI Safety",
        "url": "https://en.wikipedia.org/wiki/Center_for_AI_Safety",
        "title": "Center for AI Safety"
      },
      {
        "text": "Center for Applied Rationality",
        "url": "https://en.wikipedia.org/wiki/Center_for_Applied_Rationality",
        "title": "Center for Applied Rationality"
      },
      {
        "text": "Center for Human-Compatible Artificial Intelligence",
        "url": "https://en.wikipedia.org/wiki/Center_for_Human-Compatible_Artificial_Intelligence",
        "title": "Center for Human-Compatible Artificial Intelligence"
      },
      {
        "text": "Centre for the Study of Existential Risk",
        "url": "https://en.wikipedia.org/wiki/Centre_for_the_Study_of_Existential_Risk",
        "title": "Centre for the Study of Existential Risk"
      },
      {
        "text": "EleutherAI",
        "url": "https://en.wikipedia.org/wiki/EleutherAI",
        "title": "EleutherAI"
      },
      {
        "text": "Future of Humanity Institute",
        "url": "https://en.wikipedia.org/wiki/Future_of_Humanity_Institute",
        "title": "Future of Humanity Institute"
      },
      {
        "text": "Future of Life Institute",
        "url": "https://en.wikipedia.org/wiki/Future_of_Life_Institute",
        "title": "Future of Life Institute"
      },
      {
        "text": "Google DeepMind",
        "url": "https://en.wikipedia.org/wiki/Google_DeepMind",
        "title": "Google DeepMind"
      },
      {
        "text": "Humanity+",
        "url": "https://en.wikipedia.org/wiki/Humanity%2B",
        "title": "Humanity+"
      },
      {
        "text": "Institute for Ethics and Emerging Technologies",
        "url": "https://en.wikipedia.org/wiki/Institute_for_Ethics_and_Emerging_Technologies",
        "title": "Institute for Ethics and Emerging Technologies"
      },
      {
        "text": "Leverhulme Centre for the Future of Intelligence",
        "url": "https://en.wikipedia.org/wiki/Leverhulme_Centre_for_the_Future_of_Intelligence",
        "title": "Leverhulme Centre for the Future of Intelligence"
      },
      {
        "text": "Machine Intelligence Research Institute",
        "url": "https://en.wikipedia.org/wiki/Machine_Intelligence_Research_Institute",
        "title": "Machine Intelligence Research Institute"
      },
      {
        "text": "OpenAI",
        "url": "https://en.wikipedia.org/wiki/OpenAI",
        "title": "OpenAI"
      },
      {
        "text": "Scott Alexander",
        "url": "https://en.wikipedia.org/wiki/Slate_Star_Codex",
        "title": "Slate Star Codex"
      },
      {
        "text": "Sam Altman",
        "url": "https://en.wikipedia.org/wiki/Sam_Altman",
        "title": "Sam Altman"
      },
      {
        "text": "Yoshua Bengio",
        "url": "https://en.wikipedia.org/wiki/Yoshua_Bengio",
        "title": "Yoshua Bengio"
      },
      {
        "text": "Nick Bostrom",
        "url": "https://en.wikipedia.org/wiki/Nick_Bostrom",
        "title": "Nick Bostrom"
      },
      {
        "text": "Paul Christiano",
        "url": "https://en.wikipedia.org/wiki/Paul_Christiano_(researcher)",
        "title": "Paul Christiano (researcher)"
      },
      {
        "text": "Eric Drexler",
        "url": "https://en.wikipedia.org/wiki/K._Eric_Drexler",
        "title": "K. Eric Drexler"
      },
      {
        "text": "Sam Harris",
        "url": "https://en.wikipedia.org/wiki/Sam_Harris",
        "title": "Sam Harris"
      },
      {
        "text": "Stephen Hawking",
        "url": "https://en.wikipedia.org/wiki/Stephen_Hawking",
        "title": "Stephen Hawking"
      },
      {
        "text": "Dan Hendrycks",
        "url": "https://en.wikipedia.org/wiki/Dan_Hendrycks",
        "title": "Dan Hendrycks"
      },
      {
        "text": "Geoffrey Hinton",
        "url": "https://en.wikipedia.org/wiki/Geoffrey_Hinton",
        "title": "Geoffrey Hinton"
      },
      {
        "text": "Bill Joy",
        "url": "https://en.wikipedia.org/wiki/Bill_Joy",
        "title": "Bill Joy"
      },
      {
        "text": "Shane Legg",
        "url": "https://en.wikipedia.org/wiki/Shane_Legg",
        "title": "Shane Legg"
      },
      {
        "text": "Elon Musk",
        "url": "https://en.wikipedia.org/wiki/Elon_Musk",
        "title": "Elon Musk"
      },
      {
        "text": "Steve Omohundro",
        "url": "https://en.wikipedia.org/wiki/Steve_Omohundro",
        "title": "Steve Omohundro"
      },
      {
        "text": "Huw Price",
        "url": "https://en.wikipedia.org/wiki/Huw_Price",
        "title": "Huw Price"
      },
      {
        "text": "Martin Rees",
        "url": "https://en.wikipedia.org/wiki/Martin_Rees",
        "title": "Martin Rees"
      },
      {
        "text": "Stuart J. Russell",
        "url": "https://en.wikipedia.org/wiki/Stuart_J._Russell",
        "title": "Stuart J. Russell"
      },
      {
        "text": "Jaan Tallinn",
        "url": "https://en.wikipedia.org/wiki/Jaan_Tallinn",
        "title": "Jaan Tallinn"
      },
      {
        "text": "Max Tegmark",
        "url": "https://en.wikipedia.org/wiki/Max_Tegmark",
        "title": "Max Tegmark"
      },
      {
        "text": "Frank Wilczek",
        "url": "https://en.wikipedia.org/wiki/Frank_Wilczek",
        "title": "Frank Wilczek"
      },
      {
        "text": "Roman Yampolskiy",
        "url": "https://en.wikipedia.org/wiki/Roman_Yampolskiy",
        "title": "Roman Yampolskiy"
      },
      {
        "text": "Eliezer Yudkowsky",
        "url": "https://en.wikipedia.org/wiki/Eliezer_Yudkowsky",
        "title": "Eliezer Yudkowsky"
      },
      {
        "text": "Statement on AI risk of extinction",
        "url": "https://en.wikipedia.org/wiki/Statement_on_AI_risk_of_extinction",
        "title": "Statement on AI risk of extinction"
      },
      {
        "text": "Human Compatible",
        "url": "https://en.wikipedia.org/wiki/Human_Compatible",
        "title": "Human Compatible"
      },
      {
        "text": "Open letter on artificial intelligence (2015)",
        "url": "https://en.wikipedia.org/wiki/Open_letter_on_artificial_intelligence_(2015)",
        "title": "Open letter on artificial intelligence (2015)"
      },
      {
        "text": "Our Final Invention",
        "url": "https://en.wikipedia.org/wiki/Our_Final_Invention",
        "title": "Our Final Invention"
      },
      {
        "text": "The Precipice",
        "url": "https://en.wikipedia.org/wiki/The_Precipice:_Existential_Risk_and_the_Future_of_Humanity",
        "title": "The Precipice: Existential Risk and the Future of Humanity"
      },
      {
        "text": "Superintelligence: Paths, Dangers, Strategies",
        "url": "https://en.wikipedia.org/wiki/Superintelligence:_Paths,_Dangers,_Strategies",
        "title": "Superintelligence: Paths, Dangers, Strategies"
      },
      {
        "text": "Do You Trust This Computer?",
        "url": "https://en.wikipedia.org/wiki/Do_You_Trust_This_Computer%3F",
        "title": "Do You Trust This Computer?"
      },
      {
        "text": "Artificial Intelligence Act",
        "url": "https://en.wikipedia.org/wiki/Artificial_Intelligence_Act",
        "title": "Artificial Intelligence Act"
      },
      {
        "text": "Category",
        "url": "https://en.wikipedia.org/wiki/Category:Existential_risk_from_artificial_general_intelligence",
        "title": "Category:Existential risk from artificial general intelligence"
      },
      {
        "text": "v",
        "url": "https://en.wikipedia.org/wiki/Template:Cybernetics",
        "title": "Template:Cybernetics"
      },
      {
        "text": "t",
        "url": "https://en.wikipedia.org/wiki/Template_talk:Cybernetics",
        "title": "Template talk:Cybernetics"
      },
      {
        "text": "e",
        "url": "https://en.wikipedia.org/wiki/Special:EditPage/Template:Cybernetics",
        "title": "Special:EditPage/Template:Cybernetics"
      },
      {
        "text": "cybernetics",
        "url": "https://en.wikipedia.org/wiki/Cybernetics",
        "title": "Cybernetics"
      },
      {
        "text": "Biological cybernetics",
        "url": "https://en.wikipedia.org/wiki/Biocybernetics",
        "title": "Biocybernetics"
      },
      {
        "text": "Biomedical cybernetics",
        "url": "https://en.wikipedia.org/wiki/Biomedical_cybernetics",
        "title": "Biomedical cybernetics"
      },
      {
        "text": "Biorobotics",
        "url": "https://en.wikipedia.org/wiki/Biorobotics",
        "title": "Biorobotics"
      },
      {
        "text": "Biosemiotics",
        "url": "https://en.wikipedia.org/wiki/Biosemiotics",
        "title": "Biosemiotics"
      },
      {
        "text": "Neurocybernetics",
        "url": "https://en.wikipedia.org/wiki/Brain%E2%80%93computer_interface",
        "title": "Brain–computer interface"
      },
      {
        "text": "Catastrophe theory",
        "url": "https://en.wikipedia.org/wiki/Catastrophe_theory",
        "title": "Catastrophe theory"
      },
      {
        "text": "Computational neuroscience",
        "url": "https://en.wikipedia.org/wiki/Computational_neuroscience",
        "title": "Computational neuroscience"
      },
      {
        "text": "Connectionism",
        "url": "https://en.wikipedia.org/wiki/Connectionism",
        "title": "Connectionism"
      },
      {
        "text": "Control theory",
        "url": "https://en.wikipedia.org/wiki/Control_theory",
        "title": "Control theory"
      },
      {
        "text": "Conversation theory",
        "url": "https://en.wikipedia.org/wiki/Conversation_theory",
        "title": "Conversation theory"
      },
      {
        "text": "Cybernetics in the Soviet Union",
        "url": "https://en.wikipedia.org/wiki/Cybernetics_in_the_Soviet_Union",
        "title": "Cybernetics in the Soviet Union"
      },
      {
        "text": "Decision theory",
        "url": "https://en.wikipedia.org/wiki/Decision_theory",
        "title": "Decision theory"
      },
      {
        "text": "Emergence",
        "url": "https://en.wikipedia.org/wiki/Emergence",
        "title": "Emergence"
      },
      {
        "text": "Engineering cybernetics",
        "url": "https://en.wikipedia.org/wiki/Engineering_cybernetics",
        "title": "Engineering cybernetics"
      },
      {
        "text": "Homeostasis",
        "url": "https://en.wikipedia.org/wiki/Homeostasis",
        "title": "Homeostasis"
      },
      {
        "text": "Information theory",
        "url": "https://en.wikipedia.org/wiki/Information_theory",
        "title": "Information theory"
      },
      {
        "text": "Management cybernetics",
        "url": "https://en.wikipedia.org/wiki/Management_cybernetics",
        "title": "Management cybernetics"
      },
      {
        "text": "Medical cybernetics",
        "url": "https://en.wikipedia.org/wiki/Medical_cybernetics",
        "title": "Medical cybernetics"
      },
      {
        "text": "Second-order cybernetics",
        "url": "https://en.wikipedia.org/wiki/Second-order_cybernetics",
        "title": "Second-order cybernetics"
      },
      {
        "text": "Cybersemiotics",
        "url": "https://en.wikipedia.org/wiki/Cybersemiotics",
        "title": "Cybersemiotics"
      },
      {
        "text": "Sociocybernetics",
        "url": "https://en.wikipedia.org/wiki/Sociocybernetics",
        "title": "Sociocybernetics"
      },
      {
        "text": "Synergetics",
        "url": "https://en.wikipedia.org/wiki/Synergetics_(Haken)",
        "title": "Synergetics (Haken)"
      },
      {
        "text": "Cyberneticians",
        "url": "https://en.wikipedia.org/wiki/Cyberneticist",
        "title": "Cyberneticist"
      },
      {
        "text": "Alexander Lerner",
        "url": "https://en.wikipedia.org/wiki/Alexander_Lerner",
        "title": "Alexander Lerner"
      },
      {
        "text": "Alexey Lyapunov",
        "url": "https://en.wikipedia.org/wiki/Alexey_Lyapunov",
        "title": "Alexey Lyapunov"
      },
      {
        "text": "Alfred Radcliffe-Brown",
        "url": "https://en.wikipedia.org/wiki/Alfred_Radcliffe-Brown",
        "title": "Alfred Radcliffe-Brown"
      },
      {
        "text": "Allenna Leonard",
        "url": "https://en.wikipedia.org/wiki/Allenna_Leonard",
        "title": "Allenna Leonard"
      },
      {
        "text": "Anthony Wilden",
        "url": "https://en.wikipedia.org/wiki/Anthony_Wilden",
        "title": "Anthony Wilden"
      },
      {
        "text": "Buckminster Fuller",
        "url": "https://en.wikipedia.org/wiki/Buckminster_Fuller",
        "title": "Buckminster Fuller"
      },
      {
        "text": "Charles François",
        "url": "https://en.wikipedia.org/wiki/Charles_Fran%C3%A7ois_(systems_scientist)",
        "title": "Charles François (systems scientist)"
      },
      {
        "text": "Genevieve Bell",
        "url": "https://en.wikipedia.org/wiki/Genevieve_Bell",
        "title": "Genevieve Bell"
      },
      {
        "text": "Margaret Boden",
        "url": "https://en.wikipedia.org/wiki/Margaret_Boden",
        "title": "Margaret Boden"
      },
      {
        "text": "Claude Bernard",
        "url": "https://en.wikipedia.org/wiki/Claude_Bernard",
        "title": "Claude Bernard"
      },
      {
        "text": "Cliff Joslyn",
        "url": "https://en.wikipedia.org/wiki/Cliff_Joslyn",
        "title": "Cliff Joslyn"
      },
      {
        "text": "Erich von Holst",
        "url": "https://en.wikipedia.org/wiki/Erich_von_Holst",
        "title": "Erich von Holst"
      },
      {
        "text": "Ernst von Glasersfeld",
        "url": "https://en.wikipedia.org/wiki/Ernst_von_Glasersfeld",
        "title": "Ernst von Glasersfeld"
      },
      {
        "text": "Francis Heylighen",
        "url": "https://en.wikipedia.org/wiki/Francis_Heylighen",
        "title": "Francis Heylighen"
      },
      {
        "text": "Francisco Varela",
        "url": "https://en.wikipedia.org/wiki/Francisco_Varela",
        "title": "Francisco Varela"
      },
      {
        "text": "Frederic Vester",
        "url": "https://en.wikipedia.org/wiki/Frederic_Vester",
        "title": "Frederic Vester"
      },
      {
        "text": "Charles Geoffrey Vickers",
        "url": "https://en.wikipedia.org/wiki/Geoffrey_Vickers",
        "title": "Geoffrey Vickers"
      },
      {
        "text": "Gordon Pask",
        "url": "https://en.wikipedia.org/wiki/Gordon_Pask",
        "title": "Gordon Pask"
      },
      {
        "text": "Gordon S. Brown",
        "url": "https://en.wikipedia.org/wiki/Gordon_S._Brown",
        "title": "Gordon S. Brown"
      },
      {
        "text": "Gregory Bateson",
        "url": "https://en.wikipedia.org/wiki/Gregory_Bateson",
        "title": "Gregory Bateson"
      },
      {
        "text": "Heinz von Foerster",
        "url": "https://en.wikipedia.org/wiki/Heinz_von_Foerster",
        "title": "Heinz von Foerster"
      },
      {
        "text": "Humberto Maturana",
        "url": "https://en.wikipedia.org/wiki/Humberto_Maturana",
        "title": "Humberto Maturana"
      },
      {
        "text": "I. A. Richards",
        "url": "https://en.wikipedia.org/wiki/I._A._Richards",
        "title": "I. A. Richards"
      },
      {
        "text": "Igor Aleksander",
        "url": "https://en.wikipedia.org/wiki/Igor_Aleksander",
        "title": "Igor Aleksander"
      },
      {
        "text": "Jacque Fresco",
        "url": "https://en.wikipedia.org/wiki/Jacque_Fresco",
        "title": "Jacque Fresco"
      },
      {
        "text": "Jakob von Uexküll",
        "url": "https://en.wikipedia.org/wiki/Jakob_Johann_von_Uexk%C3%BCll",
        "title": "Jakob Johann von Uexküll"
      },
      {
        "text": "Jason Jixuan Hu",
        "url": "https://en.wikipedia.org/wiki/Jason_Jixuan_Hu",
        "title": "Jason Jixuan Hu"
      },
      {
        "text": "Jay Wright Forrester",
        "url": "https://en.wikipedia.org/wiki/Jay_Wright_Forrester",
        "title": "Jay Wright Forrester"
      },
      {
        "text": "Jennifer Wilby",
        "url": "https://en.wikipedia.org/wiki/Jennifer_Wilby",
        "title": "Jennifer Wilby"
      },
      {
        "text": "John N. Warfield",
        "url": "https://en.wikipedia.org/wiki/John_N._Warfield",
        "title": "John N. Warfield"
      },
      {
        "text": "Kevin Warwick",
        "url": "https://en.wikipedia.org/wiki/Kevin_Warwick",
        "title": "Kevin Warwick"
      },
      {
        "text": "Ludwig von Bertalanffy",
        "url": "https://en.wikipedia.org/wiki/Ludwig_von_Bertalanffy",
        "title": "Ludwig von Bertalanffy"
      },
      {
        "text": "Maleyka Abbaszadeh",
        "url": "https://en.wikipedia.org/wiki/Maleyka_Abbaszadeh",
        "title": "Maleyka Abbaszadeh"
      },
      {
        "text": "Manfred Clynes",
        "url": "https://en.wikipedia.org/wiki/Manfred_Clynes",
        "title": "Manfred Clynes"
      },
      {
        "text": "Margaret Mead",
        "url": "https://en.wikipedia.org/wiki/Margaret_Mead",
        "title": "Margaret Mead"
      },
      {
        "text": "Marian Mazur",
        "url": "https://en.wikipedia.org/wiki/Marian_Mazur",
        "title": "Marian Mazur"
      },
      {
        "text": "N. Katherine Hayles",
        "url": "https://en.wikipedia.org/wiki/N._Katherine_Hayles",
        "title": "N. Katherine Hayles"
      },
      {
        "text": "Natalia Bekhtereva",
        "url": "https://en.wikipedia.org/wiki/Natalia_Bekhtereva",
        "title": "Natalia Bekhtereva"
      },
      {
        "text": "Niklas Luhmann",
        "url": "https://en.wikipedia.org/wiki/Niklas_Luhmann",
        "title": "Niklas Luhmann"
      },
      {
        "text": "Norbert Wiener",
        "url": "https://en.wikipedia.org/wiki/Norbert_Wiener",
        "title": "Norbert Wiener"
      },
      {
        "text": "Pyotr Grigorenko",
        "url": "https://en.wikipedia.org/wiki/Petro_Grigorenko",
        "title": "Petro Grigorenko"
      },
      {
        "text": "Qian Xuesen",
        "url": "https://en.wikipedia.org/wiki/Qian_Xuesen",
        "title": "Qian Xuesen"
      },
      {
        "text": "Ranulph Glanville",
        "url": "https://en.wikipedia.org/wiki/Ranulph_Glanville",
        "title": "Ranulph Glanville"
      },
      {
        "text": "Robert Trappl",
        "url": "https://en.wikipedia.org/wiki/Robert_Trappl",
        "title": "Robert Trappl"
      },
      {
        "text": "Sergei P. Kurdyumov",
        "url": "https://en.wikipedia.org/wiki/Sergei_P._Kurdyumov",
        "title": "Sergei P. Kurdyumov"
      },
      {
        "text": "Anthony Stafford Beer",
        "url": "https://en.wikipedia.org/wiki/Stafford_Beer",
        "title": "Stafford Beer"
      },
      {
        "text": "Stuart Kauffman",
        "url": "https://en.wikipedia.org/wiki/Stuart_Kauffman",
        "title": "Stuart Kauffman"
      },
      {
        "text": "Stuart Umpleby",
        "url": "https://en.wikipedia.org/wiki/Stuart_Umpleby",
        "title": "Stuart Umpleby"
      },
      {
        "text": "Talcott Parsons",
        "url": "https://en.wikipedia.org/wiki/Talcott_Parsons",
        "title": "Talcott Parsons"
      },
      {
        "text": "Ulla Mitzdorf",
        "url": "https://en.wikipedia.org/wiki/Ulla_Mitzdorf",
        "title": "Ulla Mitzdorf"
      },
      {
        "text": "Valentin Turchin",
        "url": "https://en.wikipedia.org/wiki/Valentin_Turchin",
        "title": "Valentin Turchin"
      },
      {
        "text": "Valentin Braitenberg",
        "url": "https://en.wikipedia.org/wiki/Valentino_Braitenberg",
        "title": "Valentino Braitenberg"
      },
      {
        "text": "William Ross Ashby",
        "url": "https://en.wikipedia.org/wiki/W._Ross_Ashby",
        "title": "W. Ross Ashby"
      },
      {
        "text": "Walter Bradford Cannon",
        "url": "https://en.wikipedia.org/wiki/Walter_Bradford_Cannon",
        "title": "Walter Bradford Cannon"
      },
      {
        "text": "Walter Pitts",
        "url": "https://en.wikipedia.org/wiki/Walter_Pitts",
        "title": "Walter Pitts"
      },
      {
        "text": "Warren McCulloch",
        "url": "https://en.wikipedia.org/wiki/Warren_Sturgis_McCulloch",
        "title": "Warren Sturgis McCulloch"
      },
      {
        "text": "William Grey Walter",
        "url": "https://en.wikipedia.org/wiki/William_Grey_Walter",
        "title": "William Grey Walter"
      },
      {
        "text": "v",
        "url": "https://en.wikipedia.org/wiki/Template:Glossaries_of_science_and_engineering",
        "title": "Template:Glossaries of science and engineering"
      },
      {
        "text": "t",
        "url": "https://en.wikipedia.org/wiki/Template_talk:Glossaries_of_science_and_engineering",
        "title": "Template talk:Glossaries of science and engineering"
      },
      {
        "text": "e",
        "url": "https://en.wikipedia.org/wiki/Special:EditPage/Template:Glossaries_of_science_and_engineering",
        "title": "Special:EditPage/Template:Glossaries of science and engineering"
      },
      {
        "text": "science",
        "url": "https://en.wikipedia.org/wiki/Science",
        "title": "Science"
      },
      {
        "text": "engineering",
        "url": "https://en.wikipedia.org/wiki/Engineering",
        "title": "Engineering"
      },
      {
        "text": "Aerospace engineering",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_aerospace_engineering",
        "title": "Glossary of aerospace engineering"
      },
      {
        "text": "Agriculture",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_agriculture",
        "title": "Glossary of agriculture"
      },
      {
        "text": "Archaeology",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_archaeology",
        "title": "Glossary of archaeology"
      },
      {
        "text": "Architecture",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_architecture",
        "title": "Glossary of architecture"
      },
      {
        "text": "Artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_artificial_intelligence",
        "title": "Glossary of artificial intelligence"
      },
      {
        "text": "Astronomy",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_astronomy",
        "title": "Glossary of astronomy"
      },
      {
        "text": "Biology",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_biology",
        "title": "Glossary of biology"
      },
      {
        "text": "Botany",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_botanical_terms",
        "title": "Glossary of botanical terms"
      },
      {
        "text": "Calculus",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_calculus",
        "title": "Glossary of calculus"
      },
      {
        "text": "Cell biology",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_cell_biology",
        "title": "Glossary of cell biology"
      },
      {
        "text": "0–L",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_cellular_and_molecular_biology_(0%E2%80%93L)",
        "title": "Glossary of cellular and molecular biology (0–L)"
      },
      {
        "text": "M–Z",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_cellular_and_molecular_biology_(M%E2%80%93Z)",
        "title": "Glossary of cellular and molecular biology (M–Z)"
      },
      {
        "text": "Chemistry",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_chemistry_terms",
        "title": "Glossary of chemistry terms"
      },
      {
        "text": "Civil engineering",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_civil_engineering",
        "title": "Glossary of civil engineering"
      },
      {
        "text": "Clinical research",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_clinical_research",
        "title": "Glossary of clinical research"
      },
      {
        "text": "Computer hardware",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_computer_hardware_terms",
        "title": "Glossary of computer hardware terms"
      },
      {
        "text": "Computer science",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_computer_science",
        "title": "Glossary of computer science"
      },
      {
        "text": "Developmental and reproductive biology",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_developmental_biology",
        "title": "Glossary of developmental biology"
      },
      {
        "text": "Ecology",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_ecology",
        "title": "Glossary of ecology"
      },
      {
        "text": "Economics",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_economics",
        "title": "Glossary of economics"
      },
      {
        "text": "Electrical and electronics engineering",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_electrical_and_electronics_engineering",
        "title": "Glossary of electrical and electronics engineering"
      },
      {
        "text": "A–L",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_engineering:_A%E2%80%93L",
        "title": "Glossary of engineering: A–L"
      },
      {
        "text": "M–Z",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_engineering:_M%E2%80%93Z",
        "title": "Glossary of engineering: M–Z"
      },
      {
        "text": "Entomology",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_entomology_terms",
        "title": "Glossary of entomology terms"
      },
      {
        "text": "Environmental science",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_environmental_science",
        "title": "Glossary of environmental science"
      },
      {
        "text": "Genetics and evolutionary biology",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_genetics_and_evolutionary_biology",
        "title": "Glossary of genetics and evolutionary biology"
      },
      {
        "text": "A–M",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_geography_terms_(A%E2%80%93M)",
        "title": "Glossary of geography terms (A–M)"
      },
      {
        "text": "N–Z",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_geography_terms_(N%E2%80%93Z)",
        "title": "Glossary of geography terms (N–Z)"
      },
      {
        "text": "Arabic toponyms",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_Arabic_toponyms",
        "title": "Glossary of Arabic toponyms"
      },
      {
        "text": "Hebrew toponyms",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_Hebrew_toponyms",
        "title": "Glossary of Hebrew toponyms"
      },
      {
        "text": "Western and South Asia",
        "url": "https://en.wikipedia.org/wiki/Oikonyms_in_Western_and_South_Asia",
        "title": "Oikonyms in Western and South Asia"
      },
      {
        "text": "Geology",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_geology",
        "title": "Glossary of geology"
      },
      {
        "text": "Ichthyology",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_ichthyology",
        "title": "Glossary of ichthyology"
      },
      {
        "text": "Machine vision",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_machine_vision",
        "title": "Glossary of machine vision"
      },
      {
        "text": "Mathematics",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_areas_of_mathematics",
        "title": "Glossary of areas of mathematics"
      },
      {
        "text": "Mechanical engineering",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_mechanical_engineering",
        "title": "Glossary of mechanical engineering"
      },
      {
        "text": "Medicine",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_medicine",
        "title": "Glossary of medicine"
      },
      {
        "text": "Meteorology",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_meteorology",
        "title": "Glossary of meteorology"
      },
      {
        "text": "Mycology",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_mycology",
        "title": "Glossary of mycology"
      },
      {
        "text": "Nanotechnology",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_nanotechnology",
        "title": "Glossary of nanotechnology"
      },
      {
        "text": "Ornithology",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_bird_terms",
        "title": "Glossary of bird terms"
      },
      {
        "text": "Physics",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_physics",
        "title": "Glossary of physics"
      },
      {
        "text": "Probability and statistics",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_probability_and_statistics",
        "title": "Glossary of probability and statistics"
      },
      {
        "text": "Psychiatry",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_psychiatry",
        "title": "Glossary of psychiatry"
      },
      {
        "text": "Quantum computing",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_quantum_computing",
        "title": "Glossary of quantum computing"
      },
      {
        "text": "Robotics",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_robotics",
        "title": "Glossary of robotics"
      },
      {
        "text": "Scientific naming",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_scientific_naming",
        "title": "Glossary of scientific naming"
      },
      {
        "text": "Structural engineering",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_structural_engineering",
        "title": "Glossary of structural engineering"
      },
      {
        "text": "Virology",
        "url": "https://en.wikipedia.org/wiki/Glossary_of_virology",
        "title": "Glossary of virology"
      },
      {
        "text": "Authority control databases",
        "url": "https://en.wikipedia.org/wiki/Help:Authority_control",
        "title": "Help:Authority control"
      },
      {
        "text": "Germany",
        "url": "https://d-nb.info/gnd/4033447-8"
      },
      {
        "text": "United States",
        "url": "https://id.loc.gov/authorities/sh85008180"
      },
      {
        "text": "France",
        "url": "https://catalogue.bnf.fr/ark:/12148/cb11932084t"
      },
      {
        "text": "BnF data",
        "url": "https://data.bnf.fr/ark:/12148/cb11932084t"
      },
      {
        "text": "Japan",
        "url": "https://id.ndl.go.jp/auth/ndlna/00574798"
      },
      {
        "text": "Czech Republic",
        "url": "https://aleph.nkp.cz/F/?func=find-c&local_base=aut&ccl_term=ica=ph116536&CON_LNG=ENG"
      },
      {
        "text": "Spain",
        "url": "https://datos.bne.es/resource/XX4659822"
      },
      {
        "text": "Latvia",
        "url": "https://kopkatalogs.lv/F?func=direct&local_base=lnc10&doc_number=000050010&P_CON_LNG=ENG"
      },
      {
        "text": "Israel",
        "url": "https://www.nli.org.il/en/authorities/987007294969105171"
      },
      {
        "text": "https://en.wikipedia.org/w/index.php?title=Artificial_intelligence&oldid=1289722010",
        "url": "https://en.wikipedia.org/w/index.php?title=Artificial_intelligence&oldid=1289722010"
      },
      {
        "text": "Categories",
        "url": "https://en.wikipedia.org/wiki/Help:Category",
        "title": "Help:Category"
      },
      {
        "text": "Artificial intelligence",
        "url": "https://en.wikipedia.org/wiki/Category:Artificial_intelligence",
        "title": "Category:Artificial intelligence"
      },
      {
        "text": "Computational fields of study",
        "url": "https://en.wikipedia.org/wiki/Category:Computational_fields_of_study",
        "title": "Category:Computational fields of study"
      },
      {
        "text": "Computational neuroscience",
        "url": "https://en.wikipedia.org/wiki/Category:Computational_neuroscience",
        "title": "Category:Computational neuroscience"
      },
      {
        "text": "Cybernetics",
        "url": "https://en.wikipedia.org/wiki/Category:Cybernetics",
        "title": "Category:Cybernetics"
      },
      {
        "text": "Data science",
        "url": "https://en.wikipedia.org/wiki/Category:Data_science",
        "title": "Category:Data science"
      },
      {
        "text": "Formal sciences",
        "url": "https://en.wikipedia.org/wiki/Category:Formal_sciences",
        "title": "Category:Formal sciences"
      },
      {
        "text": "Intelligence by type",
        "url": "https://en.wikipedia.org/wiki/Category:Intelligence_by_type",
        "title": "Category:Intelligence by type"
      },
      {
        "text": "Webarchive template wayback links",
        "url": "https://en.wikipedia.org/wiki/Category:Webarchive_template_wayback_links",
        "title": "Category:Webarchive template wayback links"
      },
      {
        "text": "CS1 German-language sources (de)",
        "url": "https://en.wikipedia.org/wiki/Category:CS1_German-language_sources_(de)",
        "title": "Category:CS1 German-language sources (de)"
      },
      {
        "text": "CS1 Japanese-language sources (ja)",
        "url": "https://en.wikipedia.org/wiki/Category:CS1_Japanese-language_sources_(ja)",
        "title": "Category:CS1 Japanese-language sources (ja)"
      },
      {
        "text": "Articles with short description",
        "url": "https://en.wikipedia.org/wiki/Category:Articles_with_short_description",
        "title": "Category:Articles with short description"
      },
      {
        "text": "Short description is different from Wikidata",
        "url": "https://en.wikipedia.org/wiki/Category:Short_description_is_different_from_Wikidata",
        "title": "Category:Short description is different from Wikidata"
      },
      {
        "text": "Use dmy dates from July 2023",
        "url": "https://en.wikipedia.org/wiki/Category:Use_dmy_dates_from_July_2023",
        "title": "Category:Use dmy dates from July 2023"
      },
      {
        "text": "Wikipedia indefinitely semi-protected pages",
        "url": "https://en.wikipedia.org/wiki/Category:Wikipedia_indefinitely_semi-protected_pages",
        "title": "Category:Wikipedia indefinitely semi-protected pages"
      },
      {
        "text": "Articles with excerpts",
        "url": "https://en.wikipedia.org/wiki/Category:Articles_with_excerpts",
        "title": "Category:Articles with excerpts"
      },
      {
        "text": "All accuracy disputes",
        "url": "https://en.wikipedia.org/wiki/Category:All_accuracy_disputes",
        "title": "Category:All accuracy disputes"
      },
      {
        "text": "Articles with disputed statements from July 2024",
        "url": "https://en.wikipedia.org/wiki/Category:Articles_with_disputed_statements_from_July_2024",
        "title": "Category:Articles with disputed statements from July 2024"
      },
      {
        "text": "Pages displaying short descriptions of redirect targets via Module:Annotated link",
        "url": "https://en.wikipedia.org/wiki/Category:Pages_displaying_short_descriptions_of_redirect_targets_via_Module:Annotated_link",
        "title": "Category:Pages displaying short descriptions of redirect targets via Module:Annotated link"
      },
      {
        "text": "CS1: long volume value",
        "url": "https://en.wikipedia.org/wiki/Category:CS1:_long_volume_value",
        "title": "Category:CS1: long volume value"
      },
      {
        "text": "Pages using Sister project links with hidden wikidata",
        "url": "https://en.wikipedia.org/wiki/Category:Pages_using_Sister_project_links_with_hidden_wikidata",
        "title": "Category:Pages using Sister project links with hidden wikidata"
      },
      {
        "text": "Articles with Internet Encyclopedia of Philosophy links",
        "url": "https://en.wikipedia.org/wiki/Category:Articles_with_Internet_Encyclopedia_of_Philosophy_links",
        "title": "Category:Articles with Internet Encyclopedia of Philosophy links"
      },
      {
        "text": "Creative Commons Attribution-ShareAlike 4.0 License",
        "url": "https://en.wikipedia.org/wiki/Wikipedia:Text_of_the_Creative_Commons_Attribution-ShareAlike_4.0_International_License",
        "title": "Wikipedia:Text of the Creative Commons Attribution-ShareAlike 4.0 International License"
      },
      {
        "text": "Terms of Use",
        "url": "https://foundation.wikimedia.org/wiki/Special:MyLanguage/Policy:Terms_of_Use",
        "title": "foundation:Special:MyLanguage/Policy:Terms of Use"
      },
      {
        "text": "Privacy Policy",
        "url": "https://foundation.wikimedia.org/wiki/Special:MyLanguage/Policy:Privacy_policy",
        "title": "foundation:Special:MyLanguage/Policy:Privacy policy"
      },
      {
        "text": "Wikimedia Foundation, Inc.",
        "url": "https://wikimediafoundation.org/"
      },
      {
        "text": "Privacy policy",
        "url": "https://foundation.wikimedia.org/wiki/Special:MyLanguage/Policy:Privacy_policy"
      },
      {
        "text": "About Wikipedia",
        "url": "https://en.wikipedia.org/wiki/Wikipedia:About"
      },
      {
        "text": "Disclaimers",
        "url": "https://en.wikipedia.org/wiki/Wikipedia:General_disclaimer"
      },
      {
        "text": "Contact Wikipedia",
        "url": "https://en.wikipedia.org/wiki/Wikipedia:Contact_us"
      },
      {
        "text": "Code of Conduct",
        "url": "https://foundation.wikimedia.org/wiki/Special:MyLanguage/Policy:Universal_Code_of_Conduct"
      },
      {
        "text": "Developers",
        "url": "https://developer.wikimedia.org"
      },
      {
        "text": "Statistics",
        "url": "https://stats.wikimedia.org/#/en.wikipedia.org"
      },
      {
        "text": "Cookie statement",
        "url": "https://foundation.wikimedia.org/wiki/Special:MyLanguage/Policy:Cookie_statement"
      },
      {
        "text": "Mobile view",
        "url": "https://en.m.wikipedia.org/w/index.php?title=Artificial_intelligence&mobileaction=toggle_view_mobile"
      },
      {
        "text": "Add topic",
        "url": "https://en.wikipedia.org/wiki/Artificial_intelligence"
      }
    ],
    "matches": [],
    "news": [],
    "content": [
      {
        "heading": "Artificial intelligence",
        "content": "166 languages\n\n\n\n\nAfrikaansAlemannischአማርኛالعربيةAragonésԱրեւմտահայերէնঅসমীয়াAsturianuAvañe'ẽAzərbaycancaتۆرکجهবাংলা閩南語 / Bân-lâm-gúБашҡортсаБеларускаяБеларуская (тарашкевіца)भोजपुरीBikol CentralБългарскиBoarischབོད་ཡིགBosanskiBrezhonegБуряадCatalàЧӑвашлаCebuanoČeštinaCymraegDanskالدارجةDeutschEestiΕλληνικάEspañolEsperantoEstremeñuEuskaraفارسیFiji HindiFrançaisFurlanGaeilgeGaelgGàidhligGalego贛語Gĩkũyũगोंयची कोंकणी / Gõychi Konknni한국어HausaՀայերենहिन्दीHrvatskiIdoIgboIlokanoBahasa IndonesiaInterlinguaInterlingueIsiZuluÍslenskaItalianoעבריתJawaಕನ್ನಡქართულიकॉशुर / کٲشُرҚазақшаKiswahiliKreyòl ayisyenKriyòl gwiyannenKurdîКыргызчаລາວLatinaLatviešuLëtzebuergeschLietuviųLigureLimburgsLa .lojban.LombardMagyarMadhurâМакедонскиMalagasyമലയാളംMaltiमराठीმარგალურიمصرىBahasa MelayuMinangkabauМонголမြန်မာဘာသာNederlandsNedersaksiesनेपालीनेपाल भाषा日本語NordfriiskNorsk bokmålNorsk nynorskOccitanଓଡ଼ିଆOʻzbekcha / ўзбекчаਪੰਜਾਬੀپنجابیپښتوPatoisភាសាខ្មែរPicardPiemontèisPlattdüütschPolskiPortuguêsQaraqalpaqshaQırımtatarcaReo tahitiRipoarischRomânăRuna SimiРусиньскыйРусскийСаха тылаScotsShqipසිංහලSimple EnglishسنڌيSlovenčinaSlovenščinaŚlůnskiکوردیСрпски / srpskiSrpskohrvatski / српскохрватскиSuomiSvenskaTagalogதமிழ்Татарча / tatarçaతెలుగుไทยТоҷикӣTürkçeTürkmençeУкраїнськаاردوئۇيغۇرچە / UyghurcheVènetoTiếng ViệtVõroWalonWinaray吴语ייִדיש粵語ZazakiŽemaitėška中文BetawiKadazandusunFɔ̀ngbèꠍꠤꠟꠐꠤⵜⴰⵎⴰⵣⵉⵖⵜ ⵜⴰⵏⴰⵡⴰⵢⵜ\n\nEdit links\n\n"
      }
    ]
  },
  "_metadata": {
    "source": "https://en.wikipedia.org/wiki/Artificial_intelligence",
    "source_type": "url",
    "extraction_params": {
      "model": "llama3-70b-8192"
    }
  }
}


```

## Quick Start

### Installation

```bash
pip install contextextract
```

### Usage

```python
from contextextract import ContextExtractor

# Initialize with your Groq API key
extractor = ContextExtractor(api_key=" ")

# Extract from URL
url_data = extractor.extract_from_url("https://en.wikipedia.org/wiki/Artificial_intelligence")

# Extract from PDF
pdf_data = extractor.extract_from_pdf("path/to/document.pdf")

# Extract from text
text_data = extractor.extract_from_text("Your text content here...")

# Save to JSON file
extractor.save_to_json(url_data, "output.json")
```

### Command Line Usage

```bash
# Set your API key as an environment variable
export GROQ_API_KEY=" "

# Extract from URL
contextextract url https://en.wikipedia.org/wiki/Artificial_intelligence -o ai_data.json

# Extract from PDF
contextextract pdf document.pdf -o pdf_data.json

# Extract from text file
contextextract text input.txt --is-file -o text_data.json

# Extract from direct text input
contextextract text "This is sample text to extract key information from."
```

## Features

- **URL Processing**: Extract key-value pairs from web content
- **PDF Processing**: Extract structured data from PDF documents
- **Text Processing**: Extract information from raw text input
- **Customization**: Configure extraction parameters
- **JSON Output**: Save results in structured JSON format
- **Command Line Interface**: Use from terminal without writing code

## Requirements

- Python 3.8+
- Groq API key 

## Advanced Usage

### Customizing Extraction

```python
# Custom extraction parameters
params = {
    "model": "llama3-70b-8192",  # Choose Groq model
    "system_message": "Extract technical terms and their definitions as key-value pairs."
}

# Use custom parameters
result = extractor.extract_from_url("https://en.wikipedia.org/wiki/Machine_learning", params)
```
## Development

### Local Development Setup

## 1. Set Up Your Project Environment

### Create Directory Structure

Open your terminal/command prompt and run:

```bash
# Create main project directory
mkdir -p contextextract/src/contextextract/processors contextextract/src/contextextract/utils contextextract/tests
cd contextextract
```

## 2. Create Package Files

Copy all the code files provided into their respective directories:

### Core Files
- `LICENSE` → Place in root directory
- `README.md` → Place in root directory
- `pyproject.toml` → Place in root directory
- `setup.py` → Place in root directory

### Package Files
- `src/contextextract/__init__.py`
- `src/contextextract/extractor.py`
- `src/contextextract/cli.py`
- `src/contextextract/processors/__init__.py`
- `src/contextextract/processors/url_processor.py`
- `src/contextextract/processors/pdf_processor.py`
- `src/contextextract/processors/text_processor.py`
- `src/contextextract/utils/__init__.py`
- `src/contextextract/utils/helpers.py`

### Test Files
- `tests/__init__.py`
- `tests/test_extractor.py`

## 3. Set Up Virtual Environment

```bash
# Create a virtual environment
python -m venv venv

# Activate it
# On Windows:
venv\Scripts\activate
# On macOS/Linux:
source venv/bin/activate
```

## 4. Install Required Dependencies

```bash
pip install requests beautifulsoup4 PyPDF2 tqdm groq
```

## 5. Install the Package in Development Mode

```bash
pip install -e .
```

## 6. Set Your Groq API Key

```bash
# On Windows:
set GROQ_API_KEY=gsk_Jv...

# On macOS/Linux:
export GROQ_API_KEY=gsk_Jv...
```

Replace `gsk_Jv...` with your actual Groq API key.

## 7. Run the Example Script

Create a file called `example_run.py` in the root directory with the following content:

```python
from contextextract import ContextExtractor
import os

# Get API key from environment variable
api_key = os.environ.get("GROQ_API_KEY")
if not api_key:
    print("Please set your GROQ_API_KEY environment variable")
    exit(1)

# Initialize the extractor
extractor = ContextExtractor(api_key=api_key)

# URL to extract information from
url = "https://en.wikipedia.org/wiki/Artificial_intelligence"
print(f"Extracting information from {url}...")

# Perform extraction
result = extractor.extract_from_url(url)

# Save to JSON file
output_file = "ai_data.json"
extractor.save_to_json(result, output_file)

print(f"Extraction complete! Data saved to {output_file}")
```

Run the example:

```bash
python example_run.py
```

## 8. Try the Command Line Interface

Once installed in development mode, you can also use the command line interface:

```bash
# Extract from URL
contextextract url https://en.wikipedia.org/wiki/Artificial_intelligence

# Extract from a text input
contextextract text "Artificial intelligence is the simulation of human intelligence by machines."
```

## Troubleshooting

1. **ImportError**: Make sure you've installed the package in development mode with `pip install -e .`

2. **API Key Issues**: Verify your Groq API key is correctly set and starts with "gsk_"

3. **Dependency Errors**: Ensure all required packages are installed:
   ```bash
   pip install requests beautifulsoup4 PyPDF2 tqdm groq
   ```
4. **Permission Issues**: Make sure you have appropriate permissions for creating files in the output directory
